define([
		"component/errorhandler/ErrorLevel"
	],
	function (
		ErrorLevel
	) {
		"use strict";

		/**
		 * This is used to log errors to the console for debugging
		 * @exports Debug
		 * @class
		 * @param {ErrorHandler}
		 */
		var Debug = function (errorHandler) {
			errorHandler.on("error", _.bind(this._handleError, this));
		};

		/**
		 * Handle an error event of the ErrorHandler
		 * @param {ErrorItem} errorItem - The error item as sent by ErrorHandler
		 */
		Debug.prototype._handleError = function (errorItem) {
			switch (errorItem.getLevel()) {
			case ErrorLevel.SEVERE:
				if (!window.console.error) {
					window.console.log(errorItem);
					return;
				}
				window.console.error(errorItem);
				break;
			case ErrorLevel.WARNING:
				if (!window.console.warn) {
					window.console.log(errorItem);
					return;
				}
				window.console.warn(errorItem);
				break;
			default:
				window.console.log(errorItem);
				return;

			}
		};

		return Debug;
	});