define([
		"component/message/MessageComponent",
		"component/errorhandler/ErrorLevel",
		"underscore"
	],
	function (
		MessageComponent,
		ErrorLevel,
		_) {
		"use strict";

		/**
		 * This component bootstraps the message module that will use the component messagewidget and messagemode
		 * @param {JQueryObj} context - The context object to install the messagewidget on
		 * @param {ErrorHandler} errorHandler
		 */
		var MessageController = function MessageController(context, errorHandler) {
			this._messageModel = new MessageComponent.MessageModel();
			this._messageWidget = new MessageComponent.MessageWidget(this._messageModel, context);

			errorHandler.on("error", _.bind(this._handleError, this));
		};

		/**
		 * Handle an error event of the ErrorHandler
		 * @param {ErrorItem} errorItem - The error item as sent by ErrorHandler
		 */
		MessageController.prototype._handleError = function (errorItem) {
			var message;
			switch (errorItem.getLevel()) {
			case ErrorLevel.SEVERE:
				message = new MessageComponent.Message(MessageComponent.MessageType.ERROR, errorItem.getMessage());
				break;
			case ErrorLevel.WARNING:
				message = new MessageComponent.Message(MessageComponent.MessageType.WARN, errorItem.getMessage());
				break;
			default:
				message = new MessageComponent.Message(MessageComponent.MessageType.INFO, errorItem.getMessage());
				break;
			}
			this._messageModel.addToMessageQueue(message);
		};

		/**
		 * Display a success message.
		 * @param {String} message
		 */
		MessageController.prototype.sendSuccessMessage = function (message) {
			var message = new MessageComponent.Message(MessageComponent.MessageType.SUCCESS, message, null, true);
			this._messageModel.addToMessageQueue(message);
		};

		return MessageController;
	});