define(["WFEditor/workflow/helper/LifelineHelper"], function (LifelineHelper) {
	"use strict";

	/**
	 * LifelineHelper for NodeConfiguration Popup
	 * This lifeline is smart as it doesn't need to have its endpoint being set to render correctly
	 * @exports NodeConfigurationLifelineHelper
	 * @augments LifelineHelper
	 * 
	 * @param {Workflow}               workflow - workflow model
	 * @param {String}                 id       - id of the lifeline
	 * @param {Scene}                  scene    - Scene 
	 * @param {NodeConfigurationPopup} popup    - popup for which the lifeline is shown
	 */
	var NodeConfigurationLifelineHelper = function (workflow, id, scene, popup) {
		LifelineHelper.call(this, workflow, id);
		this._scene = scene;
		this._popup = popup;
	};

	NodeConfigurationLifelineHelper.prototype = Object.create(LifelineHelper.prototype);
	NodeConfigurationLifelineHelper.prototype.constructor = NodeConfigurationLifelineHelper;


	/**
	 * Notify that the endpoint of the lifeline has changed
	 */
	NodeConfigurationLifelineHelper.prototype.setEndPointModified = function () {
		this._emit("changed.endPoint");
	};

	/**
	 * Get the end point of the lifeline
	 * @override
	 * @returns {ShapeUtils.Point} world coordinates of the endpoint of the lifeline
	 */
	NodeConfigurationLifelineHelper.prototype.getEndPoint = function () {
		var transformed = this._scene.convertScenePointToWorld(this._popup.getCenter());
		return transformed;
	};

	return NodeConfigurationLifelineHelper;
});