define([
	],
	function (
	) {
		"use strict";

		/**
		 * GalleryNode represents the model for a node in the NodeGallery.
		 * 
		 * @exports GalleryNode
		 * @class
		 * 
		 * @param {String} name     - the name of the node
		 * @param {String} iconUrl  - path to the icon
		 * @param {String} category - category to which the node belongs
		 */
		var GalleryNode = function (name, iconUrl, category) {

            /**
			 *  @member {String}
			 *  @private
			 */
            this._iconUrl = iconUrl;
            
			/**
			 *  @member {String}
			 *  @private
			 */
			this._category = category;
            
            /**
			 *  @member {String}
			 *  @private
			 */
            this._name = name;
			
			/**
			 * @member {Object}  these options can be used for construction of nodes in the factory
			 * @private
			 */
			this._options = {};


		};
        
        /**
         * Get the full url to the icon of the GalleryNode. 
         * @returns {String} iconUrl
         */
        GalleryNode.prototype.getIconUrl = function () {
            return this._iconUrl;
        };
    
        /**
         * Get the category to which the GalleryNode belongs.
         * @returns {String} category
         */
        GalleryNode.prototype.getCategory = function () {
            return this._category;
        };
    
        /**
         * Get the label that should be shown for the node in the gallery. This is the name if there is one specified, else it's the nodeType.
         * @returns {String}
         */
        GalleryNode.prototype.getLabel = function () {
            return this._name;
        };
	
		/**
		 * sets options, these options can be used for construction of nodes in the factory
		 * @param {Object} options
		 */
		GalleryNode.prototype.setOptions = function (options) {
			this._options = options;
		};
	
		/**
		 * gets the construction options
		 * @returns {Object}
		 */
		GalleryNode.prototype.getOptions = function () {
			return this._options;
		};
        
		return GalleryNode;
	});