define(["underscore",
		"jquery",
		"WFEditor/contextMenu/ContextMenu",
		"WFEditor/tools/AbstractTool",
		"WFEditor/tools/ToolConstants",
		"utils/Observer"
	],
	function (_,
		$,
		ContextMenu,
		AbstractTool,
		ToolConstants,
		Observer) {

		"use strict";

		/**
		 * @class
		 * @exports ContextMenuTool
		 * @augments AbstractTool
		 * @mixes Observer
		 * @param {MouseInteractionTool} mouseInteractionEvents 
		 * @param {WFEditorContext} WFEditorContext 
		 */
		var ContextMenuTool = function (mouseInteractionEvents, WFEditorContext) {
			AbstractTool.call(this, WFEditorContext.get("scene").getContext(), ToolConstants.Tools.CONTEXTMENUTOOL, WFEditorContext);
			Observer.mixin(this);

			this._observe(mouseInteractionEvents, "mousedown", this._checkForContextMenuClick);
			
			/**
			 * @member {ContextMenuModel}
			 * @private
			 */
			this._contextMenuModel = WFEditorContext.get("contextMenuModel");
			
			/**
			 * @member {ContextMenu}
			 * @private
			 */
			this._contextMenu = new ContextMenu(this._contextMenuModel, WFEditorContext.get("scene"));

			/**
			 * @member {Scene}
			 * @private
			 */
			this._scene = WFEditorContext.get("scene");
		};

		ContextMenuTool.prototype = Object.create(AbstractTool.prototype);
		ContextMenuTool.prototype.constructor = ContextMenuTool;

		/**
		 * check if the menu should be shown
		 * @param {Object} options 
		 */
		ContextMenuTool.prototype._checkForContextMenuClick = function (options) {

			if(options.e.button === 2) {
				// Right click
				this._contextMenuModel.setContextMenuWorldLocation(this._scene.getWorldPointFromScenePoint(this._getMousePosition(options.e)));
				this._contextMenuModel.setContextMenuSceneLocation(this._getMousePosition(options.e));
				this._contextMenuModel.setHitArea(options.hitArea);
				this._contextMenu.show();
			} else {
				this._contextMenu.hide();
			}


		};

		return ContextMenuTool;
	});
