define([
		"WFEditor/workflow/node/Node",
		"WFEditor/tools/drawEdge/MousePin"
	],
	function (
		Node,
		MousePin
	) {
		"use strict";

		/**
		 * A mouse node is a node representing a mouse location. It has one pin which is a mouse pin.
		 * There can only be one mouse node (the id is always the same)
		 * @exports MouseNode
		 * @class
		 * @augments Node
		 *
		 * @param {Wofkflow} workflow - the workflow to which the node belongs
		 */
		var MouseNode = function (workflow) {
			Node.call(this, workflow, MouseNode.ID);

			this.addPin(new MousePin(this.getWorkflow(), this, this.getId() + "MousePin"));
		};

		MouseNode.prototype = Object.create(Node.prototype);
		MouseNode.prototype.constructor = MouseNode;

		MouseNode.ID = "MouseNode";

		/**
		 * Get the mouse (input) pin of this node
		 * @returns {MousePin}
		 */
		MouseNode.prototype.getMousePin = function () {
			return this.getPinById(this.getId() + "MousePin");
		}

		return MouseNode;
	});