define([
		"WFEditor/workflow/node/NodeView",
		"utils/ShapeUtils"
	],
	function (
		NodeView,
		ShapeUtils
	) {
		"use strict";

		/**
		 * The view for a mouse node.
		 * This is an invisible node used while drawing/adding an edge.
		 *
		 * @exports MouseNodeView
		 * @class
		 * @augments NodeView
		 *
		 * @param {Node} nodeModel - The node model
		 */
		var MouseNodeView = function (nodeModel) {
			NodeView.call(this, nodeModel);

			this._observe(nodeModel, "changed.location", this._updateBoundingRect);
		};

		MouseNodeView.prototype = Object.create(NodeView.prototype);
		MouseNodeView.prototype.constructor = MouseNodeView;


		/**
		 * @override
		 */
		MouseNodeView.prototype.render = function (context, layer, quickRender) {
			/* Debug Mouse Node rendering * 
			context.save();
			var pos = this._model.getLocation();
			context.fillStyle = "red";
			context.fillRect(pos.x, pos.y, 10, 10);
			context.restore();
			/**/
			// do not render
			return;
		};

		/**
		 * @override
		 */
		MouseNodeView.prototype._updateBoundingRect = function () {
			var location = this._model.getLocation();
			this._setBoundingRect([location.x, location.y, location.x, location.y]);
		};

		return MouseNodeView;

	});