define([
		"WFEditor/workflow/pin/PinView",
		"utils/ShapeUtils"
	],
	function (
		PinView,
		ShapeUtils
	) {
		"use strict";

		/**
		 * The view for a mouse pin item
		 *
		 * @exports MousePinView
		 * @class
		 * @augments PinView
		 *
		 * @param {Pin} pinModel - model for the pin
		 * @param {MouseNodeView} nodeView - view for the node to which the pin belongs
		 * @param {Scene} scene
		 */
		var MousePinView = function (pinModel, nodeView, scene) {
			PinView.call(this, pinModel, nodeView);

			this._scene = scene;

			this._observe(this._model.getNode(), "changed.location", this._locationChanged);
		};

		MousePinView.prototype = Object.create(PinView.prototype);
		MousePinView.prototype.constructor = MousePinView;

		/**
		 * The location was changed of the pin view
		 * update hit areas, bounding rect and make the view dirty
		 */
		MousePinView.prototype._locationChanged = function () {
			this._updateBoundingRect();
			this._updateHitAreas();
			this.makeDirty();
		};

		/**
		 * @override
		 */
		MousePinView.prototype.render = function (context, layer, quickRender) {
			/* Debug mouse pin rendering *
			context.save();
			var pos = this._model.getNode().getLocation();
			context.fillStyle = "blue";
			context.fillRect(pos.x, pos.y, 5, 5);
			context.restore();
			/**/

			// do not render
			return;
		};

		/**
		 * @override
		 */
		MousePinView.prototype._updateBoundingRect = function () {
			var location = this._nodeView.getLocationForPin();

			this._setBoundingRect([location.x, location.y, location.x, location.y]);
		};

		return MousePinView;

	});