define(["WFEditor/workflow/helper/Helper",
		"WFEditor/workflow/ModelConstants",
		"underscore"
	],
	function (Helper,
		ModelConstants,
		underscore) {

		"use strict";

		/**
		 * A Selection Helper is used to indicate a selection in the workflow
		 * @exports SelectionHelper
		 * @class
		 * @augments Helper
		 * @param {Workflow} workflow for which the helper is used
		 * @parma {String} unique id for the SelectionHelper
		 */
		var SelectionHelper = function (workflow, id) {
			Helper.call(this, workflow, id);

			/**
			 * @member {Boolean} is the user selecting
			 * @private
			 */
			this._isSelecting = false;

			/**
			 * @member {ShapeUtils.Rect} current selection (in world coordinates)
			 * @private
			 */
			this._selectionRect = null;
		};

		SelectionHelper.prototype = Object.create(Helper.prototype);
		SelectionHelper.prototype.constructor = SelectionHelper;


		/**
		 * Is the selection active?
		 * @returns {Boolean}
		 */
		SelectionHelper.prototype.isSelecting = function () {
			return this._isSelecting;
		};

		/**
		 * activate/deactivate the selection
		 * @param {Boolean} isSelecting
		 */
		SelectionHelper.prototype.setIsSelecting = function (isSelecting) {
			if (this._isSelecting !== isSelecting) {

				this._isSelecting = isSelecting;

				this._emit("changed.isSelecting", isSelecting);
			}
		};
		/**
		 * Get the current selection rectangle
		 * @returns {ShapeUtils.Rect} World Coordinates
		 */
		SelectionHelper.prototype.getSelectionRect = function () {
			return this._selectionRect;
		};

		/**
		 * Set the ucrrent selection rectangle
		 * @param {ShapeUtils.Rect} rect - World Coordinates
		 */
		SelectionHelper.prototype.setSelectionRect = function (rect) {
			if (this._selectionRect === null || !this._selectionRect.rectEquals(rect)) {
				this._selectionRect = rect;
				this._emit("changed.selectionRect", rect);
			}
		};

		return SelectionHelper;

	});