define([
		"utils/Cache",
		"underscore"
	],
	function (
		Cache,
		_
	) {
		"use strict";

		/**
		 * Singleton instance for the IconDataStorage.
		 */
		var iconDataStorageInstance = null;


		/**
		 * IconDataStorage is a datastorage for loading icons/images and storing for re-use
		 * by using a Cache. The IconDataStorage can be used as singleton or by creating a new instance.
		 *
		 * @exports IconDataStorage
		 * @class
		 * @augments Cache
		 */
		var IconDataStorage = function () {
			Cache.call(this, 100, false);

			this._loadItem = function (urlToIcon) {
				var img = new Image();
				img.onload = _.bind(function () {
					this._registerItem(urlToIcon, img);
				}, this);
				img.src = urlToIcon;
			};
		};

		IconDataStorage.prototype = Object.create(Cache.prototype);
		IconDataStorage.prototype.constructor = IconDataStorage;

		return {
			getInstance: function () {
				if (iconDataStorageInstance !== null) {
					return iconDataStorageInstance;
				} else {
					iconDataStorageInstance = new IconDataStorage();
					return iconDataStorageInstance;
				}

			},
			createInstance: function () {
				return new IconDataStorage();
			}
		};

	});