define([
		"WFEditor/workflow/WorkflowItem",
		"WFEditor/workflow/ModelConstants"
	],
	function (
		WorkflowItem,
		ModelConstants
	) {
		"use strict";

		/**
		 * Edge represents the model for an edge in the workflow. An edge connects two
		 * pins.
		 *
		 * @exports Edge
		 * @class
		 * @augments WorkflowItem
		 *
		 * @param {Workflow} workflow
		 * @param {String} id - edge id
		 * @param {Pin} from
		 * @param {Pin} to
		 */
		var Edge = function (workflow, id, from, to) {
			WorkflowItem.call(this, workflow, ModelConstants.WorkflowItemType.Edge, id);

			/**
			 *  @member {Pin}
			 *  @private
			 */
			this._from = from;

			/**
			 *  @member {Pin}
			 *  @private
			 */
			this._to = to;

		};

		Edge.prototype = Object.create(WorkflowItem.prototype);
		Edge.prototype.constructor = Edge;

		/**
		 * Return the Pin where the edge starts.
		 * @returns {Pin}
		 */
		Edge.prototype.getFromPin = function () {
			return this._from;
		};

		/**
		 * Return the Pin where the edge stops.
		 * @returns {Pin}
		 */
		Edge.prototype.getToPin = function () {
			return this._to;
		};

		return Edge;
	});