define([
		"WFEditor/scene/AbstractView"
	],
	function (
		AbstractView
	) {
		"use strict";

		/**
		 * EdgeView is a view object for rendering edges on a canvas. For specific edges,
		 * the render methods needs to be implemented.
		 *
		 * @exports EdgeView
		 * @class
		 * @augments AbstractView
		 *
		 * @param {Edge} edgeModel
		 * @param {PinView} fromPinView - view of the pin where the edge starts
		 * @param {PinView} toPinView - view of the pin where the edge stops
		 */
		var EdgeView = function (edgeModel, fromPinView, toPinView) {
			AbstractView.call(this, edgeModel);

			/**
			 * @member {PinView}
			 * @private
			 */
			this._fromPinView = fromPinView;

			/**
			 * @member {PinView}
			 * @private
			 */
			this._toPinView = toPinView;
		};

		EdgeView.prototype = Object.create(AbstractView.prototype);
		EdgeView.prototype.constructor = EdgeView;

		/**
		 * Eges are drawn at z-index 10 by default
		 * @Override
		 */
		EdgeView.prototype.getZIndex = function () {
			return 10;
		};

		/**
		 * Get the pin view of the pin where the edge is coming from
		 * @returns {PinView}
		 */
		EdgeView.prototype.getFromPinView = function () {
			return this._fromPinView;
		};

		/**
		 * Get the pin view of the pin where the edge is going to
		 * @returns {PinView}
		 */
		EdgeView.prototype.getToPinView = function () {
			return this._toPinView;
		};

		return EdgeView;

	});