define(["WFEditor/workflow/helper/Helper",
		"underscore"
	],
	function (Helper,
		underscore) {

		"use strict";

		/**
		 * A Popuplifeline Helper is used to draw a lifeline between two points
		 * @exports LifelineHelper
		 * @class
		 * @augments Helper
		 * @param {Workflow} workflow for which the helper is used
		 * @parma {String} unique id for the LifelineHelper
		 */
		var LifelineHelper = function (workflow, id) {
			Helper.call(this, workflow, id);

			/**
			 * @member {ShapeUtils.Point} start point (world coordinates)
			 * @private
			 */
			this._startPoint = null;

			/**
			 * @member {ShapeUtils.Point} end point (world coordinates)
			 * @private
			 */
			this._endPoint = null;
		};

		LifelineHelper.prototype = Object.create(Helper.prototype);
		LifelineHelper.prototype.constructor = LifelineHelper;

		/**
		 * Get the start point of the lifeline
		 * @returns {ShapeUtil.Point} world coordinates, null if not set	
		 */
		LifelineHelper.prototype.getStartPoint = function () {
			return this._startPoint;
		};

		/**
		 * Get the end point of the lifeline
		 * @returns {ShapeUtils.Poin} world coordinates, null if not set
		 */
		LifelineHelper.prototype.getEndPoint = function () {
			return this._endPoint;
		};

		/**
		 * Set the start point of the lifeline
		 * @param {ShapeUtils.Point} point - world coordinates
		 */
		LifelineHelper.prototype.setStartPoint = function (point) {
			if (!this._startPoint || !this._startPoint.equals(point)) {
				this._startPoint = point;
				this._emit("changed.startPoint", point);
			}
		};

		/**
		 * Set the end point of the lifeline
		 * @param {ShapeUtils.Point} point - world coordinates
		 */
		LifelineHelper.prototype.setEndPoint = function (point) {
			if (!this._endPoint || !this._endPoint.equals(point)) {
				this._endPoint = point;
				this._emit("changed.endPoint", point);
			}
		};


		return LifelineHelper;
	});