define(["WFEditor/scene/AbstractView"
	],
	function (AbstractView) {
		"use strict";

		/**
		 * A view for a LifelineHelper
		 * @exports LifelineHelperView
		 * @class
		 * @augments {AbstractView}
		 *
		 * @param {SelectionHelper} model
		 */
		var LifelineHelperView = function (model) {
			AbstractView.call(this, model);

			this._observe(model, "changed.*", function () {
				this._updateBoundingRect();
				this.makeDirty();
			});

		};

		LifelineHelperView.prototype = Object.create(AbstractView.prototype);
		LifelineHelperView.prototype.constructor = LifelineHelperView;

		/**
		 * Renders the view on canvas context.
		 * @Override
		 * @param {CanvasRenderingContext2D} context
		 * @param {Layer} layer
		 * @param {Boolean} quickRender - if true, only high priority render actions should be executed (i.e. during panning)
		 */
		LifelineHelperView.prototype.render = function (ctx, layer, quickRender) {
			var start = this._model.getStartPoint();
			var end = this._model.getEndPoint();

			if (start && end) {
				ctx.save();
				ctx.beginPath();
				ctx.strokeStyle = "#ccc";
				ctx.moveTo(start.x, start.y);
				ctx.lineTo(end.x, end.y);
				ctx.stroke();

				ctx.restore();

				this._updateBoundingRect();
			}
		};

		/**
		 * @Override
		 */
		LifelineHelperView.prototype.getZIndex = function () {
			return 15;
		};

		/**
		 * @Override
		 */
		LifelineHelperView.prototype._updateBoundingRect = function () {
			var start = this._model.getStartPoint();
			var end = this._model.getEndPoint();

			if (start && end) {
				this._setBoundingRect([Math.min(start.x, end.x),
									   Math.min(start.y, end.y),
									   Math.max(start.x, end.x),
									   Math.max(start.y, end.y)]);
			} else {
				this._setBoundingRect(null);
			}

		};

		return LifelineHelperView;
	});