define([
		"WFEditor/scene/AbstractView"
	],
	function (
		AbstractView
	) {
		"use strict";

		/**
		 * NodeView is a view object for rendering nodes on a canvas. For specific nodes,
		 * the render methods needs to be implemented.
		 *
		 * @exports NodeView
		 * @class
		 * @augments AbstractView
		 *
		 * @param {Node} nodeModel
		 */
		var NodeView = function (nodeModel) {
			AbstractView.call(this, nodeModel);
		};

		NodeView.prototype = Object.create(AbstractView.prototype);
		NodeView.prototype.constructor = NodeView;

		/**
		 * Nodes are drawn at z-index 40 by default
		 * @Override
		 */
		NodeView.prototype.getZIndex = function () {
			return 40;
		};

		/**
		 * Get the center of the node view
		 * @returns {ShapeUtils.Point} world coordinates
		 */
		NodeView.prototype.getCenter = function () {
			return this._model.getLocation().copy();
		};

		/**
		 * Get the location for the given pin
		 * @param {Pin} pin The pin to get the location for
		 */
		NodeView.prototype.getLocationForPin = function (pin) {
			return this._model.getLocation().copy();
		};

		return NodeView;

	});