define([
		"WFEditor/scene/AbstractView"
	],
	function (
		AbstractView
	) {
		"use strict";

		/**
		 * PinView is a view object for rendering a view on a canvas. For specific pins,
		 * the render methods needs to be implemented.
		 *
		 * @exports PinView
		 * @class
		 * @augments AbstractView
		 *
		 * @param {Pin} pinModel
		 * @param {NodeView} nodeView
		 */
		var PinView = function (pinModel, nodeView) {
			AbstractView.call(this, pinModel);

			/**
			 * @member {NodeView} Node view this pin belongs to
			 */
			this._nodeView = nodeView;
		};

		PinView.prototype = Object.create(AbstractView.prototype);
		PinView.prototype.constructor = PinView;


		/**
		 * Pin are drawn at z-index 30 by default
		 * @Override
		 */
		PinView.prototype.getZIndex = function () {
			return 30;
		};

		/**
		 * Get the location of the pin.
		 * @returns {ShapeUtils.Point}
		 */
		PinView.prototype.getLocation = function () {
			return this._nodeView.getLocationForPin(this._model);
		};

		/**
		 * Get the location of the edge that is arriving in the pin
		 * @param   {String} pinId
		 * @param   {EdgeView} edge
		 * @returns {ShapeUtils.Point}
		 */
		PinView.prototype.getEdgeLocation = function (pinId, edge) {
			return this.getLocation();
			//implement is specific pin view to overwrite basic implementation
		};

		/**
		 * Get the view objec tof the node this pin is part of.
		 * @returns {NodeView}
		 */
		PinView.prototype.getNodeView = function () {
			return this._nodeView;
		};

		/**
		 * Returns the view of the first edge of the pin
		 */
		PinView.prototype.getFirstEdge = function () {
			//to be implemented by the specific view
		};

		return PinView;

	});