define(["component/modal/Modal",
		"component/button/Button",
		"utils/webi18n!WFEditorWCR",
		"underscore",
		"jquery",

	],
	function (
		Modal,
		Button,
		i18n,
		_,
		$) {

		"use strict";

		/**
		 * Popup used to export a workflow
		 * @exports ExportWorkflowPopup
		 * @class
		 */
		var ExportWorkflowPopup = function (wfEditorWCR) {
			this._wfEditorWCR = wfEditorWCR;

			// Popup content
			this._content = $("<div>").text(i18n.t("workflowExportSaveFirst"));
			this._exportWarningPopup = new Modal(this._content);
			this._exportWarningPopup.setTitle(i18n.t("workflowExportTooltip"));
			this._exportWarningPopup.onClose(_.bind(function () {
				this.destroy()
			}, this._exportWarningPopup));

			this._cancelButton = new Button(null, null, false, "Cancel", i18n.t("configurationCancel"), true, _.bind(function () {
				this._exportWarningPopup.close();
			}, this));
			this._cancelButton.addClass("btn btn-default btn-md");

			this._exportWithSaveButton = new Button(null, null, false, "OK", i18n.t("configurationOK"), true, _.partial(function (popup) {
				this.setEnabled(false);
				// Wait until save is done
				var savePromise = wfEditorWCR.doSaveCurrentWorkflow();
				savePromise.done(_.bind(function () {
					popup._wfEditorWCR.doExportWorkflow();
					this.setEnabled(true);
				}, this)).always(function () {
					// errors are already shown
					popup._exportWarningPopup.close();
				});
			}, this));
			this._exportWithSaveButton.addClass("btn btn-primary btn-md");

			this._buttonGroup = $("<div>").addClass("btn-group pull-right");
			this._buttonGroup.append(this._cancelButton.element).append(this._exportWithSaveButton.element);
			this._exportWarningPopup.setFooter(this._buttonGroup);
		};

		/**
		 * Open the popup
		 */
		ExportWorkflowPopup.prototype.open = function () {
			this._exportWarningPopup.open();
		};

		return ExportWorkflowPopup;
	});