define(["component/modal/Modal",
		"component/button/Button",
		"utils/webi18n!WFEditorWCR",
		"underscore",
		"jquery",

	],
	function (
		Modal,
		Button,
		i18n,
		_,
		$) {

		"use strict";

		/**
		 * Popup used to confirm resetting a workflow to a manual task
		 * @exports ResetToManualPopup
		 * @class
		 */
		var ResetToManualPopup = function (wfEditorWCR) {
			this._wfEditorWCR = wfEditorWCR;

			// Popup content
			this._content = $("<div />").text(i18n.t("workflowResetToManualConfirm"));
			this._confirmPopup = new Modal(this._content);
			this._confirmPopup.setTitle(i18n.t("workflowResetToManualTooltip"));

			this._confirmPopup.onClose(_.bind(function () {
				this.destroy();
			}, this._confirmPopup));

			this._yesButton = new Button(null, null, false, "Yes", i18n.t("yes"), true, _.partial(function (popup) {
				this.setEnabled(false);
				$.when(popup._wfEditorWCR.doResetToManualTask()).always(function () {
					// errors already logged
					popup._confirmPopup.close();
				});
			}, this));
			this._yesButton.addClass("btn btn-default btn-md");

			this._noButton = new Button(null, null, false, "No", i18n.t("no"), true, _.partial(function (popup) {
				popup._wfEditorWCR.doSaveCurrentWorkflow();
				popup._confirmPopup.close();
			}, this));
			this._noButton.addClass("btn btn-primary btn-md");

			this._buttonGroup = $("<div>").addClass("btn-group pull-right");
			this._buttonGroup.append(this._yesButton.element).append(this._noButton.element);
			this._confirmPopup.setFooter(this._buttonGroup);
		};

		/**
		 * Open the popup
		 */
		ResetToManualPopup.prototype.open = function () {
			this._confirmPopup.open();
			this._yesButton.setEnabled(true);
		};

		return ResetToManualPopup;
	});