define([],
	function () {
		"use strict";

		/**
		 * Represents a custom smartname
		 * @param {String}  smartName       - The smartname key
		 * @param {String}  category        - The smartname category
		 */
		var CustomSmartName = function (smartName, category) {
			this._smartName = smartName;
			this._category = category;
		};

		/**
		 * Get the smartname key
		 * @returns {String}
		 */
		CustomSmartName.prototype.getSmartName = function () {
			return this._smartName;
		};

		/**
		 * Get the category it belongs to
		 * @returns {String}
		 */
		CustomSmartName.prototype.getCategory = function () {
			return this._category;
		};

		/**
		 * Create CustomSmartName from xml
		 * @param   {String} xml
		 * @returns {CustomSmartName}
		 */
		CustomSmartName.fromXML = function (xml) {
			var name, category;
			_.each(xml.childNodes, function (child) {
				if (child.tagName === "name") {
					name = child.textContent;
				} else if (child.tagName === "category") {
					category = child.textContent;
				}
			}, this);
			return new CustomSmartName(name, category);
		};

		return CustomSmartName;
	});