define([
		"utils/Cache",
		"utils/XMLUtils",
		"underscore"
	],
	function (
		Cache,
		XMLUtils,
		_
	) {
		"use strict";

		/** 
		 * This singleton is used to cache document version view info.
		 * You get an Object back: {supported: true if document type is supported, viewable: true if and only if the document is viewable}
		 * @exports DocVersionViewableCache
		 * @class
		 * @augments Cache
		 * @param {WebCenterAPI} webCenterAPI    
		 * @param {ErrorHandler} errorHandler
		 */
		var DocVersionViewableCache = function (webCenterAPI, errorHandler) {
			Cache.call(this, 100, true);

			this._webCenterAPI = webCenterAPI;
			this._errorHandler = errorHandler;
		};

		DocVersionViewableCache.prototype = Object.create(Cache.prototype);
		DocVersionViewableCache.prototype.constructor = DocVersionViewableCache;

		/**
		 * @Override
		 */
		DocVersionViewableCache.prototype._loadItem = function (docVersionID) {

			var urlToCheckViewStatus = this._webCenterAPI.constructURL("GetDocViewableStatus.jsp", {
				docversionid: docVersionID
			});

			var viewStatusPromise = $.ajax(urlToCheckViewStatus, {
				dataType: "xml",
				cache: false
			}).fail(_.bind(function (jqXHR, textStatus, errorThrown) {
				this._errorHandler.severe("Failed to check " + urlToCheckViewStatus, jqXHR, textStatus, errorThrown);
			}, this));

			$.when(viewStatusPromise).done(_.bind(function (viewStatusXML) {
				var viewableObj = {
					supported: true,
					viewable: false
				};
				var viewStatus = XMLUtils.xml2obj(viewStatusXML);
				if (viewStatus.result !== undefined) {
					if (viewStatus.result.doc_supported !== undefined) {
						if (viewStatus.result.doc_supported == "0") { // == intentional
							viewableObj.supported = false;
							viewableObj.viewable = false; // never viewable
						} else {
							viewableObj.supported = true;
							if (viewStatus.result.doc_ready_to_view == "1") { // == intentional
								viewableObj.viewable = true; // ready to view
							} else {
								if (viewStatus.result.data_generation_in_progress == "0") { // == intentional
									viewableObj.viewable = false; // view file generation failed
								} else {
									viewableObj = undefined; // generation still in progress, so next time ask again
								}
							}
						}
					}
				}
				this._registerItem(docVersionID, viewableObj);
			}, this));
		};

		return DocVersionViewableCache;
	});