define(["utils/XMLUtils"], function (XMLUtils) {
	"use strict";

	/**
	 * Data structure for representing WebCenterProject Status
	 * @exports WebCenterProjectStatus
	 * @class
	 * @param {String} id           - id of the Project Status
	 * @param {String} name         - name of the status
	 * @param {Number} displayOrder - display Order
	 * @param {String} locKey       - language key (if defined)
	 */
	var WebCenterProjectStatus = function (id, name, displayOrder, locKey) {
		this._id = id;
		this._name = name;
		this._displayOrder = displayOrder;
		this._locKey = locKey;
	};

	/**
	 * Get the ID of the project status
	 * @returns {String} 
	 */
	WebCenterProjectStatus.prototype.getId = function () {
		return this._id;
	};

	/**
	 * Get the name of the project status
	 * @returns {String} 
	 */
	WebCenterProjectStatus.prototype.getName = function () {
		return this._name;
	};

	/**
	 * Get the display order of the project status
	 * @returns {Number} 
	 */
	WebCenterProjectStatus.prototype.getDisplayOrder = function () {
		return this._displayOrder;
	};

	/**
	 * Initialize a new PRojectStatus from an XML element <ProjectStatus><id/><StatusName/><DisplayOrder/><locKey/></ProjectStatus>
	 * @param   {XMLNode}                xml - xml description of the project status
	 * @returns {WebCenterProjectStatus} 
	 */

	WebCenterProjectStatus.fromXML = function (xml) {
		var obj = XMLUtils.xml2obj(xml);

		return new WebCenterProjectStatus(obj.ID, obj.StatusName, parseInt(obj.DisplayOrder, 10), obj.LocKey);
	};

	return WebCenterProjectStatus;

});