define(["utils/XMLUtils"], function (XMLUtils) {
	"use strict";

	/**
	 * Data structure for describing a WebCenter Task Status 
	 * @class
	 * @exports WebCenterTaskStatus
	 * @param {String} statusViewID - ID of the task status viewe
	 * @param {String} statusID     - ID of the task status
	 * @param {String} taskTypeID   - ID of the task type
	 * @param {String} name         - Name of the Status
	 * @param {String} iconName     - icon of the status
	 * @param {Number} displayOrder - display Order of the status
	 * @param {String} type         - type
	 */
	var WebCenterTaskStatus = function (statusViewID, statusID, taskTypeID, name, iconName, displayOrder, type) {
		this._statusViewID = statusViewID;
		this._statusID = statusID;
		this._taskTypeID = taskTypeID;
		this._name = name;
		this._iconName = iconName;
		this._displayOrder = displayOrder;
		this._type = type;
	};

	/**
	 * Get the ID
	 * @returns {String}
	 */
	WebCenterTaskStatus.prototype.getId = function () {
		return this._statusID;
	};

	/**
	 * Get the Name
	 * @returns {String} 
	 */
	WebCenterTaskStatus.prototype.getName = function () {
		return this._name;
	};

	/**
	 * Get the display order 
	 * @returns {Number} 
	 */
	WebCenterTaskStatus.prototype.getDisplayOrder = function () {
		return this._displayOrder;
	};

	/**
	 * Create a new WebCenterTaskStatus based on a XML description of the status
	 * @param   {XMLDocument}         xml - xml description of the task status
	 *                                    @returns {WebCenterTaskStatus} 
	 */
	WebCenterTaskStatus.fromXML = function (xml) {
		var obj = XMLUtils.xml2obj(xml);

		var statusViewID = obj.attributes.id;
		var statusID = obj.wc_status.attributes.id;
		var taskTypeID = obj.wctask_type.id;
		var name = obj.wc_status.status_name;
		var iconName = obj.wc_status.icon_name;
		var displayOrder = parseInt(obj.wc_status.display_order, 10);
		var type = obj.wc_status.status_type;

		return new WebCenterTaskStatus(statusViewID, statusID, taskTypeID, name, iconName, displayOrder, type);
	};

	return WebCenterTaskStatus;

});