define(["utils/XMLUtils"], function (XMLUtils) {
	"use strict";

	/**
	 * Datastructure for representing a WebCenter Workflow Connection
	 * @class
	 * @exports WebCenterWorkflowConnection
	 * @param {String} id   
	 * @param {String} name 
	 * @param {String} UNC  - UNC Path
	 */
	var WebCenterWorkflowConnection = function (id, name, UNC) {
		this._id = id;
		this._name = name;
		this._UNC = UNC;
	};

	/**
	 * Get the ID
	 * @returns {String} 
	 */
	WebCenterWorkflowConnection.prototype.getId = function () {
		return this._id;
	};

	/**
	 * Get the name
	 * @returns {String} 
	 */
	WebCenterWorkflowConnection.prototype.getName = function () {
		return this._name;
	};

	/**
	 * Get the UNC Path of the connection
	 * @returns {String} 
	 */
	WebCenterWorkflowConnection.prototype.getUNC = function () {
		return this._UNC;
	};

	/**
	 * is this a JMF Connection? 
	 * A WorkflowConnection is a JMF connection if its UNC starts with HTTP or HTTPS
	 * @returns {Boolean}
	 */
	WebCenterWorkflowConnection.prototype.isJMF = function () {
		var unc = (this.getUNC() || "").toLowerCase();
		return unc.indexOf("http://") === 0 || unc.indexOf("https://") === 0;
	};

	/**
	 * Construct a new WebCenterWorkflowConnection from XML Description
	 * @param   {XMLNode}                  xml - XML description of the connection
	 * @returns {WebCenterWorkflowConnection} 
	 */
	WebCenterWorkflowConnection.fromXML = function (xml) {
		var obj = XMLUtils.xml2obj(xml);

		return new WebCenterWorkflowConnection(obj.ID, obj.Name, obj.UNC);
	};

	return WebCenterWorkflowConnection;
});