define([
		"WFEditor/scene/Scene",
		"utils/ShapeUtils",
		"WFEditorWCR/core/WebCenterWFEditorConstants"
	],
	function (
		Scene,
		ShapeUtils,
		WebCenterWFEditorConstants
	) {
		"use strict";

		/**
		 * The WebCenter Scene is responsible for the layers and registers listeners on the model.
		 * It uses the viewFactory to create the correct view components and adds these to
		 * the correct layer. Specific webcenter functionality is added here to the general Scene.
		 *
		 * @exports WebCenterScene
		 * @class
		 *
		 * @param {JQueryObj}           context       - the context in which the workflow scene is drawn
		 * @param {SceneModel}	        sceneModel	  - the model of the scene
		 * @param {Workflow}            workflowModel - model of the workflow which contains all the workflow items
		 * @param {AbstractViewFactory} viewFactory   - factory used to generate all the view objects
		 * @param {WebCenterAPI} 		webCenterAPI 
		 * @param {WFEditorContext} 	WFEditorContext 
		 */
		var WebCenterScene = function (context, sceneModel, workflowModel, viewFactory, webCenterAPI, WFEditorContext) {
			Scene.call(this, context, sceneModel, workflowModel, viewFactory, WFEditorContext);

			this._sceneModel.setWorldBoundingBox(new ShapeUtils.Rect(
				new ShapeUtils.Point(WebCenterWFEditorConstants.WorkflowWorldBounds.x, WebCenterWFEditorConstants.WorkflowWorldBounds.y),
				new ShapeUtils.Size(WebCenterWFEditorConstants.WorkflowWorldBounds.width, WebCenterWFEditorConstants.WorkflowWorldBounds.height)));

			this._webCenterAPI = webCenterAPI;
			// set the insets correctly, we want 5px padding + scrollbars shouldn't overlap canvas content
			this._sceneModel.setInsets(55, this._verticalScroll.element.width() + 5, this._horizontalScroll.element.height() + 5, 5);

		};

		WebCenterScene.prototype = Object.create(Scene.prototype);
		WebCenterScene.prototype.constructor = WebCenterScene;

		/**
		 * @override
		 * A token got selected in the view, emit an event where the controller can listen to.
		 *
		 * @param {Token}  token      - the token that got selected
		 * @param {String} versionId - the id of the document version in the token that got selected
		 */
		WebCenterScene.prototype.tokenItemSelected = function (token, versionId) {
			this._emit("tokenItemSelected", token, versionId);
		};


		/**
		 * Get a reference to the WebCenter API
		 * @returns {WebCenterAPI} 
		 */
		WebCenterScene.prototype.getWebCenterAPI = function () {
			return this._webCenterAPI;
		};

		return WebCenterScene;

	});
