define([
		"component/tooltip/Tooltip",
		"utils/webi18n!WFEditorWCR"
	],
	function (
		Tooltip,
		i18n //only t is supported never provide langBundle from here!
	) {
		"use strict";

		/**
		 * View for the showing the task status in the toolbar of the workflow editor
		 *
		 * @exports StatusToolbarComponent
		 * @class
		 *
		 * @param {String} url to the icon of the task status
		 * @param {String} the name of the task status
		 * @param {JQueryObj} globalContext
		 */
		var StatusToolbarComponent = function (icon, status, globalContext) {

			/**
			 * @member {String} the url to the icon for the task status
			 * @private
			 */
			this._icon = icon;

			/**
			 * @member {String} the name of the task status
			 * @private
			 */
			this._status = status;

			/**
			 * @member {JQueryObj} the element of the component
			 */
			this.element = $("<div>").addClass("statusToolbarComponent").addClass(this._name);
			this._taskStatus = $("<span>").text(this._status).addClass("enableTextSelection");
			this._content = $("<div>").addClass("statusToolbarContent");
			if (this._icon) {
				this._iconEl = $("<img>").attr("src", this._icon); //the image icon
				this._content.append(this._iconEl);
			}
			this._content.append(this._taskStatus);
			//append the content to the components element
			this.element.append(this._content);

			//add the correct tooltip
			this._tooltip = new Tooltip(i18n, this._content, globalContext, globalContext, false, i18n.t("workflowStatus"));
		};

		/**
		 * Update the status toolbar component in the workflow editor
		 * @param {Object} data - contains the icon and status properties, icon is not needed
		 */
		StatusToolbarComponent.prototype.updateView = function (data) {
			this._icon = data.icon;
			this._status = data.status;
			this._content.empty();

			if (this._iconEl) {
				if (this._icon) {
					this._iconEl.attr("src", this._icon);
				} else {
					this._iconEl = null;
				}
			} else {
				this._iconEl = $("<img>").attr("src", this._icon);
			}

			if (this._iconEl) {
				this._content.append(this._iconEl);
			}

			this._taskStatus.text(this._status);
			this._content.append(this._taskStatus);
		};

		return StatusToolbarComponent;
	});