define([
		"WFEditorWCR/webcenterInformationPopup/WebCenterInformationPopup"
	],
	function (
		WebCenterInformationPopup
	) {
		"use strict";

		/**
		 * Pin information is shown in a movable popup. It shows the tokens and their documents
		 * as a list in the popup. The color is the same as the pin color. The popup is part of
		 * the pin. The popup extends WebCenterInformationPopup in the WFEditor framework.
		 *
		 * @exports WebCenterPinInformationPopup
		 * @class
		 * @augments WebCenterInformationPopup
		 *
		 * @param {WebCenterPinView} pinView
		 * @param {WebCenterPinModel} pinModel
		 * @param {Scene} scene
		 */
		var WebCenterPinInformationPopup = function (pinView, pinModel, scene) {
			WebCenterInformationPopup.call(this, pinModel.getWorkflow(), scene, pinView.getPinColor(), pinView);

			/**
			 * @member {WebCenterPinView} view object of the pin
			 * @private
			 */
			this._pinView = pinView;

			/**
			 * @member {WebCenterPin} model of the pin, used to fetch the tokens from
			 * @private
			 */
			this._pinModel = pinModel;
		};

		WebCenterPinInformationPopup.prototype = Object.create(WebCenterInformationPopup.prototype);
		WebCenterPinInformationPopup.prototype.constructor = WebCenterPinInformationPopup;

		/**
		 * @override
		 * The title of the popup is the label of the pin
		 */
		WebCenterPinInformationPopup.prototype.getTitle = function () {
			return this._pinModel.getLabel();
		};

		/**
		 * @override
		 * the location of the popup is next to the pin
		 */
		WebCenterPinInformationPopup.prototype.getPopupLocation = function () {
			var location = this._pinView.getLocation();
			location.offsetXY(10, 4);
			return location;
		};

		/**
		 * @override
		 * the tokens in the popup are the tokens of the pin
		 */
		WebCenterPinInformationPopup.prototype.getTokens = function () {
			return this._pinModel.getTokens();
		};


		/**
		 * @Override
		 */
		WebCenterPinInformationPopup.prototype.show = function () {
			this._pinView.setPopupOpen(true);
			WebCenterInformationPopup.prototype.show.call(this);
		};

		/**
		 * @Override
		 */
		WebCenterPinInformationPopup.prototype._closed = function () {
			WebCenterInformationPopup.prototype._closed.call(this);

			this._pinView.setPopupOpen(false);
		};
		return WebCenterPinInformationPopup;

	});