define([
		"WFEditorWCR/webcenterInformationPopup/WebCenterInformationPopup",
		"WFEditorWCR/scene/WebCenterViewConstants"
	],
	function (
		WebCenterInformationPopup,
		WebCenterViewConstants
	) {
		"use strict";

		/**
		 * The information of a token in progress is shown in a movable popup. It shows the tokens and their documents
		 * as a list in the popup. 
		 *
		 * @exports WebCenterTokenInformationPopup
		 * @class
		 * @augments WebCenterInformationPopup
		 *
		 * @param {WebCenterPinView} pinView
		 * @param {WebCenterToken} tokenModel
		 * @param {Scene} scene
		 * @param {TokenView} tokenView
		 */
		var WebCenterTokenInformationPopup = function (pinView, tokenModel, scene, tokenView) {
			WebCenterInformationPopup.call(this, tokenModel.getWorkflow(), scene, WebCenterViewConstants.TokenStatusTextColor, tokenView);

			/**
			 * @member {WebCenterPinView} the input 
			 * @private
			 */
			this._pinView = pinView;

			/**
			 * @member {WebCenterToken} model of the token
			 * @private
			 */
			this._tokenModel = tokenModel;

			/**
			 * @member {WebCenterTokenView} view object of the token
			 * @private
			 */
			this._tokenView = tokenView;


		};

		WebCenterTokenInformationPopup.prototype = Object.create(WebCenterInformationPopup.prototype);
		WebCenterTokenInformationPopup.prototype.constructor = WebCenterTokenInformationPopup;


		/**
		 * @override
		 * @returns {String} The title of the popup
		 */
		WebCenterTokenInformationPopup.prototype.getTitle = function () {
			return this._tokenView.getStatusText();
		};

		/**
		 * @override
		 * @returns {ShapeUtils.Point} The default location
		 */
		WebCenterTokenInformationPopup.prototype.getPopupLocation = function () {
			var point = this._pinView.getLocationForToken(this._tokenModel);
			point.offsetXY(16, 9);
			return point;
		};

		/**
		 * @override
		 * @returns {Array.Token}
		 */
		WebCenterTokenInformationPopup.prototype.getTokens = function () {
			if (this._tokenModel.getSubTokens) {
				return this._tokenModel.getSubTokens();
			} else {
				return [this._tokenModel];
			}
		};

		/**
		 * @Override
		 */
		WebCenterTokenInformationPopup.prototype.show = function () {
			this._tokenView.setPopupOpen(true);
			WebCenterInformationPopup.prototype.show.call(this);
		};

		/**
		 * @Override
		 */
		WebCenterTokenInformationPopup.prototype._closed = function () {
			WebCenterInformationPopup.prototype._closed.call(this);
			this._tokenView.setPopupOpen(false);
		};
		return WebCenterTokenInformationPopup;

	});
