define(["WFEditorWCR/core/WFEditorWCR",
		"WFEditorWCR/wfPopup/WFEditorWCRPopupToolbar",
		"WFEditorWCR/wfPopup/MinifiedWFEditorSceneController",
		"WFEditor/workflow/ModelConstants",
		"WFEditor/tools/ToolConstants",
		"WFEditorWCR/workflow/node/WebCenterNodeConstants",
		"WFEditorWCR/wfPopup/MouseInteractionPanTool",
		"utils/ShapeUtils",
		"utils/Observer",
		"underscore"
	],
	function (WFEditorWCR,
		WFEditorWCRPopupToolbar,
		MinifiedWFEditorSceneController,
		ModelConstants,
		ToolConstants,
		WebCenterNodeConstants,
		MouseInteractionPanTool,
		ShapeUtils,
		Observer,
		_) {

		"use strict";

		/**
		 * This Editor will strip out the toolbar and add only the step through active nodes buttons to the jQuery element it was given on creation.
		 * After initialization it will zoom in to an active node if available.
		 * @class
		 * @augments WFEditorWCR
		 * @exports MinifiedWFEditorWCR
		 * @mixes {Observer}
		 * @param {String} taskId - id of the task this editor has to open
		 * @param {String} taskTypeId - id of the type of the task this editor has to open
		 * @param {JQueryObject} context - element in which the editor has to render
		 * @param {JQueryObject} toolbarContext - the context for the step through buttons
		 */
		var MinifiedWFEditorWCR = function (taskId, taskTypeId, context, toolbarContext, privileges) {

			/**
			 * @member {JQueryObject} 
			 * @private
			 */
			this._toolbarContext = toolbarContext;

			WFEditorWCR.call(this, context, _.extend(this.getPrivileges(taskId, taskTypeId), privileges), taskId, taskTypeId);
			Observer.mixin(this);

		};


		MinifiedWFEditorWCR.prototype = Object.create(WFEditorWCR.prototype);
		MinifiedWFEditorWCR.prototype.constructor = MinifiedWFEditorWCR;

		/**
		 * @override
		 */
		MinifiedWFEditorWCR.prototype._initializeToolbar = function (toolbarModel, context, globalContext) {
			var toolbar = new WFEditorWCRPopupToolbar(toolbarModel, this._toolbarContext, $("body"));
			this._toolbar = toolbar;
			return toolbar;
		};

		/**
		 * @override
		 */
		MinifiedWFEditorWCR.prototype._initializeScene = function (context, sceneModel, workflow, workflowViewFactory, i18n) {
			var scene = WFEditorWCR.prototype._initializeScene.call(this, context, sceneModel, workflow, workflowViewFactory, i18n);
			this._observe(scene, "NodeConfigurationController.open.configurationPanel", function () {
				var visibleRect = this._scene.getVisibleRect(true);
				// Resize the popup if a node configuration has been opened, 700, 700 is preferred width and height
				this._emit("resize", 700, 700);
				this._sceneController.zoomToRect(visibleRect, 1);
				this._scene.resized();
				// Don't resize it after it has been done once
				this._stopObserveObjectChannel(scene, "NodeConfigurationController.open.configurationPanel");

			});
			return scene;
		};


		/**
		 * @override
		 */
		MinifiedWFEditorWCR.prototype._initializeSceneController = function (workflowFactory, sceneModel, workflowModel, scene, WFEditorContext) {
			return new MinifiedWFEditorSceneController(workflowFactory, sceneModel, workflowModel, scene, WFEditorContext);
		};

		/**
		 * @override
		 * zooms in to an active node on init
		 */
		MinifiedWFEditorWCR.prototype.setWorkflow = function (workflow, callback) {
			WFEditorWCR.prototype.setWorkflow.call(this, workflow, _.bind(function () {
				callback();
				this._webCenterAPI.getWorkflowReport(this._taskId).done(_.bind(function () {
					workflow.shiftFocusedActiveNodeIndex(0);
					this._scene.getSceneModel().setHighlightMode(true);

				}, this));
			}, this));
		};

		/**
		 * gets the default privileges for the popup. Only allow for zooming to active nodes and opening the nodes' configuration
		 */
		MinifiedWFEditorWCR.prototype.getPrivileges = function (taskId, taskTypeId) {
			var privileges = {
				hasTaskEditRights: false, // change task permissions
				isMasterTask: false, // is a mastertask or not
				autorefresh: true
			};

			privileges[ModelConstants.Privileges.zoomToActiveNode] = !!taskId;
			privileges[ModelConstants.Privileges.addEdges] = false; // editor mode if taskid is not defined
			privileges[ModelConstants.Privileges.removeEdges] = false;
			privileges[ModelConstants.Privileges.moveEdges] = false;
			privileges[ModelConstants.Privileges.canSave] = false;
			privileges[ModelConstants.Privileges.addNodes] = false;
			privileges[ModelConstants.Privileges.moveNodes] = true;
			privileges[ModelConstants.Privileges.removeNodes] = false;
			privileges[WebCenterNodeConstants.Privileges.editLabels] = false;
			privileges[WebCenterNodeConstants.Privileges.editStickyNotes] = false;
			privileges[WebCenterNodeConstants.Privileges.showWorkflowControls] = false;
			privileges[ModelConstants.Privileges.viewNodeConfiguration] = true;
			privileges[ModelConstants.Privileges.editNodeConfiguration] = false;
			privileges[ModelConstants.Privileges.copyNodes] = false;
			return privileges;

		};


		return MinifiedWFEditorWCR;

	});