define(["underscore", "WFEditor/tools/PanTool", "utils/Observer", "WFEditor/tools/ToolConstants"], function (_, PanTool, Observer, ToolConstants) {

	"use strict";

	/**
	 * a class that activates the pan tool if the mouse interaction tool sends a mousedown event on a location without hitArea. 
	 * This tool will interfer with the selection tool so they cannot be active at the same time
	 * @class
	 * @exports MouseInteractionPanTool
	 * @augments PanTool
	 * @param {Observable} mouseInteractionEvents
	 * @param {WFEditorContext} WFEditorContext
	 */
	var MouseInteractionPanTool = function (mouseInteractionEvents, WFEditorContext) {
		PanTool.call(this, WFEditorContext);
		Observer.mixin(this);
		this._observe(mouseInteractionEvents, "mousedown", this._checkForActivate);
		this._observe(mouseInteractionEvents, "mousemove", this._checkForCursor);

		this._states[ToolConstants.State.PANNINGSTATE].mouseup = _.bind(function (e) {
			this._toolManager.deactivateCurrentTool();
		}, this);
		this._states[ToolConstants.State.PANNINGSTATE].mouseleave = _.bind(function (e) {
			e.preventDefault();
			this._calculateOffset(e);
			this._toolManager.deactivateCurrentTool();
		}, this);


	};

	MouseInteractionPanTool.prototype = Object.create(PanTool.prototype);
	MouseInteractionPanTool.prototype.constructor = MouseInteractionPanTool;

	/**
	 * Activate the pan tool on mouse down
	 * @param {Object} options as sent by the mouse interaction tool
	 */
	MouseInteractionPanTool.prototype._checkForActivate = function (options) {
		if (!options.hitArea) {
			this._toolManager.activateTool(this);
			this._startPoint = this._getMousePosition(options.e);
			this.changeState(ToolConstants.State.PANNINGSTATE);
		}
	};

	/**
	 * set the correct cursor
	 * @param {Object} options as sent by the mouse interaction tool
	 */
	MouseInteractionPanTool.prototype._checkForCursor = function (options) {
		if (!options.hitArea) {
			this._sceneModel.setCursor(ToolConstants.Cursors.HAND);
		}
	};

	return MouseInteractionPanTool;

});
