define([
		"WFEditor/components/Popup",
		"underscore",
		"utils/webcss!WFEditorWCR/core/wfeditorwcr-style.css"
	],
	function (
		Popup,
		_
	) {

		"use strict";

		/**
		 * 
		 * @class
		 * @augments Popup
		 * @exports WFEditorWCRPopup
		 * @param {String} name - name used for the observable id
		 * @param {JQueryObject} containment - dom object to which this popup will be added
		 * @param {String} title - will be set in the popup header
		 * @param {String} [cssClass] - class to be added to the popup's element
		 */
		var WFEditorWCRPopup = function (name, containment, title, cssClass) {
			Popup.call(this, name, containment, cssClass);

			this.setTitle(title);

			this._closeBtn.element.on("mousedown", function (e) {
				e.stopPropagation();
			});

			this.element.addClass("WFEditorWCRPopup");

		};


		WFEditorWCRPopup.prototype = Object.create(Popup.prototype);
		WFEditorWCRPopup.prototype.constructor = Popup;

		/**
		 * @override
		 */
		WFEditorWCRPopup.prototype.fitContent = function () {
			// We don't want to fit content
		};

		/**
		 * @override
		 */
		WFEditorWCRPopup.prototype._initializeResizableDraggable = function () {
			var minWidth = parseInt(this.element.css("min-width"));
			var minHeight = parseInt(this.element.css("min-height"));
			Popup.prototype._initializeResizableDraggable.call(this, minWidth, minHeight);
			this.element.resizable("option", "containment", "document");
			this.element.draggable("option", "containment", "document");
		};

		/**
		 * get the JQuery element of the footer
		 * @returns {JQueryObject}
		 */
		WFEditorWCRPopup.prototype.getFooter = function () {
			return this._footer;
		};

		/**
		 * get the JQuery element of the header
		 * @returns {JQueryObject}
		 */
		WFEditorWCRPopup.prototype.getHeader = function () {
			return this._header;
		};


		/**
		 * The close button was pressed
		 * @protected
		 */
		WFEditorWCRPopup.prototype._closeButtonPressed = function (e) {
			var canCloseObj = {
				canClose: true
			};
			// send event to see if we can close the popup
			this._emit("closed", canCloseObj);
			if (canCloseObj.canClose) {
				this.hide();
			}
			e.stopPropagation();
		};

		/**
		 * Resize the popup to a certain prefered width and height. The width and height is bound by the window's width and height.
		 * @param {Integer} prefWidth - the prefered width of the popup
		 * @param {Integer} prefHeight - the prefered height of the popup
		 */
		WFEditorWCRPopup.prototype.resize = function (prefWidth, prefHeight) {
			var footerHeight = $(".wcr-page-footer").height();
			var headerHeight = $(".navbar-wcr").height();
			var body = $("body");
			var scrollbarSize = getScrollBarWidth();
			prefHeight = window.Math.min(window.innerHeight - scrollbarSize, prefHeight);
			prefWidth = window.Math.min(window.innerWidth - scrollbarSize, prefWidth);


			if (this.element.width() < prefWidth) {
				this.element.width(prefWidth);
			}
			if (this.element.height() < prefHeight) {
				this.element.height(prefHeight);
			}

			// If the popup would overflow the window horizontally, set left to 0
			if (window.innerWidth - scrollbarSize < this.element.offset().left + this.element.width()) {
				this.element.css({
					left: 0
				});
			}

			// If the popup would overflow vertically
			if (($(window).height() - prefHeight) < this.element.offset().top - footerHeight || ($(body).height() - prefHeight) < this.element.offset().top) {

				// calculate the top offset in order that the window is above the bottom of the window
				var top = Math.min($(window).height() - prefHeight + window.pageYOffset - footerHeight, $(body).height() - prefHeight);

				// now check if the top op the window isn't above the top of the window
				if (top < Math.max(headerHeight, window.pageYOffset)) {

					// if so, adjust the height of the popup and the top to make sure the popup is inside the visible area
					prefHeight = prefHeight - Math.abs(this.element.offset().top - Math.max(window.pageYOffset, headerHeight));
					top = Math.max(headerHeight, window.pageYOffset);
				}
				this.element.css({
					top: top
				});
			}



		};

		// Get the width of the scrollbar http://www.alexandre-gomes.com/?p=115
		var getScrollBarWidth = _.memoize(function () {
			var inner = document.createElement('p');
			inner.style.width = "100%";
			inner.style.height = "200px";

			var outer = document.createElement('div');
			outer.style.position = "absolute";
			outer.style.top = "0px";
			outer.style.left = "0px";
			outer.style.visibility = "hidden";
			outer.style.width = "200px";
			outer.style.height = "150px";
			outer.style.overflow = "hidden";
			outer.appendChild(inner);

			document.body.appendChild(outer);
			var w1 = inner.offsetWidth;
			outer.style.overflow = 'scroll';
			var w2 = inner.offsetWidth;
			if (w1 == w2) {
				w2 = outer.clientWidth;
			}

			document.body.removeChild(outer);

			return (w1 - w2);
		});

		return WFEditorWCRPopup;

	});
