define([
		"utils/Observer",
		"WFEditor/toolbar/Toolbar",
		"component/toolbar/ToolbarButton",
		"component/toolbar/ButtonGroup",
		"WFEditor/tools/ToolConstants",
		"utils/webi18n!WFEditorWCR",
		"WFEditor/utils/WFI18nConstants"
	],
	function (
		Observer,
		Toolbar,
		ToolbarButton,
		ButtonGroup,
		ToolConstants,
		i18n,
		WFI18nConstants
	) {
		"use strict";

		/**
		 * This class is used to display the toolbar of  the poor mans workflow editor. The toolbar only has two buttons: to step through all active nodes
		 *
		 * @exports WFEditorWCRPopupToolbar
		 * @class
		 * @augments Toolbar
		 *
		 * @param {ToolbarModel} toolbarModel
		 * @param {JQueryObj} context
		 * @param {JQueryObj} globalContext - used to create buttons in
		 */
		var WFEditorWCRPopupToolbar = function (toolbarModel, context, globalContext) {
			Toolbar.call(this, toolbarModel, context);
			/**
			 * @member {JQueryObj}
			 * @private
			 * The global context to which the toolbar button tooltips will be added
			 */
			this._globalContext = globalContext;

			this._buttonGroup = new ButtonGroup(ToolConstants.ButtonGroups.STEPTHROUGH);

			/**
			 * @member {JQueryObject} div to display the index of the active node;
			 * @private
			 */
			this._contextDiv = $("<div/>").addClass("minified-wfeditor-footer");
			context.append(this._contextDiv.append(this._buttonGroup.element));

		};

		WFEditorWCRPopupToolbar.prototype = Object.create(Toolbar.prototype);
		WFEditorWCRPopupToolbar.prototype.constructor = WFEditorWCRPopupToolbar;


		/**
		 * @override
		 * Only add stepthrough buttons
		 */
		WFEditorWCRPopupToolbar.prototype._addButton = function (componentId, buttonId) {
			if (this._toolbarButtons[buttonId] === undefined && componentId === ToolConstants.ButtonGroups.STEPTHROUGH) {

				var buttonData = this._model.getButtonData(buttonId);
				if (buttonData) {
					var icon = buttonData.icon;
					if (icon && !_.isString(buttonData.icon) && buttonData.icon.icon && buttonData.icon.name) {
						icon = $("<div>").text(buttonData.icon.name);
					}
					if (buttonData.content) {
						icon = buttonData.content;
					}
					var button = new ToolbarButton(i18n, this._globalContext, false, buttonData.id, icon, false, buttonData.action, buttonData.tooltipText);
					button.element.addClass("btn-xs");
					
					// prevent the workflow from losing focus.
					button.element.on("mousedown", function(e){e.preventDefault()});
					
					this._toolbarButtons[buttonId] = button;
					button.setEnabled(buttonData.enabled);

					this._buttonGroup.addButton(button);
				}
			}
		};
	
		/**
		 * Update the button with given id. only enabled needed right now
		 * @param {String} buttonId
		 */
		WFEditorWCRPopupToolbar.prototype._updateButton = function (buttonId) {
			if (this._toolbarButtons[buttonId]) {
				var buttonModel = this._model.getButtonData(buttonId);
				this._toolbarButtons[buttonId].setEnabled(buttonModel.enabled);
			}
		};




		return WFEditorWCRPopupToolbar;
	});
