define([
		"WFEditor/workflow/edge/Edge",
		"tpl!WFEditorWCR/workflow/edge/WebCenterEdge"
	],
	function (
		Edge,
		WebCenterEdgeXML
	) {
		"use strict";

		/**
		 * WebCenterEdge represents the model for an edge in the WebCenter workflow. An edge connects two
		 * pins.
		 *
		 * @exports WebCenterEdge
		 * @class
		 * @augments Edge
		 *
		 * @param {Workflow} workflow
		 * @param {String} id - edge id
		 */
		var WebCenterEdge = function (workflow, id, from, to) {
			Edge.call(this, workflow, id, from, to);
			/**
			 * @member {Boolean} if an edge is implicit, it is implicitly added to make sure the workflow works correctly, but shouldn't be shown to the user
			 */
			this._isImplicit = false;
		};

		WebCenterEdge.prototype = Object.create(Edge.prototype);
		WebCenterEdge.prototype.constructor = WebCenterEdge;

		/**
		 * Get the ID of the node to which this edge goes
		 * @returns {String} destinatio nnode id
		 */
		WebCenterEdge.prototype.getDestinationNodeId = function () {
			var to = this.getToPin();
			if (to) {
				var destinationNode = to.getNode();
				if (destinationNode) {
					return destinationNode.getId();
				}
			}
			return "";
		};

		/**
		 * Get the name of the transition (used for writing XML)
		 * @returns {String} name of the transition
		 */
		WebCenterEdge.prototype.getTransitionName = function () {
			var from = this.getFromPin();
			var name = "";

			if (from) {
				name = from.getId();
			}
			name += "/" + (from.getEdgeIndex(this) + 1);

			return name;
		};


		/**
		 * @Override
		 */
		WebCenterEdge.prototype.toXML = function () {
			return WebCenterEdgeXML(this);
		};

		/**
		 * Is the Edge implicit?
		 * @returns {Boolean}
		 */
		WebCenterEdge.prototype.isImplicit = function () {
			return this._isImplicit;
		};

		/**
		 * Make the Edge implicit (or not)
		 * @param {Boolean} isImplicit
		 */
		WebCenterEdge.prototype.setImplicit = function (implicit) {
			this._isImplicit = implicit;
		};

		/**
		 * Make sure implicit edges are not drawn
		 * @Override
		 */
		WebCenterEdge.prototype.isVisible = function () {
			return Edge.prototype.isVisible.call(this) && !this.isImplicit();
		};


		return WebCenterEdge;
	});