define(["underscore",
		"WFEditor/workflow/node/NodeConfigurationPanel",
		"component/helpIcon/HelpIcon"
	],
	function (_,
		NodeConfigurationPanel,
		HelpIcon) {
		"use strict";

		/**
		 * Configuration Panel for a WebCenter Node
		 * @class
		 * @export WebCenterNodeConfigurationPanel
		 * @augments NodeConfigurationPanel
		 * @param {Node} node - node for which the configuration panel is created
		 */
		var WebCenterNodeConfigurationPanel = function (node) {
			NodeConfigurationPanel.call(this, node);

			this._element.addClass("wfeditor-node-configuration");

			/**
			 * @member {JQueryObject}
			 * @private
			 */
			this._helpBalloon = null;

			/**
			 * @member {Tooltip} tooltip for the help icon, referenced to destroy it if panel is destroyed
			 * @private
			 */
			this._tooltip = null;

		};

		WebCenterNodeConfigurationPanel.prototype = Object.create(NodeConfigurationPanel.prototype);
		WebCenterNodeConfigurationPanel.prototype.constructor = WebCenterNodeConfigurationPanel;


		/**
		 * Get the title of the panel
		 * @override
		 * @returns {String} 
		 */
		WebCenterNodeConfigurationPanel.prototype.getTitle = function () {
			return this._node.getLabel();
		};

		/**
		 * Focus the first input element
		 * @override
		 */
		WebCenterNodeConfigurationPanel.prototype.focus = function () {
			this._element.find("input,textarea").first().focus();
		};

		/**
		 * Add a help balloon to the footer
		 * @override
		 */
		WebCenterNodeConfigurationPanel.prototype.getFooterContent = function () {
			if (!this._helpBalloon && this._node.getHelpTopic()) {
				var options = {
					cssClass: "wfeditor-node-help-tooltip tooltip inline_help_tooltip"
				};
				this._helpBalloon = HelpIcon.getInlineHelpTopicJQuery(this._node.getHelpTopic(),
					undefined, options);
				this._tooltip = options.tooltipReference;

			}
			return this._helpBalloon;
		};

		/**
		 * @override
		 */
		WebCenterNodeConfigurationPanel.prototype.destroy = function () {
			NodeConfigurationPanel.prototype.destroy.call(this);
			if(this._tooltip){
				this._tooltip.destroy();
			}
		};


		return WebCenterNodeConfigurationPanel;
	});
