define([
		"WFEditorWCR/workflow/node/operation/OperationNode",
		"WFEditorWCR/workflow/node/WebCenterNodeConstants",
		"WFEditorWCR/workflow/pin/OutputPinOK",
		"WFEditorWCR/workflow/pin/WebCenterPinConstants"
	],
	function (
		OperationNode,
		WebCenterNodeConstants,
		OutputPinOK,
		WebCenterPinConstants
	) {
		"use strict";

		/**
		 * DataSplitterNode represents the model for a  DataSplitterNode node in the WebCenter Workflow Editor
		 *
		 * @exports DataSplitterNode
		 * @class
		 * @augments OperationNode
		 *
		 * @param {Workflow} workflow - the workflow to which the node belongs
		 * @param {String} id - node id
		 * @param {String} pathToIcons - gives the url to the map where the icons can be found
		 * @param {String} [label] - the label of the node
		 * @param {WebCenterAPI} webCenterAPI - used to access webcenter data                        
		 */
		var DataSplitterNode = function (workflow, id, pathToIcons, label, webCenterAPI) {
			var icon = WebCenterNodeConstants.Icons.DATASPLITTER;
			OperationNode.call(this, workflow, id, WebCenterNodeConstants.Nodes.DATASPLITTER, pathToIcons + icon, label, webCenterAPI);
		};

		DataSplitterNode.prototype = Object.create(OperationNode.prototype);
		DataSplitterNode.prototype.constructor = DataSplitterNode;

		/**
		 * @Override
		 */
		DataSplitterNode.prototype._initializePins = function () {
			this._addInputPin();
			this.addPin(new OutputPinOK(this._workflow, this, WebCenterPinConstants.Type.WorkflowConstructOK));
		};

		/**
		 * @override
		 */
		DataSplitterNode.prototype.getHelpTopic = function () {
			return WebCenterNodeConstants.HelpTopics.DATASPLITTER;
		};

		return DataSplitterNode;
	});