define([
		"WFEditorWCR/workflow/node/WebCenterNode",
		"WFEditorWCR/workflow/node/WebCenterNodeConstants",
		"WFEditorWCR/workflow/pin/WebCenterPinConstants",
		"WFEditorWCR/workflow/pin/OutputPinOK",
		"WFEditorWCR/workflow/pin/ImplicitInputPin"
	],
	function (
		WebCenterNode,
		WebCenterNodeConstants,
		WebCenterPinConstants,
		OutputPinOK,
		ImplicitInputPin
	) {
		"use strict";

		/**
		 * ErrorHandlerNode represents the model for a  ErrorHandlerNode node in the WebCenter Workflow Editor.
		 *
		 * @exports ErrorHandlerNode
		 * @class
		 * @augments WebCenterNode
		 *
		 * @param {Wofkflow} workflow - the workflow to which the node belongs
		 * @param {String} id - node id
		 * @param {String} pathToIcons - gives the url to the map where the icons can be found
		 * @param {String} [label] - the label of the node
		 * @param {WebCenterAPI} webCenterAPI - used to access webcenter data                        
		 */
		var ErrorHandlerNode = function (workflow, id, pathToIcons, label, webCenterAPI) {
			var icon = WebCenterNodeConstants.Icons.ERRORHANDLER;
			WebCenterNode.call(this, workflow, id, WebCenterNodeConstants.Nodes.ERRORHANDLER, pathToIcons + icon, label, webCenterAPI);

		};

		ErrorHandlerNode.prototype = Object.create(WebCenterNode.prototype);
		ErrorHandlerNode.prototype.constructor = ErrorHandlerNode;

		/**
		 * @Override
		 */
		ErrorHandlerNode.prototype._initializePins = function () {
			this._inputPin = new ImplicitInputPin(this._workflow, this);
			this.addPin(this._inputPin);
			this.addPin(new OutputPinOK(this._workflow, this, WebCenterPinConstants.Type.OutOK, ""));
		};

		/**
		 * @override
		 */
		ErrorHandlerNode.prototype.getHelpTopic = function () {
			return WebCenterNodeConstants.HelpTopics.ERRORHANDLER;
		};

		return ErrorHandlerNode;
	});