define([
		"WFEditorWCR/workflow/node/WebCenterNode",
		"WFEditorWCR/workflow/node/WebCenterNodeConstants",
		"WFEditorWCR/workflow/pin/OutputPinOK",
		"WFEditorWCR/workflow/pin/WebCenterPinConstants"
	],
	function (
		WebCenterNode,
		WebCenterNodeConstants,
		OutputPinOK,
		WebCenterPinConstants
	) {
		"use strict";

		/**
		 * ErrorHandling represents the model for the invisible errorHandling nodes.
		 *
		 * @exports ErrorHandlingNode
		 * @class
		 * @augments WebCenterNode
		 *
		 * @param {Wofkflow} workflow - the workflow to which the node belongs
		 * @param {String} id - node id
		 * @param {String} pathToIcons - gives the url to the map where the icons can be found
		 * @param {String} label - the label of the node
		 * @param {WebCenterAPI} webCenterAPI - used to access webcenter data                        
		 */
		var ErrorHandlingNode = function (workflow, id, pathToIcons, label, webCenterAPI) {
			var icon = WebCenterNodeConstants.Icons.ERRORHANDLING;
			WebCenterNode.call(this, workflow, id, WebCenterNodeConstants.Nodes.ERRORHANDLING, pathToIcons + icon, label, webCenterAPI);

			this._isVisible = false;
		};

		ErrorHandlingNode.prototype = Object.create(WebCenterNode.prototype);
		ErrorHandlingNode.prototype.constructor = ErrorHandlingNode;

		/**
		 * @Override
		 */
		ErrorHandlingNode.prototype._initializePins = function () {
			this._addInputPin();
			this.addPin(new OutputPinOK(this._workflow, this, WebCenterPinConstants.Type.OutOK));
		};

		return ErrorHandlingNode;
	});