define([
		"WFEditorWCR/workflow/node/operation/OperationNode",
		"WFEditorWCR/workflow/node/WebCenterNodeConstants",
		"WFEditorWCR/workflow/pin/WebCenterPinConstants",
		"WFEditorWCR/workflow/pin/OutputPinOK",
		"tpl!WFEditorWCR/workflow/node/fork/ForkNode"
	],
	function (
		OperationNode,
		WebCenterNodeConstants,
		WebCenterPinConstants,
		OutputPinOK,
		ForkNodeXML
	) {
		"use strict";

		/**
		 * ForkNode represents the model for a  ForkNode node in the WebCenter Workflow Editor.
		 *
		 * @exports ForkNode
		 * @class
		 * @augments OperationNode
		 *
		 * @param {Wofkflow} workflow - the workflow to which the node belongs
		 * @param {String} id - node id
		 *                    @param {String} pathToIcons - gives the url to the map where the icons can be found
		 * @param {String} [label] - the label of the node
		 * @param {WebCenterAPI} webCenterAPI - used to access webcenter data                        
		 */
		var ForkNode = function (workflow, id, pathToIcons, label, webCenterAPI) {
			var icon = WebCenterNodeConstants.Icons.FORK;
			OperationNode.call(this, workflow, id, WebCenterNodeConstants.Nodes.FORK, pathToIcons + icon, label, webCenterAPI);


		};

		ForkNode.prototype = Object.create(OperationNode.prototype);
		ForkNode.prototype.constructor = ForkNode;

		/**
		 * @Override
		 */
		ForkNode.prototype._initializePins = function () {
			this._addInputPin();
			this.addPin(new OutputPinOK(this._workflow, this, WebCenterPinConstants.Type.WorkflowConstructOK));
		};


		/**
		 * @Override
		 */
		ForkNode.prototype.toXML = function () {
			return ForkNodeXML(this);
		};

		/**
		 * @override
		 */
		ForkNode.prototype.getHelpTopic = function () {
			return WebCenterNodeConstants.HelpTopics.FORK;
		};

		return ForkNode;
	});