define([
		"WFEditorWCR/workflow/node/dataCollector/DataCollectorNode",
		"WFEditorWCR/workflow/node/WebCenterNodeConstants",
		"WFEditorWCR/workflow/pin/OutputPinOK",
		"WFEditorWCR/workflow/pin/WebCenterPinConstants",
		"tpl!WFEditorWCR/workflow/node/join/JoinNode",
		"utils/XMLUtils"
	],
	function (
		DataCollectorNode,
		WebCenterNodeConstants,
		OutputPinOK,
		WebCenterPinConstants,
		JoinNodeXML,
		XMLUtils

	) {
		"use strict";

		/**
		 * JoinNode represents the model for a  JoinNode node in the WebCenter Workflow Editor.
		 *
		 * @exports JoinNode
		 * @class
		 * @augments DataCollectorNode
		 *
		 * @param {Wofkflow} workflow - the workflow to which the node belongs
		 * @param {String} id - node id
		 * @param {String} pathToIcons - gives the url to the map where the icons can be found
		 * @param {String} [label] - the label of the node
		 * @param {WebCenterAPI} webCenterAPI - used to access webcenter data                        
		 */
		var JoinNode = function (workflow, id, pathToIcons, label, webCenterAPI) {
			this._icon = WebCenterNodeConstants.Icons.JOIN;
			this._type = WebCenterNodeConstants.Nodes.JOIN;
			DataCollectorNode.call(this, workflow, id, pathToIcons, label, webCenterAPI);
		};

		JoinNode.prototype = Object.create(DataCollectorNode.prototype);
		JoinNode.prototype.constructor = JoinNode;

		/**
		 * @override
		 */
		JoinNode.prototype.readErrorPolicyFromXML = function (nodeXML) {
			var nodeData = XMLUtils.xml2obj(nodeXML);
			this._errorPolicy = nodeData.errorpolicy;
			this._ErrorPolicyParam.setValue(this._errorPolicy);
			this._updatePins();
		};

		/**
		 * @Override
		 */
		JoinNode.prototype.toXML = function () {
			return JoinNodeXML(this);
		};

		/**
		 * @override
		 */
		JoinNode.prototype.getHelpTopic = function () {
			return WebCenterNodeConstants.HelpTopics.JOIN;
		};

		return JoinNode;
	});
