define([
		"WFEditorWCR/workflow/node/WebCenterNode",
		"WFEditorWCR/workflow/node/WebCenterNodeConstants"
	],
	function (
		WebCenterNode,
		WebCenterNodeConstants
	) {
		"use strict";

		/**
		 * OperationNode represents the model for a node that consists of an operation in the WebCenter Workflow Editor.
		 *
		 * @exports OperationNode
		 * @class
		 * @augments WebCenterNode
		 *
		 * @param {Workflow} workflow    - the workflow to which the node belongs
		 * @param {String}   id          - node id
		 * @param {String}   type        - the type of the node   
		 * @param {String}   pathToIcons - gives the url to the map where the icons can be found
		 * @param {String}   [label]     - the label of the node
		 * @param {WebCenterAPI} webCenterAPI - used to access webcenter data                        
		 */
		var OperationNode = function (workflow, id, type, pathToIcons, label, webCenterAPI) {
			WebCenterNode.call(this, workflow, id, type, pathToIcons, label, webCenterAPI);

			/**
			 * All operation tokens in this node
			 */
			this._operationTokens = {};

		};

		OperationNode.prototype = Object.create(WebCenterNode.prototype);
		OperationNode.prototype.constructor = OperationNode;

		/**
		 * Retrieve the operation tokens
		 * @returns {Map.<Sring,OperationToken>}
		 */
		OperationNode.prototype.getOperationTokens = function () {
			return this._operationTokens;
		};

		/**
		 * add an operation token to this node
		 * @param {OperationToken} opToken
		 */
		OperationNode.prototype.addOperationToken = function (opToken) {
			this._operationTokens[opToken.getId()] = opToken;
		};

		/**
		 * Removes an operation token
		 * @param {OperationToken} opToken
		 */
		OperationNode.prototype.removeOperationToken = function (opToken) {
			delete this._operationTokens[opToken.getId()];

		};


		return OperationNode;
	});
