define([
		"./RouterDecorator",
		"utils/webi18n!WFEditorWCR",
		"WFEditorWCR/workflow/node/WebCenterNodeConstants",

		"underscore",
		"jquery"
	],
	function (
		RouterDecorator,
		i18n,
		WebCenterNodeConstants,
		_,
		$
	) {

		"use strict";

		/**
		 * A router decorator that adds a checkbox for case sensitivity
		 * 
		 * @class 
		 * @exports CaseSensitiveDecorator
		 * @augments RouterDecorator
		 * 
		 * @param {String}                             id                      - Id of the router decorator
		 * @param {String}                             name                    - name for displaying purposes
		 * @param {WorkflowSmartNameDictionaryService} smartNameDictionary     - the smartname dictionary that can be used for smartnamerouterrule
		 */
		var CaseSensitiveDecorator = function (id, name, smartNameDictionary) {
			RouterDecorator.call(this, id, name, smartNameDictionary);

			/**
			 * @member {JqueryObjec}
			 * @private
			 */
			this._caseSensitiveCheckbox = $("<input type='checkbox'/>");
			this._caseSensitiveCheckboxDiv = $("<div/>");
			this._element.prepend(this._caseSensitiveCheckboxDiv.addClass("checkbox")
				.append($("<label/>")
					.text(" " + i18n.t("wfui.route.panel.casesensitive"))
					.prepend(this._caseSensitiveCheckbox)));

		};

		CaseSensitiveDecorator.prototype = Object.create(RouterDecorator.prototype);
		CaseSensitiveDecorator.prototype.constructor = CaseSensitiveDecorator;

		/**
		 * @override
		 */
		CaseSensitiveDecorator.prototype.handleParameter = function (routerParameter) {
			RouterDecorator.prototype.handleParameter.call(this, routerParameter);
			if (routerParameter.getRouterRuleType() === WebCenterNodeConstants.RouterNode.RuleTypes.StringRule) {
				this._caseSensitiveCheckboxDiv.show();
				this._caseSensitiveCheckbox.attr("checked", routerParameter.isCaseSensitive());
			} else {
				this._caseSensitiveCheckboxDiv.hide();
			}
		};

		/**
		 * @override
		 * @param {RouterParameter}
		 */
		CaseSensitiveDecorator.prototype.fillInParameter = function (routerParameter) {
			RouterDecorator.prototype.fillInParameter.call(this, routerParameter);
			routerParameter.isCaseSensitive(this._caseSensitiveCheckbox.attr("checked"));
		};

		/**
		 * @override
		 */
		CaseSensitiveDecorator.prototype.disable = function () {
			RouterDecorator.prototype.disable.call(this);
			this._caseSensitiveCheckbox.attr("disabled", true);
		};

		return CaseSensitiveDecorator;

	});