define([
	"jquery",
	"underscore",
	"./RouterDecorator",
	"../routerRules/SmartNameRouterRule",
	"../routerPanel/RouterRule",
	"utils/webi18n!WFEditorWCR",
	"WFEditorWCR/workflow/panel/WorkflowSmartNameDictionaryService",
	"WFEditorWCR/workflow/node/WebCenterNodeConstants"

], function (
	$,
	_,
	RouterDecorator,
	SmartNameRouterRule,
	RouterRule,
	i18n,
	WorkflowSmartNameDictionaryService,
	WebCenterNodeConstants) {

	"use strict";

	/**
	 *
	 * Router Decorator used for document name routing
	 *
	 * @class
	 * @exports DocumentNameRouter
	 * @augments RouterDecorator
	 * @param {WorkflowSmartNameDictionaryService} smartNameDictionary     - the smartname dictionary that can be used for smartnamerouterrule
	 * @param {DateSmartNameDictionaryService}     dateSmartNameDictionary - the smartname dicitionary that can be used for date smartnamerouterrules
	 */
	var DocumentNameRouter = function (smartNameDictionary, dateSmartNameDictionary) {
		RouterDecorator.call(this, WebCenterNodeConstants.RouterNode.Routers.DocumentName, i18n.t("router.documentname"), smartNameDictionary, dateSmartNameDictionary);

		/**
		 * @member {Array.<RouterRule>}
		 * @private
		 */
		this._rules = [new RouterRule("RS_IS_EMPTY", i18n.t("wfui.route.ruleop.empty"), i18n.t("wfui.route.ruleop.empty")),
			new SmartNameRouterRule("RS_IS_EQUAL", i18n.t("wfui.route.ruleop.equal"), i18n.t("wfui.route.ruleop.match"), this._smartNameDictionaryService),
			new SmartNameRouterRule("RS_IS_NOT_EQUAL", i18n.t("wfui.route.ruleop.noequal"), i18n.t("wfui.route.ruleop.nomatch"), this._smartNameDictionaryService),
			new SmartNameRouterRule("RS_CONTAINS", i18n.t("wfui.route.ruleop.contain"), i18n.t("wfui.route.ruleop.match"), this._smartNameDictionaryService),
			new SmartNameRouterRule("RS_DOES_NOT_CONTAIN", i18n.t("wfui.route.ruleop.nocontain"), i18n.t("wfui.route.ruleop.nomatch"), this._smartNameDictionaryService),
			new SmartNameRouterRule("RS_MATCHES", i18n.t("wfui.route.ruleop.match"), i18n.t("wfui.route.ruleop.match"), this._smartNameDictionaryService),
			new SmartNameRouterRule("RS_DOES_NOT_MATCH", i18n.t("wfui.route.ruleop.nomatch"), i18n.t("wfui.route.ruleop.nomatch"), this._smartNameDictionaryService),
			new SmartNameRouterRule("RS_BEGINS_WITH", i18n.t("wfui.route.ruleop.begins"), i18n.t("wfui.route.ruleop.match"), this._smartNameDictionaryService),
			new SmartNameRouterRule("RS_ENDS_WITH", i18n.t("wfui.route.ruleop.ends"), i18n.t("wfui.route.ruleop.match"), this._smartNameDictionaryService)
		];

		/**
		 * @member {JQueryObject}
		 * @private
		 */
		this._caseSensitiveCheckbox = $("<input type='checkbox'/>");
		this._caseSensitiveCheckboxDiv = $("<div/>").addClass("col-xs-12 col-md-6").append(
			$("<div/>").addClass("checkbox").append($("<label/>")
				.text(" " + i18n.t("wfui.route.panel.casesensitive"))
				.prepend(this._caseSensitiveCheckbox)));

		/**
		 * @member {JQueryObject}
		 * @private
		 */
		this._includeExtensionCheckbox = $("<input type='checkbox'/>");
		this._includeExtensionCheckboxDiv = $("<div/>").addClass("col-xs-12 col-md-6").append(
			$("<div/>").addClass("checkbox").append($("<label/>")
				.text(" " + i18n.t("wfui.route.panel.ignoreextension"))
				.prepend(this._includeExtensionCheckbox)));

		this._element.prepend($("<div/>").addClass("row").append(this._caseSensitiveCheckboxDiv).append(this._includeExtensionCheckboxDiv));
	};

	DocumentNameRouter.prototype = Object.create(RouterDecorator.prototype);
	DocumentNameRouter.prototype.constructor = DocumentNameRouter;

	/**
	 * @override
	 */
	DocumentNameRouter.prototype.init = function () {
		this._routerView.getRouter().setRouterRules(this._rules);
	};

	/**
	 * @override
	 */
	DocumentNameRouter.prototype.handleParameter = function (routerParameter) {
		RouterDecorator.prototype.handleParameter.call(this, routerParameter);
		this._includeExtensionCheckbox.attr("checked", routerParameter.shouldIncludeExtension());
		this._caseSensitiveCheckbox.attr("checked", routerParameter.isCaseSensitive());
	};

	/**
	 * @override
	 * @param {RouterParameter}
	 */
	DocumentNameRouter.prototype.fillInParameter = function (routerParameter) {
		RouterDecorator.prototype.fillInParameter.call(this, routerParameter);
		routerParameter.isCaseSensitive(this._caseSensitiveCheckbox.attr("checked"));
		routerParameter.shouldIncludeExtension(this._includeExtensionCheckbox.attr("checked"));
		routerParameter.setRouterRuleType(WebCenterNodeConstants.RouterNode.RuleTypes.StringRule);

	};

	/**
	 * @override
	 */
	DocumentNameRouter.prototype.disable = function () {
		RouterDecorator.prototype.disable.call(this);
		this._caseSensitiveCheckbox.attr("disabled", true);
		this._includeExtensionCheckbox.attr("disabled", true);
	};

	return DocumentNameRouter;
});