define([
	"./RouterDecorator",
	"../routerRules/SmartNameRouterRule",
	"../routerRules/BetweenSmartNameRouterRule",
	"utils/webi18n!WFEditorWCR",
	"WFEditorWCR/workflow/node/WebCenterNodeConstants"

], function (
	RouterDecorator,
	SmartNameRouterRule,
	BetweenSmartNameRouterRule,
	i18n,
	WebCenterNodeConstants) {

	"use strict";

	/**
	 *
	 * Router Decorator used for number of documents routing
	 *
	 * @class
	 * @exports NumberOfDocumentsRouter
	 * @augments RouterDecorator
	 * @param {WorkflowSmartNameDictionaryService} smartNameDictionary     - the smartname dictionary that can be used for smartnamerouterrule
	 * @param {DateSmartNameDictionaryService}     dateSmartNameDictionary - the smartname dicitionary that can be used for date smartnamerouterrules
	 */
	var NumberOfDocumentsRouter = function (smartNameDictionary, dateSmartNameDictionary) {
		RouterDecorator.call(this, WebCenterNodeConstants.RouterNode.Routers.NumberOfDocuments, i18n.t("router.numberOfDocuments"), smartNameDictionary, dateSmartNameDictionary);

		// Router Rules for a Number of Documents
		this._numberRules = [
			new SmartNameRouterRule("RN_EQUAL", i18n.t("wfui.route.ruleop.equal"), "=", this._smartNameDictionaryService, null, "="),
			new SmartNameRouterRule("RN_LESS_OR_EQUAL", i18n.t("wfui.route.ruleop.lessequal"), "<=", this._smartNameDictionaryService, null, "<="),
			new SmartNameRouterRule("RN_LESS", i18n.t("wfui.route.ruleop.less"), "<", this._smartNameDictionaryService, null, "<"),
			new SmartNameRouterRule("RN_GREATER_OR_EQUAL", i18n.t("wfui.route.ruleop.greaterequal"), ">=", this._smartNameDictionaryService, null, ">="),
			new SmartNameRouterRule("RN_GREATER", i18n.t("wfui.route.ruleop.greater"), ">", this._smartNameDictionaryService, null, ">"),
			new BetweenSmartNameRouterRule("RN_BETWEEN", i18n.t("wfui.route.ruleop.between"), "><", this._smartNameDictionaryService),
			new SmartNameRouterRule("RN_NOT_EQUAL", i18n.t("wfui.route.ruleop.noequal"), "<>", this._smartNameDictionaryService, null, "<>"),

		];
	};

	NumberOfDocumentsRouter.prototype = Object.create(RouterDecorator.prototype);
	NumberOfDocumentsRouter.prototype.constructor = NumberOfDocumentsRouter;

	/**
	 * @override
	 */
	NumberOfDocumentsRouter.prototype.init = function () {
		this._routerView.getRouter().setRouterRules(this._numberRules);
	};

	/**
	 * @override
	 */
	NumberOfDocumentsRouter.prototype.fillInParameter = function (routerParameter) {
		routerParameter.setRouterRuleType(WebCenterNodeConstants.RouterNode.RuleTypes.NumericRule);
		RouterDecorator.prototype.fillInParameter.call(this, routerParameter);
	};

	return NumberOfDocumentsRouter;
});