define([
	"jquery",
	"underscore",
	"./CaseSensitiveDecorator",
	"../routerRules/SmartNameRouterRule",
	"../routerPanel/RouterRule",
	"utils/webi18n!WFEditorWCR",
	"WFEditorWCR/workflow/node/WebCenterNodeConstants",

	"WFEditorWCR/workflow/panel/WorkflowSmartNameDictionaryService"
], function (
	$,
	_,
	CaseSensitiveDecorator,
	SmartNameRouterRule,
	RouterRule,
	i18n,
	WebCenterNodeConstants,
	WorkflowSmartNameDictionaryService) {

	"use strict";

	/**
	 * A router decorator to route on project field
	 * 
	 * @class
	 * @exports AttributeRouter
	 * @augments CaseSensitiveRouter
	 * 
	 * @param {WorkflowSmartNameDictionaryService} smartNameDictionary     - the smartname dictionary that can be used for smartnamerouterrule
	 * @param {DateSmartNameDictionaryService}     dateSmartNameDictionary - the smartname dicitionary that can be used for date smartnamerouterrules
	 */
	var ProjectFieldRouter = function (smartNameDictionary, dateSmartNameDictionary) {
		CaseSensitiveDecorator.call(this, WebCenterNodeConstants.RouterNode.Routers.ProjectField, i18n.t("router.projectfields"),
			smartNameDictionary, dateSmartNameDictionary);


		/**
		 * @member {Array.<RouterRule>}
		 * @private
		 */
		this._rules = [new RouterRule("RS_IS_EMPTY", i18n.t("wfui.route.ruleop.empty"), i18n.t("wfui.route.ruleop.empty"), this._smartNameDictionaryService),
			new SmartNameRouterRule("RS_IS_EQUAL", i18n.t("wfui.route.ruleop.equal"), i18n.t("wfui.route.ruleop.match"), this._smartNameDictionaryService),
			new SmartNameRouterRule("RS_IS_NOT_EQUAL", i18n.t("wfui.route.ruleop.noequal"), i18n.t("wfui.route.ruleop.nomatch"), this._smartNameDictionaryService, null, i18n.t("wfui.route.ruleop.prefix.not")),
			new SmartNameRouterRule("RS_CONTAINS", i18n.t("wfui.route.ruleop.contain"), i18n.t("wfui.route.ruleop.match"), this._smartNameDictionaryService),
			new SmartNameRouterRule("RS_DOES_NOT_CONTAIN", i18n.t("wfui.route.ruleop.nocontain"), i18n.t("wfui.route.ruleop.nomatch"), this._smartNameDictionaryService, null, i18n.t("wfui.route.ruleop.prefix.not")),
			new SmartNameRouterRule("RS_MATCHES", i18n.t("wfui.route.ruleop.match"), i18n.t("wfui.route.ruleop.match"), this._smartNameDictionaryService),
			new SmartNameRouterRule("RS_DOES_NOT_MATCH", i18n.t("wfui.route.ruleop.nomatch"), i18n.t("wfui.route.ruleop.nomatch"), this._smartNameDictionaryService, null, i18n.t("wfui.route.ruleop.prefix.not")),
			new SmartNameRouterRule("RS_BEGINS_WITH", i18n.t("wfui.route.ruleop.begins"), i18n.t("wfui.route.ruleop.match"), this._smartNameDictionaryService),
			new SmartNameRouterRule("RS_ENDS_WITH", i18n.t("wfui.route.ruleop.ends"), i18n.t("wfui.route.ruleop.match"), this._smartNameDictionaryService)
		];

		/**
		 * @member {Object} used to create the select for the project field
		 * @private
		 */
		this._options = [{
			id: "projname",
			label: i18n.t("projname")
		}, {
			id: "projdescr",
			label: i18n.t("projdescr")
		}, {
			id: "projmanager",
			label: i18n.t("projmanager")
		}, {
			id: "projsalesmgr",
			label: i18n.t("projsalesmgr")
		}, {
			id: "compname",
			label: i18n.t("compname")
		}, {
			id: "compLegalName",
			label: i18n.t("compLegalName")
		}, {
			id: "compShortName",
			label: i18n.t("compShortName")

		}, {
			id: "comploc",
			label: i18n.t("comploc")
		}];

		/**
		 * @member {JQueryObject}
		 * @private
		 */
		this._select = $("<select/>").addClass("form-control");

		// Add options to select
		_.each(this._options, function (option) {
			this._select.append($("<option/>").val(option.id).text(option.label));
		}, this);


		this._element.prepend($("<div/>").addClass("form-group")
			.append($("<label/>").text(i18n.t("wfui.route.field.label")))
			.append($("<div/>")
				.append(this._select)));


	};

	ProjectFieldRouter.prototype = Object.create(CaseSensitiveDecorator.prototype);
	ProjectFieldRouter.prototype.constructor = ProjectFieldRouter;

	/**
	 * @override
	 */
	ProjectFieldRouter.prototype.init = function () {
		this._routerView.getRouter().setRouterRules(this._rules);
	};

	/**
	 * @override
	 */
	ProjectFieldRouter.prototype.fillInParameter = function (routerParameter) {
		CaseSensitiveDecorator.prototype.fillInParameter.call(this, routerParameter);
		routerParameter.setRouterRuleType(WebCenterNodeConstants.RouterNode.RuleTypes.StringRule);
		routerParameter.setValue(this._select.val());
	};

	/**
	 * @override
	 * @param {RouterParameter} routerParameter 
	 */
	ProjectFieldRouter.prototype.handleParameter = function (routerParameter) {
		CaseSensitiveDecorator.prototype.handleParameter.call(this, routerParameter);
		if (routerParameter.getRouterType() === this.getId() && routerParameter.getValue()) {
			this._select.val(routerParameter.getValue());
		}
	};

	/**
	 * @override
	 */
	ProjectFieldRouter.prototype.disable = function () {
		CaseSensitiveDecorator.prototype.disable.call(this);
		this._select.attr("disabled", true);
	};


	return ProjectFieldRouter;
});