define(["underscore", "jquery", "utils/Observer"], function (_, $, Observer) {

	"use strict";

	/**
	 * View and controller of the rule of a route rentry
	 * @param {Router}      router      
	 * @param {RouterEntry} routerEntry 
	 */
	var RuleSelectorView = function (router, routerEntry) {
		Observer.mixin(this);

		/**
		 * @member {Router}
		 * 
		 */
		this._router = router;

		/**
		 * @member {RouterEntry}
		 * @private
		 */
		this._routerEntry = routerEntry;

		/**
		 * @member {JQueryObject}
		 * @private
		 */
		this._select = $("<select/>").addClass("form-control");

		/**
		 * @member {JQueryObject}
		 * @private
		 */
		this._selectDiv = $("<div/>").append(this._select);

		this._fillSelectWithRules();

		this._observe(router, "changed.rules", this._rulesChanged);

		this._observe(routerEntry, "changed.rule", function () {
			this._select.val(this._routerEntry.getRule().getType());
		});

		this._select.on("change", _.bind(function () {
			var rule = this._router.createNewRouterRule(this._select.val());
			// set the values of the previous rule to the new one
			rule.setValues(this._routerEntry.getRule().getValues());
			this._routerEntry.setRule(rule);
		}, this));

		if (this._routerEntry.getRule()) {
			this._select.val(this._routerEntry.getRule().getType());
		}
	};

	/**
	 * If the rules have changed, set the correct entries in the select s
	 */
	RuleSelectorView.prototype._rulesChanged = function () {
		this._select.empty();
		this._fillSelectWithRules();
		if (this._routerEntry.getRule()) {
			this._select.val(this._routerEntry.getRule().getType());
		}

	};

	/**
	 * fill the select with all available rules
	 */
	RuleSelectorView.prototype._fillSelectWithRules = function () {
		_.each(this._router.getRouterRules(), function (rule, index) {
			this._select.append($("<option/>").val(rule.getType()).text(rule.getLabel()));
		}, this);

	};

	/**
	 * @returns {JQueryObject}
	 */
	RuleSelectorView.prototype.getContext = function () {
		return this._selectDiv;
	};

	/**
	 * destroy the rule selector
	 */
	RuleSelectorView.prototype.destroy = function () {
		this._stopObserveAll();
	};

	/**
	 * enable ruleselector
	 */
	RuleSelectorView.prototype.enable = function () {
		this._select.attr("disabled", false);
	};

	/**
	 * disable ruleselector
	 */
	RuleSelectorView.prototype.disable = function () {
		this._select.attr("disabled", true);
	};

	return RuleSelectorView;
});
