define([
		"WFEditorWCR/workflow/node/WebCenterNode",
		"WFEditorWCR/workflow/node/WebCenterNodeConstants",
		"WFEditorWCR/workflow/pin/OutputPinOK",
		"WFEditorWCR/workflow/pin/WebCenterPinConstants",
		"tpl!WFEditorWCR/workflow/node/startNode/StartNode",
		"utils/webi18n!WFEditorWCR"
	],
	function (
		WebCenterNode,
		WebCenterNodeConstants,
		OutputPinOK,
		WebCenterPinConstants,
		StartNodeXML,
		i18n
	) {
		"use strict";

		/**
		 * StartNode represents the model for a  StartNode node in the WebCenter Workflow Editor.
		 *
		 * @exports StartNode
		 * @class
		 * @augments WebCenterNode
		 *
		 * @param {Wofkflow} workflow - the workflow to which the node belongs
		 * @param {String} id - node id
		 * @param {String} pathToIcons - gives the url to the map where the icons can be found
		 * @param {String} [label] - the label of the node
		 * @param {WebCenterAPI} webCenterAPI - used to access webcenter data                        
		 */
		var StartNode = function (workflow, id, pathToIcons, label, webCenterAPI) {
			var icon = WebCenterNodeConstants.Icons.START;
			if (!label) {
				label = i18n.t("Start");
			}
			WebCenterNode.call(this, workflow, id, WebCenterNodeConstants.Nodes.START, pathToIcons + icon, label, webCenterAPI);

		};

		StartNode.prototype = Object.create(WebCenterNode.prototype);
		StartNode.prototype.constructor = StartNode;


		/**
		 * @Override
		 */
		StartNode.prototype._initializePins = function () {
			this.addPin(new OutputPinOK(this._workflow, this, WebCenterPinConstants.Type.WorkflowConstructOK));
		};

		/**
		 * @Override
		 */
		StartNode.prototype.toXML = function () {
			return StartNodeXML(this);
		};

		/**
		 * @override
		 */
		StartNode.prototype.isRemovable = function () {
			return false;
		};
	
		/**
		 * @override
		 */
		StartNode.prototype.isCopyable = function () {
			return false;
		};

		return StartNode;
	});