define([
		"WFEditorWCR/workflow/node/WebCenterNode",
		"WFEditorWCR/workflow/node/WebCenterNodeConstants",
		"WFEditorWCR/workflow/pin/OutputPinOK",
		"WFEditorWCR/workflow/pin/OutputPinWarning",
		"WFEditorWCR/workflow/pin/OutputPinError",
		"WFEditorWCR/workflow/panel/WebCenterParameter",
		"utils/webi18n!WFEditorWCR"
	],
	function (
		WebCenterNode,
		WebCenterNodeConstants,
		OutputPinOK,
		OutputPinWarning,
		OutputPinError,
		WebCenterParameter,
		i18n
	) {
		"use strict";

		/**
		 * SubmitWorkflowNode represents the model for a SubmitWorkflow node in the WebCenter Workflow Editor.
		 *
		 * @exports SubmitWorkflowNode
		 * @class
		 * @augments WebCenterNode
		 *
		 * @param {Workflow} workflow - the workflow to which the node belongs
		 * @param {String} id - node id
		 * @param {ShapeUtils.Point} location - location of the node
		 * @param {String} icon - the url of the icon
		 * @param {String} [label] - the label of the node
		 * @param {WebCenterAPI} webCenterAPI - used to access webcenter data                        
		 */
		var SubmitWorkflowNode = function (workflow, id, icon, label, webCenterAPI) {
			WebCenterNode.call(this, workflow, id, WebCenterNodeConstants.Nodes.SUBMITWORKFLOW, icon, label, webCenterAPI);


		};

		SubmitWorkflowNode.prototype = Object.create(WebCenterNode.prototype);
		SubmitWorkflowNode.prototype.constructor = SubmitWorkflowNode;

		/**
		 * @override
		 */
		SubmitWorkflowNode.prototype.setNodeXML = function (nodeEl) {
			var params = nodeEl.querySelectorAll("action > parameters > parameter > Name");
			_.each(params, function (nameNode) {
				var name = nameNode.textContent;

				// Migrate public parameters to new checkboxes
				if (name === WebCenterNodeConstants.SubmitWorkflow.PUBLICPARAMETERS) {
					var publicParam = new WebCenterParameter(WebCenterNodeConstants.SubmitWorkflow.PUBLICPARAMETERS);
					publicParam.updateFromXML(nameNode.parentNode);

					if (publicParam.getValue() === "true") {
						// document properties
						this._migrateParameterToTrue(WebCenterNodeConstants.SubmitWorkflow.DOCUMENTPROPERTIES);
						// project properties
						this._migrateParameterToTrue(WebCenterNodeConstants.SubmitWorkflow.PROJECTPROPERTIES);
						// document attributes
						this._migrateParameterToTrue(WebCenterNodeConstants.SubmitWorkflow.DOCUMENTATTRIBUTES);
						// project attributes
						this._migrateParameterToTrue(WebCenterNodeConstants.SubmitWorkflow.PROJECTATTRIBUTES);
					}
				} else {
					var param = this.getConfigurationParameterByName(name);
					if (param) {
						param.updateFromXML(nameNode.parentNode);
					}
				}

			}, this);
		};

		/**
		 * Migrate one of the parameters with the given name to true
		 * @param {String} name - Name of the parameter to set to true
		 */
		SubmitWorkflowNode.prototype._migrateParameterToTrue = function (name) {
			var param = this.getConfigurationParameterByName(name);
			if (param) {
				param.setValue("true");
			}
		};

		return SubmitWorkflowNode;
	});