define([
		"WFEditorWCR/workflow/node/TokenMarkerSelectorNode",
		"WFEditorWCR/workflow/node/WebCenterNodeConstants",
		"WFEditorWCR/workflow/pin/OutputPinOK",
		"WFEditorWCR/workflow/pin/WebCenterPinConstants",
		"tpl!WFEditorWCR/workflow/node/tokenMarker/TokenMarkerNode"
	],
	function (
		TokenMarkerSelectorNode,
		WebCenterNodeConstants,
		OutputPinOK,
		WebCenterPinConstants,
		TokenMarkerNodeXML
	) {
		"use strict";

		/**
		 * TokenMarkerNode represents the model for a  TokenMarkerNode node in the WebCenter Workflow Editor.
		 *
		 * @exports TokenMarkerNode
		 * @class
		 * @augments TokenMarkerSelectorNode
		 *
		 * @param {Wofkflow} workflow - the workflow to which the node belongs
		 * @param {String} id - node id
		 * @param {String} pathToIcons - gives the url to the map where the icons can be found
		 * @param {String} label - the label of the node
		 * @param {WebCenterAPI} webCenterAPI - used to access webcenter data                        
		 */
		var TokenMarkerNode = function (workflow, id, pathToIcons, label, webCenterAPI) {
			var icon = WebCenterNodeConstants.Icons.TOKENMARKER;
			var nodeType = WebCenterNodeConstants.Nodes.TOKENMARKER;
			TokenMarkerSelectorNode.call(this, workflow, id, nodeType, pathToIcons, icon, label, webCenterAPI);
		};

		TokenMarkerNode.prototype = Object.create(TokenMarkerSelectorNode.prototype);
		TokenMarkerNode.prototype.constructor = TokenMarkerNode;

		/**
		 * @Override
		 */
		TokenMarkerNode.prototype.getActionXML = function () {
			return TokenMarkerNodeXML(this);
		};

		/**
		 * @override
		 */
		TokenMarkerNode.prototype._getMarkersSourceNodeType = function () {
			return WebCenterNodeConstants.Nodes.TOKENSELECTOR;
		};
	
		/**
		 * @override
		 */
		TokenMarkerNode.prototype.getHelpTopic = function () {
			return WebCenterNodeConstants.HelpTopics.MARK;
		};

		return TokenMarkerNode;
	});