define([
		"WFEditorWCR/workflow/node/TokenMarkerSelectorNode",
		"WFEditorWCR/workflow/node/WebCenterNodeConstants",
		"WFEditorWCR/workflow/pin/OutputPinOK",
		"WFEditorWCR/workflow/pin/WebCenterPinConstants",
		"tpl!WFEditorWCR/workflow/node/tokenSelector/TokenSelectorNode"
	],
	function (
		TokenMarkerSelectorNode,
		WebCenterNodeConstants,
		OutputPinOK,
		WebCenterPinConstants,
		TokenSelectorNodeXML
	) {
		"use strict";

		/**
		 * TokenSelectorNode represents the model for a  TokenSelectorNode node in the WebCenter Workflow Editor.
		 *
		 * @exports TokenSelectorNode
		 * @class
		 * @augments TokenMarkerSelectorNode
		 *
		 * @param {Wofkflow} workflow - the workflow to which the node belongs
		 * @param {String} id - node id
		 * @param {String} pathToIcons - gives the url to the map where the icons can be found
		 * @param {String} label - the label of the node
		 * @param {WebCenterAPI} webCenterAPI - used to access webcenter data   
		 */
		var TokenSelectorNode = function (workflow, id, pathToIcons, label, webCenterAPI) {
			var icon = WebCenterNodeConstants.Icons.TOKENSELECTOR;
			var nodeType = WebCenterNodeConstants.Nodes.TOKENSELECTOR;
			TokenMarkerSelectorNode.call(this, workflow, id, nodeType, pathToIcons, icon, label, webCenterAPI);
		};

		TokenSelectorNode.prototype = Object.create(TokenMarkerSelectorNode.prototype);
		TokenSelectorNode.prototype.constructor = TokenSelectorNode;

		/**
		 * @Override
		 */
		TokenSelectorNode.prototype.getActionXML = function () {
			return TokenSelectorNodeXML(this);
		};

		/**
		 * @override
		 */
		TokenSelectorNode.prototype._getMarkersSourceNodeType = function () {
			return WebCenterNodeConstants.Nodes.TOKENMARKER;
		};
	
		/**
		 * @override
		 */
		TokenSelectorNode.prototype.getHelpTopic = function () {
			return WebCenterNodeConstants.HelpTopics.SELECT;
		};

		return TokenSelectorNode;
	});