define(["underscore",
		"jquery",
		"WFEditor/workflow/panel/CompositePanelComponent",
		"WFEditorWCR/workflow/panel/StaticSDropPanel",
		"utils/webi18n!WFEditorDAMPushDocumentNode",
		"utils/webi18n!WFEditorWCR",
		"utils/Map",
		"utils/HTTPUtils",
		"WFEditorWCR/workflow/panel/WorkflowSmartNameDictionaryService"
	],
	function (_,
		$,
		CompositePanelComponent,
		StaticSDropPanel,
		i18n,
		i18nWFEditor,
		Map,
		HTTPUtils,
		WorkflowSmartNameDictionaryService) {

		"use strict";

		var WFCONFIGJS = "wfConfigJS";
		var WFCONFIGHTML = "wfConfigHTML";

		var DAMCONPARAMETER = "pushtodam.damconnection";
		var DAMCONPARAMETERDATA = "pushtodam.damconnection.data";
		/**
		 * TODO: I do not want to put this in WebCenterAPI as most often it will not be used. However. Putting it here will
		 * make the connections be the same cross browser tab. So refreshing the page in one browser tab will not refresh
		 * the data. to be decided how to do this best
		 *
		 */
		var damConnectionsPromise = null;

		var getDAMConnectionsPromise = function (webCenterAPI, errorHandler) {
			if (!damConnectionsPromise) {
				var deferred = $.Deferred();
				var url = webCenterAPI.constructURL("DamConnectionServlet.wcr", {
					action: "info",
					addActions: true
				});
				$.get(url).done(function (data) {
                    if(data.error && data.error.msg){
                        errorHandler.severe(data.error.msg);
                    }else{
                        var map = new Map();
                        _.each(data.result.dams, function (dam) {
                            map.add(dam.id, dam);
                            dam.getName = function () {
                                return dam.name;
                            };

                        });
                        deferred.resolve(map);
                    }
				});

				damConnectionsPromise = deferred.promise();
			}
			return damConnectionsPromise;
		};


		/**
		 * @class
		 * @augments CompostiePanelComponent
		 * @param {String} paramId
		 * @param {String} name
		 * @param {WebCenterAPI} webCenterAPI
		 * @param {Array} customSmartNames
		 * @param {WFEditorContext} context
		 */
		var DAMPushDocument = function (webCenterAPI, taskTypeID, nodeXML, customSmartNames, context) {
			CompositePanelComponent.call(this, [DAMCONPARAMETER, DAMCONPARAMETERDATA]);

			this._currentDAMHandler = null;
            
            this._errorHandler = context.get("errorHandler");

			this._promise = getDAMConnectionsPromise(webCenterAPI, this._errorHandler);

            
			this._customSmartNames = customSmartNames;
			this._taskTypeID = taskTypeID;

			this.add(this._getStaticSDrop(DAMCONPARAMETER));

			this._webCenterAPI = webCenterAPI;
			this._webCenterBaseUrl = webCenterAPI.getWebCenterConfig().webInstAbsPath;

			this._damConnectionConfigContainer = $("<div/>");
			this._loadingIndicator = $("<div/>").text(i18nWFEditor.t("loading")).hide();
			this._element.append(this._damConnectionConfigContainer);
			this._element.append(this._loadingIndicator);
			this._element.addClass("parameter-panel form-compact form-horizontal");
		};

		DAMPushDocument.prototype = Object.create(CompositePanelComponent.prototype);
		DAMPushDocument.prototype.constructor = DAMPushDocument;

		/**
		 * @override
		 */
		DAMPushDocument.prototype.setParameters = function (parameters) {
			CompositePanelComponent.prototype.setParameters.call(this, parameters);
			var param = this.getParameterByName(DAMCONPARAMETER);
			var dataParam = this.getParameterByName(DAMCONPARAMETERDATA);
			if (param.getValue()) {
				var data;
				try {
					data = JSON.parse(dataParam.getValue());
				} catch (e) {
					data = {};
				}
				this._onDAMConnectionChange(param.getValue(), data);
			}

		};

		/**
		 * Called when the dam connection has changegd
		 */
		DAMPushDocument.prototype._onDAMConnectionChange = function (damid, data) {
			getDAMConnectionsPromise().done(_.bind(function (map) {
				var dam = map.get(damid);
				var defaultData = {};
				if(this._currentDAMHandler && this._currentDAMProvider == dam.provider) {
					defaultData = this._currentDAMHandler.getData();
				}
				this._damConnectionConfigContainer.empty();

				this._setConfigForDAM(this._damConnectionConfigContainer, dam, data || defaultData);
			}, this));
		};

		/**
		 * requires the correct content for the popup from the actions
		 * @param {$} container
		 * @param {Object} dam
		 * @param {Object} data
		 */
		DAMPushDocument.prototype._setConfigForDAM = function (container, dam, data) {

			if (dam.actions) {
				var dependencies = [];

				if (dam.actions[WFCONFIGHTML]) {
					if (dam.actions[WFCONFIGHTML].indexOf("/") !== 0) {
						dam.actions[WFCONFIGHTML] = this._webCenterBaseUrl + "/" + dam.actions[WFCONFIGHTML];
					}
					dependencies.push("lib/text!" + dam.actions[WFCONFIGHTML]);
				} else {
					dependencies.push("");
				}


				if (dam.actions[WFCONFIGJS]) {
					if (dam.actions[WFCONFIGJS].indexOf("/") !== 0) {
						dam.actions[WFCONFIGJS] = this._webCenterBaseUrl + "/" + dam.actions[WFCONFIGJS];
					}
					dependencies.push(dam.actions[WFCONFIGJS]);
				} else {
					dependencies.push("");
				}

				this._loadingIndicator.show();
				requirejs(dependencies, _.bind(function (configHTML, ConfigJS) {
					this._loadingIndicator.hide();
					var param = this.getParameterByName(DAMCONPARAMETER);
					if (dam.id === param.getValue()) {

						if (configHTML) {
							container.html(configHTML);
						}

						var api = this._createAPI(dam);

						if (ConfigJS) {
							var config = new ConfigJS(api);
							this._currentDAMHandler = config;
							this._currentDAMProvider = dam.provider;
							config.init(container, data);
							if(!this._isEnabled) {
								config.disable();
							}
						} else {
							this._currentDAMProvider = null;
							this._currentDAMHandler = null;
						}
						this._fitContent();
					}
				}, this));
				this._fitContent();

			}


		};


		DAMPushDocument.prototype._createAPI = function (dam) {
			return {
				getWorkflowDictionaryService: _.bind(function () {
					return new WorkflowSmartNameDictionaryService(this._webCenterAPI, this._taskTypeID, this._customSmartNames);
				}, this),
				getDAMName : function () {
					return dam.name;
				}
			};
		};

		/**
		 * returns an sdrop containing all the DAMs and overrides the onChangedByUser function to make sure the
		 * correct dam content is called.
		 */
		DAMPushDocument.prototype._getStaticSDrop = function (paramId) {
			var panel = new StaticSDropPanel(paramId, i18n.t(paramId), "", this._promise);
			panel._onChangedByUser = _.partial(function (dAMPushDocumentPanel) {
				StaticSDropPanel.prototype._onChangedByUser.call(this);
				var damConParam = dAMPushDocumentPanel.getParameterByName(paramId);
				dAMPushDocumentPanel.getParameterByName(DAMCONPARAMETERDATA).setValue("{}");
				dAMPushDocumentPanel._onDAMConnectionChange(damConParam.getValue());
			}, this);
			return panel;
		};

		DAMPushDocument.prototype.getParameters = function () {
			var params = CompositePanelComponent.prototype.getParameters.call(this);
			var DAMData = this._currentDAMHandler ? this._currentDAMHandler.getData() : {};
			var dataParam = this.getParameterByName(DAMCONPARAMETERDATA);
			try {
				dataParam.setValue(JSON.stringify(DAMData));
			} catch (exception) {
				dataParam.setValue("{}");
			}
			return params;
		};
		
		/**
		 * Get a width that can show the metadata mapping properly
		 * @returns {Number}
		 */
		DAMPushDocument.prototype.getPreferredWidth = function(){
			if(this._currentDAMHandler && this._currentDAMHandler.getPreferredWidth){
				return this._currentDAMHandler.getPreferredWidth();
			}
			
			return CompositePanelComponent.prototype.getPreferredWidth();
		};
	
		/**
		 * @override
		 */
		DAMPushDocument.prototype.disable = function () {
			CompositePanelComponent.prototype.disable.call(this);
			if(this._currentDAMHandler && this._currentDAMHandler.disable) {
				this._currentDAMHandler.disable();
			}
		};



		return DAMPushDocument;

	});
