define(["WFEditor/workflow/panel/AbstractPanelComponent", "jquery", "underscore"],
	function (AbstractPanelComponent, $, _) {

		"use strict";

		/**
		 * A Panel for displaying a dropdown element	
		 * @class
		 * @exports DropdownPanel
		 * @augments PanelComonent
		 * 
		 * @param {String} parameterId - id of the parameter for this panel
		 * @param {String} label       - label to be displayed
		 */
		var DropdownPanel = function (parameterId, label) {
			AbstractPanelComponent.call(this, [parameterId]);

			/**
			 * @member {JQueryObject} label
			 * @private
			 */
			this._label = $('<label/>').addClass("col-sm-12 col-lg-3").text(label);

			/* 
			 * @member {Array.<Object>} list of options
			 * @protected 
			 */
			this._options = [];

			/**
			 * @member {JQueryObject} read only span
			 * @private
			 */
			this._dropdown = $('<select/>').addClass('form-control').on("change", _.bind(function () {
				if (this._parameters[0]) {
					this._parameters[0].setValue(this._dropdown.val());
				}
			}, this));

			this._dropdownWrapper = $("<div>").addClass("col-sm-12 col-lg-9").append(this._dropdown);

			this._element.append(this._label).append(this._dropdownWrapper);
			this._element.addClass('form-group');

			this._updateDropdown();
		};

		DropdownPanel.prototype = Object.create(AbstractPanelComponent.prototype);
		DropdownPanel.prototype.constructor = DropdownPanel;

		/**
		 * @override
		 */
		DropdownPanel.prototype.setParameters = function (parameters) {
			AbstractPanelComponent.prototype.setParameters.call(this, parameters);
			var param = parameters[0];
			if (param) {
				this._dropdown.val(param.getValue());
			}
		};

		/**
		 * Set the options of the dropdown
		 * @param {Array.<Object>} options - plain object with value and label properties
		 */
		DropdownPanel.prototype.setOptions = function (options) {
			this._options = options;
			this._updateDropdown();
		};

		/**
		 * Get the options
		 * @returns {Array} 
		 */
		DropdownPanel.prototype._getOptions = function () {
			return this._options;
		};

		/**
		 * Update the dropdown
		 */
		DropdownPanel.prototype._updateDropdown = function () {
			var value = this._dropdown.val();
			if (!value && this._parameters && this._parameters[0]) {
				value = this._parameters[0].getValue();
			}
			this._dropdown.detach(); // detach from DOM to avoid constant layout updates while updating the dropdown
			this._dropdown.empty();

			_.each(this._getOptions(), function (option) {
				this._dropdown.append($("<option>").val(option.value).text(option.label));
			}, this);
			this._dropdown.val(value);
			this._dropdown.appendTo(this._dropdownWrapper);
		};

		/**
		 * @override
		 */
		DropdownPanel.prototype.disable = function () {
			AbstractPanelComponent.prototype.disable.call(this);
			this._dropdown.attr("disabled", true);
		};

		return DropdownPanel;

	});