define(["WFEditor/workflow/panel/AbstractPanelComponent",
		"WFEditorWCR/workflow/panel/WebCenterParameter",
		"jquery",
		"underscore",
		"component/javascripteditor/javascripteditor"
	],
	function (AbstractPanelComponent,
		WebCenterParameter,
		$,
		_,
		JavaScriptEditor) {

		"use strict";


		/**
		 * @class
		 * @exports JavaScriptPanel
		 * @augments PanelComonent
		 * 
		 * A JavaScript panel
		 * 
		 * @param {String} parameterId - id of the parameter for this panel
		 * @param {String} label       - label to be displayed
		 * @param {Object} options     - options for the panel. 
		 *                             Currently supported: {Number} maxScriptLength;
		 */
		var JavaScriptPanel = function (parameterId, label, options) {
			AbstractPanelComponent.call(this, [parameterId]);

			/**
			 * @member {Object} options
			 * @private
			 */
			this._options = _.extend({}, options);

			/**
			 * @member {String} the parameterId used by this panel
			 */
			this.parameterId = parameterId;

			/**
			 * @member {JQueryObject} label
			 * @private
			 */
			this._label = $('<label/>').addClass("col-sm-12 col-lg-3").text(label);

			/**
			 * @member {JQueryObject} editor div
			 * @private
			 */
			this._editorDiv = $('<input/>').addClass("col-sm-12 col-lg-12");
			this._element.append(this._editorDiv);

			this._element.addClass('form-group');
		};

		JavaScriptPanel.prototype = Object.create(AbstractPanelComponent.prototype);
		JavaScriptPanel.prototype.constructor = JavaScriptPanel;


		/**
		 * Function is called when constructor is done
		 * @override
		 */
		JavaScriptPanel.prototype.init = function () {
			//call the editor
			var script = this.getParameterByName(this.parameterId).getValue();
			this._editor = new JavaScriptEditor(this._editorDiv, script, {
				maxScriptLength: this._options.maxScriptLength,
				scrollbarVisibilityChanged: _.bind(this.resize, this),
			});

			//remove ugly white space
			var formGroup = this._element.closest(".form-group");
			formGroup.css("margin-bottom", "0");
			formGroup.parent().css("margin", "0");
			this._element.closest(".wfeditor-node-configuration").css("margin", "0");

			//remove the default webcenter popup scrollbar
			this._element.closest(".wfeditor-popup-content").css("overflow", "hidden");

			this._editor.saveChangesTo(this.getParameterByName(this.parameterId));
		};

		/**
		 * Handles the resize event
		 * @override
		 */
		JavaScriptPanel.prototype.resize = function () {
			var parent = this._element.closest(".wfeditor-popup-content");
			var newHeight = $(parent).height();
			this._editor.resize(newHeight);
		};

		/**
		 * this method is called right before the panel is removed from the dom
		 * @override
		 */
		JavaScriptPanel.prototype.destroy = function () {
			this._editor.destroy();
		};

		/**
		 * @override
		 */
		JavaScriptPanel.prototype.validate = function () {
			return this._editor.validate();
		};

		return JavaScriptPanel;

	});