define(["WFEditorWCR/workflow/panel/WebCenterParameter"], function (WebCenterParameter) {

	"use strict";

	/**
	 * This parameterclass can be used for parameters that enable/disable an outputpin if it is chosen in fe. a radio checkbox
	 * @class
	 * @augments WebCenterParameter
	 * @exports PinParameter
	 * @param {String} name - id of the parameter
	 * @param {String} defaultValue
	 * @param {String} [value]
	 * @param {Array.<Parameter>} subparameters
	 * @param {Function} pinFactory - function that returns a Pin
	 */
	var PinParameter = function (name, defaultValue, value, subparameters, pinFactory) {
		WebCenterParameter.call(this, name, defaultValue, value, subparameters);

		/**
		 * @member {Function.<Pin>}
		 * @private
		 */
		this._pinFactory = pinFactory;
		
		/**
		 * @member {Pin}
		 * @private
		 */	
		this.pins = pinFactory();

	};

	PinParameter.prototype = Object.create(WebCenterParameter.prototype);
	PinParameter.prototype.constructor = PinParameter;

	/**
	 * @override
	 */
	PinParameter.prototype.copy = function () {
		var copiedSubparams = [];
		_.each(this._subparameters, function (subParam) {
			copiedSubparams.push(subParam.copy());
		});		
		var param = new PinParameter(this._name, this._defaultValue, this._value, copiedSubparams, this._pinFactory);
		param.pins = this.pins;
		return param;
	};
	
	/**
	 * sets a new pin.
	 */
	PinParameter.prototype.setNewPin = function () {
		this.pins = this._pinFactory();
	};

	return PinParameter;

});
