define(["WFEditorWCR/workflow/panel/WebCenterCompositePanelComponent",
		"utils/Observable",
		"underscore"
	],
	function (WebCenterCompositePanelComponent, Observable, _) {

		"use strict";

		/**
		 * @class
		 * @exports RadioPanel
		 * @augments CompositePanelComponent
		 * Composite Panel Component used as a radio button in a radio group panel
		 * @param {String} parameterId 
		 * @param {String} label - used to display as a label	
		 */
		var RadioPanel = function (parameterId, label) {
			Observable.mixin(this, "RadioComponent." + parameterId);
			WebCenterCompositePanelComponent.call(this, [parameterId]);

			/**
			 * @member {String} id of the parameter
			 * @private
			 */
			this._paramId = parameterId;

			/**
			 * @member {JqueryObject} label
			 * @private
			 */
			this._label = $('<label/>');

			/**
			 * @member {JqueryObject} radio button
			 * @private
			 */
			this._radio = $('<input type="radio"/>').on('change', _.bind(function () {
				this._emit("checked", this);
			}, this));

			this._label.append(this._radio);
			if (label.indexOf("\n") >= 0) {
				var labelArray = label.split("\n");
				$.each(labelArray, _.bind(function (index, value) {
					this._label.append(value + "<br/>");
				}, this));

			} else {
				this._label.append(label);
			}

			/**
			 * @member {JqueryObject} div for all child sub panels
			 * @private	
			 */
			this._childDiv = $('<div class="child-panel col-sm-12 col-lg-12"/>');

			this._element.append($('<div class="radio col-sm-12"/>').append(this._label)).append(this._childDiv);
			this._element.addClass('form-group radio-panel');
		};

		RadioPanel.prototype = Object.create(WebCenterCompositePanelComponent.prototype);
		RadioPanel.prototype.constructor = RadioPanel;

		/**
		 * gets the parameter id of this panel
		 * @returns {String}
		 */
		RadioPanel.prototype.getParamId = function () {
			return this._paramId;
		};

		/**
		 * (un)check the radio button and show/hide the child div
		 * @param {Boolean} check                 
		 * @param {Boolean} visibleWhenNotChecked 
		 */
		RadioPanel.prototype.check = function (check, visibleWhenNotChecked) {
			this._radio.prop('checked', check);
			if (!check && !visibleWhenNotChecked) {
				_.each(this._subPanels, function (panel) {
					panel.hide();
					panel.setNotApplicable();
				});
				this._childDiv.hide();
				this._element.removeClass("has-children");
			} else {
				_.each(this._subPanels, function (panel) {
					panel.show();
					panel.setApplicable();
				});
				if (_.size(this._subPanels) > 0) {
					this._element.addClass("has-children");
				}
				this._childDiv.show();
			}

		};

		/**
		 * @override
		 */
		RadioPanel.prototype.add = function (panelComponent) {
			this._subPanels.push(panelComponent);
			this._childDiv.append(panelComponent.getContext());
			this._element.addClass("has-children");

			this._fixLabels(this._childDiv, this._subPanels);
		};

		/**
		 * @override
		 */
		RadioPanel.prototype.disable = function () {
			WebCenterCompositePanelComponent.prototype.disable.call(this);
			this._radio.attr("disabled", true);
		};



		return RadioPanel;

	}
);