define(["WFEditor/workflow/panel/AbstractPanelComponent",
		"jquery",
		"underscore"
	],
	function (AbstractPanelComponent,
		$,
		_) {

		"use strict";

		/**
		 * @class
		 * @exports ReadOnlyStringPanel
		 * @augments PanelComonent
		 * 
		 * A read only panel
		 * 
		 * @param {String} parameterId - id of the parameter for this panel
		 * @param {String} label       - label to be displayed
		 */
		var ReadOnlyStringPanel = function (parameterId, label) {
			AbstractPanelComponent.call(this, [parameterId]);

			/**
			 * @member {JQueryObject} label
			 * @private
			 */
			this._label = $('<label/>').addClass("col-sm-12 col-lg-3").text(label);

			/**
			 * @member {JQueryObject} read only span
			 * @private
			 */
			this._valueDiv = $('<div/>').addClass('read-only-string col-sm-12 col-lg-9');

			this._element.append(this._label).append(this._valueDiv);

			this._element.addClass('form-group');

		};

		ReadOnlyStringPanel.prototype = Object.create(AbstractPanelComponent.prototype);
		ReadOnlyStringPanel.prototype.constructor = ReadOnlyStringPanel;

		/**
		 * @override
		 */
		ReadOnlyStringPanel.prototype.setParameters = function (parameters) {
			AbstractPanelComponent.prototype.setParameters.call(this, parameters);
			var param = parameters[0];
			if (param) {
				this._valueDiv.text(param.getValue());
			}
		};

		return ReadOnlyStringPanel;

	});