define(["WFEditor/workflow/panel/AbstractPanelComponent",
        "component/sdrop/SDrop",
		"jquery",
		"underscore"
	],
	function (AbstractPanelComponent,
		SDrop,
		$, 
		_) {

		"use strict";

		/**
		 * A panel containing an SDrop
		 * @class
		 * @exports SDropPanel
		 * @augments PanelComonent
		 *             
		 * @param {String} parameterId - id of the parameter for this panel
		 * @param {String} label       - label to be displayed
		 */
		var SDropPanel = function (parameterId, label) {
			AbstractPanelComponent.call(this, [parameterId]);

			/**
			 * @member {JQueryObject} label
			 * @private
			 */
			this._label = $('<label/>').addClass("col-sm-12 col-lg-3").text(label);

			/**
			 * @member {SDrop} sdrop
			 */
			this._sdrop = null;

			/**
			 * @member {JQueryObject} read only span
			 * @private
			 */
			this._dropdown = $('<select/>');
			this._element.append(this._label).append($("<div>").addClass("col-sm-12 col-lg-9").append(this._dropdown));
			this._element.addClass('form-group');
		};

		SDropPanel.prototype = Object.create(AbstractPanelComponent.prototype);
		SDropPanel.prototype.constructor = SDropPanel;

		/**
		 * @override
		 */
		SDropPanel.prototype.setParameters = function (parameters) {
			AbstractPanelComponent.prototype.setParameters.call(this, parameters);
			var param = parameters[0];
			if (param) {
				if (this._sdrop) {
					this._sdrop.setSelectedItemByID(param.getValue());
				} else {
					this._dropdown.val(param.getValue());
				}
			}
		};

		/**
		 * Get the DataProvider 
		 * @returns {SDropDataProvider}
		 */
		SDropPanel.prototype._getDataProvider = function () {
			throw new Error("IMPLEMENT");
		};

		/**
		 * Initialize the SDrop instance
		 */
		SDropPanel.prototype.init = function () {
			var initialValue = null;
			if (this._parameters && this._parameters[0]) {
				initialValue = this._parameters[0].getValue();
			}

			this._sdrop = new SDrop(this._dropdown, null, this._getDataProvider(), {
				onChangedByUser: _.bind(this._onChangedByUser, this),
				initialValue: initialValue,
				autoload: true, // needs autoload for undo/redo
				autoloadOnFirstUsage: true,
				manageStyleAndWidth: false
			});

			if (!this._isEnabled) {
				this._element.find(".sdrop").addClass("disabled");
			}
		};

		SDropPanel.prototype._onChangedByUser = function() {
			this._parameters[0].setValue(this._dropdown.val());
		};
	
		/**
		 * @Override
		 */
		SDropPanel.prototype.destroy = function () {
			AbstractPanelComponent.prototype.destroy.call(this);

			if (this._sdrop) {
				this._sdrop.destroy();
			}
		};


		/**
		 * Get the options
		 * @returns {Array} [[Description]]
		 */
		SDropPanel.prototype._getOptions = function () {
			return [];
		};

		/**
		 * Make sure the sdrop is closed when the user starts dragging or resizing
		 * @override
		 */
		SDropPanel.prototype.startInteractive = function () {
			if (this._sdrop) {
				this._sdrop.disable(null, true);
			}
		};

		/**
		 * @override
		 */
		SDropPanel.prototype.disable = function () {
			AbstractPanelComponent.prototype.disable.call(this);
			if (this._sdrop) {
				this._sdrop.setDisabled(true);
			}
		};

		return SDropPanel;

	});
