define(["WFEditor/workflow/panel/AbstractPanelComponent",
		"jquery",
		"underscore"
	],
	function (AbstractPanelComponent,
		$,
		_) {

		"use strict";

		/**
		 * @class
		 * @exports SecretPanel
		 * @augments PanelComonent
		 * 
		 * A panel that displays the contents as a password field
		 * 
		 * @param {String} parameterId - id of the parameter for this panel
		 * @param {String} label       - label to be displayed
		 */
		var SecretPanel = function (parameterId, label) {
			AbstractPanelComponent.call(this, [parameterId]);

			/**
			 * @member {JQueryObject} label
			 * @private
			 */
			this._label = $('<label/>').addClass("col-sm-12 col-lg-3").text(label);

			/**
			 * @member {JQueryObject} input field for password
			 * @private
			 */
			this._input = $('<input type="password" class="form-control"/>');

			this._input.on('change', _.bind(function () {
				if (this._parameters[0]) {
					this._parameters[0].setValue(this._input.val());
				}
			}, this));

			this._element.append(this._label).append($("<div>").addClass("col-sm-12 col-lg-9").append(this._input));

			this._element.addClass('form-group');

		};

		SecretPanel.prototype = Object.create(AbstractPanelComponent.prototype);
		SecretPanel.prototype.constructor = SecretPanel;

		/**
		 * @override
		 */
		SecretPanel.prototype.setParameters = function (parameters) {
			AbstractPanelComponent.prototype.setParameters.call(this, parameters);
			var param = parameters[0];
			if (param) {
				this._input.val(param.getValue());
			}
		};

		/**
		 * @override
		 */
		SecretPanel.prototype.disable = function () {
			AbstractPanelComponent.prototype.disable.call(this);
			this._input.attr("disabled", true);
		};

		return SecretPanel;

	});