define(["WFEditorWCR/workflow/panel/SDropPanel",
		"component/sdrop/dataproviders/MapPromiseDataProvider",
		"jquery",
		"underscore",
		"wcr/sdrop"],
	function (SDropPanel,
		MapPromiseDataProvider,
		$,
		_) {

		"use strict";



		/**
		 * @class
		 * @exports SDropPanel
		 * @augments PanelComonent
		 * 
		 * A read only panel
		 * 
		 * @param {String}        parameterId  - id of the parameter for this panel
		 * @param {String}        label        - label to be displayed
		 * @param {String}        defaultValue - default value of the parameter
		 * @param {Promise.<Map>} promise	   - data promise for the sdrop
		 * @param {Function}      [sortMethod] - sorting function  for the sdrop results
		 * @param {String}	      nameGetter   - Function name to get the name of an item in the resulting map                                   
		 */
		var StaticSDropPanel = function (parameterId, label, defaultValue, promise, sortMethod, nameGetter) {
			SDropPanel.call(this, parameterId, label, defaultValue);

			this._dataProvider = null;

			if (!nameGetter) {
				nameGetter = "getName";
			}

			this._dataproviderOptions = {
				nameGetter: nameGetter,
				promise: promise
			};

			if (sortMethod) {
				this._dataproviderOptions.sortMethod = sortMethod;
			}
		};

		StaticSDropPanel.prototype = Object.create(SDropPanel.prototype);
		StaticSDropPanel.prototype.constructor = StaticSDropPanel;


		/**
		 * Initialize the StaticList DataProvider 
		 * @override
		 */
		StaticSDropPanel.prototype._getDataProvider = function () {
			if (!this._dataProvider) {
				this._dataProvider = new MapPromiseDataProvider(this._dataproviderOptions);
			}

			return this._dataProvider;
		};





		return StaticSDropPanel;

	});