define(["WFEditor/workflow/panel/CompositePanelComponent"
	],
	function (CompositePanelComponent) {

		"use strict";

		/**
		 * @class
		 * @exports {TabbedPanel}
		 * @augments CompositePanelComponent
		 * 
		 * A Panel Component that will generate sub abstractPanelComponents as tabs. Expects the sub abstractPanelComponents to be TabPanels
		 * 
		 * @param {Array.<String>} parameters
		 */
		var TabbedPanel = function (parameters) {
			CompositePanelComponent.call(this, parameters);

			/**
			 * @member {JQueryObject} UL of all tabgs 
			 * @private
			 */
			this._tabs = $('<ul/>').addClass("nav nav-tabs tabbed-panel-tabs");

			/**
			 * @member {JQueryObject} current active tab 
			 * @private
			 */
			this._currentTab = $('<div />');

			this._element.append(this._tabs);
			this._element.append(this._currentTab);
		};

		TabbedPanel.prototype = Object.create(CompositePanelComponent.prototype);
		TabbedPanel.prototype.constructor = TabbedPanel;

		/**
		 * @override
		 * @param {TabPanel} abstractPanelComponent
		 */
		TabbedPanel.prototype.add = function (abstractPanelComponent) {
			this._subPanels.push(abstractPanelComponent);

			// create a tab
			var li = $('<li/>').addClass("tabbed-panel-tab");
			li.append($("<a src='#' />").text(abstractPanelComponent.getName()));

			// on click set the right panel to active
			li.on('click', _.partial(function (tabbedPanel) {
				if (!$(this).hasClass('active')) {
					tabbedPanel._tabs.find('.active').removeClass('active');
					$(this).addClass('active');
					_.each(tabbedPanel._subPanels, function (tab) {
						tab.hide();
					});
					abstractPanelComponent.show();

					tabbedPanel._fitContent();
				}
			}, this));


			// add the tab
			this._tabs.append(li);
			this._currentTab.append(abstractPanelComponent.getContext());
			if (this._subPanels.length === 1) {
				li.addClass('active');
				abstractPanelComponent.show();
			} else {
				abstractPanelComponent.hide();
			}

		};

		/**
		 * @override
		 */
		TabbedPanel.prototype.getPreferredWidth = function () {
			var tabsWidth = 0;
			this._tabs.find("li.tabbed-panel-tab").each(function () {
				tabsWidth += $(this).width();
			});
			tabsWidth += 2;
			var contentWidth = CompositePanelComponent.prototype.getPreferredWidth.call(this);
			return tabsWidth > contentWidth ? tabsWidth : contentWidth;
		};

		return TabbedPanel;

	}
);