define(["WFEditor/workflow/panel/AbstractPanelComponent",
		"component/inputDropdown/InputDropdown",
		"utils/Observer",
		"jquery",
		"underscore"
	],
	function (AbstractPanelComponent,
		InputDropdown,
		Observer,
		$,
		_) {

		"use strict";

		/**
		 * @class
		 * @exports {TagSelectPanel}
		 * @augments AbstractPanelComponent
		 * 
		 * A Panel Component that allows to select a tag
		 * 
		 * @param {String} parameterId     - Id of the parameter this panel belongs to
		 * @param {String} label - Label to show next to the tag selector
		 */
		var TagSelectPanel = function (parameterId, label) {
			AbstractPanelComponent.call(this, [parameterId]);

			Observer.mixin(this);

			this._inputDropdownWrapper = $("<div />").addClass("col-sm-12");

			this._inputDropdown = new InputDropdown({hideOnInputFocus: true});
			this._observe(this._inputDropdown, "changed.value", function (value) {
				if (this._parameters[0]) {
					this._parameters[0].setValue(value);
				}
			});
			this._observe(this._inputDropdown, "new.input", function (value) {
				if (this._parameters[0]) {
					this._parameters[0].setValue(value);
				}
			});

			this._inputDropdownWrapper.append(this._inputDropdown.getElement());

			this._label = $('<label/>').addClass("col-sm-12").text(label);

			this._element.addClass("form-group").append(this._label).append(this._inputDropdownWrapper);
		};

		TagSelectPanel.prototype = Object.create(AbstractPanelComponent.prototype);
		TagSelectPanel.prototype.constructor = TagSelectPanel;

		/**
		 * @override
		 */
		TagSelectPanel.prototype.init = function () {
			// Let the dropdown flow over the popup
			var popupContent = this._element.parents(".wfeditor-popup-content");
			if (_.size(popupContent) === 1) {
				$(popupContent[0]).css("overflow", "visible");
			}
		};

		/**
		 * Set all tag options
		 * @param {Array.<String>} tag options
		 */
		TagSelectPanel.prototype.setOptions = function (options) {
			this._inputDropdown.setOptions(options);
		};

		/**
		 * @override
		 */
		TagSelectPanel.prototype.setParameters = function (parameters) {
			AbstractPanelComponent.prototype.setParameters.call(this, parameters);
			var param = parameters[0];
			if (param) {
				this._inputDropdown.val(param.getValue());
			}
		};

		/**
		 * @override
		 */
		TagSelectPanel.prototype.disable = function () {
			AbstractPanelComponent.prototype.disable.call(this);
			this._inputDropdown.disable();
		};

		return TagSelectPanel;

	}
);