define(["underscore", "jquery", "WFEditorWCR/workflow/panel/MultiAttributePanel", "utils/webi18n!WFEditorWCR"], function (_, $, MultiAttributePanel, i18n) {

	"use strict";

	/**
	 * A panel to set the task specifications of a task type node 
	 *
	 * @class
	 * @augments MultiAttributePanel
	 * @exports TaskSpecificationsPanel
	 * @param {String}                             parameterId  	          - id of the parameter for this panel
	 * @param {String}                             label                      - label to be displayed
	 * @param {WorkflowSmartNameDictionaryService} smartNameDictionaryService - the smartname dictionary for smartnames in value fields
	 * @param {WorkflowSmartNameDictionaryService} smartNameDictionaryService - the smartname dictionary for date attributes
	 * @param {WebCenterAPI}                       webCenterAPI	              - webcenter interface
	 * @param {Promise}                            restriction	              - the promise for the specifications
	 */
	var TaskSpecificationsPanel = function (parameterId, nameLabel, valueLabel, smartNameDictionaryService, dateSmartNameDictionaryService, webCenterAPI, restriction) {
		MultiAttributePanel.call(this, parameterId, nameLabel, valueLabel, smartNameDictionaryService, dateSmartNameDictionaryService, webCenterAPI, true, restriction);

		/**
		 * @override
		 */
		this._parameterWishList = [parameterId, "task.failifexists"];

		/**
		 * @member {String}
		 * @private
		 */
		this._parameterId = parameterId;

		/**
		 * @member {WebCenterParameter}
		 * @private
		 */
		this._failIfExisits = null;

		/**
		 * @param {JQueryObject}
		 * @private
		 */
		this._checkbox = $("<input type='checkbox' />");

		/**
		 * @param {JQueryObject}
		 * @private
		 */
		this._checkboxDiv = $("<div/>").addClass("checkbox");

		this._checkbox.on("change", _.bind(function () {
			this.getParameterByName(this._parameterId).shouldAddNotSelectedSpecifications(this._checkbox.prop("checked"));
		}, this));

		this._element.append(
			this._checkboxDiv
			.append($("<label/>")
				.append(this._checkbox)
				.append(i18n.t("task.guidescription.specifications.info"))));

	};

	TaskSpecificationsPanel.prototype = Object.create(MultiAttributePanel.prototype);
	TaskSpecificationsPanel.prototype.constructor = TaskSpecificationsPanel;

	/**
	 * @override
	 */
	TaskSpecificationsPanel.prototype.setParameters = function (parameters) {
		var myParmeter = _.find(parameters, function (param) {
			return param.getName() === this._parameterId;
		}, this);
		this._failIfExisits = _.find(parameters, function (param) {
			return param.getName() === "task.failifexists";
		}, this);
		MultiAttributePanel.prototype.setParameters.call(this, [myParmeter]);
		this._checkbox.prop("checked", this.getParameterByName(this._parameterId).shouldAddNotSelectedSpecifications());
	};

	/**
	 * @override
	 */
	TaskSpecificationsPanel.prototype.show = function () {
		// Only show checkbox if the task can be updated 
		if (this._failIfExisits.getValue() === "true") {
			this._checkboxDiv.show();
		} else {
			this._checkboxDiv.hide();
			this.getParameterByName(this._parameterId).shouldAddNotSelectedSpecifications(false);
			this._checkbox.prop("checked", false);
		}
		MultiAttributePanel.prototype.show.call(this);
	};

	/**
	 * @override
	 */
	TaskSpecificationsPanel.prototype.disable = function () {
		MultiAttributePanel.prototype.disable.call(this);
		this._checkbox.prop("disabled", true);
	};

	return TaskSpecificationsPanel;

});
