define(["WFEditor/workflow/panel/AbstractPanelComponent",
		"WFEditor/components/InputField",
		"WFEditorWCR/workflow/panel/WebCenterParameter",
		"utils/ShapeUtils"
	],
	function (
		AbstractPanelComponent,
		InputField,
		WebCenterParameter,
		ShapeUtils) {

		"use strict";

		/**
		 * a basic panel component used for rapid prototyping
		 * @param {String} propertyName - name of the parameter
		 * @param {String} propertyType - type of the parameter
		 */
		var TestPanel = function (propertyId, propertyName, propertyType, defaultValue) {
			AbstractPanelComponent.call(this, [propertyId]);

			/**
			 * @member {JQueryObject} label
			 * @private
			 */
			this._label = $('<label/>').text(propertyName);

			/**
			 * @member {JQueryObject} label
			 * @private
			 */
			this._inputElement = $('<input />').addClass('form-control input-sm');

			/**
			 * @member {JQueryObject} label
			 * @private
			 */
			this._inlineForm = $('<div/>').addClass('form-group');

			this._parameters = [new WebCenterParameter(propertyId, defaultValue)];
			this._inputElement.val(this._parameters[0].getValue());

			this._inputElement.on("change", _.bind(function () {
				if (this._parameters[0]) {
					this._parameters[0].setValue(this._inputElement.val());
				}
			}, this));

			this._inlineForm.append(this._label);
			this._inlineForm.append(this._inputElement);
			this._element.append(this._inlineForm);



		};

		TestPanel.prototype = Object.create(AbstractPanelComponent.prototype);
		TestPanel.prototype.constructor = TestPanel;

		/**
		 * When the parameter is set, input field should be changed
		 * @param {Array.<Parameter>} parameters
		 */
		TestPanel.prototype.setParameters = function (parameters) {
			AbstractPanelComponent.prototype.setParameters.call(this, parameters);
			this._inputElement.val(parameters[0].getValue());
		};



		return TestPanel;


	});