define(["WFEditorWCR/workflow/panel/RadioPanel",
	"WFEditorWCR/workflow/panel/RadioGroupPanel",
	"WFEditorWCR/workflow/node/WebCenterNodeConfigurationPanel",
	"utils/webi18n!WFEditorWCR",
	"WFEditorWCR/workflow/node/WebCenterNodeConstants",
	"WFEditorWCR/workflow/pin/OutputPinWarning",
	"WFEditorWCR/workflow/pin/WebCenterPinConstants"
], function (RadioPanel, RadioGroupPanel, WebCenterNodeConfigurationPanel, i18n, WebCenterNodeConstants, OutputPinWarning, WebCenterPinConstants) {

	"use strict";

	/**
	 * Configuration panel for the configuration of the warning policy
	 * @class
	 * @augments WebCenterNodeConfigurationPanel
	 * @exports WarningPanel
	 * @param {WebCenterNode} node
	 */
	var WarningPanel = function (node) {
		WebCenterNodeConfigurationPanel.call(this, node);
		
		this._element.addClass("parameter-panel form-horizontal form-compact");
		
		var radioGroupPanel = new RadioGroupPanel(WebCenterNodeConstants.WarningPolicy.WARNINGPOLICY, undefined, WebCenterNodeConstants.WarningPolicy.WARNINGPOLICY);
		this.add(radioGroupPanel);


		var okPanel = new RadioPanel(WebCenterNodeConstants.WarningPolicy.OK, i18n.t(WebCenterNodeConstants.WarningPolicy.OK));
		var errorPanel = new RadioPanel(WebCenterNodeConstants.WarningPolicy.ERROR, i18n.t(WebCenterNodeConstants.WarningPolicy.ERROR));
		var dedicatedPanel = new RadioPanel(WebCenterNodeConstants.WarningPolicy.DEDICATED, i18n.t(WebCenterNodeConstants.WarningPolicy.DEDICATED));

		// If the dedicated panel gets checked a new warning pin should be created
		dedicatedPanel.check = function (check, visibleWhenNotChecked) {
			RadioPanel.prototype.check.call(this, check, visibleWhenNotChecked);
			if (this._parameters[0]) {
				this._parameters[0].setNewPin();
			}
		};

		radioGroupPanel.add(okPanel);
		radioGroupPanel.add(errorPanel);
		radioGroupPanel.add(dedicatedPanel);
	};

	WarningPanel.prototype = Object.create(WebCenterNodeConfigurationPanel.prototype);
	WarningPanel.prototype.constructor = WarningPanel;

	return WarningPanel;
});
