define(["WFEditor/workflow/panel/CompositePanelComponent",
	"underscore"
], function (CompositePanelComponent, _) {
	"use strict";

	/**
	 * WebCenter implementation of a CompositePanelComponent
	 * It contains a utilty method for getting the checkbox alignment correct and optimized
	 * @class WebCenterCompositePanelComponent
	 * @exports WebCenterCompositePanelComponent
	 * @augments CompositePanelComponent
	 */
	var WebCenterCompositePanelComponent = function () {
		CompositePanelComponent.apply(this, arguments);
	};

	WebCenterCompositePanelComponent.prototype = Object.create(CompositePanelComponent.prototype);
	WebCenterCompositePanelComponent.prototype.constructor = WebCenterCompositePanelComponent;

	/**
	 * hide offsetlabel if all children have an offset label
	 * @Override
	 */
	WebCenterCompositePanelComponent.prototype.add = function () {
		CompositePanelComponent.prototype.add.apply(this, arguments);

		this._fixLabels(this._element, this._subPanels);
	};

	/**
	 * hide offsetlabel if all children have an offset label
	 * @param   {JQueryObj}              element - element which contains the panels
	 * @param   {Array.<PanelComponent>} panels  - list of panels that need to be checed
	 */
	WebCenterCompositePanelComponent.prototype._fixLabels = function (element, panels) {
		element.toggleClass("onlyOffsetLabels", _.every(panels, function (panel) {
			return (panel.hasOffsetLabel);
		}));
		element.toggleClass("notOnlyOffsetLabels", !_.every(panels, function (panel) {
			return (panel.hasOffsetLabel);
		}));
	};


	return WebCenterCompositePanelComponent;

});
