define(["underscore", "jquery", "WFEditor/workflow/panel/Parameter"], function (_, $, Parameter) {

	"use strict";

	/**
	 * An implementation of a parameter used in the WebCenterWorkflowEditor
	 * 
	 * @exports WebCenterParameter
	 * @class
	 * @augments Parameter
	 * 
	 * @param {String} name              
	 * @param {String} [defaultValue = ""]
	 * @param {String} [value]       
	 * @param {Array.<WebCenterParameter>} [subparameters]       
	 */
	var WebCenterParameter = function (name, defaultValue, value, subparameters) {
		Parameter.call(this, name, defaultValue, value, subparameters);
	};

	WebCenterParameter.prototype = Object.create(Parameter.prototype);
	WebCenterParameter.prototype.constructor = WebCenterParameter;

	/**
	 * updates a parameter from xml
	 * @param   {String} xml
	 * @returns {Parameter}
	 */
	WebCenterParameter.prototype.updateFromXML = function (xml) {
		_.each(xml.childNodes, function (child) {
			if (child.tagName === "Name") {
				this._name = child.textContent.trim();
			} else if (child.tagName === "Value") {
				//Take only direct children under this tag
				var potentialSubparams = $(child).children("parameter");
				if (potentialSubparams.length > 0) {
					_.each(potentialSubparams, function (subparamXML) {
						var subParam = new WebCenterParameter();
						subParam.updateFromXML(subparamXML);
						this._subparameters.push(subParam);
					}, this);
				} else {
					this._value = child.textContent.trim();
				}
			}
		}, this);
	};

	/**
	 * @override
	 */
	WebCenterParameter.prototype.copy = function () {
		var copiedSubparams = [];
		_.each(this._subparameters, function (subParam) {
			copiedSubparams.push(subParam.copy());
		});
		return new WebCenterParameter(this._name, this._defaultValue, this._value, copiedSubparams);
	};


	return WebCenterParameter;

});
