define([
		"WFEditorWCR/workflow/pin/WebCenterPin",
		"WFEditorWCR/workflow/pin/WebCenterPinConstants"
	],
	function (
		WebCenterPin,
		WebCenterPinConstants
	) {
		"use strict";

		/**
		 * InputPin represents the model for an input pin in the WebCenter Workflow Editor.
		 * The pin has a label
		 *
		 * @exports InputPin
		 * @class
		 * @augments WebCenterPin
		 *
		 * @param {Workflow} workflow - the workflow to which the node belongs
		 * @param {Node} node - node to which the pin belongs
		 */
		var InputPin = function InputPin(workflow, node) {
			WebCenterPin.call(this, workflow, node, node.getId() + WebCenterPinConstants.Type.In, WebCenterPinConstants.Type.In);
		};

		InputPin.prototype = Object.create(WebCenterPin.prototype);
		InputPin.prototype.constructor = InputPin;

		/**
		 * @override
		 */
		InputPin.prototype.acceptsIncomingEdges = function (fromPin) {
			// a WebCenter input pin only accepts edges from an output pin of another node (not the same one)
			return !fromPin || fromPin.getNode() !== this.getNode();
		};


		/**
		 * @override
		 */
		InputPin.prototype.acceptsOutgoingEdges = function (toPin) {
			// never accept outgoing edges
			return false;
		};


		return InputPin;
	});