define([
		"WFEditorWCR/workflow/pin/WebCenterPin"
	],
	function (
		WebCenterPin
	) {
		"use strict";

		/**
		 * OutputPin represents the model for an output pin in the WebCenter Workflow Editor.
		 * The pin has a label
		 *
		 * @exports OutputPin
		 * @class
		 * @augments WebCenterPin
		 *
		 * @param {Workflow} workflow - the workflow to which the node belongs
		 * @param {Node} node - node to which the pin belongs
		 * @param {String} ID - pin id
		 * @param {WebCenterPinConstants.Type} type
		 * @param {String} [label = ""] - label of the pin
		 */
		var OutputPin = function OutputPin(workflow, node, ID, type, label) {
			WebCenterPin.call(this, workflow, node, node.getId() + ID, type, label);
			
			/**
			 * @member {String} the id of the output status (eg. COMPLETED)
			 * @private
			 */
			this._outputID = ID;

		};

		OutputPin.prototype = Object.create(WebCenterPin.prototype);
		OutputPin.prototype.constructor = OutputPin;

		/**
		 * @override
		 */
		OutputPin.prototype.acceptsOutgoingEdges = function (toPin) {
			// a WebCenter output pin only accepts outgoing edges to an input pin of another node (not the same one)
			return !toPin || toPin.getNode() !== this.getNode();
		};


		/**
		 * @override
		 */
		OutputPin.prototype.acceptsIncomingEdges = function (fromPin) {
			// an output pin never accepts incoming edges
			return false;
		};
	
		/**
		 * returns the id of the output status of this pin
		 * @returns {String}
		 */
		OutputPin.prototype.getOutputId = function () {
			return this._outputID;	
		};


		return OutputPin;
	});