define([
		"WFEditorWCR/workflow/pin/OutputPin",
		"WFEditorWCR/workflow/pin/WebCenterPinConstants",
		"utils/webi18n!WFEditorWCR"

	],
	function (
		OutputPin,
		WebCenterPinConstants,
		i18n
	) {
		"use strict";

		/**
		 * OutputPinError represents the model for an ouput pin in the WebCenter Workflow Editor.
		 * The pin has a label
		 *
		 * @exports OutputPinError
		 * @class
		 * @augments WebCenterPin
		 *
		 * @param {Workflow} workflow - the workflow to which the node belongs
		 * @param {Node} node - node to which the pin belongs
		 * @param {String} id - pin id
		 * @param {String} [label=Error] - error label
		 */
		var OutputPinError = function OutputPinError(workflow, node, ID, label) {
			if (!ID) {
				ID = WebCenterPinConstants.Type.OutError;
			}

			if (typeof label === "undefined") {
				label = i18n.t(WebCenterPinConstants.Type.OutError);
			}

			OutputPin.call(this, workflow, node, ID, WebCenterPinConstants.Type.OutError, label);

		};

		OutputPinError.prototype = Object.create(OutputPin.prototype);
		OutputPinError.prototype.constructor = OutputPinError;


		return OutputPinError;
	});