define(["web-viewer/data/AbstractDataAdapter",
		"web-viewer/core/Extendable"
	],
	function (AbstractDataAdapter, Extendable) {
		"use strict";
		/**
		 * Create new AbstractConfig
		 * 
		 * @exports AbstractConfig
		 * @memberof Core
		 * @class Configuration for Web Viewer. A configuration provides the correct DataAdapter (to interact with the server) and sets up the debugger
		 */
		var AbstractConfig = function () {
			Extendable.installTo(this);

			/**
			 * @private
			 */
			this.properties = {};
		};

		/**
		 * Set a property in the config
		 * 
		 * @param {String} key - The name of the property
		 * @param {Any} value - The value of the property
		 */
		AbstractConfig.prototype.set = function (key, value) {
			this.properties[key] = value;
		};

		/**
		 * Get a property from the config
		 * 
		 * @param {String} key - The name of the property for which we want the value
		 * @returns {Any} The value of the property
		 */
		AbstractConfig.prototype.get = function (key) {
			return this.properties[key];
		};


		/**
		 * Initialize the DataAdapter
		 * 
		 * (This method should be overridden by the a specific DataAdapter)
		 * 
		 * @param {Core.ViewerFacade} f
		 */
		AbstractConfig.prototype.initializeAdapter = function (f) {
			this.adapter = new AbstractDataAdapter(f);

			return this.adapter;
		};

		/**
		 * Get the user who is logged in
		 * 
		 * @returns {User} the currently logged in user
		 */
		AbstractConfig.prototype.getUser = function () {
			return undefined;
		};


		/**
		 * Get the modules to load 
		 * 
		 * @return {Array.<String>} array of modules to load
		 */
		AbstractConfig.prototype.getModules = function () {
			return [];
		};

		return AbstractConfig;
	});