define(["web-viewer/layout/LayoutConstants",
		"web-viewer/layout/LayoutMode"
	],
	function (
		LayoutConstants,
		LayoutMode
	) {
		"use strict";

		/**
		 * @exports BasicMode
		 * @memberof Layout
		 * @class
		 * Basic mode of the desktoplayout. Will allow all the layout items to be added and the state is persisted.
		 * @constructor
		 * @param {Core.ViewerFacade} f
		 * @param {Layout} layout
		 */
		var BasicMode = function (f, layout) {
			LayoutMode.call(this, f, layout, LayoutConstants.LayoutMode.BASIC);
		};

		BasicMode.prototype = new LayoutMode();
		BasicMode.prototype.constructor = BasicMode;

		/**
		 * Turns On/Off the layoutMode
		 * @param {Boolean} toggle
		 */
		BasicMode.prototype.toggle = function (toggle) {
			if (toggle === undefined) {
				toggle = !this._isActive;
			}
			this._isActive = toggle;
		};

		/**
		 * Checks if the item is allowed for this layout mode.
		 *
		 * @param {String} itemname
		 * @returns {Boolean}
		 */
		BasicMode.prototype.isItemAllowed = function (itemname) {
			// prevents documentselector toolbarcomponent
			if (itemname === LayoutConstants.ToolbarComponent.DOCUMENTSELECTOR) {
				return false;
			} else {
				return true; //for basic mode all items are allowed to be visible
			}
		};

		/**
		 * Checks if the state of the layout should be persisted.
		 * @return {Boolean}
		 */
		BasicMode.prototype.isPersisted = function () {
			return true;
		};

		return BasicMode;
	});