define(["web-viewer/layout/LayoutConstants",
		"web-viewer/layout/LayoutMode"
	],
	function (
		LayoutConstants,
		LayoutMode
	) {
		"use strict";

		/**
		 * @exports AnnotationViewMode
		 * @memberof Layout
		 * @class
		 * Mode for mobile layout, shows the annotation widget
		 * @constructor
		 * @augments LayoutMode
		 * @param {Core.ViewerFacade} f
		 * @param {Layout} layout
		 */
		var AnnotationViewMode = function (f, layout) {
			LayoutMode.call(this, f, layout, LayoutConstants.LayoutMode.MOBILE_ANNOTATION);

			this.f.emit("layout.modeAvailabilityChanged", this, true, {
				icon: "icon-WCR_Annotate",
				title: "AnnToolsTitle"
			});
		};

		AnnotationViewMode.prototype = new LayoutMode();
		AnnotationViewMode.prototype.constructor = AnnotationViewMode;

		/**
		 * Turns On/Off the layoutMode
		 * @param {Boolean} toggle
		 */
		AnnotationViewMode.prototype.toggle = function (toggle) {
			if (toggle === undefined) {
				toggle = !this._isActive;
			}
			this._isActive = toggle;
		};

		/**
		 * Checks if the item is allowed for this layout mode. Prevents channels and CAD widget from loading.
		 * 
		 * @param {String} itemname
		 * @returns {Boolean}
		 */
		AnnotationViewMode.prototype.isItemAllowed = function (itemname) {
			// only allow viewport widget
			return itemname === LayoutConstants.Widget.VIEWPORT || itemname === LayoutConstants.Widget.ANNOTATION || itemname === LayoutConstants.ToolbarComponent.DOCUMENTSELECTOR || itemname === LayoutConstants.ToolbarComponent.APPROVAL || itemname === LayoutConstants.ToolbarComponent.ANNOTATION || itemname === LayoutConstants.Widget.MESSAGE;
		};

		/**
		 * Checks if the state of the layout should be persisted.
		 * @return {Boolean}
		 */
		AnnotationViewMode.prototype.isPersisted = function () {
			return false;
		};

		/**
		 * Decide whether or not to show the mode panel
		 * @override
		 */
		AnnotationViewMode.prototype.isModePanelEnabled = function () {
			return true;
		};

		/**
		 * @override
		 */
		AnnotationViewMode.prototype.showModePanelWidgetTitles = function () {
			return false;
		};

		/**
		 * list of needed widgets in modepanel for annotation view mode
		 * @returns {Array}    
		 * @override
		 */
		AnnotationViewMode.prototype.getModePanelContent = function () {
			return [LayoutConstants.Widget.ANNOTATION];
		};

		return AnnotationViewMode;
	});