define(["web-viewer/data/AbstractDocumentPage",
		"underscore"
	],
	function (AbstractDocumentPage,
		_) {

		/**
		 * Inject pagelist functionality in the data model
		 * 
		 * @exports PagelistDataExtensions
		 * @memberof PagelistModule
		 * @param {Core.ViewerFacade} f
		 */
		var PagelistDataExtensions = function (f) {
			var dataAdapter = f.getDataAdapter();

			// only the WebCenter data-adapter is supported
			if (!dataAdapter.WebCenter) {
				f.emit("error.SEVERE", "Can't initialize Pagelists on a non-webcenter data-adapter");
				return;
			}


			//---------------- AbstractDocumentPage extensions -------------------------------------------------------------

			/**
			 * Is this page marked
			 * @returns {Boolean} True if marked, false otherwise
			 */
			AbstractDocumentPage.prototype.isPagelistMarked = function () {
				return (this._pagelistMarked !== undefined && this._pagelistMarked === true);
			};

			/**
			 * Set the page marked
			 * @param {Boolean} pagelistMarked - True to set it marked, false to set it not marked
			 */
			AbstractDocumentPage.prototype.setPagelistMarked = function (pagelistMarked) {
				if (this._pagelistMarked !== pagelistMarked) {
					this._pagelistMarked = pagelistMarked;
					this._emit("pagelistMarked.changed", this);
				}
			};

			/**
			 * Get the page name
			 * @returns {String} The page name or empty string if not defined 
			 */
			AbstractDocumentPage.prototype.getPageName = function () {
				return this.get("pagename") || this.getPagenum()+"" || "";
			};

		};

		return PagelistDataExtensions;
	});