define('web-viewer/svg/SvgDataExtensions',["web-viewer/webcenter/WebCenterDocumentPage",
"utils/ShapeUtils", "jquery"], function (WebCenterDocumentPage, ShapeUtils, $) {
	
	
	/**
	 * Set Extensions for SVG pages
	 */
	function SvgDataExtensions(f) {
		
		/**
		 * returns the size of the svg
		 * @return {ShapeUtils.Size}
		 */
		WebCenterDocumentPage.prototype.getSVGSize = function () {
			if (this.get("SVGSize")){
				return this.get("SVGSize");
			} else {
				return new ShapeUtils.Size();
			}
		};
		
		/**
		 * Check if the svg has been loaded
		 * @return {Boolean}
		 */
		WebCenterDocumentPage.prototype.isSVGLoaded = function(){
			var svgData = this.get("svgData");
			return  svgData && svgData.loaded === true && svgData.rawSVG;
		};
		
		/**
		 * Returns the svg element
		 * @return {JQueryObject}
		 */
		WebCenterDocumentPage.prototype.getSVGElement = function(){	
			return this.get("svgData") && this.get("svgData").rawSVG;
		};
	}


	return SvgDataExtensions;

});

define('web-viewer/svg/SvgLayerModel',["web-viewer/viewport/model/ViewportLayerModel",
		"utils/ShapeUtils",
		"web-viewer/utils/ListenerUtil"
	],
	function (
		ViewportLayerModel,
		ShapeUtils,
		ListenerUtil
	) {
		"use strict";
		/**
		 * @exports SvgLayerModel
		 * @augments ViewportLayerModel
		 * @class This layer model is responsible to draw svgs
		 * @constructor
		 * @mixes Utils.ListenerUtilMixin
		 *
		 * @param {Core.ViewerFacade} f - Viewer facade
		 * @param {String} ID - the ID of the layer model
		 * @param {AbstractDocumentPage} page
		 */

		var SvgLayerModel = function (f, ID, page) {
			ViewportLayerModel.call(this, f, ID);
			ListenerUtil.mixin(this, f);

			this.f.whenModuleAvailable("viewport", function (viewportModule) {
				this._viewport = viewportModule;
			}, this);

			this._page = page;

			this._registerListener("doc.parameters.changed", function () {
				this._emit("repaint");
			}, this);

		};

		// inherit
		SvgLayerModel.prototype = Object.create(ViewportLayerModel.prototype);
		// correct the constructor pointer 
		SvgLayerModel.prototype.constructor = SvgLayerModel;


		/**
		 * Gets the SVG element
		 */
		SvgLayerModel.prototype.getSVGElement = function () {
			if (this._page && this._page.isSVGLoaded()) {
				return this._page.getSVGElement();
			} else {
				return null;
			}
		};

		/**
		 * Remove all listeners
		 */
		SvgLayerModel.prototype.destroy = function () {
			ViewportLayerModel.prototype.destroy.call(this);

			this._unregisterAllListeners();
		};

		/**
		 * returns the size of the svg
		 * @return ShapeUtils.Size
		 */
		SvgLayerModel.prototype.getSVGSize = function () {
			var activePage = this.f.getActivePage();
			if (this._page && this._page.isSVGLoaded()) {
				return this._page.getSVGSize();
			} else if(!this._page && activePage && activePage.isSVGLoaded() && activePage.isReaderSpread()){
				return activePage.getSVGSize();
			} 
			return null;
		};



		SvgLayerModel.prototype.setPage = function (page) {
				this._page = page;
				this._emit("pageChanged");
		};
		
		SvgLayerModel.prototype.getPage = function () {
			return this._page;

		};


		/**
		 * @return {String}
		 */
		SvgLayerModel.prototype.getType = function () {
			return "svg";
		};

		SvgLayerModel.prototype.getReaderSpreadOffset = function () {
			var activePage = this.f.getActivePage();
			var diffPage = this.f.getDocumentController().getDifferencePage();
			
			if(activePage === this._page && this._page.isReaderSpread() && this._page.get("isRightPage")) {
				// Active page is right page
				return new ShapeUtils.Point(diffPage ? diffPage.getSVGSize().width : activePage.getSVGSize().width, 0);
			}
			if(activePage !== this._page && activePage && activePage.isReaderSpread() && !activePage.get("isRightPage")) {
				return new ShapeUtils.Point(activePage.getSVGSize().width, 0);
			}
			return new ShapeUtils.Point();
		};




		return SvgLayerModel;
	});

define('web-viewer/svg/SvgDiffLayerModel',["./SvgLayerModel"], function (SvgLayerModel) {

	"use strict";

	/**
	 * @class layer model of the difference page
	 * @augments SvgLayerModel
	 *
	 * @param {Core.ViewerFacade} f - Viewer facade
	 * @param {String} ID - the ID of the layer model
	 * @param {AbstractDocumentPage} page
	 */
	var SvgDiffLayerModel = function (f, ID, page) {
		SvgLayerModel.call(this, f, ID, page);
		this._registerListener("doc.page.difference", this._updateDiffPage, this);
	};

	SvgDiffLayerModel.prototype = Object.create(SvgLayerModel.prototype);
	SvgDiffLayerModel.prototype.constructor = SvgDiffLayerModel;

	/** 
     * Updates the page of layer model
	 * @param {AbstractDocumentPage} oldPage
	 * @param {AbstractDocumentPage} diffPage
	 */
	SvgLayerModel.prototype._updateDiffPage = function (oldPage, diffPage) {
		this.setPage(diffPage);
	};

	return SvgDiffLayerModel;


});


define('tpl!web-viewer/svg/TextSelectionPopoverTemplate', function(){return function(d){
var __t,__p='',__j=Array.prototype.join,print=function(){__p+=__j.call(arguments,'');};
__p+='<ul>\r\n    <li class="addTextHighlightAnnotation"><a><i class="icon icon-WCR_Annotation-Highlight-cont containerIcon"><i class="icon subIcon icon icon-WCR_Annotation-Highlight-sub icon-yellow"></i></i><span>'+
((__t=(d.i18n("AddHighlightAnnotation")))==null?'':_.escape(__t))+
'</span></a></li>\r\n	<li class="addTextAnnotation"><a><i class="icon icon-WCR_Annotation-Rect12 icon-red"></i><span>'+
((__t=(d.i18n("AddRectangularAnnotation")))==null?'':_.escape(__t))+
'</span></a></li>\r\n	<li class="copyText"><a><i class="icon icon-WCR_Actions-Copy12"></i><span>'+
((__t=(d.i18n("CopySelText")))==null?'':_.escape(__t))+
'</span></a></li>            \r\n</ul>';
return __p;
}});
define('web-viewer/svg/TextSelectionPopoverModel',["web-viewer/utils/ViewerUtils",
        "web-viewer/viewport/model/ViewportPopoverModel",
        "tpl!web-viewer/svg/TextSelectionPopoverTemplate",
        "Template",
        "utils/ShapeUtils",
        "underscore",
        "jquery",
        "web-viewer/annotation/AnnotationConstants"
    ],
    function (ViewerUtils,
        ViewportPopoverModel,
        tpl,
        Template,
        ShapeUtils,
        _,
        $,
        AnnotationConstants) {
        "use strict";

        /**
         * PoveroverModel for text selection tool 
         * 
         * @exports TextSelectionPopoverModel
         * @memberof SvgModule
         * @class TextSelectionPopoverModel
         * @augments Viewport.Model.ViewportPopoverModel
         * @constructor
         * 
         * @param {Core.ViewerFacade} f
         * @param {String} name
         */
        var TextSelectionPopoverModel = function (f, name) {
            ViewportPopoverModel.call(this, f, name);

            this._content = $("<div/>").addClass("TextSelectionPopover");
            this.textContent = "";
            this._popoverLocation = null;
            this._worldTextFrames = null;
            this._boundingWorldFrame = null;

            // initialize template
            this.t = new Template(f.i18n, tpl);
            this.t.setContext(this._content);

            // Add a regular annotation
            this.t.bind("mousedown", ".addTextAnnotation", _.bind(function (source, event) {
                this.f.requestModule("annotation", _.bind(function (annotationModule) {
                    annotationModule.promptIfAnnotationOutsidePage(this._boundingWorldFrame, _.bind(function () {
                        // add annotation
                        this.f.emit("module.annotation.createAnnotation", this._boundingWorldFrame, this._textContent);
                        this._emit("addAnnotation");
                    }, this), function () {
                        // do nothing when 'No' is pressed
                    }, false, true);
                }, this));
                this._emit("popupClosed");
            }, this));


            // Copy selection
            this.t.bind("mousedown", ".copyText", _.bind(function (source, event) {
                document.execCommand("copy");
                this._emit("popupClosed");
            }, this));


            // Add multiple linked highlight annotations
            this.t.bind("mousedown", ".addTextHighlightAnnotation", _.bind(function (source, event) {
                this.f.requestModule("annotation", _.bind(function (annotationModule) {
                    annotationModule.promptIfAnnotationOutsidePage(this._boundingWorldFrame, _.bind(function () {
						annotationModule.addLinkedAnnotations(this._worldTextFrames, this._textContent, AnnotationConstants.AnnotationType.ANNOT_HIGHLIGHT);


                        this._emit("addAnnotation");
                    }, this), function () {
                        // do nothing when 'No' is pressed
                    }, false, true);
                }, this));
                this._emit("popupClosed");
            }, this));

            // load language if needed
            this.f.i18n.loadBundle("viewer", _.bind(function () {
                this.t.render();
            }, this));

            this.getFrame = function () {
                if (this._popoverLocation) {
                    return this._popoverLocation;
                } else {
                    return new ShapeUtils.Rect(new ShapeUtils.Point(0, 0), new ShapeUtils.Size(1, 1));
                }
            };

            this.getContent = function () {
                return this._content;
            };

            this.getPreferredPosition = function () {
                // override
                return "right";
            };

            this.getRestrictBorder = function () {
                return 0;
            };

            this.update();
        };

        // inherit
        TextSelectionPopoverModel.prototype = Object.create(ViewportPopoverModel.prototype);
        TextSelectionPopoverModel.prototype.constructor = TextSelectionPopoverModel;


        /**
         * Update the popover
         */
        TextSelectionPopoverModel.prototype.update = function () {
            this.t.render();
        };

        /**
         * Set the list of areas of the highlight popover
         * @param {Array.<ShapeUtils.Rect>} The array of areas that overlap the individual text tags
         */
        TextSelectionPopoverModel.prototype.setWorldTextFrames = function (worldTextFrames) {
            this._worldTextFrames = worldTextFrames;
            // Calculate the bounding rect which contains all these text frames
            this._boundingWorldFrame = this._calculateBoundingWorldFrame(worldTextFrames);
        };

        /**
         * Set the location of the popover
         * @param {ShapeUtils.Point} point for which the popover should be shown
         */
        TextSelectionPopoverModel.prototype.setPopoverLocation = function (point) {
            this._popoverLocation = new ShapeUtils.Rect(point, new ShapeUtils.Size(0.001, 0.001));
        };

        /**
         * Set the area of the popover
         * @param {ShapeUtils.Rect} area for which the popover should be shown
         */
        TextSelectionPopoverModel.prototype.setTextContent = function (content) {
            this._textContent = content;
        };

        /**
         * Get the bounding world frame, based on given the array of world text rects
         * @private
         * @param   {Array.<ShapeUtils.Rect>} worldTextFrames - the array of individual rects
         * @returns {ShapeUtils.Rect} the bounding world rect
         */
        TextSelectionPopoverModel.prototype._calculateBoundingWorldFrame = function (worldTextFrames) {
            var boundingWorldFrame = null;
            if (worldTextFrames) {
                _.each(worldTextFrames, _.bind(function (textFrame) {
                    if (!boundingWorldFrame) {
                        boundingWorldFrame = textFrame;
                    } else {
                        boundingWorldFrame = boundingWorldFrame.calculateArea(textFrame);
                    }
                }, this));
            }
            return boundingWorldFrame;
        };

        return TextSelectionPopoverModel;
    });

define('web-viewer/svg/TextSelectionLayerModel',["web-viewer/viewport/model/ViewportLayerModel",
        "./TextSelectionPopoverModel",
        "utils/ShapeUtils",
        "web-viewer/utils/ListenerUtil"
    ],
    function (ViewportLayerModel,
        TextSelectionPopoverModel,
        ShapeUtils,
        ListenerUtil
    ) {
        "use strict";
        /**
         * @exports TextSelectionLayerModel
         * @memberof SvgModule
         * @augments ViewportLayerModel
         * @class This class gives the linework to render selected text and show popover.
         * @constructor
         *
         * @param {Core.ViewerFacade} f - Viewer facade
         * @param {String} ID - the ID of the layer model
         * @param {TextSelectionModel} textSelectionModel - Model of the text selection tool
         */
        var TextSelectionLayerModel = function (f, ID, textSelectionModel) {
            ViewportLayerModel.call(this, f, ID);
            ListenerUtil.mixin(this, f);

            // Variables
            this._textSelectionModel = textSelectionModel;
            this._textSelectionPopover = null;
            this._textSelectionPopoverListener = null;
            this._worldTextFrames = null;
            
        };

        // inherit
        TextSelectionLayerModel.prototype = Object.create(ViewportLayerModel.prototype);
        TextSelectionLayerModel.prototype.constructor = TextSelectionLayerModel;

        /**
         * Start showing the textSelection popover
         */
        TextSelectionLayerModel.prototype.showPopover = function () {
            if (!this._textSelectionPopover) {
                this._textSelectionPopover = new TextSelectionPopoverModel(this.f, "TextSelectionPopover");
                this._textSelectionPopoverListener = this._registerListener("popupClosed", function (e) {
                    this.hidePopover();
                }, this, this._textSelectionPopover);
                this.modelChanged();

                this.addPopoverModel(this._textSelectionPopover);
            }
        };

        /**
         * Hide the textSelection popover
         */
        TextSelectionLayerModel.prototype.hidePopover = function () {
            if (this._textSelectionPopover) {
                this.removePopoverModel(this._textSelectionPopover.getID());
                this.removePopover(this._textSelectionPopover.getID());
                this._unregisterListener(this._textSelectionPopoverListener);
                this._textSelectionPopover = null;
            }
        };

        /**
         * Override the model changed, so the popovermodel is updated when needed.
         * @override
         */
        TextSelectionLayerModel.prototype.modelChanged = function () {
            if (this._textSelectionPopover) {
                this._textSelectionPopover.setTextContent(this._textSelectionModel.getContent());
                this._textSelectionPopover.setWorldTextFrames(this._worldTextFrames);
                this._textSelectionPopover.setPopoverLocation(this._textSelectionModel.getEndPoint());

            }
        };    
        
        
        /**
         * Set the array of world rects that covers all the selected text area's
         * @param {Array.<ShapeUtils.Rect>} The array of rects that are positioned on the individual text tags
         */
        TextSelectionLayerModel.prototype.setWorldTextFrames = function (worldTextFrames) {
            this._worldTextFrames = worldTextFrames;
        };

        /**
         * Get Popover Model
         * @returns Popover Model
         */
        TextSelectionLayerModel.prototype.getPopoverModel = function () {
            return this._textSelectionPopover;
        };

        return TextSelectionLayerModel;
    });

define('web-viewer/svg/TextSelectionTool',["underscore",
        "jquery",
        "web-viewer/viewport/tools/AbstractTool",
        "web-viewer/compare/CompareConstants",
        "web-viewer/core/CoreConstants",
        "web-viewer/utils/ConversionConstants",
        "./TextSelectionLayerModel",
        "rbush",
        "utils/ShapeUtils",
        "web-viewer/utils/ListenerUtil",
        "lib/rbushknn"
    ],
    function (_,
        $,
        AbstractTool,
        CompareConstants,
        CoreConstants,
        ConversionConstants,
        TextSelectionLayerModel,
        rbush,
        ShapeUtils,
        ListenerUtil,
        rbushknn) {
        "use strict";

        var DEFAULTSTATE = "default";
        var DRAGGINGSTATE = "dragging";
        var SELECTEDSTATE = "selected";

        /**
         * @exports TextSelectionTool
         * @memberof SvgModule
         * @class The TextSelectionTool allows to select text in SVG files
         * @constructor
         * @augments {Core.AbstractTool}
         *
         * @param {Core.ViewerFacade} f - Viewer facade
         * @param {SvgModule.TextSelectionModel}
         */
        var TextSelectionTool = function (f, textSelectionModel) {
            AbstractTool.call(this, f, CoreConstants.TOOLS.TEXTSELECTION);
            ListenerUtil.mixin(this, f);

            // listen tot popover interaction to change state
            this.currentPopoverListener = null;

            /**
             * @member {TextSelectionModel}
             * @private
             */
            this._textSelectionModel = textSelectionModel;

            /**
             * @member {TextSelectionLayerModel}
             * @private
             */
            this._textSelectionLayerModel = new TextSelectionLayerModel(f, this.getIID(), this._textSelectionModel);

            this.f.whenModuleAvailable("viewport", function (viewportModule) {
                this._viewport = viewportModule;
                if (this.isActive()) {
                    this._viewport.getFirstViewOccurrence("Main").getViewContext().addClass("enableTextSelection");
                }
            }, this);


            /**
             * @member {Rbush}
             * @private
             */
            this._rbush = null;

            f.getDocumentController().whenActiveOrDifferencePageChangedAndParametersAvailableOrChange(_.bind(this._onPageChange, this));

            var startElement = null;
            var startCharIndex = null;
            var startElementIndex = null;

            /**
             * DEFAULT STATE -> nothing set
             */
            this.registerState(DEFAULTSTATE, {

                enterState: _.bind(function () {
                    this._textSelectionModel.setContent("");
                    this._textSelectionModel.setStartPoint(null);
                    this._textSelectionModel.setEndPoint(null);
                }, this),

                leaveState: _.bind(function () {}, this),

                mousedown: _.bind(function (e) {
                    document.activeElement.blur();
                    if (!this.isActive()) {
                        // This is only triggered in the SELECTED state (destroys popup and text selection)
                        this.changeState(DEFAULTSTATE);
                    } else {
                        var curLoc = this.keepPointWithinWorldBounds(this.getWorldPoint(e), false);
                        this._textSelectionModel.setStartPoint(curLoc);

                        var result = rbushknn(this._rbush, curLoc.x, curLoc.y, 1);

                        if (result.length > 0) {
                            startElement = result[0].element;
                            startCharIndex = result[0].charIndex;
                            startElementIndex = result[0].elementIndex;
                            this.changeState(DRAGGINGSTATE);
                        }
                    }
                }, this),

                mouseup: function () {},

                mousemove: function () {},

                mouseout: function () {},

                mouseleave: function () {},

                /**
                 * no context menu!
                 */
                contextmenu: _.bind(function (e) {
                    e.preventDefault();
                    e.stopPropagation();
                }, this),

                canBeInterrupted: true
            });

            /**
             * Dragging STATE -> selecting text
             */
            this.registerState(DRAGGINGSTATE, _.defaults({

                mousedown: function () {},

                mouseup: _.bind(function (e) {
                    var curLoc = this.keepPointWithinWorldBounds(this.getWorldPoint(e), false);
                    this._textSelectionModel.setEndPoint(curLoc);

                    if (curLoc.equals(this._textSelectionModel.getStartPoint())) {
                        this.changeState(DEFAULTSTATE);
                    } else {
                        this.changeState(SELECTEDSTATE);
                    }
                }, this),

                mousemove: _.bind(function (e) {
                        var curLoc = this.keepPointWithinWorldBounds(this.getWorldPoint(e), false);
                        // update selected text with current location

                        if (!curLoc.equals(this._textSelectionModel.getStartPoint())) {
                            var result = rbushknn(this._rbush, curLoc.x, curLoc.y, 1);

                            if (result.length > 0) {
                                var endElement = result[0].element;
                                var endCharIndex = result[0].charIndex;
                                var endElementIndex = result[0].elementIndex;

                                var selection = window.getSelection();
                                selection.removeAllRanges();
                                var range = document.createRange();
                                if (startElementIndex < endElementIndex) {
                                    range.setStart(startElement.firstChild, startCharIndex);
                                    range.setEnd(endElement.firstChild, endCharIndex + 1);
                                } else if (startElementIndex > endElementIndex) {
                                    range.setStart(endElement.firstChild, endCharIndex);
                                    range.setEnd(startElement.firstChild, startCharIndex + 1);
                                } else {
                                    if (endCharIndex < startCharIndex) {
                                        range.setStart(startElement.firstChild, endCharIndex);
                                        range.setEnd(endElement.firstChild, startCharIndex);
                                    } else {
                                        range.setStart(startElement.firstChild, startCharIndex);
                                        range.setEnd(endElement.firstChild, endCharIndex + 1);
                                    }
                                }
                                selection.addRange(range);
                            }
                        }
                    },
                    this),

            }, this.getState(DEFAULTSTATE)));

            /**
             * selected STATE -> text is selected and annotation balloon is shown
             */
            this.registerState(SELECTEDSTATE, _.defaults({
                enterState: _.bind(function () {
                    var selection = window.getSelection();
                    if (selection.rangeCount > 0) {
                        // Calculate the text world rects of the selected text
                        var range = selection.getRangeAt(0);
                        var startTextTag = range.startContainer.parentNode;
                        var endTextTag = range.endContainer.parentNode;
                        var textWorldFrames = [];

                        if (range.startContainer === range.endContainer) {
                            // Calculate bounding box of the single text tag                           
                            textWorldFrames.push(this._calculateBoundingBoxOfText(startTextTag, range.startOffset, range.endOffset));
                        } else {
                            // Calculate the bounding box of the first text tag between position range.startOffset <-> startTextTag.getNumberOfChars()
                            if (range.startOffset < startTextTag.getNumberOfChars()) {                                
                                textWorldFrames.push(this._calculateBoundingBoxOfText(startTextTag, range.startOffset, startTextTag.getNumberOfChars()));
                            }

                            // Calculate the bounding boxes of the text tags between position 0 <-> textElement.getNumberOfChars()
                            _.each(this._getElementsInsideRange(range), _.bind(function (element) {
                                $(element).find("text").each(_.bind(function (index, textElement) {                                    
                                    textWorldFrames.push(this._calculateBoundingBoxOfText(textElement, 0, textElement.getNumberOfChars()));
                                }, this));
                            }, this));

                            // Calculate the bounding box of the last text tag between position 0 <-> range.endOffset
                            if (range.endOffset > 0) {
                                textWorldFrames.push(this._calculateBoundingBoxOfText(endTextTag, 0, range.endOffset));
                            }
                        }

                        // Populate models & show popover
                        this._textSelectionLayerModel.setWorldTextFrames(textWorldFrames);
                        // encode the string and set it as contents
                        this._textSelectionModel.setContent($("<div/>").text(selection.toString()).html());
                        this._textSelectionLayerModel.showPopover();

                        //register the listener to the model to create global annotations
                        this.currentPopoverListener = this._registerListener("addAnnotation", function () {
                            this.changeState(DEFAULTSTATE);
                        }, this, this._textSelectionLayerModel.getPopoverModel());
                    }
                }, this),

                leaveState: _.bind(function () {
                    this._textSelectionLayerModel.hidePopover();
                    window.getSelection().removeAllRanges();
                    if (this.currentPopoverListener) {
                        this._unregisterListener(this.currentPopoverListener);
                    }
                }, this),

            }, this.getState(DEFAULTSTATE)));

            this.registerActiveEvents(["mousedown", "mousemove", "mouseup", "mouseleave", "contextmenu"]);
            this.registerPassiveEvents(["mousedown"]);

            // Esc allows to reset selection
            this.activeKeyEvents.push(["esc", _.bind(function (e) {
                this.changeState(DEFAULTSTATE);
                e.preventDefault();
                e.stopPropagation();
            }, this), "keyup"]);


            /**
             * @override
             */
            this._override("initialize", function (widget, toolManager) {
                this._super(widget, toolManager);
                this.changeState(DEFAULTSTATE);
            });

            /**
             * @override
             */
            this._override("activate", function (interruptRequest) {
                this._super(interruptRequest);
                if (this._viewport) {
                    this._viewport.getFirstViewOccurrence("Main").getViewContext().addClass("enableTextSelection");
                }
                this._initializeRbush();
                this.f.getModule("viewport").addLayer(this.getIID(), this._textSelectionLayerModel);
            });

            /**
             * @override
             */
            this._override("deactivate", function (interruptRequest) {
                this._super(interruptRequest);
                if (!interruptRequest) {
                    this._rbush = null;
                    this.changeState(DEFAULTSTATE);
                    // The SVGLayer should be first in the dom
                    this.f.emit("viewport.viewmodel.Main.layers.swapIfIndexIsHigher", "SVGLayer", "SVGDifferenceLayer");
                    this._textSelectionLayerModel.modelChanged(true);
                    this.f.getModule("viewport").removeLayer(this.getIID());
                    if (this._viewport) {
                        this._viewport.getFirstViewOccurrence("Main").getViewContext().removeClass("enableTextSelection");
                    }

                }
            });

            // activate text selection tool
            this.passiveKeyEvents.push(["t", _.bind(function (e) {
                if (this.f.getActivePage().hasSvg && this.f.getActivePage().hasSvg()) {
                    e.preventDefault();
                    f.emit("toolManager.activateTool", this);
                }
            }, this), "keypress"]);

        };


        // extend from the AbstractTool
        // inherit
        TextSelectionTool.prototype = Object.create(AbstractTool.prototype);
        TextSelectionTool.prototype.constructor = TextSelectionTool;


        TextSelectionTool.prototype._onPageChange = function () {
            if (this.isActive()) {
                this.changeState(DEFAULTSTATE);
                this._rbush = null;
                this._initializeRbush();
            }
        };

        /**
         * Returns the default cursor for the tool
         * @returns {String}
         */
        TextSelectionTool.prototype.getDefaultCursor = function () {
            return "cursor-textSelect";
        };



        /**
         * If the world is animating, cancel it and wait for the svglayer to have been repainted
         */
        TextSelectionTool.prototype._initializeRbush = function () {
            if (this._rbush) {
                return;
            }
            var svgLayer;
            if (this._widget.getWorld().isAnimating()) {
                // As there is a lot of asynchronicity in the viewer, we have to make sure the SVG's transform is the same as the viewer's transform
                // To make sure this is the case we first have to listen to the a repaint of the view.
                // This will trigger all layers to rerender. This also happens asynchronous. So we should then listen to the new repaint of the svg layer
                svgLayer = this._viewport.getFirstViewOccurrence("Main").getLayer("SVGLayer");
                var viewListener = this._registerListener("repainted", function () {
                    // The widget has been repainted, now we have to wait to make sure the svg's transformation is updated as well
                    var layerListener = this._registerListener("repainted", function () {
                        this._calculateRbush();
                        this._unregisterListener(layerListener);
                    }, this, svgLayer);
                    this._unregisterListener(viewListener);
                }, this, this._widget);

                this._widget.getWorld().cancelAnimation();
            } else {
                this._calculateRbush();
            }
        };

        /**
         * Initializes the Rbush with the text elements in the svg
         */
        TextSelectionTool.prototype._calculateRbush = function () {
            this._rbush = new rbush();
            var rbushElems = [];
            if (this.f.getDocumentController().hasDifferenceDocumentPage()) {
                if (!this.f.getActivePage().get("isRightPage")) {
                    // For the text selection to work in readerspread mode the left page should be the first in the dom.
                    this.f.emit("viewport.viewmodel.Main.layers.swapIfIndexIsHigher", "SVGLayer", "SVGDifferenceLayer");
                    this._calculateRbushElements($(this.f.getActivePage().getSVGElement()), rbushElems);
                    this._calculateRbushElements($(this.f.getDocumentController().getDifferencePage().getSVGElement()), rbushElems);
                } else {
                    // For the text selection to work in readerspread mode the left page should be the first in the dom.
                    this.f.emit("viewport.viewmodel.Main.layers.swapIfIndexIsHigher", "SVGDifferenceLayer", "SVGLayer");
                    this._calculateRbushElements($(this.f.getDocumentController().getDifferencePage().getSVGElement()), rbushElems);
                    this._calculateRbushElements($(this.f.getActivePage().getSVGElement()), rbushElems);
                }
            } else {
                this._calculateRbushElements($(this.f.getActivePage().getSVGElement()), rbushElems);
            }

            try {
                this._rbush.load(rbushElems);
            } catch (e) {
                console.error("rbush - could not insert character bounding boxes");
            }


            //>>excludeStart("PExclude", pragmas.productionExclude);
            //this._renderRbush(); //debug
            //>>excludeEnd("PExclude");

        };


        /**
         * @param {Node} svgElement
         * @param {Array.<Object>} rbushElems
         */
        TextSelectionTool.prototype._calculateRbushElements = function (svgElement, rbushElems) {
            var self = this;
            svgElement.find("text").each(function (index) {
                var el = $(this);
                var length = el[0].getNumberOfChars();

                for (var j = 0; j < length; j++) {
                    var coords = self._convertCoords(j, el[0]);
                    var obj = {
                        minX: coords.origin.x,
                        minY: coords.origin.y,
                        maxX: coords.origin.x + coords.size.width,
                        maxY: coords.origin.y + coords.size.height,
                        charIndex: j,
                        element: el[0],
                        elementIndex: rbushElems.length
                    };
                    rbushElems.push(obj);
                }
            });

        };


        /**
         * @param {Integer} index of character in text element
         * @param {Node} element - the text element
         */
        TextSelectionTool.prototype._convertCoords = function (index, element) {
            var extent = element.getExtentOfChar(index);
            var matrix = element.getScreenCTM();
            var svg = $(this.f.getActivePage().getSVGElement());

            var pt = svg[0].createSVGPoint();
            pt.x = extent.x;
            pt.y = extent.y;
            pt = pt.matrixTransform(matrix);

            var pt2 = svg[0].createSVGPoint();
            pt2.x = extent.x + extent.width;
            pt2.y = extent.y + extent.height;
            pt2 = pt2.matrixTransform(matrix);

            var parent = this._viewport.getFirstViewOccurrence("Main").getViewContext().offset();
            var scenePoint = new ShapeUtils.Point(pt.x - parent.left, pt.y - parent.top);
            var sceneSize = new ShapeUtils.Size(pt2.x - pt.x, pt2.y - pt.y);

            return this.sceneToWorldRect(new ShapeUtils.Rect(scenePoint, sceneSize));
        };

        TextSelectionTool.prototype.canBeInterrupted = function (tool) {
            return this.getCurrentStateName() !== DRAGGINGSTATE;
        };


        //>>excludeStart("PExclude", pragmas.productionExclude);
        /**
         * Renders rectangles around the text elements
         * @private
         */
        TextSelectionTool.prototype._renderRbush = function () {
            this.requestCanvasLayer("Main");
            var ctx = this.getCanvasCtx();
            if (!this._interval) {
                this._interval = setInterval(_.bind(function () {
                    if (this._rbush) {
                        var allElements = this._rbush.all();
                        ctx.setTransform(1, 0, 0, 1, 0, 0);
                        ctx.clearRect(0, 0, ctx.canvas.width, ctx.canvas.height);
                        ctx.beginPath();
                        _.each(allElements, function (obj) {
                            var worldOrigin = new ShapeUtils.Point(obj.minX, obj.minY);
                            var worldSize = new ShapeUtils.Size(obj.maxX - obj.minX, obj.maxY - obj.minY);
                            var sceneOrigin = this.worldToScenePoint(worldOrigin);
                            var sceneSize = this.worldToSceneSize(worldSize);
                            ctx.rect(sceneOrigin.x, sceneOrigin.y, sceneSize.width, sceneSize.height);

                        }, this);

                        ctx.stroke();
                    }
                }, this), 1000 / 30);
            }
        };

        //>>excludeEnd("PExclude");

        /**
         * Gets all the elements inside the range, start and end node are not included
         * @private
         * @param   {Range}   range - the range object
         * @returns {Array.<Node>} an array of nodes inside the given range
         */
        TextSelectionTool.prototype._getElementsInsideRange = function (range) {
            var start = range.startContainer.parentNode;
            var end = range.endContainer.parentNode;
            var ancestor = range.commonAncestorContainer;
            var el;
            var before = [];
            while (start.parentNode !== ancestor) {
                el = start;
                while (el.nextSibling) {
                    before.push(el = el.nextSibling);
                }
                start = start.parentNode;
            }

            var after = [];
            while (end.parentNode !== ancestor) {
                el = end;
                while (el.previousSibling) {
                    after.push(el = el.previousSibling);
                }
                end = end.parentNode;
            }
            after.reverse();

            while ((start = start.nextSibling) !== end) {
                before.push(start);
            }
            return before.concat(after);
        };

        
        /**
         * Calculates the bounding box of a svg text tag with a given start and end offset
         * @private
         * @param   {Node} text  svg text tag
         * @param   {Integer} start Char position of start
         * @param   {Integer} end   Char position of end
         * @returns {ShapeUtils.Rect} The world bounding box of the given text tag with start and end offset
         */
        TextSelectionTool.prototype._calculateBoundingBoxOfText = function (text, start, end) {
            var boundingBox = null;
            for (var i = start; i < end; i++) {
                if (!boundingBox) {
                    // Start boundingBox with the first char of the text
                    boundingBox = this._convertCoords(i, text);
                } else {
                    // Keep expanding the boundingBox with the other chars
                    boundingBox = boundingBox.calculateArea(this._convertCoords(i, text));
                }

            }
            return boundingBox;
        }


        return TextSelectionTool;
    });

define('web-viewer/svg/TextSelectionModel',["web-viewer/core/AbstractModel",
        "utils/ShapeUtils"
    ],
    function (AbstractModel,
        ShapeUtils) {
        "use strict";

        /**
         * @exports TextSelectionModel
         * @memberof SvgModule
         * @class The TextSelectionModel is used for representing all text selection tool info
         * @constructor
         * @augments {Core.AbstractModel}
         *
         * @param {Core.ViewerFacade} f - Viewer facade
         * @param {String} privateChannelName - The privateChannelName of the model
         */
        var TextSelectionModel = function (f, privateChannelName) {
            AbstractModel.call(this, f, privateChannelName);

            this._startPoint = null;
            this._endPoint = null;
            this._content = "";
        };

        TextSelectionModel.prototype = Object.create(AbstractModel.prototype);
        TextSelectionModel.prototype.constructor = TextSelectionModel;

        /**
         * Set the start point.
         * @param {ShapeUtils.Point} startPoint
         */
        TextSelectionModel.prototype.setStartPoint = function (startPoint) {
            this._startPoint = startPoint;
        };

        /**
         * Get the start point.
         * @returns {ShapeUtils.Point} - startPoint
         */
        TextSelectionModel.prototype.getStartPoint = function () {
            if (this._startPoint) {
                return this._startPoint;
            } else {
                return new ShapeUtils.Point(0, 0);
            }
        };


        /**
         * Set the end point.
         * @param {ShapeUtils.Point} endPoint
         */
        TextSelectionModel.prototype.setEndPoint = function (endPoint) {
            this._endPoint = endPoint;
        };

        /**
         * Get the end point.
         * @returns {ShapeUtils.Point} - endPoint
         */
        TextSelectionModel.prototype.getEndPoint = function () {
            if (this._endPoint) {
                return this._endPoint;
            } else {
                return new ShapeUtils.Point(0, 0);
            }
        };

        /**
         * Set the text content.
         * @param {String} content
         */
        TextSelectionModel.prototype.setContent = function (content) {
            this._content = content;
        };

        /**
         * Get the text content
         * @returns {String} - content
         */
        TextSelectionModel.prototype.getContent = function () {
            return this._content;
        };

        return TextSelectionModel;
    });

/**
 * @namespace SvgModule
 */
define('web-viewer/svg/SvgModule',["web-viewer/core/AbstractModule",
		"web-viewer/compare/CompareConstants",
		"./SvgDataExtensions",
		"./SvgLayerModel",
		"./SvgDiffLayerModel",
		"./TextSelectionTool",
		"./TextSelectionModel",
		"web-viewer/layout/LayoutConstants",
		"component/toolbar/ToolbarComponent",
		"component/toolbar/ButtonGroup",
		"web-viewer/layout/component/ViewerToolbarButton",
		"underscore"
	],
	function (AbstractModule,
		CompareConstants,
		SvgDataExtensions,
		SvgLayerModel,
		SvgDiffLayerModel,
		TextSelectionTool,
		TextSelectionModel,
		LayoutConstants,
		ToolbarComponent,
		ButtonGroup,
		ViewerToolbarButton,
		_) {
		"use strict";

		/**
		 * Module for enable viewing of svg files
		 * @param {ViewerFacade} f
		 * @param {Boolean} silenced
		 */
		var SvgModule = function (f, silenced) {
			AbstractModule.call(this, f, silenced, "svg");
			SvgDataExtensions(f);

			/**
			 * @member {SvgLayerModel} SvgLayerModel
			 * @private
			 */
			this._layerModel = null;

			/**
			 * @member {SvgDiffLayerModel} SvgDiffLayerModel
			 * @private
			 */
			this._diffLayerModel = null;

			f.getDocumentController().whenActiveOrDifferencePageChangedAndParametersAvailable(_.bind(this._setSVGLayerModels, this));

			// Toggle the diff layer 
			this.f.on("module.compare.changed.diffMode", _.bind(function (oldMode, newMode) {
				this.f.getModule("viewport").toggleLayer("SVGDifferenceLayer", newMode === CompareConstants.diffMode.READERSPREAD);
			}, this));


			this._textSelectionModel = new TextSelectionModel(f, [this.getPrivateChannelName(), "textSelection", "model"]);

			// Add text selection tool to the toolbar
			this._textSelectionTool = new TextSelectionTool(f, this._textSelectionModel);
			this._publishTool(this._textSelectionTool);

			this._textSelectionButtonGroup = null;

			this._publishToolbarComponent(LayoutConstants.ToolbarComponent.TEXTSELECTION, _.bind(function (layoutType) {
				/**
				 * Component: Textselection
				 */
				var textSelectionToolbar = new ToolbarComponent(LayoutConstants.ToolbarComponent.TEXTSELECTION, f);


				/**
				 * Group
				 */
				var selectionGroup = new ButtonGroup("selectionGroup");
				selectionGroup.setTitle(f.i18n, "viewer", "TextBtnGroupTitle");
				textSelectionToolbar.addButtonGroup(selectionGroup);

				this._textSelectionButtonGroup = selectionGroup;

				// select button
				var textSelectionButton = new ViewerToolbarButton(f, "TextSelectionButton", "icon icon-WCR_Viewer-TextSelection", false);
				textSelectionButton.setTooltip("viewer", "TextSelectionTT");
				textSelectionButton.listenToTool(this._textSelectionTool, true);
				selectionGroup.addButton(textSelectionButton);


				return textSelectionToolbar;
			}, this));
		};

		// inherit
		SvgModule.prototype = Object.create(AbstractModule.prototype);
		// correct the constructor pointer 
		SvgModule.prototype.constructor = SvgModule;

		/**
		 * set the correct pages for the svg layer models
		 * @param {WebCenterDocumentPage} page
		 */
		SvgModule.prototype._setSVGLayerModels = function () {
			var page = this.f.getActivePage();
			var hasSVG = page.hasSvg();
			if (hasSVG) {
				if (!this._layerModel) {
					this._layerModel = new SvgLayerModel(this.f, "SVGLayer", page);
				} else {
					this._layerModel.setPage(page);
				}

				var diffPage = this.f.getDocumentController().getDifferencePage();

				// could be that diffpage is null -> no problem
				if (!this._diffLayerModel) {
					this._diffLayerModel = new SvgDiffLayerModel(this.f, "SVGDifferenceLayer", diffPage);
				}

				if (this._textSelectionButtonGroup) {
					this._textSelectionButtonGroup.show();
				}

			} else {
				if (this._textSelectionButtonGroup) {
					this._textSelectionButtonGroup.hide();
				}
				if (this._textSelectionTool) {
					this._textSelectionTool.deactivate();
				}
			}

			// Set/Remove svg layers
			this.f.whenModuleAvailable("viewport", function (viewportModule) {
				viewportModule.whenWidgetModelAvailable(function () {
					if (hasSVG) {
						viewportModule.addLayer("SVGLayer", this._layerModel);
						viewportModule.addLayer("SVGDifferenceLayer", this._diffLayerModel);
					} else {
						viewportModule.removeLayer("SVGLayer");
						viewportModule.removeLayer("SVGDifferenceLayer");
					}


				}, this);
			}, this);
		};

		return SvgModule;

	});

