define(["web-viewer/layout/component/Popup",
		"web-viewer/layout/component/MiniButton",
		"./TextElementDynContentWidget",
		"packaging-content-management/text-content-services/languageService",
		"packaging-content-management/text-content-utils/LanguageUtils",
		"jquery",
		"underscore"
	],
	function (Popup,
		MiniButton,
		TextElementDynContentWidget,
		languageService,
		languageUtils,
		$,
		_) {
		"use strict";

		/**
		 * Create an annotation popup. 
		 * Initial (re)paint should be called by caller
		 * 
		 * @exports DynContentPopup
		 * @memberof TextContentModule
		 * @class
		 * The dyncontent annotation popup controls the popup for dyncontent annotation details
		 * @constructor	  
		 * @augments Layout.Popup
		 * @param {Core.ViewerFacade} f - Viewerfacade
		 * @param {DynContentModel} dynContentModel - The dynamic content model
		 * @param {String} id - Id of the popup used for its private channel
		 * @param {List<DynContentAnnotation>} dynContentAnnotations - DynContentAnnotations this popup belongs to
		 * @param {JQueryObj} container - The container where the popup should stay in
		 */
		var DynContentPopup = function (f, id, dynContentModel, dynContentPopupModel, textElement, container) {
			this.f = f;
			Popup.call(this, f, id, container);

			this.dynContentPopupModel = dynContentPopupModel;
			this.dynContentModel = dynContentModel;
			this.textElement = textElement;
			this.element.addClass("DynContentPopup");

			// By default, the popup is not visible.
			this.visible = false;

			// The text element widget
			this._textElementWidget = undefined;

			this.minWidth = 300;
			this.minHeight = 144;
		};

		DynContentPopup.prototype = Object.create(Popup.prototype);
		DynContentPopup.prototype.constructor = DynContentPopup;

		/**
		 * Initialize the popup, create needed DOM events, listeners
		 * 
		 * @private
		 * @override
		 */
		DynContentPopup.prototype._initialize = function () {
			if (!this._isInitialized) {
				Popup.prototype._initialize.call(this);

				// Generate the language header.
				languageService.getLanguages(this.textElement.parentStatement.projectId, function (projectMasterLangs, projectTranslationLangs, allMasterLangs, allTranslationLangs) {
					// Find the language object for this text element.
					var language;
					if (this.textElement.isMaster()) {
						language = languageUtils.getLangForCode(allMasterLangs, this.textElement.language);
					} else {
						language = languageUtils.getLangForCode(allTranslationLangs, this.textElement.language);
					}

					// Generate the language header.
					var langHeader = $("<span>", {
						"class": "TransHeader"
					});
					langHeader.append($("<img>", {
						"src": "./images/country_flags/" + language.langFlag,
						"style": "margin-top: -3px; margin-right: 5px;"
					}));
					langHeader.append($("<span>", {
						"style": "font-weight: bold"
					}).text(language.langDesc));

					// Add it to the header
					this.header.append(langHeader);
				}.bind(this));

				// Create the TextElementDynContentWidget
				this._textElementWidget = new TextElementDynContentWidget(this.dynContentModel, this.dynContentPopupModel, this.textElement);
				this.setContent(this._textElementWidget.getJQElement());
			}
		};
		
		/**
		 * 
		 * @param location
		 * @param width
		 */
		DynContentPopup.prototype.show = function (location, width) {
			Popup.prototype.show.call(this, location, width);
			this._textElementWidget.shownInPage();
		};

		/**
		 * Update the popup with a new textElement.
		 * 
		 * @param textElement
		 */
		DynContentPopup.prototype.update = function (textElement) {

			// Only update if a different text element is passed.
			if (textElement == this.textElement) {
				return;
			}

			// Set the new text element.
			this.textElement = textElement;
			if (this._textElementWidget) {
				this._textElementWidget.update(textElement);
			}
		};

		/**
		 * Set focus on or off on the widget.
		 */
		DynContentPopup.prototype.focus = function (focus) {
			if (this._textElementWidget) {
				this._textElementWidget.focus(focus);
			}
		};

		return DynContentPopup;
	});