define(["component/toolbar/ToolbarComponent",
		"component/toolbar/ButtonGroup",
		"web-viewer/layout/component/ViewerToolbarButton",
		"web-viewer/layout/component/SubtoolbarButton",
		"web-viewer/layout/LayoutConstants",
	],
	function (ToolbarComponent,
		ButtonGroup,
		ViewerToolbarButton,
		SubtoolbarButton,
		LayoutConstants) {
		"use strict";

		
		/**
		 * @exports DynContentToolbarComponent
		 * @memberof DynContentModule
		 * @constructor
		 * @param {Core.ViewerFacade} f - Viewer facade
		 * @param {DynContentModel} dynContentModel - Dynamic Content model
		 * @param {DynContentTool} dynContentTool - The dynamic content tool
		 */
		var DynContentToolbarComponent = function (f, dynContentModel, dynContentTool) {
			ToolbarComponent.call(this, LayoutConstants.ToolbarComponent.DYNCONTENT, f);
			this.f = f;
			this.dynContentModel = dynContentModel;
			/**
			 * Group: annotate
			 */
			var dynContentGroup = new ButtonGroup("DynContentGroup");
			dynContentGroup.setTitle(f.i18n, "viewer", "DynContentBtnGroupTitle");
			this.addButtonGroup(dynContentGroup);
			
			// DynContent ViewerToolbarButton
			var toggleDynContentButton = new ViewerToolbarButton(f, "ToggleDynContentButton", f.getOption("PREFERENCES_DYNCONTENTTOOLS_VISIBLE") ? "icon-WCR_Annotation-DC-Hide" : "icon-WCR_Annotation-DC-Show", true, function () {
				dynContentModel.toggleVisibility();
			});
			// set initial tooltip
			toggleDynContentButton.setTooltip("viewer", f.getOption("PREFERENCES_DYNCONTENTTOOLS_VISIBLE") ? "HideDynContentsBtnTT" : "ShowDynContentsBtnTT");
			// react on preference changes
			f.getCurrentUser().on("options.changed.PREFERENCES_DYNCONTENTTOOLS_VISIBLE", function (oldValue, newValue) {
				if (newValue) {
					toggleDynContentButton.setTooltip("viewer", "HideDynContentsBtnTT");
					toggleDynContentButton.setIcon("icon-WCR_Annotation-DC-Hide");
				} else {
					toggleDynContentButton.setTooltip("viewer", "ShowDynContentsBtnTT");
					toggleDynContentButton.setIcon("icon-WCR_Annotation-DC-Show");
				}
			});
			dynContentGroup.addButton(toggleDynContentButton);
		};
		
		DynContentToolbarComponent.prototype = Object.create(ToolbarComponent.prototype);
		DynContentToolbarComponent.prototype.constructor = DynContentToolbarComponent;
		DynContentToolbarComponent.toolbarName = LayoutConstants.ToolbarComponent.DYNCONTENT;
		
		
		return DynContentToolbarComponent;
});
		