/**
 * ContentStatementElement object
 * @author HUBU
 */
define(["jquery",
        "packaging-content-management/text-content-element-widget/TextContentElementWidget",
        "packaging-content-management/text-content-services/languageService",
		"packaging-content-management/text-content-utils/LanguageUtils",
		"utils/ShapeUtils",
		"utils/webi18n!viewer"
	],
	function ($,
			TextContentElementWidget,
			languageService,
			languageUtils,
			ShapeUtils,
			i18nViewerStrings) {
		"use strict";
		
		var TextElementDynContentWidget = function (dynContentModel, dynContentPopupModel, textElement) {
			
			this.dynContentModel = dynContentModel;
			this.dynContentPopupModel = dynContentPopupModel;
			this.textElement = textElement;
			this.popup = this.dynContentPopupModel.popup;
			this.transTextElement;

			// Create the wrapping table.
			this._wrapper = $("<table>").css("height","100%").css("width","100%");
			
			// Initialize the widget.
			this.init();
		};
		
		/**
		 * Initialize the widget.
		 */
		TextElementDynContentWidget.prototype.init = function () {

			// Create a TextContentElementWidget.
			this._widget = new TextContentElementWidget(this.textElement, {
				viewOptions: {
					widgetview : "viewer",
					maxChars : this.textElement.getParent().getMaxChars()
				}
			});
			this._widget.onChange(function () {
				// Show the save button if it's not already there.
				if (this._rightOptionCell.has(this._saveButton)) {
					this._rightOptionCell.append(this._saveButton);
				}
				this.dynContentModel.textElementChanged(this.textElement, this);
			}.bind(this));
			// Add the TextContentElementWidget to the wrapper.
			this._masterTextWidgetRow = $("<tr>", {"style" : "height: 100%;"});
			this._masterTextWidgetCell = $("<td>", {"style" : "height: 100%;"});
			this._wrapper.append(this._masterTextWidgetRow.append(this._masterTextWidgetCell.append(this._widget.getJQElement())));
			
			// Add a hidden row to show the header of a potential translation language.
			this._translationHeaderCell = $("<td>");
			this._translationHeaderRow = $("<tr>",{"class" : "TransHeaderRow"}).hide();
			this._wrapper.append(this._translationHeaderRow.append(this._translationHeaderCell));
			
			// Add a hidden row to show the widget of a potential translation language.
			this._transWidget;
			this._translationWidgetCell = $("<td>", {"style" : "height: 100%;"});
			this._translationWidgetRow = $("<tr>", {"style" : "height: 100%;"}).hide();
			this._wrapper.append(this._translationWidgetRow.append(this._translationWidgetCell));
			
			// Create a bottom bar to show additional options.
			this._leftOptionCell = $("<td>", {"class" : "LeftOption"});
			this._rightOptionCell = $("<td>", {"class" : "RightOption"});
			this._optionBar = $("<table>", {"class" : "OptionBar"}).append($("<tr>").append(this._leftOptionCell).append(this._rightOptionCell));
				
			// Add the save button.
			this._saveButton = $("<a>", {"class": "btn btn-default btn-mini btn-success"});
			this._saveButton.append($("<span>", {"class" : "icon icon-WCR_Save12 marginRight5 icon-normal", "style" : "color: #333;"}));
			this._saveButton.append($("<span>").text(i18nViewerStrings.t("PCMDynContentSave")));
			this._saveButton.on("click", function (e) {
				this.dynContentModel.save(this.textElement);
			}.bind(this));
			if (this.textElement.isChanged()) {
				this._rightOptionCell.append(this._saveButton);
			}
			
			
			// Add the option bar to the wrapper.
			this._wrapper.append($("<tr>", {"class" : "OptionRow"}).append($("<td>").append(this._optionBar)));
			
			// Show the option to translate the statement.
			this._updateShowTranslationOption();
			
			// When the translation language changes ... update also the translation option.
			this.dynContentModel.on("translationLangChanged", function () {
				this._updateShowTranslationOption();
				this.hideTranslation();
			}.bind(this));
			
			// When a text element was changed from within a widget.
			this.dynContentModel.on("textElementChanged", function (textElement, fromWidget) {
				if (fromWidget == this) {
					return false;
				}
				if (textElement == this.textElement) {
					this._widget.update(textElement);
					this._rightOptionCell.empty();
					this._rightOptionCell.append(this._saveButton);
					return true;
				} else if (textElement == this.transTextElement) {
					this._transWidget.update(textElement);
					this._rightOptionCell.empty();
					this._rightOptionCell.append(this._saveButton);
					return true;
				}
			}.bind(this));
			
			// Disable the widget when save operation starts.
			this.dynContentModel.on("save.started", function (textElement, fromWidget) {
				// Disable the widgets and buttons.
				if (this._widget) {
					this._widget.disable();
				}
				if (this._transWidget) {
					this._transWidget.disable();
				}
				if (this._saveButton) {
					this._saveButton.prop('disabled', true);
				}
			}.bind(this));
			
			// Enable the widget when save operation finishes.
			this.dynContentModel.on("save.finished", function (textElement, fromWidget) {
				// Disable the widgets and buttons.
				if (this._widget) {
					this._widget.enable();
				}
				if (this._transWidget) {
					this._transWidget.enable();
				}
				if (this._saveButton) {
					this._saveButton.prop('disabled', false);
				}
			}.bind(this));
			
		};
		
		/**
		 * This is going to be called when the widget is shown in the page.
		 */
		TextElementDynContentWidget.prototype.shownInPage = function () {
			this._widget.shownInPage();
		};
		
		/**
		 * Update the widget with a different text element.
		 * 
		 * @param textElement
		 */
		TextElementDynContentWidget.prototype.update = function (textElement) {
			// Update the textElement.
			this.textElement = textElement;
			this.transTextElement = undefined;
			// Re-init the widget.
			this._wrapper.empty();
			this.init();
		};
		
		/**
		 * Show another translation language allong the master language.
		 * 
		 * @param langCode
		 */
		TextElementDynContentWidget.prototype.showTranslation = function (transTextElement) {
			
			// Check if this is a master language.
			if (!this.textElement.isMaster()) {
				return;
			}
			
			// If we're already showing a translation.
			if (this.showingTranslation) {
				return;
			}
			
			// If this is a new transTextElement.
			if (transTextElement != this.transTextElement) {
				this.transTextElement = transTextElement;
				
				// Create a TextContentElementWidget for this translation.
				this._transWidget = new TextContentElementWidget(transTextElement, {
					viewOptions: {
						widgetview : "viewer",
						maxChars : this.textElement.getParent().getMaxChars()
					}
				});
				this._transWidget.onChange(function () {
					// Show the save button if it's not already there.
					if (this._rightOptionCell.has(this._saveButton)) {
						this._rightOptionCell.append(this._saveButton);
					}
					this.dynContentModel.textElementChanged(this.transTextElement, this);
				}.bind(this));
				this._translationWidgetCell.empty();
				this._translationWidgetCell.append(this._transWidget.getJQElement());
				
				// Create a header for this translation.
				languageService.getLanguages(this.textElement.parentStatement.projectId, function(projectMasterLangs, projectTranslationLangs, allMasterLangs, allTranslationLangs) {
					// Get the translang object.
					var language = languageUtils.getLangForCode(allTranslationLangs, transTextElement.language);

					// Generate the language header.
					var transHeader = $("<span>", {"class": "TransHeader"});
					transHeader.append($("<img>", {"src": "./images/country_flags/"+language.langFlag, "style" : "margin-top: -3px; margin-right: 5px;"}));
					transHeader.append($("<span>", {"style":"font-weight: bold"}).text(language.langDesc));
					
					// Add it to the row
					this._translationHeaderCell.empty();
					this._translationHeaderCell.append(transHeader);
				}.bind(this));
				
			} else {
				// This translation language is already set, just show it again.
			}
			
			// Set the variable on true
			this.showingTranslation = true;
			
			// Make room to show the translation.
			this._resizeToShowTranslation();
			
			// Apply the correct CSS to fill.
			this._translationWidgetCell.attr("style", "height: 45%;)");
			this._translationWidgetRow.attr("style", "height: 45%;");
			this._masterTextWidgetRow.attr("style", "height: 45%;");
			this._masterTextWidgetCell.attr("style", "height: 45%;");
			
			// Show/Hide the necessary elements.
			this._translationHeaderRow.show();
			this._translationWidgetRow.show();
			this._hideTransButton.show();
			this._showTransButton.hide();
		};
		
		/**
		 * Hide the translation language for this master language.
		 * 
		 * @param langCode
		 */
		TextElementDynContentWidget.prototype.hideTranslation = function () {
			
			// Check if this is a master language.
			if (!this.textElement.isMaster()) {
				return;
			}
			
			// If we're already hiding the translation.
			if (!this.showingTranslation) {
				return;
			}
			
			// Set the variable on false.
			this.showingTranslation = false;
			
			// Clear room to show only the master text.
			this._resizeToHideTranslation();
			
			// Apply the correct CSS to fill.
			this._translationWidgetCell.attr("style", "height: 100%;");
			this._translationWidgetRow.attr("style", "height: 100%;");
			this._masterTextWidgetRow.attr("style", "height: 100%;");
			this._masterTextWidgetCell.attr("style", "height: 100%;");
			
			// Show/Hide the necessary elements.
			this._translationHeaderRow.hide();
			this._translationWidgetRow.hide();
			this._hideTransButton.hide();
			this._showTransButton.show();
		};
		
		/**
		 * Resize the containing popup so that there's room to show the translation.
		 */
		TextElementDynContentWidget.prototype._resizeToShowTranslation = function () {
			// Only make vertically room.
			var curHeight = this.popup.element.height();
			// How many of that space is taken up by the master text?
			var masterTextHeight = Math.max(curHeight-(26+36+2), 78);
			// We'll have to be carefull to not make the widget to big, therefore ceil the masterTextHeight to 120px;
			var ceiledMasterTextHeight = Math.min(120, masterTextHeight);
			// The new height should be twice the height of the master text + space of the translation header.
			var newHeight = 26 + ceiledMasterTextHeight + 26 + ceiledMasterTextHeight + 36 + 2;
			// Create the new size.
			var newSize = new ShapeUtils.Size(this.popup.element.width()+2, newHeight);
			// Calculate the new min size.
			this.popup.minHeight = this.popup.minHeight + 78 + 26;
			var minSize = new ShapeUtils.Size(this.popup.minWidth, this.popup.minHeight);
			
			// Set the new size.
			this.popup.setMinSize(minSize);
			this.popup.setSize(newSize);
			var ui = {
					position: {
						left: this.popup.element.position().left,
						top: this.popup.element.position().top
					},
					size: {
						width: newSize.width,
						height: newSize.height
					}
				};
			this.popup._fireResized(ui, false);
		};
		
		/**
		 * Resize the containing popup so that room will free up since the translation no longer needs to be shown.
		 */
		TextElementDynContentWidget.prototype._resizeToHideTranslation = function () {
			// Only make vertically room. curHeight = master header (26) + translation header (26) + flag area (36) + text area for two languages (78*2)
			var curHeight = this.popup.element.height();
			// How many space do both texts take up? 
			var bothTextHeight = Math.max(curHeight-(26+26+36), 2*78);
			// We'll have to be carefull to not make the widget to big
			var masterTextHeight = Math.floor(bothTextHeight/2);
			// The new height should be twice the height of the master text + space of the translation flag.
			var newHeight = 26 + masterTextHeight + 36 + 2;
			// Create the new size.
			var newSize = new ShapeUtils.Size(this.popup.element.width()+2, newHeight);			
			// Calculate the new min size.
			this.popup.minHeight = 144;
			var minSize = new ShapeUtils.Size(this.popup.minWidth, this.popup.minHeight);			
			// Set the new size.
			this.popup.setMinSize(minSize);
			this.popup.setSize(newSize);
			var ui = {
					position: {
						left: this.popup.element.position().left,
						top: this.popup.element.position().top
					},
					size: {
						width: newSize.width,
						height: newSize.height
					}
				};
			this.popup._fireResized(ui, false);
		};
		
		
		/**
		 * This will possibly generate a button to display the text of current translation language along with the current master text of this text element.
		 * (Will only show when this is a popup for a master text).
		 */
		TextElementDynContentWidget.prototype._updateShowTranslationOption = function () {
			
			if (this.textElement.isMaster()) {
				// Get the current translation language.
				var curTransLang = this.dynContentModel.getCurrentTransLangCode();
				
				// Check if this master statement has the translation attached of the current translation language.
				var transTextElement = undefined;
				for (var i=0; i < this.textElement.parentStatement.element.length; i++) {
					var aTextElement = this.textElement.parentStatement.element[i];
					if (aTextElement.language == curTransLang && !aTextElement.isMaster()) {
						transTextElement = aTextElement;
						break;
					}
				}
				
				// If such a translation was found, generate a button to show it in this popup.
				if (transTextElement) {
					// Generate the language header.
					languageService.getLanguages(this.textElement.parentStatement.projectId, function(projectMasterLangs, projectTranslationLangs, allMasterLangs, allTranslationLangs) {
						// Find the language object for this text element.
						
						var language = languageUtils.getLangForCode(allTranslationLangs, curTransLang);
						
						// Generate the show translate button.
						this._showTransButton = $("<a>", {"class": "btn btn-default btn-mini"});
						this._showTransButton.append($("<span>").text(i18nViewerStrings.t("PCMDynContentShow")));
						this._showTransButton.append($("<img>", {"src": "./images/country_flags/"+language.langFlag, "style" : "margin-top: -2px; margin-left: 5px;"}));
						
						// Generate the hide translate button.
						this._hideTransButton = $("<a>", {"class": "btn btn-default btn-mini"});
						this._hideTransButton.append($("<span>").text(i18nViewerStrings.t("PCMDynContentHide")));
						this._hideTransButton.append($("<img>", {"src": "./images/country_flags/"+language.langFlag, "style" : "margin-top: -2px; margin-left: 5px;"}));
						this._hideTransButton.hide();
						
						// When the show translate button is clicked.
						this._showTransButton.on("click", function () {
							this.showTranslation(transTextElement);
						}.bind(this));
						
						// When the show translate button is clicked.
						this._hideTransButton.on("click", function () {
							this.hideTranslation();
						}.bind(this));
						
						// Add it.
						this._leftOptionCell.empty();
						this._leftOptionCell.append(this._showTransButton);
						this._leftOptionCell.append(this._hideTransButton);
						
						//if there was already a translation that was opened on canvas, then close that and show the new language that was clicked from filter
						if(this.showingTranslation){
							this.hideTranslation();		
							this.showTranslation(transTextElement);
						}
							
					}.bind(this));
				} else {
									
					this._leftOptionCell.empty();
				}
			} else {
				this._leftOptionCell.empty();
			}
			
		};
		
		/**
		 * Focus on this popup widget.
		 */
		TextElementDynContentWidget.prototype.focus = function (focus) {
			this._widget.focus(focus);
		};
		
		/**
		 * 
		 * @returns
		 */
		TextElementDynContentWidget.prototype.onChange = function (callback) {
			this._widget.onChange(callback);
		};
		
		/**
		 * 
		 * @returns
		 */
		TextElementDynContentWidget.prototype.getJQElement = function () {
			return this._wrapper;
		};
		
		return TextElementDynContentWidget;
});