define(["component/toolbar/ToolbarComponent",
		"component/toolbar/ButtonGroup",
		"web-viewer/layout/component/ViewerToolbarButton",
		"web-viewer/layout/LayoutConstants"
	],
	function (ToolbarComponent,
		ButtonGroup,
		ViewerToolbarButton,
		LayoutConstants
	) {
		"use strict";

		/**
		 * @exports View3DToolbarComponent
		 * @memberof View3DModule
		 * @constructor
		 * @param {Core.ViewerFacade} f - Viewer facade
		 * @param {View3DModule} viewController
		 */
		var View3DToolbarComponent = function (f, viewController) {
			ToolbarComponent.call(this, LayoutConstants.ToolbarComponent.VIEW3D, f);

			this.f = f;

			this._viewController = viewController;

			var view3DBtnGroup = new ButtonGroup("View3DGroup");
			view3DBtnGroup.setTitle(this.f.i18n, "viewer", "View3DBtnGroupTitle");
			this.addButtonGroup(view3DBtnGroup);

			var view3DButton = new ViewerToolbarButton(this.f, "view3DButton", "icon-WCR_3D", false, _.bind(this._show3DView, this));
			view3DButton.setTooltip("viewer", "Open3DViewTT");
			view3DBtnGroup.addButton(view3DButton);

		};

		View3DToolbarComponent.prototype = Object.create(ToolbarComponent.prototype);
		View3DToolbarComponent.prototype.constructor = View3DToolbarComponent;
		View3DToolbarComponent.toolbarName = LayoutConstants.ToolbarComponent.VIEW3D;

		/**
		 * Show the 3D view, take unsaved alignment into account.
		 * @private
		 */
		View3DToolbarComponent.prototype._show3DView = function () {
			var compareModule = this.f.getModule("compare");
			if (compareModule) { //pass opening of 3D through the compare module
				compareModule.checkAligmentAndShow3D();
			} else { //no compare module (only CAD is open) load the 3D View
				this._viewController.show3D();
			}
		};

		return View3DToolbarComponent;

	});