define(["web-viewer/core/AbstractConfig",
		"web-viewer/webcenter/WebCenterDataAdapter"
	],
	function (AbstractConfig,
		WebCenterDataAdapter) {
		/**
		 * @exports WebCenterConfig
		 * @class WebCenter configuration  <<extends AbstractConfig>>
		 * 
		 * configuration class specific for WebCenter usage
		 * @exports WebCenterConfig
		 * @memberof WebCenter
		 * @constructor
		 * @param instance - URL to WebCenter instance
		 * @param viewserver - URL to WebCenter ViewServer
		 */
		var WebCenterConfig = function (instance, viewserver, user) {
			AbstractConfig.call(this);

			/**
			 * @private
			 */
			this.modules = [];
			/**
			 * @private
			 */
			this.instance = instance;
			/**
			 * @private
			 */
			this.user = user;
			/**
			 * @private
			 */
			this.viewserver = viewserver;
		};

		WebCenterConfig.prototype = Object.create(AbstractConfig.prototype);
		WebCenterConfig.prototype.constructor = WebCenterConfig;

		/**
		 * Add a module
		 * @param {Core.AbstractModule} module
		 */
		WebCenterConfig.prototype.addModule = function (module) {
			this.modules.push(module);
		};

		/**
		 * Initialize this adapter
		 * @param {ViewerCore} f
		 * @returns {WebCenterDataAdapter} Initialized adapter
		 */
		WebCenterConfig.prototype.intializeAdapter = function (f) {
			this.adapter = new WebCenterDataAdapter(f, this.instance, this.viewserver);
			return this.adapter;
		};

		/**
		 * Get user
		 * @returns {WebCenterUser}
		 */
		WebCenterConfig.prototype.getUser = function () {
			return this.user;
		};

		/**
		 * Get modules
		 * @returns {Array.<String>}
		 */
		WebCenterConfig.prototype.getModules = function () {
			return this.modules;
		};

		return WebCenterConfig;
	});