define(["web-viewer/viewport/model/ViewportViewModel",
		"underscore"
	],
	function (ViewportViewModel,
		_) {
		"use strict";

		/**
		 * @memberof WebviewerModule
		 * @exports ViewserverViewModel
		 * @class 
		 * The viewserver view model is responsible to manage the layers on a view
		 * @constructor
		 * @augments Viewport.ViewportViewModel
		 * @param {Core.ViewerFacade} f - Facade
		 * @param {String} ID
		 * @param {String} title
		 * @param {Boolean} isDefaultView
		 */
		var WebviewerViewModel = function (f, ID, title, isDefaultView) {
			ViewportViewModel.call(this, f, ID, title, isDefaultView);

			var layerOrder = ["Graphics", "SVGLayer", "SVGDifferenceLayer", "Cad", "currentDiffCad", "referenceDiffCad", "referenceCad", "CadOverlay", "DynContent", "DynContentPopup", "Annotations", "AnnotationPopups"];



			/**
			 * Returns the index for a layer
			 * TODO: improve this implementation
			 */
			this.indexForLayer = function (layername, layers) {
				//Use the intersection of the layers and the layerOrder, so the index of the layers can be returned
				var currentLayers = _.keys(layers);
				currentLayers.push(layername);
				var layerUnion = _.intersection(layerOrder, currentLayers);
				return _.indexOf(layerUnion, layername);
			};

			/**
			 * swaps two layers if the index of the first layer is higher than the second
			 *
			 */
			this.swapLayers = function (layer, swap) {
				var index = layerOrder.indexOf(layer);
				var index2 = layerOrder.indexOf(swap);
				if (index > index2) {
					layerOrder[index2] = layer;
					layerOrder[index] = swap;
					this._emit("layerIndexChanged", [layer, swap]);
				}
			};
			this.on("layers.swapIfIndexIsHigher", _.bind(this.swapLayers, this));


		};

		// inherit
		WebviewerViewModel.prototype = Object.create(ViewportViewModel.prototype);
		// correct the constructor pointer 
		WebviewerViewModel.prototype.constructor = WebviewerViewModel;


		return WebviewerViewModel;
	});
