define(["./AbstractAPI",
		"./data/WebCenterSavedSearch",
		"utils/Map",
		"utils/webi18n!WebCenterAPI",
		"underscore",
		"jquery"
	],
	function (
		AbstractAPI,
		WebCenterSavedSearch,
		Map,
		i18n,
		_,
		$) {
		"use strict";

		/**
		 * Utility class used for all communication with WebCenter around attributes
		 * @exports SavedSearchAPI
		 * @class
		 * 
		 * @param {Object} wcrConfig - webcenter configuration object
		 */
		var SavedSearchAPI = function (wcrConfig) {
			AbstractAPI.call(this, wcrConfig);

			this._savedSearchPromise = null;
		};

		SavedSearchAPI.prototype = Object.create(AbstractAPI.prototype);
		SavedSearchAPI.prototype.constructor = SavedSearchAPI;


		/**
		 * Get a map of the available Saved Searches
		 * @returns {Promise.<Map.<id, WebCenterSavedSearch>>}
		 */
		SavedSearchAPI.prototype.getSavedSearches = function () {

			if (!this._savedSearchPromise) {
				this._savedSearchPromise = Promise.resolve(this.callSDK("GetSavedSearchList.jsp", {
					ajax: "1"
				}, {
					cache: false
				})).then(function (XML) {
					var map = new Map();
					_.each(XML.getElementsByTagName("saved_search"), function (XMLEl) {
						var search = WebCenterSavedSearch.fromXML(XMLEl);
						if (search) {
							map.add(search.getSavedSearchId(), search);
						}
					});

					return map;

				});
			}

			return this._savedSearchPromise;
		};


		return SavedSearchAPI;
	});