define([],
	function () {
		"use strict";

		/**
		 * Represents a WebCenter attribute
		 * @param {String}                 id            - Id of the attribute
		 * @param {String}                 name          - Name of the atttribute
		 * @param {WebCenterAttributeUnit} unit          - Unit of the attribute
		 * @param {WebCenterRestrictedSet} [restrictedSet] - Restricted set of the attribute (if any)
		 */
		var WebCenterAttribute = function (id, name, unit, restrictedSet) {
			this._id = id;
			this._name = name;
			this._unit = unit;
			this._restrictedSet = restrictedSet;
		};

		/**
		 * Get the ID of the attribute
		 * @returns {String}
		 */
		WebCenterAttribute.prototype.getId = function () {
			return this._id;
		};

		/**
		 * Get the name of attribute
		 * @returns {String}
		 */
		WebCenterAttribute.prototype.getName = function () {
			return this._name;
		};

		/**
		 * Get the unit attribute
		 * @returns {WebCenterAttributeUnit}
		 */
		WebCenterAttribute.prototype.getType = function () {
			return this._unit;
		};

		/**
		 * Get the restrictedSet or undefined if it isn't linked to one
		 * @returns {WebCenterRestrictedSet}
		 */
		WebCenterAttribute.prototype.getRestrictedSet = function () {
			return this._restrictedSet;
		};

		/**
		 * is this attribute of the Document Reference type?
		 * @returns {Boolean} 
		 */
		WebCenterAttribute.prototype.isDocRef = function () {
			if (this._unit) {
				return this._unit.isDocRef();
			} else {
				return false;
			}
		};


		return WebCenterAttribute;
	});