define([],
	function () {
		"use strict";

		/**
		 * Represents a WebCenter attribute unit
		 * @param {String} id - Id of the attribute unit
		 * @param {String} name - Name of the attribute unit e.g. Distance
		 * @param {String} type - Type of the attribute unit e.g. UNITS
		 */
		var WebCenterAttributeUnit = function (id, name, type) {
			this._id = id;
			this._name = name;
			this._type = type;
		};

		/**
		 * Get the ID of the attribute unit
		 * @returns {String}
		 */
		WebCenterAttributeUnit.prototype.getId = function () {
			return this._id;
		};

		/**
		 * Get the name of the attribute unit
		 * @returns {String}
		 */
		WebCenterAttributeUnit.prototype.getName = function () {
			return this._name;
		};

		/**
		 * Get the type of the attribute unit
		 * @returns {String}
		 */
		WebCenterAttributeUnit.prototype.getType = function () {
			return this._type;
		};

		/**
		 * Is it a document reference unit
		 * @returns {Boolean} 
		 */
		WebCenterAttributeUnit.prototype.isDocRef = function () {
			return this._id === '00001_0000000022';
		};
		
		/**
		 * Is it a dateTime attibute
		 * @returns {Boolean} 
		 */
		WebCenterAttributeUnit.prototype.isDateTime = function () {
			return this._id === '00001_0000000020';
		};

		return WebCenterAttributeUnit;
	});