define([],
	function () {
		"use strict";

		/**
		 * Represents a WebCenter restricted set
		 * @param {String} id - Id of the restricted set
		 * @param {String} name - Name of the restricted set e.g. Languages
		 * @param {WebCenterAttributeUnit} unit - Unit of the restricted set
		 * @param {Array.<WebCenterRestrictedSetValue>} values - Values of the restricted set                               
		 */
		var WebCenterRestrictedSet = function (id, name, unit, values) {
			this._id = id;
			this._name = name;
			this._unit = unit;
			this._values = values;
		};

		/**
		 * Get the ID of the restricted set
		 * @returns {String}
		 */
		WebCenterRestrictedSet.prototype.getId = function () {
			return this._id;
		};

		/**
		 * Get the name of the restricted set
		 * @returns {String}
		 */
		WebCenterRestrictedSet.prototype.getName = function () {
			return this._name;
		};

		/**
		 * Get the unit of the restricted set
		 * @returns {WebCenterAttributeUnit}
		 */
		WebCenterRestrictedSet.prototype.getType = function () {
			return this._unit;
		};

		/**
		 * Get the values of the restricted set
		 * @returns {Array.<WebCenterRestrictedSetValue>}
		 */
		WebCenterRestrictedSet.prototype.getValues = function () {
			return this._values;
		};


		return WebCenterRestrictedSet;
	});