define(["utils/FilterUtils", "underscore"],
	function (FilterUtils, _) {
		"use strict";

		/**
		 * Represents a WebCenter role
		 * @param {String} id - Id of the role
		 * @param {String} name - Name of the role
		 */
		var WebCenterRole = function (id, name, members) {
			this._id = id;
			this._name = name;
			this._members = members;
		};

		/**
		 * Get the ID of the role
		 * @returns {String}
		 */
		WebCenterRole.prototype.getId = function () {
			return this._id;
		};

		/**
		 * Get the name of the role
		 * @returns {String}
		 */
		WebCenterRole.prototype.getName = function () {
			return this._name;
		};


		WebCenterRole.prototype.setMembers = function (members) {
			this._members = members;
		};

		WebCenterRole.prototype.getMembers = function () {
			return this._members;
		};

		WebCenterRole.prototype.match = function (query, includeMembers) {
			var regex = FilterUtils.generateRegex(query, true);
			return this._name.match(regex) || (includeMembers && _.some(this._members, function (member) {
				return member.match(query, false);
			}));
		};

		/**
		 * Add extra markers for SAHI if needed (they are added after the default SHAI marker)
		 * @param {String} extraMarker - or null to reset extra markers
		 */
		WebCenterRole.prototype.setExtraSAHIMarkers = function (extraMarker) {
			this._extraMarker = extraMarker;
		};

		/**
		 * Get the SAHI Marker that can be used for this group
		 * @returns {string} [[Description]]
		 */
		WebCenterRole.prototype.getSAHIMarker = function () {
			var extra = (this._extraMarker ? (" " + this._extraMarker) : "");
			return "WCRROLE " + this.getName() + extra;
		};

		return WebCenterRole;
	});