define([], function () {
	"use strict";

	/**
	 * A representation of a SavedSearch
	 * @param {String}  savedSearchId         
	 * @param {String}  name                  
	 * @param {String}  type                  
	 * @param {Boolean} isGlobal              
	 * @param {String}  user_id               
	 * @param {String}  needsSmartNameContext 
	 */
	var WebCenterSavedSearch = function (savedSearchId, name, type, isGlobal, user_id, needsSmartNameContext) {
		this._savedSearchId = savedSearchId;
		this._name = name;
		this._type = type;
		this._isGlobal = isGlobal;
		this._user_id = user_id;
		this._needsSmartNameContext = needsSmartNameContext;
	};

	
	/**
	 * Get the Saved Search ID
	 * @returns {String} 
	 */
	WebCenterSavedSearch.prototype.getSavedSearchId = function () {
		return this._savedSearchId;
	};

	/**
	 * Get the name of the Saved Search
	 * @returns {String} 
	 */
	WebCenterSavedSearch.prototype.getName = function () {
		return this._name;
	};

	/**
	 * Get the type of the Saved Search
	 * @returns {String} 
	 */
	WebCenterSavedSearch.prototype.getType = function () {
		return this._type;
	};

	/**
	 * Is this search global
	 * @returns {Boolean} 
	 */
	WebCenterSavedSearch.prototype.isGlobal = function () {
		return this._isGlobal;
	};
	
	/**
	 * Get the User ID of the personal saved search
	 * @returns {String} 
	 */
	WebCenterSavedSearch.prototype.getUserId = function () {
		return this._user_id;
	};

	/**
	 * Is a smartname context needed
	 * @returns {Boolean} 
	 */
	WebCenterSavedSearch.prototype.needsSmartNameContext = function () {
		return this._needsSmartNameContext;
	};

	/**
	 * Convert in to a plain JSON object
	 * @returns {object} 
	 */
	WebCenterSavedSearch.prototype.toJSONObject = function () {
		return {
			savedSearchId: this.getSavedSearchId(),
			name: this.getName(),
			type: this.getType(),
			isGlobal: this.isGlobal(),
			user_id: this.getUserId(),
			needsSmartNameContext: this.needsSmartNameContext()
		};
	};

	/**
	 * Initialize a SavedSearch from JSON
	 * @param   {object}               JSON 
	 * @returns {WebCenterSavedSearch} (or undefined if something went wrong)
	 */
	WebCenterSavedSearch.fromJSONObject = function (JSON) {
		if (JSON && JSON.savedSearchId && JSON.name && JSON.type) {
			return new WebCenterSavedSearch(JSON.savedSearchId,
				JSON.name,
				JSON.type,
				JSON.isGlobal,
				JSON.user_id,
				JSON.needsSmartNameContext);

		}

	};

	/**
	 * Initialize a SavedSearch from XML
	 * @param   {XMLNode}              XMLNode 
	 *                                         @returns {WebCenterSavedSearch} 
	 */
	WebCenterSavedSearch.fromXML = function (XMLNode) {
		var id = XMLNode.getAttribute("id");
		var name = XMLNode.getElementsByTagName("name")[0];
		var deleted = XMLNode.getElementsByTagName("deleted")[0];
		var type = XMLNode.getElementsByTagName("type")[0];
		var scope = XMLNode.getElementsByTagName("scope_type")[0];
		var userid = XMLNode.getElementsByTagName("user_id")[0];
		var smartname = XMLNode.getElementsByTagName("smart_name_context")[0];

		if (id && deleted && type && scope && userid && smartname) {
			if (!deleted || deleted.textContent === "0") {
				return new WebCenterSavedSearch(id, name.textContent, type.textContent, scope.textContent === "0", userid.textContent, smartname.textContent === "1");
			}
		}
	};

	return WebCenterSavedSearch;

});