define(["utils/XMLUtils",
		"WFEditorWCR/core/WebCenterWFEditorConstants"
	],
	function (XMLUtils,
		WebCenterWFEditorConstants) {
		"use strict";

		/**
		 * Data structure for describing a WebCenter Task Type
		 * @class
		 * @exports WebCenterTaskType
		 */
		var WebCenterTaskType = function (taskTypeID, name, description, creatorID, leadDays, leadTime, hasWorkflow, icon, restrictedAssignee) {
			this._taskTypeID = taskTypeID;
			this._name = name;
			this._description = description;
			this._creatorID = creatorID;
			this._leadDays = leadDays;
			this._leadTime = leadTime;
			this._hasWorkflow = hasWorkflow;
			this._icon = icon;
			this._restrictedAssignee = restrictedAssignee;
		};

		/**
		 * Get the ID
		 * @returns {String}
		 */
		WebCenterTaskType.prototype.getId = function () {
			return this._taskTypeID;
		};

		/**
		 * Get the Name
		 * @returns {String} 
		 */
		WebCenterTaskType.prototype.getName = function () {
			return this._name;
		};

		/**
		 * Get the Name
		 * @returns {String} 
		 */
		WebCenterTaskType.prototype.getDescription = function () {
			return this._description;
		};

		/**
		 * Get the Lead Days
		 * @returns {String} 
		 */
		WebCenterTaskType.prototype.getLeadDays = function () {
			return this._leadDays;
		};

		/**
		 * Get the Lead Time
		 * @returns {String} 
		 */
		WebCenterTaskType.prototype.getLeadTime = function () {
			return this._leadTime;
		};

		/**
		 * Get the Icon
		 * @returns {String} 
		 */
		WebCenterTaskType.prototype.getIcon = function () {
			return this._icon || WebCenterWFEditorConstants.WorkflowTaskDefaultIcon;
		};

		/**
		 * Gets data about assignee restriction
		 * 
		 * @returns {Object} 		 {
		 *   							restriction : "role" | "group" | "noUser",
		 *   							[id]: <String>
		 *  						}
		 */
		WebCenterTaskType.prototype.getRestrictedAssignee = function () {
			return this._restrictedAssignee;
		};

		/**
		 * Has the task type a workflow or not
		 * @returns {Boolean} True if it is a workflow, false for a manual task
		 */
		WebCenterTaskType.prototype.hasWorkflow = function () {
			return this._hasWorkflow == "1";
		};

		/**
		 * Create a new WebCenterTaskType based on a XML description of the task type
		 * @param   {XMLDocument}         xml - xml description of the task type (wctask_type element)
		 * @returns {WebCenterTaskType} 
		 */
		WebCenterTaskType.fromXML = function (xml) {
			var taskTypeID = xml.getAttribute("id");
			var name = xml.getElementsByTagName("task_type_name")[0];
			var description = xml.getElementsByTagName("description")[0];
			var creatorID = xml.getElementsByTagName("creator_id")[0];
			var leadDays = xml.getElementsByTagName("approximate_length")[0];
			var leadTime = xml.getElementsByTagName("approximate_time")[0];
			var hasWorkflow = xml.getElementsByTagName("has_workflow")[0];
			var icon = xml.getElementsByTagName("icon")[0];
			var restrictedAssignee;
			var restrictedAssigneeTag = xml.getElementsByTagName("restrict_assignees");
			if (restrictedAssigneeTag && restrictedAssigneeTag[0] && restrictedAssigneeTag[0].textContent === "1") {
				var restrictAssigneeID = xml.getElementsByTagName("main_assignee_id");
				if (restrictAssigneeID && restrictAssigneeID[0]) {
					restrictedAssignee = {
						restriction: "roleOrGroup",
						id: restrictAssigneeID[0].textContent
					};
				} else {
					restrictedAssignee = {
						restriction: "noUser"
					};
				}

			}
			if (taskTypeID && name && description && creatorID && leadDays && leadTime && hasWorkflow && icon) {
				return new WebCenterTaskType(taskTypeID, name.textContent, description.textContent, creatorID.textContent, leadDays.textContent, leadTime.textContent, hasWorkflow.textContent, icon.textContent, restrictedAssignee);
			}
		};

		return WebCenterTaskType;

	});