<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
  <!ENTITY copy "&#169;">
  <!ENTITY nbsp "&#160;">
  <!ENTITY lk "/webcenter_page/user_lang_key">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java" xmlns:XSLUtils="com.esko.webcenter.jsp.XSLUtils" xmlns:Lang="com.esko.webcenter.jsp.LanguageMgr"
	exclude-result-prefixes="XSLUtils java Lang">
<xsl:import href="attrunittmplts.xsl"/>
<xsl:import href="templatedate.xsl"/>
 <xsl:import href="wizardtemplates.xsl"/>

  <xsl:key name="restrictedSetIDKey" match="/webcenter_page/restricted_set_list/restricted_set" use="@id"/>

	<!-- 
	Display the header on the attribute category (project or document details)
	
	If "useLabelOfDetailsMenu" is true, the label of the menu will be used instead.
	
	The catDisplayViewName is not used... (name of viewed is not displayed in the header)
	 -->
	<xsl:template name="DetailsAttributeHeader">
		<xsl:param name="catDisplayName"/>
		<xsl:param name="catDisplayViewName" select="Lang:getStr(&lk;, 'ACLayoutDefault')"/>
		<xsl:param name="isEditable"/>
		<xsl:param name="changeActionValue"/>
		<xsl:param name="showPrintButton" select="false()" />
		<xsl:param name="useLabelOfDetailsMenu"/>
		
		<!-- get the menu label -->
		<xsl:variable name="selecteddetailsmenulabeltag" select="/webcenter_page/nav/menus//menuitem[./name = string(/webcenter_page/nav/menu3/@selected)]/labeltag"/>
		
		<h2 class="page-sub-title">
			<xsl:choose>
				<xsl:when test="$useLabelOfDetailsMenu and $selecteddetailsmenulabeltag">
					<span><xsl:value-of select="Lang:getStrFallback(&lk;, $selecteddetailsmenulabeltag, $selecteddetailsmenulabeltag)"/></span>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="Lang:getStr(&lk;,'ATTR_CATEGORY_TITLE')"/>&nbsp;<span class="attribute-category-name"><xsl:value-of select="$catDisplayName"/></span>
				</xsl:otherwise>
			</xsl:choose>
			
			<div class="btn-group">
				<xsl:if test="$isEditable">
					<a class="btn btn-no-border hidden-print">
						<xsl:attribute name="title"><xsl:value-of select="Lang:getStr(&lk;,'PROJDETAILSATTRSCATEGORY_TAG')"/></xsl:attribute>
						 <xsl:call-template name="changeCategoryHref"/>
						<i class="icon icon-normal icon-WCR_Edit"></i>
					</a>
				</xsl:if>
					<a class="btn btn-no-border hiddenElement hidden-print" href="javascript:saveButtonClicked('{$changeActionValue}');" id="HeaderActionSaveAttrButton">
						<xsl:attribute name="title"><xsl:value-of select="Lang:getStr(&lk;,'SAVECHANGES')"/></xsl:attribute>
						<i class="icon icon-normal icon-WCR_Save"></i>
					</a>
				<xsl:if test="$showPrintButton">
					<a class="btn btn-no-border hidden-print" href="javascript:PrintWindow(true);">
						<xsl:attribute name="title"><xsl:value-of select="Lang:getStr(&lk;,'PRINT')" /></xsl:attribute>
						<i class="icon icon-normal icon-WCR_Print"></i>					
					</a>
				</xsl:if>
			</div>
		</h2>
	</xsl:template>	
	
	
  <xsl:template name="changeCategoryHref"/>

	
	<xsl:template name="DetailsAttributeCategoryHeader">
		<xsl:variable name="stepTag" select="checkin_wizard_definition/wizard_data/current_step_tag"></xsl:variable>
		<xsl:call-template name="WizardBar">
		  <xsl:with-param name="taskTitle" select="Lang:getStr(&lk;,'PICKCATEGORY')"/>
		  <xsl:with-param name="stepLabel" select="Lang:getStr(&lk;,$stepTag)"/>
		  <xsl:with-param name="wizardData" select="checkin_wizard_definition/wizard_data"/>
		  <xsl:with-param name="showTotalSteps" select="false()"/>
		  <xsl:with-param name="disableAfterSubmit" select="true()"/>
		  <xsl:with-param name="isBodyContentWizard" select="true()"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="DetailsAttributeCategoryTableHeader">
	  <xsl:param name="showRequired" select="false()"/>
	  <thead>
		  <tr>
			
			<th><xsl:value-of select="Lang:getStr(&lk;, 'NAME')"/></th>
			<th><xsl:value-of select="Lang:getStr(&lk;, 'VALUE')"/></th>
			<th><xsl:value-of select="Lang:getStr(&lk;, 'TYPE')"/></th>
			
		  </tr>
	   </thead>
	</xsl:template>	
	
	<!-- 
		
		Template that controls a display of list of attributes for management purposes
		
	-->
  <xsl:template name="DisplayAttributes">
	<xsl:param name="showAction" select="true()"/>
	<xsl:param name="showRequired" select="false()"/>
	<xsl:param name="showCheckbox" select="true()"/>
	<xsl:param name="root" select="attribute_list/attribute"/>
	<xsl:param name="showIsSpec" select="false()"/>
	<xsl:param name="widthSpace" select="'10'"/>

	<!-- data table -->
	
				<table class="ordtable">
					<!-- table header -->
					<thead>
					  <tr>
						<th class="td-checkbox">
							<xsl:choose>
								<xsl:when test="$showCheckbox">
									<input type="checkbox" name="selectall" value="" data-toggle-all="input[name='selectAttribute']">
									<xsl:attribute name="onclick">
										<xsl:if test="$showRequired">EnableAllRequired();</xsl:if>
									</xsl:attribute>
									</input>
								</xsl:when>
								<xsl:otherwise>#</xsl:otherwise>
							</xsl:choose>
						</th>
						<th>
							<xsl:value-of select="Lang:getStr(&lk;,'NAME')"/>								
						</th>
						<th>
						  <xsl:value-of select="Lang:getStr(&lk;,'DESCRIPTION')"/>
						</th>
						<th>
						  <xsl:value-of select="Lang:getStr(&lk;,'TYPE')"/>
						</th>
						
						<!-- when the task license is available, also indicate whether the attributes is marked as being a task specification -->
						<xsl:if test="count(/webcenter_page/has_task_management_license) > 0 and $showIsSpec">
							<th class="td-status">
							  <xsl:value-of select="Lang:getStr(&lk;,'PROJ_IS_TASK_SPECS')"/>
							</th>
						</xsl:if>
					  </tr>
					</thead>
					<!-- Data Elements -->
					<tbody>
					  <xsl:for-each select="$root">
						  <xsl:call-template name="AttributeMgmntRow">
							<xsl:with-param name="showNameLink" select="$showAction"/>
							<xsl:with-param name="showRequired" select="$showRequired"/>
							<xsl:with-param name="showCheckbox" select="$showCheckbox"/>
							<xsl:with-param name="showIsSpec"   select="$showIsSpec"/>							
						  </xsl:call-template>
					  </xsl:for-each>
					</tbody>
				</table>	
			
  </xsl:template>
  
  
  
<!--
	
	Template for showing an attribute row inside of the list of attributes for management purposes
	
-->    
  <xsl:template name="AttributeMgmntRow">	
	<xsl:param name="showNameLink" select="true()"/>
	<xsl:param name="showRequired" select="false()"/>
	<xsl:param name="showCheckbox" select="true()"/>
	<xsl:param name="showIsSpec" select="false()"/>
	
    <tr>
      <td class="td-checkbox">
		<xsl:choose>
			<xsl:when test="$showCheckbox">
				<input type="checkbox" name="selectAttribute" value="{@id}">
					<xsl:attribute name="onclick">Toggle(this);
					<!-- enable isRequired checkbox only when the attribute is selected -->
						<xsl:if test="$showRequired">EnableRequiredCheck(this);</xsl:if>
					</xsl:attribute>
				</input>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="position()"/>
			</xsl:otherwise>			
		</xsl:choose>
      </td>      
      <td>
		<xsl:choose>			
			<xsl:when test="$showNameLink">
				<!-- attribute name is a link to edit attribute -->
			  <a href="javascript:EditAttribute('{@id}')" >
				<xsl:value-of select="name"/>
			  </a>				
			</xsl:when>			
			<xsl:otherwise>
				<!-- attribute name is not a link. Then analyze if isRequired flag should be there -->
				<xsl:choose>
					<xsl:when test="$showRequired">
						<xsl:value-of select="name"/>&nbsp;&nbsp;
						<xsl:variable name="requiredName" select="concat('isRequired', @id)"/>												
						<input name="{$requiredName}" id="{$requiredName}" type="checkbox" disabled="disabled">
						<!-- add checked attribute based on a previous selection - NOW !!! -->
						</input>&nbsp;
						<xsl:value-of select="Lang:getStr(&lk;,'ATTR_REQUIRED')"/>						
					</xsl:when>
					<xsl:otherwise><xsl:value-of select="name"/></xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>			
		</xsl:choose>
      </td>
      <td>
          <xsl:if test="string-length(description) > 0">
            <xsl:value-of select="description"/>
          </xsl:if>
      </td>
      <td>
        <xsl:call-template name="SelAttributeUnitName">
          <xsl:with-param name="unitTypeID" select="attribute_unit_id"/>
        </xsl:call-template>
      </td>
      
      <!-- when the task license is available, show whether the attribute is marked as a task specification -->
      <xsl:if test="count(/webcenter_page/has_task_management_license) > 0 and $showIsSpec">
	      <td class="td-status">
		      	<xsl:if test="istask = 1">
		      		    <i class="icon icon-normal icon-WCR_Actions-Appr12"/>		      		
	    		</xsl:if>
	      </td>
      </xsl:if>
    </tr>
  </xsl:template>
  
  
<!--
	
	Template for showing attribute row
	
-->
  <xsl:template name="AttributeRow">
    <xsl:param name="isEditable"/>
		<xsl:param name="showRequired" select="false()"/>
		<xsl:param name="onChange"/>

    <tr id="TR{attribute/@id}">
	  <xsl:if test="position() mod 2 = 0">
		<xsl:attribute name="class"><xsl:value-of select="'alt'"/></xsl:attribute>
	  </xsl:if>
	 
      <td class="darktext_darklink_11">
				<xsl:value-of select="attribute/name"/>
	  </td>

      <xsl:call-template name="AttributeValue">
        <xsl:with-param name="isEditable" select="$isEditable"/>
        <xsl:with-param name="showRequired" select="$showRequired"/>			
				<xsl:with-param name="onChange" select="$onChange"/>
      </xsl:call-template>
      
      <td class="darktext_darklink_11">
        <xsl:call-template name="GetAttrUnitsLabel">
          <xsl:with-param name="unitTypeID" select="attribute/attribute_unit_id"/>
          <xsl:with-param name="restrictedSetID" select="attribute/restricted_set_id"/>
        </xsl:call-template>
      </td>
	  
    </tr>	
  </xsl:template>  
  
 <!--
	
	Template for attribute value display
	
 -->
  <xsl:template name="AttributeValue">
    <xsl:param name="isEditable"/>
		<xsl:param name="showRequired" select="false()"/>
		<xsl:param name="onChange"/>
	
    <!-- identify attribute type -->
	<xsl:variable name="attrUnitId" select="attribute/attribute_unit_id" />    
        
    <xsl:variable name="attributeValue">
      <xsl:call-template name="ConvertValueToUserUnits">
        <xsl:with-param name="curValue" select="attribute_value/value"/> 
        <xsl:with-param name="unitTypeID" select="attribute/attribute_unit_id"/> 
        <xsl:with-param name="withRounding" select="0"/> 
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="attributeDisplayValue">
      <xsl:call-template name="ConvertValueToUserUnits">
        <xsl:with-param name="curValue" select="attribute_value/value"/> 
        <xsl:with-param name="unitTypeID" select="attribute/attribute_unit_id"/> 
        <xsl:with-param name="withRounding" select="1"/> 
      </xsl:call-template>
    </xsl:variable>
    <input type="hidden" name="UN{attribute/@id}" value="{attribute/attribute_unit_id}"/>
		
    
	<td class="darktext_darklink_11">
		<table width="100%">
			<tr>
				<!-- show required field symbol-->
				<xsl:if test="$showRequired = true()">
				  <td align="center" class="small_text_bold" width="10" style="padding: 1px;">						
			  		<xsl:variable name="isRequired" select="is_required = '1'"/>
					  <xsl:if test="$isRequired">
							<xsl:value-of select="Lang:getStr(&lk;,'REQUIRED_FIELD_CHAR')"/>
			      </xsl:if>
				  </td>
				</xsl:if>
	
		<!-- show value -->
					
    <xsl:choose>
      <xsl:when test="$isEditable">
		<!-- display attributes based on the type. Date/time is different from others -->
		<xsl:choose>
			<xsl:when test="$attrUnitId = '00001_0000000020'">
				<!-- date/time type -->

				<xsl:call-template name="DisplayDateTypeAttributeValue">
					<xsl:with-param name="attributeValue" select="$attributeValue"/>
					<xsl:with-param name="attributeDisplayValue" select="$attributeDisplayValue"/>
					<xsl:with-param name="onChange" select="$onChange"/>
				</xsl:call-template>
				
			</xsl:when>
			
			<xsl:when test="$attrUnitId = '00001_0000000021'">
				
				<xsl:call-template name="DisplayRichTextAttributeValue">
					<xsl:with-param name="attributeValue" select="$attributeValue"/>
					<xsl:with-param name="attributeDisplayValue" select="$attributeDisplayValue"/>
					<xsl:with-param name="onChange" select="$onChange"/>
				</xsl:call-template>

			</xsl:when>
			
			<xsl:otherwise>
				<!-- non date/time types -->
			   <xsl:choose>
				  <xsl:when test="string-length(attribute/restricted_set_id)>0">
					<xsl:call-template name="RestrictedSetValue">
					  <xsl:with-param name="restrictedSetID" select="attribute/restricted_set_id"/>
					  <xsl:with-param name="attributeValue" select="$attributeValue"/>
					  <xsl:with-param name="attributeDisplayValue" select="$attributeDisplayValue"/>
					  <xsl:with-param name="attributeID" select="attribute/@id"/>
					</xsl:call-template>
				  </xsl:when>
				  <xsl:otherwise>
						<td class="darktext_darklink_11" align="left" style="padding: 1px;">
						
						<xsl:choose>
							<xsl:when test="string-length($attributeDisplayValue) &gt; 30">
								<!-- Display as a text area -->
								<textarea id="{attribute/@id}" name="{attribute/@id}" rows="4" style="width:100%; padding:1pt 3pt 1pt 3pt">
									<xsl:attribute name="onkeyup">
										return imposeMaxLength(this, <xsl:value-of select="//field_sizes/field_size [@key='attribute.value']/@value"/>);
									</xsl:attribute>
									<xsl:value-of select="$attributeDisplayValue" />
								</textarea>					
								
							</xsl:when>
							<xsl:otherwise>
								<!-- display is an input field -->
								<input id="{attribute/@id}" type="text" name="{attribute/@id}" size="30" style="width:100%; padding:1pt 3pt 1pt 3pt"
									  value="{$attributeDisplayValue}"
									  maxlength="{//field_sizes/field_size [@key='attribute.value']/@value}"
									  onchange="CheckTextInput(this.value, '{XSLUtils:encodeForJScript($attributeDisplayValue)}', 'TR{attribute/@id}');"
									  onkeyup="CheckTextInput(this.value, '{XSLUtils:encodeForJScript($attributeDisplayValue)}', 'TR{attribute/@id}');"/>
							</xsl:otherwise>
						</xsl:choose>
					</td>
				  </xsl:otherwise>
				</xsl:choose>
				
			</xsl:otherwise>
		</xsl:choose>
        
      </xsl:when>
      <xsl:otherwise>
		<!-- R/O mode -->
        <td class="darktext_darklink_11" style="padding: 1px;">
			<xsl:choose>
				<xsl:when test="$attrUnitId = '00001_0000000020'">
					<!-- date/time type -->
					<xsl:call-template name="HumanReadableLongDateAndTime">
						<xsl:with-param name="LongDateString" select="$attributeValue"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$attrUnitId = '00001_0000000021'">
					<xsl:call-template name="displayRichTextAttribute">
						<xsl:with-param name="fieldID"><xsl:value-of select="attribute/@id" /></xsl:with-param>
						<xsl:with-param name="attValue" select="$attributeDisplayValue" />
				    </xsl:call-template>					
				</xsl:when>
				<xsl:otherwise>
					<!-- other types -->
    	      		<xsl:value-of select="$attributeDisplayValue" />
				</xsl:otherwise>
			</xsl:choose>
        </td>
      </xsl:otherwise>
    </xsl:choose>
					
					<!-- end show value -->
					
			</tr>
		</table>
	</td>
	
  </xsl:template>


<!--
	
	Show tip for required fields
	
-->
<xsl:template name="ShowRequiredTip">

  <tr>
	<td align="left" class="darktext_darklink_11">
		<img src="images/clearpixel.gif" width="10" height="1"/>
		<!-- show required field -->
		<span class="small_text_bold">
		<xsl:value-of select="Lang:getStr(&lk;,'TIP')"/>:</span>
		&nbsp;<xsl:value-of select="Lang:getStr(&lk;,'REQUIRED_FIELD_KEY')"/>								
	</td>
  </tr>
	
</xsl:template>	
	

<xsl:template name="DisplayRichTextAttributeValue">
	
	<xsl:param name="attributeValue"/>
	<xsl:param name="attributeDisplayValue"/>	
	<xsl:param name="onChange" />
	
	<td class="darktext_darklink_11" id="DateControls" style="vertical-align:middle; padding: 1px;">
   		<!--<input value="{$attributeValue}" name="{attribute/@id}" type="hidden" id="{attribute/@id}"/>--> 
 		<input type="hidden" name="isRS{attribute/@id}" id="isRS{attribute/@id}" value="0" />		  


	  	<textarea type="text" id="{attribute/@id}" name="{attribute/@id}" style="width:100%; height: 120px; padding:1pt 3pt 1pt 3pt">
			<xsl:attribute name="onkeyup">
				return imposeMaxLength(this, <xsl:value-of select="//field_sizes/field_size [@key='attribute.value']/@value"/>);
			</xsl:attribute>
	  		<xsl:value-of select="$attributeDisplayValue" />
	  	</textarea>
		<a class="darktext_greenlink_12" href="javascript:edittmce('{attribute/@id}')"><xsl:value-of select="Lang:getStr(&lk;,'SHOW_ADVANCED_CONTROLS')"/></a>	
						
		<script type="text/javascript">
			tinyMceMgrObj.tmceEditors.push("<xsl:value-of select="attribute/@id" />");
		</script>		
   </td>

</xsl:template>

 <!--
		Change restricted value for an attribute
		
  -->
<xsl:template name="DisplayDateTypeAttributeValue">
	
	<xsl:param name="attributeValue"/>
	<xsl:param name="attributeDisplayValue"/>	
	<xsl:param name="onChange" />
 
   	<xsl:choose>
        <xsl:when test="string-length(attribute/restricted_set_id)>0">
	            <xsl:call-template name="RestrictedSetValue">
	              <xsl:with-param name="restrictedSetID" select="attribute/restricted_set_id"/>
	              <xsl:with-param name="attributeValue" select="$attributeValue"/>
	              <xsl:with-param name="attributeDisplayValue" select="$attributeDisplayValue"/>
	              <xsl:with-param name="attributeID" select="attribute/@id"/>
	            </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>        
				<!-- date type  -->		
				<td class="darktext_darklink_11" id="DateControls" style="vertical-align:middle; padding: 1px;">
				   	<input value="{$attributeValue}" name="{attribute/@id}" type="hidden" id="{attribute/@id}"/>   <!-- JANH is this needed??? -->
	      	 		<input type="hidden" name="isRS{attribute/@id}" id="isRS{attribute/@id}" value="0" />		  
	      	 		
	      	 		<xsl:variable name="dateID"><xsl:value-of select="'adate'"/><xsl:value-of select="attribute/@id"/></xsl:variable>
	      	 		<xsl:variable name="intValue"><xsl:value-of select="attribute_value/value"/></xsl:variable>
	      	 		<xsl:variable name="periodDay"><xsl:value-of select="'date_period_of_day_'"/><xsl:value-of select="attribute/@id"/></xsl:variable>

            <xsl:call-template name="DisplayDateWithCalendar">
							<xsl:with-param name="date" select="date"/>
							<xsl:with-param name="ShowCalendarFieldName" select="$dateID"/>	
							<xsl:with-param name="ShowCalendarFormName" select="'actionform'"/>	
							<xsl:with-param name="PeriodOfDayFieldName" select="$periodDay" />
							<xsl:with-param name="longIntDate" select="$intValue"/>
							<xsl:with-param name="onChange" select="$onChange"/>
						</xsl:call-template>
					
 		   </td>
	  </xsl:otherwise>
	</xsl:choose>
	
</xsl:template>
 
 
 <!--
		Change restricted value for an attribute
		
  -->
<xsl:template name="RestrictedSetValue">
    <xsl:param name="restrictedSetID"/>
    <xsl:param name="attributeValue"/>
    <xsl:param name="attributeDisplayValue"/>
    <xsl:param name="attributeID"/>
    
    <td class="darktext_darklink_11" style="padding: 1px;">
		
		<!-- indicate restricted set field -->    
    <input type="hidden" name="isRS{$attributeID}" id="isRS{$attributeID}" value="1" />
	  
    <select id="{$attributeID}" name="{$attributeID}"
     	onchange="CheckTextInput(this.value, '{XSLUtils:encodeForJScript($attributeValue)}', 'TR{$attributeID}')">
        <xsl:variable name="restrictedSet" select="key('restrictedSetIDKey', $restrictedSetID)"/>
        <xsl:variable name="attUnitID" select="$restrictedSet/attribute_unit_id"/>
        
        <option value="">
            <xsl:if test="string-length($attributeValue) = 0">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>
        </option>
        
        <!-- Determine if the restricted set is still there -->
        <xsl:variable name="addAsDeleted">
          <xsl:choose>
            <xsl:when test="string-length($attributeValue) = 0">
              <xsl:value-of select="0"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:variable name="matchIndex">
                <xsl:for-each select="$restrictedSet/restricted_set_value_list/restricted_set_value">
                  <xsl:variable name="restrictedSetValue">
                    <xsl:call-template name="ConvertValueToUserUnits">
                      <xsl:with-param name="curValue" select="value"/> 
                      <xsl:with-param name="unitTypeID" select="$attUnitID"/> 
                      <xsl:with-param name="withRounding" select="0"/> 
                    </xsl:call-template>
                  </xsl:variable>
                  <xsl:if test="$attributeValue = $restrictedSetValue">
                    <xsl:value-of select="position()"/>
                  </xsl:if>
                </xsl:for-each>
              </xsl:variable>
              <xsl:choose>
                <xsl:when test="string-length($matchIndex)=0">
                  <xsl:value-of select="1"/>
                </xsl:when>
                <xsl:otherwise>
                 <xsl:value-of select="0"/>
               </xsl:otherwise>
              </xsl:choose>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:variable>

        <xsl:for-each select="$restrictedSet/restricted_set_value_list/restricted_set_value">
          <xsl:variable name="restrictedSetValue">
            <xsl:call-template name="ConvertValueToUserUnits">
              <xsl:with-param name="curValue" select="value"/> 
              <xsl:with-param name="unitTypeID" select="$attUnitID"/> 
              <xsl:with-param name="withRounding" select="0"/> 
            </xsl:call-template>
          </xsl:variable>
          
          <xsl:variable name="restrictedSetDisplayValue">
            <xsl:call-template name="ConvertValueToUserUnits">
              <xsl:with-param name="curValue" select="value"/> 
              <xsl:with-param name="unitTypeID" select="$attUnitID"/> 
              <xsl:with-param name="withRounding" select="1"/> 
            </xsl:call-template>
          </xsl:variable>
          
          <option value="{$restrictedSetValue}">
              <xsl:if test="$attributeValue = $restrictedSetValue">
                <xsl:attribute name="selected">selected</xsl:attribute>
              </xsl:if>
            
			<xsl:choose>
            <xsl:when test=" $attUnitID = '00001_0000000020'">
				<xsl:variable name="restrictedDateTimeValue">
					<xsl:call-template name="HumanReadableLongDateAndTime">
						<xsl:with-param name="LongDateString"  select="$restrictedSetDisplayValue"/>
					</xsl:call-template>
				</xsl:variable>
            <xsl:value-of select="$restrictedDateTimeValue"/>            
            </xsl:when>
            <xsl:otherwise>
            	<xsl:value-of select="$restrictedSetDisplayValue"/>
            </xsl:otherwise>
            </xsl:choose>
 
          </option>  
        </xsl:for-each>
        
        <xsl:if test="$addAsDeleted > 0">
          <option value="{$attributeValue}" selected="selected"><xsl:value-of select="$attributeDisplayValue"/><xsl:value-of select="Lang:getStr(&lk;,'DELETED_ATTRIBUTE')"/></option>  
        </xsl:if>
        
      </select>
    </td>
  </xsl:template>



  <xsl:template name="CategoriesUsingThisAttribute">
	<div id="CatsUsingAttr" class="form-group">
		<label for="CatsUsingAttrLabelID">
			<xsl:value-of select="Lang:getStr(&lk;,'ATTCATEGORIES_TAG')"/>
		</label>
		<div class="form-entry"><p id="CatsUsingAttrListID" >
			<xsl:choose>
				<xsl:when test="count(/webcenter_page/categories_having_attributes/category) > 0">
				
					<xsl:for-each select="/webcenter_page/categories_having_attributes/category">
						<xsl:sort select="name"></xsl:sort>
						<xsl:value-of select="name"/>
						<xsl:if test="position() != last()">, </xsl:if>
					</xsl:for-each>

				</xsl:when>
				<xsl:otherwise>
		
						<xsl:value-of select="Lang:getStr(&lk;,'NOCATWITHATT')"/>
	
				</xsl:otherwise>
			</xsl:choose>
			</p>
			
	  	</div>
	</div>	
  </xsl:template>

  <xsl:template name="TaskTypesUsingThisSpecification">
	<div id="TaskTypesUsingSpec" class="form-group">
		<label for="TaskTypesUsingSpecLabelID">
			<xsl:value-of select="Lang:getStr(&lk;,'TASKTYPEMGMNT_TAG')"/>
		</label>
		<div class="form-entry"><p id="TaskTypesUsingSpecNoTaskTypeID">
			<xsl:choose>
				<xsl:when test="count(/webcenter_page/tasktypes_having_specifications/wctask_type) > 0">
				
					<xsl:for-each select="/webcenter_page/tasktypes_having_specifications/wctask_type">
						<xsl:sort select="task_type_name"></xsl:sort>
						<xsl:value-of select="task_type_name"/>
						<xsl:if test="position() != last()">, </xsl:if>
					</xsl:for-each>
				
				</xsl:when>
				<xsl:otherwise>
				
						<xsl:value-of select="Lang:getStr(&lk;,'NOTASKTYPEWITHSPEC')"/>
					
				</xsl:otherwise>
			</xsl:choose>
		
			</p>
	  	</div>
	</div>	
  </xsl:template>


  <xsl:template name="AttributeName">
	<div id="AttributeNameRow" class="form-group">
		<label for="AttributeNameID" class="form-required">
			<xsl:value-of select="Lang:getStr(&lk;,'NAME')"/>
		</label>
		<div class="form-entry">
			<input type="text" id="AttributeNameID" name="attributeName" class="form-control" 
					placeholder="{Lang:getStr(&lk;,'NAME')}" value="{attribute/name}"
					maxlength="{field_sizes/field_size[@key='attribute.name']/@value}">
         		<xsl:attribute name="onchange">CheckTextInput(this.value, '<xsl:value-of select="XSLUtils:encodeForJScript(attribute/name)"/>', 'AttributeNameRow');</xsl:attribute>
		        <xsl:attribute name="onkeyup">CheckTextInput(this.value, '<xsl:value-of select="XSLUtils:encodeForJScript(attribute/name)"/>', 'AttributeNameRow');</xsl:attribute>
			</input>
			<p class="help-block">
				<xsl:value-of select="Lang:getStr(&lk;,'NEWATTRNAME_TIP')"/>
			</p>
	  	</div>
	</div>	
  </xsl:template>
  
  
  <xsl:template name="AttributeDescription">
	<div id="AttributeDescRow" class="form-group">
		<label for="AttributeDescID">
			<xsl:value-of select="Lang:getStr(&lk;,'DESCRIPTION')"/>
		</label>
		<div class="form-entry">
			<input type="text" id="AttributeDescID" name="attributeDesc" class="form-control" 
					placeholder="{Lang:getStr(&lk;,'DESCRIPTION')}" value="{attribute/description}"
					maxlength="{field_sizes/field_size [@key='attribute.description']/@value}">
 				<xsl:attribute name="onchange">CheckTextInput(this.value, '<xsl:value-of select="XSLUtils:encodeForJScript(attribute/description)"/>', 'AttributeDescRow');</xsl:attribute>
				<xsl:attribute name="onkeyup">CheckTextInput(this.value, '<xsl:value-of select="XSLUtils:encodeForJScript(attribute/description)"/>', 'AttributeDescRow');</xsl:attribute>
			</input>
		</div>
	</div>	
  </xsl:template>
  
  
  <xsl:template name="AttributeUnit">
  	<xsl:param name="readOnly" select="true()"/>
  	
	<div id="AttributeUnitsRow" class="form-group">
		<label for="UnitTypeID" class="form-required">
			<xsl:value-of select="Lang:getStr(&lk;,'TYPE')"/>
		</label>
		<div id="AttributeUnitsValue" class="form-entry">
			<xsl:choose>
				<xsl:when test="$readOnly"><p>
					<xsl:call-template name="SelAttributeUnitName">
                		<xsl:with-param name="unitTypeID" select="attribute/attribute_unit_id"/>
                	</xsl:call-template></p>
				</xsl:when>
				<xsl:otherwise>
					<select id="UnitTypeID" name="unitType"
						class="form-control" 
						onchange="CheckUnitType(this.value, '', 'AttributeUnitsRow')">
						<!-- First dummy option -->
						<option value="">
							<xsl:value-of select="Lang:getStr(&lk;,'SELECTATTRTYPE')"/>
						</option>
						<xsl:for-each select="attribute_unit_list/attribute_unit">
							<xsl:call-template name="AttUnitsOption"/>
						</xsl:for-each>
					</select>
				</xsl:otherwise>
			</xsl:choose>
		</div>
	</div>
  </xsl:template>
  

  <xsl:template name="AttributeUseRestrictedSet">
  	<xsl:param name="limitRSetByAttrUnit" select="true()"/>

    <div id="AttributeValuePromptedRow" class="form-group inputValueType">
		<label for="PromptedTypeID" class="form-label form-required">
	        <xsl:value-of select="Lang:getStr(&lk;,'VALUE')"/>
		</label>
		<div class="form-entry">
			<div class="radio">
				<label>
		        	<input type="radio" id="PromptedTypeID" name="valueType" value="PROMPTED" onclick="ChangeResValueType()"/>
		        	<xsl:value-of select="Lang:getStr(&lk;,'PROMPTED')"/>
	        	</label>
	        </div>
	        
			<!-- this test is here, because here are several inputs of name "valueType" and these are accessed from several pages  -->
			<!--  by name and postitino and omitting this input would screw the functionality, as the third input(restricted set) would be in the second position -->
            <xsl:choose>            
	            <!-- should only be shown in case of attribute, not task specification -->            
	            <xsl:when test="/webcenter_page/taskspecification_page = '0' ">
					<div class="radio">
						<label>
		                	<input type="radio" id="CalculatedTypeID" name="valueType" value="CALCULATED" onclick="ChangeResValueType()"/>
			            	<xsl:value-of select="Lang:getStr(&lk;,'CALCULATED')"/></label>			           
					</div>
					 <div class="wcr-form">
				            <input type="text" id="DefExpressionID" name="defexpression" value="{attribute/default_expression}"
								class="form-control hiddenElement"
								maxlength="{field_sizes/field_size[@key='attribute.value']/@value}"/>
				            
				            <div id="AttributeValueCalculatedMsgRow" class="help-block hiddenElement">
		          				<b><xsl:value-of select="Lang:getStr(&lk;,'UPLOAD_TIP_START')"/></b>&nbsp;<xsl:value-of select="Lang:getStr(&lk;,'ATTRIBUTE_CALCULATED_TIP1')"/>&nbsp;
				                <xsl:value-of select="Lang:getStr(&lk;,'ATTRIBUTE_CALCULATED_TIP2')"/>&nbsp;
				                <xsl:value-of select="Lang:getStr(&lk;,'ATTRIBUTE_CALCULATED_TIP3')"/>
				            </div>
			            </div>		
				</xsl:when>
				<xsl:otherwise>
<!-- 				so there are no calculated attributes, but input is needed, since it is accessed by position. So only add the input and hide it  -->
					<input type="radio" id="CalculatedTypeID" name="valueType" value="CALCULATED" style="display:none"/>
				</xsl:otherwise>
			</xsl:choose>
			<div class="radio">
				<label>
		        	<input type="radio" id="RestrictedTypeID" name="valueType" value="RESTRICTED"
		        		onclick="ChangeResValueType()"/>
		        	<xsl:value-of select="Lang:getStr(&lk;,'RESTRICTEDSET')"/>
				</label>
			</div>
			<div id="formDiv" class="hiddenElement">
				<xsl:choose>
					<xsl:when test="$limitRSetByAttrUnit">
						<xsl:call-template name="RestrictedSetSelector">
							<xsl:with-param name="filterByUnitID" select="/webcenter_page/attribute/attribute_unit_id"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="RestrictedSetSelector"/>
					</xsl:otherwise>
				</xsl:choose>
			</div>
	       
		</div>
	</div>
  </xsl:template>
  
  
  <!-- Toggle indicating whether the attribute can be used as specification too -->
	<xsl:template name="AttributeUseAsSpecification">
	<xsl:param name="showIsSpec" select="true()"/>
		<xsl:choose>
			<xsl:when test="$showIsSpec">
				<div class="form-group">
					<label for="isspecification" class="offset-label"></label>
					<div class="form-entry">
						<div class="checkbox">
							<label>
							    <input type="checkbox" id="isspecification" name="isspecification">
									<xsl:if	test="/webcenter_page/attribute/istask = 1">
										<xsl:attribute name="checked"><xsl:value-of select="true()"/></xsl:attribute>
									</xsl:if>
								</input>
						    	<xsl:value-of select="Lang:getStr(&lk;,'ATT_IS_ALSO_SPECIFICATION_TAG')"/>
						    </label>
					    </div>
					</div>
				</div>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if	test="/webcenter_page/attribute/istask = 1">
					<input type="hidden" name="isspecification" value="on"/>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
  <xsl:template name="DocRefBOMOptions">
  	<xsl:param name="includeInBomValue"/>
  	<xsl:param name="includeInBomEditableValue"/>
  	<xsl:param name="showCountValue"/>
  
	<!-- when BOM is not enabled in the system configuration, all the BOM related options are not visible and off -->
	<xsl:if test="/webcenter_page/bom_enabled = '1'">
  		<input type="hidden" name="BomOptionsVisible" id="BomOptionsVisibleID" value="true"/>

		<div id="DocRefBOMOptionsRow" class="form-group DocRefDetails" style="display:none;">
			<label for="includeInBomID" class="form-label">
				<xsl:value-of select="Lang:getStr(&lk;,'ATT_BOM_SECTION')"/>
			</label>
			<div>
				<input type="checkbox" name="includeInBom" id="includeInBomID" onchange="changeBOMOptions();">
					<xsl:if test="$includeInBomValue = '1'">
						<xsl:attribute name="checked">checked</xsl:attribute>
					</xsl:if>
				</input>
		    	<xsl:value-of select="Lang:getStr(&lk;,'ATT_INCLUDE_IN_BOM')"/>
				<xsl:call-template name="inlineHelp">
	    			<xsl:with-param name="topic">common/wc/reference/re_wc_DocReferenceType_BOM</xsl:with-param>
				</xsl:call-template><br/>	
	
				<input type="checkbox" name="includeInBomEditable" id="includeInBomEditableID" onchange="changeBOMOptions();">
					<xsl:if test="$includeInBomEditableValue = '1'">
						<xsl:attribute name="checked">checked</xsl:attribute>
					</xsl:if>
				</input>
			    <xsl:value-of select="Lang:getStr(&lk;,'ATT_BOM_EDITABLE')"/><br/>
	
				<input type="checkbox" name="showCount" id="showCountInBomID" onchange="changeBOMOptions();">
					<xsl:if test="$showCountValue = '1'">
						<xsl:attribute name="checked">checked</xsl:attribute>
					</xsl:if>
				</input>
				<xsl:value-of select="Lang:getStr(&lk;,'ATT_SHOW_COUNT')"/>
			</div>						
		</div>
	</xsl:if>
  </xsl:template>


  <xsl:template name="DocRefModeOption">
  	<xsl:param name="isSpec" select="false()"/>
  	<xsl:param name="inCreationMode" select="true()"/>
		
	
	<div id="DocRefModeRow" class="form-group DocRefDetails" style="display:none;">
		<label for="docReferenceModeId" class="label-required">
			<xsl:value-of select="Lang:getStr(&lk;,'ATT_DOC_REF_MODE')"/>		
		</label>
		<div class="form-entry">
			<div class="input-group">
				<select size="1" name="docReferenceMode" id="docReferenceModeId" 
					class="form-control"  >
					<xsl:if test="$inCreationMode = false()">
						<xsl:attribute name="onchange">javascript:showWarningOnVersionRevisionModeChanged('<xsl:value-of select="$isSpec"/>');</xsl:attribute>
					</xsl:if>
				  <option value="0"><xsl:value-of select="Lang:getStr(&lk;,'ATT_LATEST_VERSION')"/></option>
				  <option value="1"><xsl:value-of select="Lang:getStr(&lk;,'ATT_SELECTED_VERSION')"/></option>
				  <option value="2"><xsl:value-of select="Lang:getStr(&lk;,'ATT_SELECTED_REVISION')"/></option>
				</select>
				<div class="input-group-btn">
					<xsl:call-template name="inlineHelp">
		    			<xsl:with-param name="topic">common/wc/reference/re_wc_DocReferenceType_Versions</xsl:with-param>
					</xsl:call-template>
				</div>
			</div>
		</div>
	</div>
  </xsl:template>
  

  <xsl:template name="DocRefCategoryOption">
    <xsl:param name="referenceCategory" select="''"/> 
 	<xsl:param name="isSpec" select="false()"/>
	<xsl:param name="inCreationMode" select="true()"/> 
    
    <xsl:choose>
    <xsl:when test="count(/webcenter_page/has_task_management_license)>0">
	<div id="DocRefCategoryOptionRow" align="left"  class="form-group DocRefDetails" style="display:none;">
		<label for="refCategoryIDSelectorID">
		  <xsl:value-of select="Lang:getStr(&lk;,'ATT_DOC_REF_CATEGORY')"/>
		</label>
		<div class="form-entry">
			<div class="input-group">
			  	<select size="1" name="refCategoryID" id="refCategoryIDSelectorID"
			  	    class="form-control">
				  	
				  	<xsl:if test="$inCreationMode = false()">
				  		<xsl:attribute name="onchange">javascript:showWarningOnReferenceCategoryChanged('<xsl:value-of select="$isSpec"/>');</xsl:attribute>
					</xsl:if>
				  
				  <option value="0"><xsl:value-of select="Lang:getStr(&lk;,'DROPDOWN_SELECTCATEGORY')"/></option>
				  <xsl:for-each select="/webcenter_page/category_list/category">
				  	<option >
				  		<xsl:attribute name="value"><xsl:value-of select="@id"/>
				  		</xsl:attribute>
				  		<xsl:if test="$referenceCategory = @id">
		                   	<xsl:attribute name="selected">selected</xsl:attribute>
		                </xsl:if>
				  		<xsl:value-of select="name"/>		  		
				  	</option>
				  </xsl:for-each>
				</select>
				<div class="input-group-btn">
					<xsl:call-template name="inlineHelp">
		    			<xsl:with-param name="topic">common/wc/reference/re_wc_DocReferenceType_ReferenceCat</xsl:with-param>
					</xsl:call-template>
				</div>
			</div>
		</div>
	</div>
    </xsl:when>
    <xsl:otherwise>
    	<!-- hidden form field to report back to JSP there is no reference attribute category -->
    	<input type="hidden" name="refCategoryID" id="refCategoryIDSelectorID" value=""/>
    </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


<!--
	
	Template for creating a new attribute and/or specification.
	
-->    
  <xsl:template name="CreateAttributeFields">	
	<xsl:param name="showIsSpec" select="false()"/>
	<xsl:param name="showBOMOptions" select="false()"/>

		<!-- Name -->
		<xsl:call-template name="AttributeName"/>
		
		<!-- Description -->
		<xsl:call-template name="AttributeDescription"/>
		
		<!--Units -->
		<xsl:call-template name="AttributeUnit">
			<xsl:with-param name="readOnly" select="false()"/>
		</xsl:call-template>

	    <!-- Values -->
		<xsl:call-template name="AttributeUseRestrictedSet"/>
		
		<!-- In case of doc referenced, type (latest version/specific version....)  -->
		<xsl:call-template name="DocRefModeOption" >
			<xsl:with-param name="showIsSpec" select="$showIsSpec"/>
			<xsl:with-param name="inCreationMode" select="true()"/>
		</xsl:call-template> 
		
		<!-- In case of doc referenced, reference category  -->
		<xsl:call-template name="DocRefCategoryOption">
			<xsl:with-param name="inCreationMode" select="true()"/>
		</xsl:call-template>
		
		<!-- In case of doc referenced, BOM options, but only for attributes (not specifications) -->
		<xsl:if test="$showBOMOptions">
			<xsl:call-template name="DocRefBOMOptions">
				<xsl:with-param name="includeInBomValue" select="'0'" />
				<xsl:with-param name="includeInBomEditableValue" select="'1'" />
				<xsl:with-param name="showCountValue" select="'1'" />
			</xsl:call-template>
		</xsl:if>

		<!-- can be used as specification? -->
		<xsl:if test="count(/webcenter_page/has_task_management_license)>0">
			<xsl:call-template name="AttributeUseAsSpecification">
				<xsl:with-param name="showIsSpec" select="$showIsSpec"/>
			</xsl:call-template>
		</xsl:if>

		
		
		<!-- Save and Cancel buttons -->
		<div class="form-group">
			<label class="offset-label"> </label>
			<div class="form-entry">
				<input type="submit" name="Save" value="{Lang:getStr(&lk;,'SAVE_TAG')}"
					class="btn btn-primary"/>
				<input type="button" name="Cancel" value="{Lang:getStr(&lk;,'CANCEL')}"
					class="btn btn-default" onclick="performCancel()"/>
			</div>
		</div>

  </xsl:template>

<!--
	
	Template for editing attribute and/or specification details (name/description/rset)
	
-->    
  <xsl:template name="EditAttributeFields">	
	<xsl:param name="showIsSpec" select="false()"/>
	<xsl:param name="showBOMOptions" select="false()"/>
	<xsl:param name="isSpec" select="false()"/>
	
    <!-- Name -->
	<xsl:call-template name="AttributeName"/>
         
    <!-- Description -->
	<xsl:call-template name="AttributeDescription"/>

    <!--Units -->
	<xsl:call-template name="AttributeUnit"/>

    <!-- Values -->
	<!-- correct radio button is selected in JavaScript page initialisation code -->	
	<xsl:call-template name="AttributeUseRestrictedSet"/>

	<!-- In case of doc referenced, type (latest version/specific version....)  -->
	<xsl:call-template name="DocRefModeOption">
		<xsl:with-param name="isSpec" select="$isSpec"/>
		<xsl:with-param name="inCreationMode" select="false()"/>		
	</xsl:call-template>
	
	<!-- In case of doc referenced, reference category  -->
	<xsl:call-template name="DocRefCategoryOption">
		<xsl:with-param name="referenceCategory" select="attribute/ref_category_id" />
		<xsl:with-param name="isSpec" select="$isSpec"/>
		<xsl:with-param name="inCreationMode" select="false()"/>		
	</xsl:call-template>
	
	<!-- In case of doc referenced, BOM options, but only for attributes (not specifications) -->
	<xsl:if test="$showBOMOptions">
		<xsl:call-template name="DocRefBOMOptions">
			<xsl:with-param name="includeInBomValue" select="attribute/include_in_bom" />
			<xsl:with-param name="includeInBomEditableValue" select="attribute/include_in_bom_editable" />
			<xsl:with-param name="showCountValue" select="attribute/show_count" />
		</xsl:call-template>
	</xsl:if>
	
	<!-- is att also a task specification? -->
	<xsl:if test="count(/webcenter_page/has_task_management_license)>0">
		<xsl:call-template name="AttributeUseAsSpecification">
			<xsl:with-param name="showIsSpec" select="$showIsSpec" />
		</xsl:call-template>
	</xsl:if>


	<!-- Show the categories using this attribute  -->
	<xsl:call-template name="CategoriesUsingThisAttribute"/>
		
	<xsl:if test="count(/webcenter_page/has_task_management_license)>0">
		<xsl:call-template name="TaskTypesUsingThisSpecification"/>
	</xsl:if>
		


	<!-- Change and Return buttons -->
	<div class="form-group">
		<label class="offset-label"> </label>
		<div class="form-entry">
			<input type="submit" name="Save" value="{Lang:getStr(&lk;,'CHANGE')}"
				class="btn btn-primary"/>
			<input type="button" name="Cancel" value="{Lang:getStr(&lk;,'RETURN')}"
				class="btn btn-default" onclick="performReturn()"/>
		</div>
	</div>
  </xsl:template>
  
  
  
  <xsl:template name="RestrictedSetOption">
    <xsl:param name="selID"/>
    <option value="{@id}">
      <xsl:if test="$selID=@id">
        <xsl:attribute name="selected">selected</xsl:attribute>
      </xsl:if>
      <xsl:value-of select="name"/>
    </option>  
  </xsl:template>
  
  
 <!-- 
  
            template that controls a display of restricted set table
            
  -->  
  <xsl:template name="DisplayRestrictedSets">
	<xsl:param name="showActions" select="true()"/>
	<xsl:param name="widthSpace" select="'10'"/>
	<xsl:param name="useRadio" select="false()"/>
	
	<!-- save selected values -->
	<input name="selectedRSetID" type="hidden" value=""/>
	<input name="selectedRSetUnitID" type="hidden" value=""/>
	
	 <!-- data table -->
	  			<table class="ordtable">
				 
					<!-- table header -->
				    <thead>
						<tr>
						 
						  <th class="td-checkbox">
							<xsl:if test="not($useRadio)">
								<input type="checkbox" name="selectall" value="" data-toggle-all="input[name='selectRestrictedSet']"/>
							</xsl:if>
						  </th>
						  <th>
							<xsl:value-of select="Lang:getStr(&lk;,'NAME')"/>
						  </th>
						  <th>
							<xsl:value-of select="Lang:getStr(&lk;,'TYPE')"/>
						  </th>						 
						</tr>
				    </thead>
					<tbody>
						<!-- Data Elements -->
						<xsl:for-each select="restricted_set_list/restricted_set">
							<xsl:call-template name="RestrictedSetRow">
								<xsl:with-param name="useRadio" select="$useRadio"/>
							</xsl:call-template>
						</xsl:for-each>
				
			 		</tbody>
			</table>
  </xsl:template>


  <!-- 
  
            template that controls a display of restricted sets in a dropdown box (not SDrop!)
            
  -->  
  <xsl:template name="RestrictedSetSelector">
  	<xsl:param name="isHidden" select="false()"/>
  	<xsl:param name="filterByUnitID" select="''"/>

	<xsl:variable name="actualRSetID" select="attribute/restricted_set_id"/>
	
	<!-- save selected values -->
	<input name="selectedRSetID" type="hidden" value="{$actualRSetID}"/>
	<input name="selectedRSetUnitID" type="hidden" value="{restricted_set_list/restricted_set[@id=$actualRSetID]/attribute_unit_id}"/>
	
	<xsl:if test="isHidden">
		<xsl:attribute name="class"><xsl:value-of select="'hiddenElement'"/></xsl:attribute>
	</xsl:if>
	<div class="form-inline-field">
		<select id="RestrictedSetsSelectorID" name="SelectRestrictedSet" 
				class="form-control form-field-medium form-dropdown-field" 
				onchange="SaveSelectedIDs(this.value, this.options[this.selectedIndex].getAttribute('attrUnitID'))">
			<xsl:if test="string-length($actualRSetID) = 0">
				<!-- First, preselected dummy option -->
				<option value="" attrUnitID="">
					<xsl:value-of select="Lang:getStr(&lk;,'DROPDOWN_SELECTRESTRICTEDSET')"/>
				</option>
			</xsl:if>
			<xsl:for-each select="restricted_set_list/restricted_set">
				<xsl:if test="(string-length($filterByUnitID) = 0) or (attribute_unit_id = $filterByUnitID)">
					<xsl:variable name="unitTypeName">
	       				<xsl:call-template name="SelAttributeUnitName">
	      					<xsl:with-param name="unitTypeID" select="attribute_unit_id"/>
	    				</xsl:call-template>
	    			</xsl:variable>
				    <option value="{@id}" attrUnitID="{attribute_unit_id}">
						<xsl:if test="@id = $actualRSetID">
							<xsl:attribute name="selected">selected</xsl:attribute>
						</xsl:if>	    	
				    	<xsl:value-of select="name"/>&nbsp;&nbsp;&nbsp;(<xsl:value-of select="$unitTypeName"/>)
				    </option>  
			    </xsl:if>
			</xsl:for-each>
		</select>
	</div>
	<div class="form-inline-field darktext_greenlink_11">
		<a href="#" onclick="ShowRestrictedSetDetailsOrWarning(document.actionform.selectedRSetID.value);">
			<xsl:value-of select="Lang:getStr(&lk;,'SHOW_DETAILS')"/>
		</a>
	</div>
  </xsl:template>
  
 <!-- 
  
            template that controls a display of restricted set row
            
  -->  
  <xsl:template name="RestrictedSetRow">
	<xsl:param name="useRadio" select="false()"/>
	
	<xsl:variable name="rsetID" select="@id"/>
	<xsl:variable name="rsetUnitID" select="attribute_unit_id"/>
	
    <tr>
      <td class="td-checkbox">
		<xsl:choose>
			<xsl:when test="$useRadio">
				<input type="radio" name="selectRestrictedSet"  value="{$rsetID}">		
					<xsl:attribute name="onclick">SelectRadio(this); SaveSelectedIDs('<xsl:value-of select="$rsetID"/>', '<xsl:value-of select="$rsetUnitID"/>');
					</xsl:attribute>
				</input>
			</xsl:when>
			<xsl:otherwise>
				<input type="checkbox" name="selectRestrictedSet"  onclick="Toggle(this)" value="{$rsetID}"/>
			</xsl:otherwise>
		</xsl:choose>
      </td>      
      <td>
          <a>
			<xsl:attribute name="href">
				<xsl:choose>
					<xsl:when test="$useRadio">javascript:ShowRestrictedSetDetailsOrWarning('<xsl:value-of select="$rsetID"/>');</xsl:when>
					<xsl:otherwise>javascript:EditRestrictedSet('<xsl:value-of select="$rsetID"/>');</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
            <xsl:value-of select="name"/>
          </a>
      </td>
      <td>
        <xsl:call-template name="SelAttributeUnitName">
	      <xsl:with-param name="unitTypeID" select="$rsetUnitID"/>
	    </xsl:call-template>
      </td>
	  
    </tr>
  </xsl:template>

   <!-- 
  
            template that controls display of final actions
            
  -->
  <xsl:template name="CreateFinalActions">
	<xsl:param name="wizardData"/>
	
	<input type="hidden" name="finalActionURL"  value=""/>
	
	<tr><td height="20" ><img src="images/spacer.gif" width="1" height="1"/></td></tr>
	<tr>
		<td colspan="7" >
			<table border="0" width="100%" cellspacing="0" cellpadding="0">
				<xsl:call-template name="AddLeftEmptyColumn"/>
				<tr><td class="darktext_darklink_11"><xsl:value-of select="Lang:getStr(&lk;,'WIZARD_FINAL_WHAT_TODO')"/></td></tr>
				<tr><td height="20" ><img src="images/spacer.gif" width="1" height="1"/></td></tr>
				
				<xsl:for-each select="$wizardData/final_action_list/final_action">
				<tr>
				   <td class="darktext_greenlink_12"> 
					<xsl:variable name="tag" select="language_tag"/>
					
					<xsl:variable name="url" select="url" />
					
					<a  href="{$url}">
						<xsl:value-of select="Lang:getStr(&lk;,$tag)"/>
					</a>
				   </td>
				</tr>
				<tr><td height="10" ><img src="images/spacer.gif" width="1" height="1"/></td></tr>
				</xsl:for-each>
			</table>
		</td>
	</tr>
  </xsl:template> 	
  
  
   <!-- 
  
            template that controls a link to specifications details
            
  -->
<xsl:template name="specificationDetailsHref">
  <xsl:param name="page" select="'specificationsmgmntedit.jsp'"/>
  <xsl:param name="specificationID" />
  
  <xsl:attribute name="href"><xsl:value-of select="$page"/>?attributeID=<xsl:value-of select="$specificationID"/>&amp;<xsl:call-template name="menuFileUrlParameter"/></xsl:attribute>
</xsl:template>

   <!-- 
  
            template that shows editable value list of restricted set
            
  -->
  <xsl:template name="RestrictedSetValueEdit">
	<xsl:param name="attUnitID" select="''"/> <!--  set on edit only -->

	<!-- Value -->
	<div class="form-group">
		<label for="long_format_newvalue" id="curUnitTD">
			<xsl:value-of select="Lang:getStr(&lk;,'VALUE')" />

                    <xsl:if test="string-length($attUnitID) > 0">
                        <xsl:call-template name="GetUserUnitsLabel">
                            <xsl:with-param name="unitTypeID" select="$attUnitID"/>
                        </xsl:call-template>                            
                    </xsl:if>
		</label>
		<div class="form-entry">
			<div class="row">
				<div class="col-md-11 col-xs-12">
                    <input type="hidden" name="newvalue" id="newvalue" size="25" />
					
                    <div id="showStandard">
						<input type="text" name="long_format_newvalue" id="long_format_newvalue"
							size="25" class="form-control">
							<xsl:attribute name="maxlength"><xsl:value-of
								select="/webcenter_page/field_sizes/field_size [@key='restrictedset.value']/@value" /></xsl:attribute>
                        </input>
                    </div>
					
					<style type="text/css">
							#showCalender { display: none; }
					</style>
					
					<div id="showCalender" class="date-time-compact">
                      	<xsl:call-template name="DisplayDateWithCalendar">
								<xsl:with-param name="date" select="/webcenter_page/due_date"/>
							<xsl:with-param name="ShowCalendarFieldName" select="'new_date'"/>	
							<xsl:with-param name="ShowCalendarFormName" select="'actionform'"/>
							<xsl:with-param name="PeriodOfDayFieldName" select="'date_period_of_day'" />
							<xsl:with-param name="longIntDate"
								select="/webcenter_page/project/due_date" />
						</xsl:call-template>
					</div>
				</div>
				
				<div class="col-md-1 col-xs-12">
					<input type="button" name="addBtn" value="{Lang:getStr(&lk;,'ADD')}"
						class="btn btn-default">
                    <xsl:attribute name="onclick">
	                    <xsl:choose>
		                    <xsl:when test="string-length($attUnitID) > 0">
		                    	<xsl:value-of select="'AddNewValue()'"/>
		                    </xsl:when>
		                    <xsl:otherwise>
		                    	<xsl:value-of select="'AddValue()'"/>
		                    </xsl:otherwise>
	                    </xsl:choose>
                    </xsl:attribute>
                    </input>
				</div>
			</div>
		</div>
	</div>
	
	
	<!-- Values -->
	<div class="form-group">
		<label for="valueList" class="form-required"><xsl:value-of select="Lang:getStr(&lk;,'VALUES')"/></label>
		<div class="form-entry">
			<table class="table-full-width">
				<thead></thead>
				<tbody>
                <tr>
						<td class="add-padding-bottom td-full-width">
							<select name="valueList" id="valueList" size="16" multiple="multiple" class="form-control">
                      <xsl:if test="string-length($attUnitID) > 0">
                          <xsl:for-each select="restricted_set/restricted_set_value_list/restricted_set_value">
                            <xsl:call-template name="RestrSetValueOption">
  		                      <xsl:with-param name="attUnitID" select="$attUnitID"/> 
                            </xsl:call-template>
                          </xsl:for-each>
                      </xsl:if>
                    </select>
                  </td>
						
						<td class="add-padding-bottom add-padding-left">
							<table>
								<thead></thead>
								<tbody>
            	<tr>
										<td class="add-padding-bottom">
											<button id="restrictedSetValuesMoveUpButton" type="button" class="btn btn-default" onclick="moveOptionsUp('valueList')"><i class="icon icon-WCR_Actions-Up"/></button>
    				</td>
                </tr>
									
            			<tr>
            				<td>
											<button id="restrictedSetValuesMoveDownButton" type="button" class="btn btn-default" onclick="moveOptionsDown('valueList')"><i class="icon icon-WCR_Actions-Down"/></button>
        					</td>
    					</tr>
					</tbody>
				</table>
							
							
							
			</td>
          </tr>
					
					<tr>
						<td>
							<xsl:if test="$attUnitID = '00001_0000000001' or string-length($attUnitID) = 0">
								<input type="button" onclick="sortList('valueList')" name="sortBtn" value="{Lang:getStr(&lk;,'SORT')}" class="btn btn-default pull-right add-spacing-left" />
							</xsl:if>
							
							<input type="button" onclick="removeOptions('valueList')" name="remBtn" value="{Lang:getStr(&lk;,'REMOVE')}" class="btn btn-default pull-right"/>
      </td>
						
						<td></td>
    </tr>
				</tbody>
			</table>
		</div>
	</div>
	
  </xsl:template>

 <!-- 
  
            template that controls create new restricted set page
            
  -->
  <xsl:template name="CreateNewRestrictedSet">
	<xsl:param name="actionValue"/>
	
		<xsl:for-each select="last_new_item">
            <xsl:call-template name="DisplayLinkToNewItem">
      		  <xsl:with-param name="createsuccesstext" select="Lang:getStr(&lk;,'CREATERSETSUCCESS')"/> 
            </xsl:call-template>
          </xsl:for-each>
    
          <form name="actionform" method="post" action="dorestrictedsetmgractions.jsp" onsubmit="return(ValidateRSetForm())" class="wcr-form">
            <input type="hidden" name="actionVal" value="{$actionValue}"/>
            <input type="hidden" name="restrictedSetValues" value=""/>
            
            <div class="form-section">
            <!-- Name -->
            <div class="form-group" id="RestrictedSetNameRow">
            	<label class="form-required" for="restrictedSetNameInput"><xsl:value-of select="Lang:getStr(&lk;,'NAME')"/></label>
            	<div class="form-entry">
            		<input id="restrictedSetNameInput" type="text" name="restrictedSetName" value="" size="30"
                    maxlength="{field_sizes/field_size [@key='restrictedset.name']/@value}"
                    onchange="CheckTextInput(this.value, '', 'RestrictedSetNameRow');" onkeyup="CheckTextInput(this.value, '', 'RestrictedSetNameRow');" class="form-control"/>
            	</div>
            </div>

            <!-- Type -->
            <div class="form-group" id="UnitTypeRow">
            	<label class="form-required" for="restrictedSetTypeSelect"><xsl:value-of select="Lang:getStr(&lk;,'TYPE')"/></label>
            	<div class="form-entry">
            		<select size="1" name="unitType" onchange="onUnitTypeChange(this)" class="form-control" id="restrictedSetTypeSelect">
                  <option value=""/>
                  <xsl:for-each select="attribute_unit_list/attribute_unit">
                  	  <xsl:if test="@id != '00001_0000000021'">
                      	<xsl:call-template name="AttUnitsOption"/>
                      </xsl:if>
                  </xsl:for-each>
	                </select>
            	</div>
            </div>
            
            <!--  Values -->
            <xsl:call-template name="RestrictedSetValueEdit"/>

			<!-- create button -->
			<div class="form-group">
				<label class="offset-label"></label>
				<div class="form-entry">
					<input type="submit" value="{Lang:getStr(&lk;,'CREATE')}" class="btn btn-primary"/>
				</div>
			</div>
            </div>
          </form>
		
          
        
  </xsl:template>
  
  
 <!-- 
  
            template that controls editing of restricted set 
            
  -->
 <xsl:template name="EditRestrictedSet">
	<xsl:param name="actionValue"/>
	
	
	<!-- Confirmation section -->
	<xsl:call-template name="DisplayNotification"/>
		
		<form name="actionform" method="post" action="dorestrictedsetmgractions.jsp" onsubmit="return(ValidateForm())" class="wcr-form">
            <input type="hidden" name="actionVal" value="{$actionValue}"/>
            <input type="hidden" name="restrictedSetValues" value=""/>
			
			<xsl:variable name="attUnitID"  select="restricted_set/attribute_unit_id" />			
            <input type="hidden" name="attUnitID" value="{$attUnitID}"/>			
            
            <div class="form-section">
            
            <!-- Name -->
            <div class="form-group" id="RestrictedSetNameRow">
            	<label class="form-required" for="restrictedSetName"><xsl:value-of select="Lang:getStr(&lk;,'NAME')"/></label>
            	<div class="form-entry">
                <input type="text" name="restrictedSetName" value="{restricted_set/name}" size="30"
                                          maxlength="{field_sizes/field_size [@key='restrictedset.name']/@value}" class="form-control" id="restrictedSetName">
                          <xsl:attribute name="onchange">CheckTextInput(this.value, '<xsl:value-of select="XSLUtils:encodeForJScript(restricted_set/name)"/>', 'RestrictedSetNameRow');</xsl:attribute>
                          <xsl:attribute name="onkeyup">CheckTextInput(this.value, '<xsl:value-of select="XSLUtils:encodeForJScript(restricted_set/name)"/>', 'RestrictedSetNameRow');</xsl:attribute>
                </input>
            	</div>
            </div>

            <!-- Type -->
            <div class="form-group" id="RestrictedSetUnitsRow">
            	<label class="form-required"><xsl:value-of select="Lang:getStr(&lk;,'TYPE')"/></label>
            	<div class="form-entry">
            		<p>
                <xsl:call-template name="SelAttributeUnitName">
                  <xsl:with-param name="unitTypeID" select="$attUnitID"/>
                </xsl:call-template>
	                </p>
            	</div>
            </div>

            <!--  Values -->
            <xsl:call-template name="RestrictedSetValueEdit">
            	<xsl:with-param name="attUnitID" select="$attUnitID"/>
            </xsl:call-template>

            <div class="form-group">
            	<label class="offset-label"></label>
            	<div class="form-entry">
            		<input type="submit" value="{Lang:getStr(&lk;,'CHANGE')}" class="btn btn-primary"/>
            	</div>
            </div>
            
            
            </div>
          </form>
		
	
 </xsl:template>
 
<xsl:template name="RestrSetValueOption">
    <xsl:param name="attUnitID"/>
    
    <xsl:variable name="attributeValue">
		   
		<xsl:choose>    
		<xsl:when test=" $attUnitID != '00001_0000000020'">
		   
		      <xsl:call-template name="ConvertValueToUserUnits">
		        <xsl:with-param name="curValue" select="value"/> 
		        <xsl:with-param name="unitTypeID" select="$attUnitID"/> 
		        <xsl:with-param name="withRounding" select="0"/> 
		      </xsl:call-template>
		       
		</xsl:when>
		<xsl:otherwise>
		<xsl:call-template name="HumanReadableShortDateInMDYTimeFormat">
			<xsl:with-param name="DateString"  select="value"/>
		</xsl:call-template>
		</xsl:otherwise>
		</xsl:choose>    
		 
    </xsl:variable>
    
    <xsl:variable name="attributeDisplayValue">
		
		<xsl:choose>    
		<xsl:when test=" $attUnitID != '00001_0000000020'">
		    
		      <xsl:call-template name="ConvertValueToUserUnits">
		        <xsl:with-param name="curValue" select="value"/> 
		        <xsl:with-param name="unitTypeID" select="$attUnitID"/> 
		        <xsl:with-param name="withRounding" select="1"/> 
		      </xsl:call-template>
		        
		</xsl:when>
		<xsl:otherwise>
		<xsl:call-template name="HumanReadableLongDateAndTime">
			<xsl:with-param name="LongDateString"  select="value"/>
		</xsl:call-template>
		</xsl:otherwise>
		</xsl:choose>    
		
    </xsl:variable>
    
    <option value="{$attributeValue}">
      <xsl:value-of select="$attributeDisplayValue"/>
    </option>  
  </xsl:template>


  <xsl:template name="AttUnitsOption">
    <option value="{@id}">
	  <xsl:call-template name="SelAttributeUnitName">
	    <xsl:with-param name="unitTypeID" select="@id"/>
	  </xsl:call-template>
    </option>  
  </xsl:template>
  

	<!-- Template displaying change, import and export buttons at the button of -->
	<!-- project and document attributes pages.                                 -->
 	<xsl:template name="AttributeActionButtons">
    <xsl:param name="action"/>
    <xsl:param name="importActionValue"/>
    <xsl:param name="exportActionValue"/>
    <xsl:param name="changeActionValue"/>
    <xsl:param name="inputTemplateName"/>
    <xsl:param name="showImportExportFunctionality" select="true()"/>
    
    <div id="AttributeActionButtons" style="display:none">
		  <form name="actionform2" method="post" action="{$action}" class="wcr-form extra-spacing-top">

			<div class="form-section section-no-labels">

		    <div id="SaveButtonRowID" style="display:none">
		    	<div class="form-group">
		    		<label class="offset-label"></label>
		    		<div class="form-entry">
		    			<input type="button" name="Save" value="{Lang:getStr(&lk;,'SAVECHANGES')}" title="{Lang:getStr(&lk;,'SAVECHANGES')}"
		          			 onclick="saveButtonClicked('{$changeActionValue}');" class="btn btn-primary"/>
 			
			<xsl:if test="$showImportExportFunctionality">
				<!-- buttons to export to JDF -->
							<input type="button" name="ExportButton" value="{Lang:getStr(&lk;,'EXPORT_ATTRS_LABEL_TAG')}" title="{Lang:getStr(&lk;,'EXPORT_ATTRS_LABEL_TAG')}"
								onclick="ExportAttrsToXML('{$exportActionValue}');" class="btn btn-default" />
						</xsl:if>
		          		
		          		<xsl:if test="$showImportExportFunctionality">
		          			<input type="button" name="ImportJDF_File_Button" value="{Lang:getStr(&lk;,'IMPORT_ATTRS_LABEL_TAG')}" title="{Lang:getStr(&lk;,'IMPORT_ATTRS_LABEL_TAG')}"
								onclick="ShowImportFromJDFDialog();" class="btn btn-default" />
			</xsl:if>
		          		
		    		</div>
		    	</div>
			</div>
 			
			
			
			</div>
			
		  </form>
			
		<div id="import_JDF_File_Section" title="{Lang:getStr(&lk;,'IMPORT_ATTRS_LABEL_TAG')}" class="hidden">	
			<form name="inputform" method="post" action="{$action}" enctype="MULTIPART/FORM-DATA" accept="application/jdf" class="wcr-form">
				<input type="hidden" name="actionVal" value="{$importActionValue}"/>
				<xsl:call-template name="menuFileHiddenInput"/>
				
				<xsl:choose>
					<xsl:when test="$inputTemplateName='docDetailsHiddenInputs'">
						<input name="docVerID" value="{/webcenter_page/doc_version/@id}" type="hidden"/>
					</xsl:when>
					<xsl:otherwise>
						  <input name="projectID" value="{/webcenter_page/project/@id}" type="hidden"/>
					</xsl:otherwise>
				</xsl:choose>
	
				<div class="form-section section-no-labels add-spacing">
				
				<xsl:if test="$showImportExportFunctionality">
					<!-- buttons to import from JDF -->
					<div class="form-group">
						<label class="offset-label"></label>
						<div class="form-entry">
							<div class="file-input-selector add-spacing-bottom" data-init="component/styledfileinput/StyledFileInput">
								<input type="file" name="XMLFile" id="XMLFile" onkeyup="VerifyInputFile(this)" onchange="VerifyInputFile(this)"></input>    
								<a class="btn btn-primary"><xsl:value-of select="Lang:getStrBundle(&lk;,'StyledFileInput','OPEN_FILE_BROWSER')"/></a>
							</div>
							<input type="button" name="ImportButton" disabled="disabled" value="{Lang:getStr(&lk;,'IMPORT_ATTRS_LABEL_TAG')}" onclick="ImportAttrsFromXML();" class="btn btn-default" />
						</div>
					</div>
				</xsl:if>
				
				</div>
			
			</form>
		</div>
	</div>
	</xsl:template>


	<xsl:template name="isPrinting">
		<xsl:choose>
			<xsl:when test="count(/webcenter_page/is_printing) &gt; 0"><xsl:value-of select="/webcenter_page/is_printing"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="0"/></xsl:otherwise>
		</xsl:choose>		
	</xsl:template>
	
	<!-- 
		template to display notification/errors when saving new attributes values (document references)
	-->
	<xsl:template name="DisplayAttrSaveNotificationBlock">
		<xsl:param name="AttrLangTag" select="'ATTRIBUTE'" />
		<xsl:for-each select="attr">
			<xsl:if test="attr_name">
				<p><xsl:value-of select ="Lang:getStr(&lk;,$AttrLangTag)"/>:&nbsp;<xsl:value-of select="attr_name"/></p>
			</xsl:if>
			<xsl:for-each select="error">
				<p><xsl:value-of select="."/></p>
			</xsl:for-each>
		</xsl:for-each>
	</xsl:template>
		
	<xsl:template name="DisplayAttrSaveNotification">
		<xsl:param name="addColspan" select="false()"/>
		<xsl:param name="addTableRow" select="true()"/>
		
		<xsl:if test="attr_err_list">
		
			<xsl:choose>
			<xsl:when test="$addTableRow = 'true'">
			<tr>
				<td>
					<xsl:if test="$addColspan = 'true'">
						<xsl:attribute name="colspan">2</xsl:attribute>
					</xsl:if>
					
					<xsl:call-template name="DisplayAttrSaveNotificationBody">
					</xsl:call-template>
				</td>
			</tr>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="DisplayAttrSaveNotificationBody">
				</xsl:call-template>
			</xsl:otherwise>
			</xsl:choose>
			
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template name="DisplayAttrSaveNotificationBody">
		
		<div class="alert alert-danger" role="alert">
			
			<div class="add-spacing-bottom">
				<!-- write project attributes notifications -->						
				<xsl:for-each select="attr_err_list/proj_attr">
					<p><xsl:value-of select ="Lang:getStr(&lk;,'PROJECT')"/>&nbsp;<xsl:value-of select="parent_name"/></p>
					
					<xsl:call-template name="DisplayAttrSaveNotificationBlock">
					</xsl:call-template>
				</xsl:for-each>
			</div>
			
			<div class="add-spacing-bottom">
				<!-- write task specifications notifications -->
				<xsl:for-each select="attr_err_list/task_attr">
					<p><xsl:value-of select ="Lang:getStr(&lk;,'TASK')"/>&nbsp;<xsl:value-of select="parent_name"/></p>
				
					<xsl:call-template name="DisplayAttrSaveNotificationBlock">
						<xsl:with-param name="AttrLangTag" select="'ACLayoutSpecification'" />
					</xsl:call-template>
				</xsl:for-each>
			</div>
				
			<div class="add-spacing-bottom">
				<!-- write document attributes notifications -->
				<xsl:for-each select="attr_err_list/doc_attr">
					<xsl:variable name="docVerId" select="parent_id" />
					<p><xsl:value-of select ="Lang:getStr(&lk;,'DOCUMENT')"/>&nbsp;<a href="./docdetails.jsp?docVerID={$docVerId}" target="_blank"><xsl:value-of select="parent_name"/></a></p>
					
					<xsl:call-template name="DisplayAttrSaveNotificationBlock">
					</xsl:call-template>
				</xsl:for-each>
			</div>
		</div>
		
	</xsl:template>

   <!-- 
  
            template that controls the inclusion of javascript functionality 
            
  -->
  <xsl:template name="AttributeTemplateJavaScript">
    <script src="javascript/TableSelection.js"/>&#xA;
    <script src="javascript/detailswin.js"/>&#xA;
    <script src="javascript/validate.js"/>&#xA;
    <script src="javascript/filter.js"/>&#xA;
	<script type="text/javascript">&#xA;
	<xsl:text disable-output-escaping="yes">&lt;!--</xsl:text>&#xA;

         var rSetCount = <xsl:value-of select="count(/webcenter_page/restricted_set_list/restricted_set)"/>;
		 
        var curUnitLablesArray = new Array();
        <xsl:for-each select="//attribute_unit_list/attribute_unit">
          <xsl:text disable-output-escaping="yes">curUnitLablesArray ["</xsl:text>
            <xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="@id" /></xsl:call-template>
            <xsl:text disable-output-escaping="yes">"] = "</xsl:text>
            <xsl:call-template name="escapequotationmark"><xsl:with-param name="string">
          <xsl:choose>
            <xsl:when test="/webcenter_page/user_units='imperial'">
                <xsl:value-of select="Lang:getStr(&lk;,imperial_conversion/to)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="Lang:getStr(&lk;,metric_conversion/to)"/>
            </xsl:otherwise>
          </xsl:choose></xsl:with-param></xsl:call-template>
            <xsl:text disable-output-escaping="yes">";</xsl:text>
        </xsl:for-each>
      
        var unitTypeArray = new Array();
        unitTypeArray[0] = '';
        <xsl:for-each select="//attribute_unit_list/attribute_unit">
          <xsl:text disable-output-escaping="yes">unitTypeArray[</xsl:text>
            <xsl:value-of select="position()"/>
            <xsl:text disable-output-escaping="yes">] = "</xsl:text>
                <xsl:value-of select="type"/>
            <xsl:text disable-output-escaping="yes">";</xsl:text>
        </xsl:for-each>
		 
  
        var attrIDArray = new Array();
        attrIDArray[0] = '';
        <xsl:for-each select="//attribute_list/attribute">
          <xsl:text disable-output-escaping="yes">attrIDArray[</xsl:text>
            <xsl:value-of select="position()"/>
            <xsl:text disable-output-escaping="yes">] = "</xsl:text>
                <xsl:value-of select="@id"/>
            <xsl:text disable-output-escaping="yes">";</xsl:text>
        </xsl:for-each>

        function SetInitialFocus()
        { 
          // set the focus to the attribute name
          if (document.actionform &amp;&amp; document.actionform.attributeName)
          {
	          document.actionform.attributeName.focus();
    	  }
	
		  InitPage();
        }
		
        function InitPage()
        {
          if (document.actionform &amp;&amp; document.actionform.attributeName)
          {
	        CheckTextInput(document.actionform.attributeName.value, '', 'AttributeNameRow');
	        CheckTextInput(document.actionform.attributeDesc.value, '', 'AttributeDescRow');
	        CheckTextInput(document.actionform.unitType.value, '', 'AttributeUnitsRow');

			ChangeResValueType();
		  }
        }

        
		function SaveSelectedIDs(rsetID, rsetUnitID)
		{
			document.actionform.selectedRSetID.value = rsetID;
			document.actionform.selectedRSetUnitID.value = rsetUnitID;
		}

		function ShowRestrictedSetDetailsOrWarning(rSetID) 
		{
			if (!rSetID &amp;&amp; (rSetID.length == 0)) {
		    	alert('<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="Lang:getStr(&lk;,'SELECTRESTRSET')"/></xsl:call-template>');
				return false;
			}
			ShowRestrictedSetDetails(rSetID);
		}
		
 
        function SelectRadio(radioElem)
        {
          ClearAllChecked(rSetCount, document.actionform.selectRestrictedSet);
          radioElem.checked = true;
          Toggle(radioElem);
        }


        function InitNewRSetPage()
        {
          // wipe out the name 
          document.actionform.restrictedSetName.value = "";
          
          onUnitTypeChange(document.actionform.unitType);
        }
      
        function onUnitTypeChange(seleElem)
        {
          // check to see if there is a value selected in the list
          while (document.actionform.valueList.options.length) 
            document.actionform.valueList.options[0] = null;
            
          CheckTextInput(seleElem.value, '', 'UnitTypeRow')
            
          // update the current units label
          setCurUnitsLabel(seleElem.options[seleElem.selectedIndex].value);
		  
		  if (seleElem.value == '00001_0000000020')
          {
            if (document.getElementById('showCalender').style.display = 'none')
            {
            	document.getElementById('showCalender').style.display = 'block';
            }
            if (document.getElementById('showStandard').style.display = 'block')
            {
            	document.getElementById('showStandard').style.display = 'none';
            }
          }
          else
          {
            if (document.getElementById('showCalender').style.display = 'block')
            {
            	document.getElementById('showCalender').style.display = 'none';
            }
            if (document.getElementById('showStandard').style.display = 'none')
            {
            	document.getElementById('showStandard').style.display = 'block';
            }
          }
		  if (seleElem.value == '00001_0000000001') // only show if Text
		  {
            document.actionform.sortBtn.style.display = 'block';
          }
          else
          {
            document.actionform.sortBtn.style.display = 'none';
          }
        }        

        function setCurUnitsLabel(selValue)
        {
          var testElem = document.getElementById( "curUnitTD");
          
          var newLabel = '<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="Lang:getStr(&lk;,'VALUE')"/></xsl:call-template>';
          if (!isEmpty(curUnitLablesArray[selValue]))
            newLabel = newLabel + ' (' + curUnitLablesArray[selValue] + ')';
          
           testElem.innerHTML= newLabel;
          
        }
      
		// chya, for datetime type, textvalue is different with real value in a option list
        //function addOption(selectElem, value)
        function addOption(selectElem, value, textValue)
        {
          // add the new option
          var optionElem = document.createElement("option") ;
          optionElem.value = value;
          optionElem.name = value;
          //optionElem.text = value;	// chya
          optionElem.text = textValue;
          if (isNav)
            selectElem.appendChild(optionElem);
          else
            selectElem.add(optionElem);
          optionElem.selected = true;
        }
        
<!--         DT106922: changed from plaing JS to jQuery. This DT was caused by 2 bugs. One was caused by redrawing? the select element in the moveOptionsUp function  -->
<!--           and the other was caused by usage of insertBefore function and array index out of array size in the moveOptionsDown function -->
        function moveOptionsUp(selectId) {
        	<!-- DT106922: in IE there was an issue with redrawing? when moving 2nd option element in the first position. This fixes it(hide and show).   -->
			$("#"+ selectId).hide();
        
        	$("#"+ selectId + " option:selected").each(function(a, b, c){
			 $(this).insertBefore($(this).prev());
			});
			
		 	$("#"+ selectId).show();		 
		 }
		
		<!-- DT106922: changed from plaing JS to jQuery - the JS function used was insertBefore and when moving option to the last position, there were attempt to acces an out of array index. The IE had trouble with that. Thus, changed to jQuery where insertAfter function is availabel -->
		function moveOptionsDown(selectId) {
			$("#"+ selectId).hide();
		
		   	$($("#"+ selectId + " option:selected").get().reverse()).each(function(a, b, c){
			 $(this).insertAfter($(this).next());
			});
		 
		 	$("#"+ selectId).show();		
		}
		
		function sortList(selectId) {
			var lb = document.getElementById(selectId);
			arrTexts = new Array();
			for(var i = 0; i &lt; lb.length; i++) {
			  arrTexts[i] = lb.options[i].text;
			}
			
			arrTexts.sort(function(x,y){ 
		      var a = String(x).toUpperCase(); 
		      var b = String(y).toUpperCase(); 
		      if (a &gt; b) 
		         return 1 
		      if (a &lt; b) 
		         return -1 
		      return 0; 
		    }); 
			
			for(var i = 0; i &lt; lb.length; i++)  {
			  lb.options[i].text = arrTexts[i];
			  lb.options[i].value = arrTexts[i];
			  lb.options[i].selected = false;
			}
		}
				
        function isDuplicate(unitType, listElem, newvalue)
        {
            var duplicate = false;
            
            var i = 0;
            for (i=0;i &lt; listElem.length;i++)
            {
              if ((unitType == 'UNITS') || (unitType == 'FLOAT') || (unitType == 'NUMBER'))
              {
                if (parseFloat(listElem.options[i].value) == parseFloat(newvalue))
                {
                  duplicate  = true;
                  break;
                }
              }
              else
              {
                if (listElem.options[i].value.toUpperCase() == newvalue.toUpperCase())
                {
                  duplicate  = true;
                  break;
                }
              }
            }
            
            return duplicate;
        }

        function isDuplicateValue(listElem, newvalue)
        {
            var duplicate = false;
            
            var i = 0;
            for (i=0;i &lt; listElem.length;i++)
            {
              if ((unitType == 'UNITS') || (unitType == 'FLOAT') || (unitType == 'NUMBER'))
              {
                if (parseFloat(listElem.options[i].value) == parseFloat(newvalue))
                {
                  duplicate  = true;
                  break;
                }
              }
              else
              {
                if (listElem.options[i].value.toUpperCase() == newvalue.toUpperCase())
                {
                  duplicate  = true;
                  break;
                }
              }
            }
            
            return duplicate;
        }

        function RemoveValue()
        {
          // check to see if there is a value selected in the list
          var selIndex = document.actionform.valueList.selectedIndex;
          if (-1 !=  selIndex)
          {       
            document.actionform.valueList.remove(selIndex);
          }
        }

		function removeOptions(selectId) {
		 var selectList = document.getElementById(selectId);
		 var selectOptions = selectList.getElementsByTagName('option');
		 for (var i = selectOptions.length-1; i &gt;= 0; i--) {
		  var opt = selectOptions[i];
		  if (opt.selected) {
		   selectList.remove(i);
		  }
		 }
		}
        
        function ValidateRSetForm() 
        {
          if (isWhitespace(document.actionform.restrictedSetName.value))
          {
            alert('<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="Lang:getStr(&lk;,'INVALIDRESTRICTEDSETNAME')"/></xsl:call-template>');
            return false;
          }
          
          // check to make sure we have the units picked
          if (document.actionform.unitType.selectedIndex == 0)
          {
            alert('<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="Lang:getStr(&lk;,'NO_RES_SET_TYPE')"/></xsl:call-template>');
            return false;
          }
          
          if (isWhitespace(document.actionform.newvalue.value) == false)
          {
            if (!confirm('<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="Lang:getStr(&lk;,'CONFIRM_IGNORE_RSET_VALUE')"/></xsl:call-template>'))
              return false;
          }

          if (document.actionform.valueList.length == 0)
          {
            alert('<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="Lang:getStr(&lk;,'NORESTRICTEDSETVALUES')"/></xsl:call-template>');
            return false;
          }

          // save all of the values in the list to a hidden field so they are passed with the form appropriately
          var list = document.actionform.valueList;

          var i = 0;
          var savedvalues = "";
          for (i=0;i &lt; list .length;i++)
          {
            if (i &gt; 0)
            {
              savedvalues = savedvalues + '\t';
            }
            savedvalues += list.options[i].value;
          }
          document.actionform.restrictedSetValues.value = savedvalues;
          
          return true;
        }
        
       function SetInitialFocusNewRSetPage()
        {
          // set the focus
          document.actionform.restrictedSetName.focus();
        }

		function EnableRequiredCheck(elem)
		{
			// when attribute is selected enable isRequired checkbox
			var requiredFieldName = "isRequired" + elem.value;
			EnableRequired(requiredFieldName, elem.checked);
		}
		
		function EnableRequired(fieldName, isChecked)
		{
			// by given required field name enable/disable it
			var requiredField = document.getElementById( fieldName);
			if (isChecked == true )
			{
				requiredField.disabled = false;
			}
			else
			{
				requiredField.checked = false;
				// Check if isRequired was checked then uncheck it
				requiredField.disabled = true;
			}			
		}
		
		function EnableAllRequired()
		{
			// required elem name is build in the following way:
			// isRequired + @id
			// get all elements from the xml then for each id
			// build elem name
			// enable/disable it
			
			  var isRequiredFieldName = "";
			  
			  // walk each of the element in the table
				var len = document.actionform.elements.length;
				var attrIndex = 0;
  				for (var i = 0; i &lt; len; i++)
				  {
					var inputElem = document.actionform.elements[i];
					
					if (inputElem.name == 'selectAttribute')
					{
					  // found attribute
					  attrIndex++;
					  
					  // build isRequired name
					  isRequiredFieldName = "isRequired" + attrIDArray[attrIndex]  ;
					 
					  if (inputElem.disabled == false)
					  {
					     EnableRequired(isRequiredFieldName, inputElem.checked);
					  }
					  
					}
				  }

		}		
		
      function ValidateAttrValueFormParams()
      {
		//alert('ValidateAttrValueFormParams');
	    // This function is called on setting project/doc/task attributes values
          <xsl:variable name="isEditable" select="(//is_project_editable &gt; 0) or (//project_user_permissions/permission/update = 1) or (//is_editable &gt; 0)"/>
          <xsl:if test="$isEditable">
            var inputElem;
            var errorMsg;
            var errorMsg2;
            var errorMsg1 = '<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="Lang:getStr(&lk;, 'THEATTRVALUE')"/></xsl:call-template>';
            var errorMsg3 = '<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="Lang:getStr(&lk;, 'ISINVALID')"/></xsl:call-template>';

            <xsl:for-each select="//attribute_value_view_list/attribute_value_view">

                inputElem = document.getElementById( '<xsl:value-of select="attribute/@id"/>' );
                errorMsg2  = '<xsl:value-of select="XSLUtils:encodeForJScript(attribute/name)"/>';
                errorMsg = errorMsg1 + ' ' +  errorMsg2  + ' ' + errorMsg3;

				//alert('elementID - <xsl:value-of select="attribute/@id"/>');
                <xsl:variable name="attributeUnitsType">
                  <xsl:call-template name="GetUnitsType">
                    <xsl:with-param name="unitTypeID" select="attribute/attribute_unit_id"/> 
                  </xsl:call-template>
                </xsl:variable>

              <xsl:if test="string-length(attribute/restricted_set_id) = 0">

  
               <xsl:if test="($attributeUnitsType='UNITS') or ($attributeUnitsType='FLOAT')">
                  if (!validateFloat(inputElem , errorMsg))
                  {
                    inputElem.focus();
                    return false;
                  }
  
                </xsl:if>
                <xsl:if test="$attributeUnitsType='NUMBER'">
                  if (!validateInt(inputElem , errorMsg))
                  {
                    inputElem.focus();
                    return false;
                  }
                </xsl:if>
                
              </xsl:if>
			  
			  // now check if attribute is required then it cannot be empty
			  var isRequiredField = <xsl:value-of select="is_required"/>;
			  if (isRequiredField)
			  {
				  if (isWhitespace(inputElem.value))
				  {
					alert('<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="Lang:getStr(&lk;,'EMPTYREQUIREDATTR')"/></xsl:call-template>');
					
					<xsl:choose>
						<xsl:when test="$attributeUnitsType='DATETIME'">
							var inputElemDateName = document.getElementById('adate<xsl:value-of select="attribute/@id"/>');
							inputElemDateName.focus();
						</xsl:when>
						<xsl:otherwise>
							inputElem.focus();
						</xsl:otherwise>
					</xsl:choose>
					
					return false;
				  }
 
			  }
            </xsl:for-each>
          </xsl:if>

      return true;
    }
    
    
    var gActionFormSubmitted = false;
    
    <!-- This function called when Save button is clicked on (at least) project/document attribute category pages -->
    function saveButtonClicked(action) {
    	var aCatObj = document.getElementById("ACatObj");
    	
    	if (aCatObj &amp;&amp; aCatObj.ACatObj) {
	    	// disable all submit buttons to prevent multiple form submits
	    	// (it needs to be here as well because of the postponed validation below)
			enableSubmitButtons(false);
    	}

		// The delay of submit is needed here to move the validation and submit (including generation of document reference "saveXML")
		// in the asynchronous calls queue after the potentially pending debounced attribute category re-paint(s), which can be triggered
		// by rules defined in attribute category.
		setTimeout(function() {
			// grab the latest attribute category object (might alter since the first time it was grabed)
	    	aCatObj = document.getElementById("ACatObj");
	    	
	    	if (aCatObj &amp;&amp; aCatObj.ACatObj) {
			    aCatObj.ACatObj.checkPasswordAndSave(function() {
			    	ChangeAttrs(action);
			    });
			    if (!gActionFormSubmitted) {
					// the form not submitted (probably due to validation issue detected) - enable all submit buttons again
					enableSubmitButtons(true);
			    }
		    }
		}.bind(this), 500);
	}

	<!-- This function is called for save changes in the attributes
		 after password validation check is performed by checkPasswordAndSave() in AttributeCategory.js -->
    function ChangeAttrs(action)
    {
		//alert('ChangeAttrs' + action);
		document.actionform.actionVal.value = action;
	    var aCatObj = document.getElementById("ACatObj");
	    var validationOK = true;
	    if (aCatObj &amp;&amp; aCatObj.ACatObj) {
		    validationOK = aCatObj.ACatObj.prepareForSubmit(false, true);
	    }
	   	if (validationOK) {
		    assignDate(document.actionform);
			gActionFormSubmitted = true;
			
			document.actionform.submit();
			
			enableSubmitButtons(false);
	    }
    }

	<!-- Function to enable/disable all submit buttons on the page. -->
	function enableSubmitButtons(enable) {
		Array.prototype.filter.call(document.actionform2.elements, 
		(function(el){
			return (el.type === "submit" || el.type === "button") &amp;&amp; el.className.indexOf("forceSubmit") == -1;
		})).forEach(function(el){
			el.disabled = !enable;
		});
	}
	

    function ExportAttrsToXML(actionvalue)
    {
       	var isAttrsChanged = false;
	    var aCatObjElem = document.getElementById("ACatObj");
	    if (aCatObjElem &amp;&amp; aCatObjElem.ACatObj) {
		    isAttrsChanged = aCatObjElem.ACatObj.attributesChanged === true;
	    }
    
    	if (isAttrsChanged) {
	    	alert('<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="Lang:getStr(&lk;,'CANNOT_EXPORT_SAVE_FIRST')"/></xsl:call-template>');
			return false;
		} else {
			document.actionform.actionVal.value = actionvalue;
	    	document.actionform.submit();
	    }
    }
	
    function ImportAttrsFromXML()
    {
	    document.inputform.submit();
    }
		
	function VerifyInputFile(field)
	{
		document.inputform.ImportButton.disabled = validateFileName(field.value);
	}

	function PropagateChange(elem)
	{
		var dstID = String(elem.id).replace(/longFormat_/, '');
		var dst = document.getElementById(dstID);
		if (dst) 
		{
			elem.value = elem.value.replace(/\s+/, '');
			if (elem.value.length == 0)
			{
				dst.value = elem.value;
			}
	 	}
	}
	
	function ShowImportFromJDFDialog() {
		
		$("#import_JDF_File_Section").dialog({
			open: function(event) {
				$("#import_JDF_File_Section").removeClass("hidden");
				$("input[name='ImportJDF_File_Button']").prop("disabled", true);
			},
			close: function() {
				$("#import_JDF_File_Section").addClass("hidden");
				$("input[name='ImportJDF_File_Button']").prop("disabled", false);
			}
		});
		
	}
	
    <xsl:text disable-output-escaping="yes">//--&gt;</xsl:text>&#xA;
	</script>&#xA;    
	 <xsl:call-template name="DateJavaScript"/>
  </xsl:template> 
</xsl:stylesheet>
