define('web-viewer/textContent/DynContentEntryView',["jquery",
		"underscore",
		"packaging-content-management/ContentConstants"],
	function (
		$,
		_,
		ContentConstants) {
		"use strict";

		/**
		 * This class enables the view for every text content in DynContentWidget
		 * Depending on the language selected, DynContentEntry View will be updated accordingly
		 */
		var DynContentEntryView = function (masterText, transText, masterStatus, transStatus, masterLangCode, transLangCode, languagesList, elementTypeColor, elementHumanReadable, isUnsaved) {
			this._masterText = masterText;
			this._transText = transText;
			this._masterStatus = masterStatus;
			this._transStatus = transStatus;
			this._languagesList = languagesList;
			this._masterLangCode = masterLangCode;
			this._transLangCode = transLangCode;
			this._elementTypeColor = elementTypeColor;
			this._elementHumanReadable = elementHumanReadable;
			this._isUnsaved = isUnsaved;

			// All the callbacks that need to be executed when the view is clicked.
			this._onClicked = [];
			this._onElementClicked = [];

			// Create the wrapping div.
			this._wrapper = $("<div>", {
				"class": "DynContentEntry"
			});

			// Create the wrapping div.
			this.init();

			// When the wrapping div is clicked ...
			this._wrapper.on("click", function () {
				for (var i = 0; i < this._onClicked.length; i++) {
					this._onClicked[i]();
				}
			}.bind(this));
		};

		/**
		 * Initialize the widget for single Text Content
		 * This includes - Color Code, Flag, Status, Actual Text for Master and translation
		 */
		DynContentEntryView.prototype.init = function () {

			// Empty the wrapper.
			this._wrapper.empty();

			// Create a lang table.
			this._langTable = $("<table>", {
				"class": "LangTable"
			});

			// Add the "Unsaved"  class if the entry is currently unsaved.
			if (this._isUnsaved) {
				this._langTable.addClass("Unsaved");
			}

			// Create the elements for the master text
			this._masterTextRow = $("<tr>", {
				"class": "MasterTextRow"
			});
			this._masterTextFlagCell = $("<td>", {
				"class": "MasterTextFlagCell"
			});
			this._masterTextFlagCell.append($("<img>", {
				"src": this._getLangFlag(true, this._masterLangCode)
			}));
			this._masterTextStateCell = $("<td>", {
				"class": "MasterTextStateCell"
			});
			this._masterTextStateCell.append($("<i>", {
				"class": this._getStateIconClass(this._masterStatus)
			}));
			this._masterTextContentCell = $("<td>", {
				"class": "MasterTextContentCell"
			});
			this._masterTextContentContainer = $("<div>", {
				"class": "MasterTextContentContainer"
			});

			// If master language is still not added, then we get master text as undefined
			if (undefined !== this._masterText && this._masterText.length > 0) {
				this._masterTextContentContainer.text(this._masterText);
			} else {
				this._masterTextContentContainer.html("&nbsp;");
			}
			this._masterTextContentCell.append(this._masterTextContentContainer);
			this._masterTextFlagCell.on("click", function (event) {
				event.stopPropagation();
				this._execOnElementClicked(this._masterLangCode);
			}.bind(this));
			this._masterTextStateCell.on("click", function (event) {
				event.stopPropagation();
				this._execOnElementClicked(this._masterLangCode);
			}.bind(this));
			this._masterTextContentContainer.on("click", function (event) {
				event.stopPropagation();
				this._execOnElementClicked(this._masterLangCode);
			}.bind(this));

			// Add them to the wrapper.
			this._langTable.append(this._masterTextRow);
			this._masterTextRow.append(this._masterTextFlagCell);
			this._masterTextRow.append(this._masterTextStateCell);
			this._masterTextRow.append(this._masterTextContentCell);

			if (this._transLangCode) {
				// Create the elements for the translation
				this._transTextRow = $("<tr>", {
					"class": "TransTextRow"
				});
				this._transTextFlagCell = $("<td>", {
					"class": "TransTextFlagCell"
				});
				this._transTextFlagCell.append($("<img>", {
					"src": this._getLangFlag(false, this._transLangCode)
				}));
				this._transTextStateCell = $("<td>", {
					"class": "TransTextStateCell"
				});
				this._transTextStateCell.append($("<i>", {
					"class": this._getStateIconClass(this._transStatus)
				}));
				this._transTextContentCell = $("<td>", {
					"class": "TransTextContentCell"
				});
				this._transTextContentContainer = $("<div>", {
					"class": "TransTextContentContainer"
				});
				if (this._transText.length > 0) {
					this._transTextContentContainer.text(this._transText);
				} else {
					this._transTextContentContainer.html("&nbsp;");
				}
				this._transTextContentCell.append(this._transTextContentContainer);
				this._transTextStateCell.on("click", function (event) {
					event.stopPropagation();
					this._execOnElementClicked(this._transLangCode);
				}.bind(this));
				this._transTextFlagCell.on("click", function (event) {
					event.stopPropagation();
					this._execOnElementClicked(this._transLangCode);
				}.bind(this));
				this._transTextContentContainer.on("click", function (event) {
					event.stopPropagation();
					this._execOnElementClicked(this._transLangCode);
				}.bind(this));

				// Add them to the wrapper.
				this._langTable.append(this._transTextRow);
				this._transTextRow.append(this._transTextFlagCell);
				this._transTextRow.append(this._transTextStateCell);
				this._transTextRow.append(this._transTextContentCell);
			}

			// If the element type of this contentstatement has a particular color ...
			if (this._elementTypeColor) {
				// Create a new wrapping table that will hold the color handle
				var mainTable = $("<table>", {
					"class": "MainTable"
				});
				var mainRow = $("<tr>", {
					"class": "MainRow"
				});
				var colorCell = $("<td>", {
					"class": "ColorCell",
					"style": "background-color: " + this._elementTypeColor + "; cursor: pointer"
				});
				var langCell = $("<td>", {
					"class": "LangCell"
				});


				// When hovering over the color cell, make it lighter ...
				colorCell.hover(function () {
					colorCell.css("opacity", 0.3);
				}.bind(this), function () {
					colorCell.css("opacity", 1);
				}.bind(this));

				// Add the element type description as a tooltip.
				if (this._elementHumanReadable) {
					colorCell.attr('title', this._elementHumanReadable);
				}

				// Put everything together.
				langCell.append(this._langTable);
				mainRow.append(colorCell);
				mainRow.append(langCell);
				mainTable.append(mainRow);
				this._wrapper.append(mainTable);
			} else {
				this._wrapper.append(this._langTable);
			}
		};

		DynContentEntryView.prototype.highlight = function () {
			this._wrapper.addClass("highlight");
			// Try to scroll the element into view.
			try {
				this._wrapper[0].scrollIntoView();
			} catch (e) {}
		};

		DynContentEntryView.prototype.unHighlight = function () {
			this._wrapper.removeClass("highlight");
		};

		DynContentEntryView.prototype.setMasterText = function (masterLang, masterPlainText, masterStatus) {
			this._masterText = masterPlainText;
			this._masterLangCode = masterLang;
			this._masterStatus = masterStatus;
			this.init();
		};

		DynContentEntryView.prototype.setTransText = function (transLang, transPlainText, transStatus) {
			this._transText = transPlainText;
			this._transLangCode = transLang;
			this._transStatus = transStatus;
			this.init();
		};

		DynContentEntryView.prototype.setUnsaved = function (isUnsaved) {
			this._isUnsaved = isUnsaved;
			// Add the "Unsaved"  class if the entry is currently unsaved.
			if (this._isUnsaved) {
				this._langTable.addClass("Unsaved");
			} else {
				this._langTable.removeClass("Unsaved");
			}
		};

		DynContentEntryView.prototype._getStateIconClass = function (state) {
			if (state == ContentConstants.State.DRAFT) {
				return "icon-WCR_Text-Status-Draft";
			} else if (state == ContentConstants.State.READY_FOR_APPROVAL) {
				return "icon-WCR_Text-Status-Pending";
			} else if (state == ContentConstants.State.APPROVED) {
				return "icon-WCR_Text-Status-Approved icon-WCR_Approve";
			} else if (state == ContentConstants.State.REJECTED) {
				return "icon-WCR_Text-Status-Rejected icon-WCR_Reject";
			}
		};

		DynContentEntryView.prototype._getLangFlag = function (isMaster, langCode) {
			if (isMaster) {
				for (var i = 0; i < this._languagesList.allMasterLangs.length; i++) {
					if (this._languagesList.allMasterLangs[i].langCode == langCode) {
						var mFlagName = this._languagesList.allMasterLangs[i].langFlag;
						return "./images/country_flags/" + mFlagName;
					}
				}
			} else {
				for (var j = 0; j < this._languagesList.allTranslationLangs.length; j++) {
					if (this._languagesList.allTranslationLangs[j].langCode == langCode) {
						var tFlagName = this._languagesList.allTranslationLangs[j].langFlag;
						return "./images/country_flags/" + tFlagName;
					}
				}
			}
		};

		DynContentEntryView.prototype._execOnElementClicked = function (langCode) {
			for (var i = 0; i < this._onElementClicked.length; i++) {
				this._onElementClicked[i](langCode);
			}
		};

		DynContentEntryView.prototype.onElementClicked = function (callback) {
			this._onElementClicked.push(callback);
		};

		DynContentEntryView.prototype.onClicked = function (callback) {
			this._onClicked.push(callback);
		};

		DynContentEntryView.prototype.getJQElement = function () {
			return this._wrapper;
		};

		return DynContentEntryView;
	});

define('web-viewer/textContent/DynContentEntry',["jquery",
		"underscore",
		"packaging-content-management/ContentConstants",
		"./DynContentEntryView"],
	function (
		$,
		_,
		ContentConstants,
		DynContentEntryView) {
		"use strict";

		/**
		 * This is the model class for Dynamic Content Entry which supports all the operation that is on the view
		 */
		var DynContentEntry = function (contentStatement, masterLang, transLang, languagesList, elementTypeList) {

			this._contentStatement = contentStatement;
			this._masterElement = this._contentStatement.getElement(masterLang, true);
			this._transElement = this._contentStatement.getElement(transLang, false);
			this._languagesList = languagesList;

			// The callbacks that need to be executed when a statement is clicked.
			this._onSelected = [];
			this._onElementSelected = [];

			var masterPlainText = this._getPlainText(this._masterElement);
			var transPlainText = this._getPlainText(this._transElement);
			var masterStatus;
			var transStatus;
			var masterElementLang;
			var transElementLang;
			var elementTypeColor;
			var elementHumanReadable = this._contentStatement.elementType;

			if (this._masterElement) {
				masterStatus = this._masterElement.state;
				masterElementLang = this._masterElement.language;
			}
			if (this._transElement) {
				transStatus = this._transElement.state;
				transElementLang = this._transElement.language;
			}
			var elementType = elementTypeList[this._contentStatement.elementType];
			if (elementType) {
				elementTypeColor = elementType.color;
				elementHumanReadable = elementType.elementHumanReadable;
			}

			// Create the view.
			this._view = new DynContentEntryView(masterPlainText, transPlainText, masterStatus, transStatus, masterElementLang, transElementLang, languagesList, elementTypeColor, elementHumanReadable, contentStatement.isChanged());

			// When the whole view is clicked
			this._view.onClicked(function () {
				for (var i = 0; i < this._onSelected.length; i++) {
					this._onSelected[i]();
				}
			}.bind(this));

			// When an element in the view is clicked
			this._view.onElementClicked(function (langCode) {
				for (var i = 0; i < this._onElementSelected.length; i++) {
					this._onElementSelected[i](langCode);
				}
			}.bind(this));
		};

		DynContentEntry.prototype.getContentStatement = function () {
			return this._contentStatement;
		};

		DynContentEntry.prototype.update = function (textElement) {
			if (textElement == this._masterElement) {
				this.setMasterLang(this._masterElement);
			} else if (textElement == this._transElement) {
				this.setTransLang(this._transElement);
			}
			if (textElement.isChanged()) {
				this._view.setUnsaved(true);
			} else {
				this._view.setUnsaved(false);
			}
		};

		DynContentEntry.prototype.onSelected = function (callback) {
			this._onSelected.push(callback);
		};

		DynContentEntry.prototype.onElementSelected = function (callback) {
			this._onElementSelected.push(callback);
		};

		DynContentEntry.prototype.highlight = function () {
			this._view.highlight();
		};

		DynContentEntry.prototype.unHighlight = function () {
			this._view.unHighlight();
		};

		DynContentEntry.prototype.setMasterLang = function (textElem) {
			var masterLang = textElem.language;
			this._masterElement = this._contentStatement.getElement(masterLang, true);
			var masterPlainText = this._getPlainText(this._masterElement);
			//Set the new status if status changed else the original status(from revert)
			var masterStatus = textElem.newState || textElem.state;
			this._view.setMasterText(masterLang, masterPlainText, masterStatus);
		};

		DynContentEntry.prototype.setTransLang = function (textElem) {
			var transLang = textElem.language;
			this._transElement = this._contentStatement.getElement(transLang, false);
			var transPlainText = this._getPlainText(this._transElement);
			//Set the new status if status changed else the original status(from revert)
			var transStatus = textElem.newState || textElem.state;
			this._view.setTransText(transLang, transPlainText, transStatus);
		};

		DynContentEntry.prototype._getPlainText = function (element) {
			if (element) {
				var plainText = element.content.content;
				if (this._contentStatement.textType == ContentConstants.TextType.RICHTEXT) {
					plainText = $("<div>").html(plainText).text();
				}
				return plainText.replace(/(\r\n|\n|\r)/gm, "");
			} else {
				return undefined;
			}
		};

		DynContentEntry.prototype.getJQElement = function () {
			return this._view.getJQElement();
		};

		return DynContentEntry;
	});


/**
 * DynContent object
 * 
 * @author KADA
 */
define('packaging-content-management/dyn-content/DynContent',["jquery"],	function ($) {
	
		"use strict";
		
		var DynContent = function (type, id) {
			this._dynContentType = type;
			this._id = id;
		};

		DynContent.prototype.getDynContentType = function () {
			return this._dynContentType;
		};
		
		DynContent.prototype.getId = function () {
			return this._id;
		};
		
		return DynContent;
});

/**
 * ContentStatement object
 * @author HUBU
 */
define('packaging-content-management/dyn-content/TextDynContent',["./DynContent",
		"jquery"
	],
	function (DynContent,
			$) {
	
		"use strict";
		
		var TextDynContent = function (contentStatementElement, locations) {
			
			// Generate an id for this TextDynContent.
			var elementLang = contentStatementElement.language;
			var elementType = contentStatementElement.parentStatement.elementType;
			var instanceSeq = contentStatementElement.parentStatement.instanceId;
			if (!instanceSeq) {
				instanceSeq = "";
			}
			var random = Math.floor(Math.random()*11);
			var id = elementType+"_I"+instanceSeq+"_"+elementLang+"_"+random;
			this._uid = contentStatementElement.parentStatement.getContentId();
			
			// Call the super
			DynContent.call(this, "Text", id);
			
			this._textElement = contentStatementElement;
			if (locations) {
				this._locations = locations;
			} else {
				this._locations = [];
			}
		};
		
		// inherit
		TextDynContent.prototype = Object.create(DynContent.prototype);
		// correct the constructor pointer 
		TextDynContent.prototype.constructor = TextDynContent;
		
		/**
		 * 
		 */
		TextDynContent.prototype.setTextElement = function (textElement) {
			this._textElement = textElement;
		};
		
		/**
		 * returns TextContentElement
		 */
		TextDynContent.prototype.getTextElement = function () {
			return this._textElement;
		};
		
		/**
		 * Return location information
		 */
		TextDynContent.prototype.getLocations = function () {
			return this._locations;
		};
		
		/**
		 * Set the array of locations for this element
		 * @param locations
		 */
		TextDynContent.prototype.setLocations = function (locations) {
			if (locations) {
				this._locations = locations;
			} else {
				this._locations = [];
			}
		};
		
		/**
		 * UID for textDynContent
		 * @returns {String}
		 */
		TextDynContent.prototype.getUid = function () {
			return this._uid;
		};		

		return TextDynContent;
});

define('packaging-content-management/dyn-content/TextDynContentLocale',["underscore",
        "jquery"],
	function (_,
		$) {
		"use strict";

		/**
		 * This class describes the structure of the location information for each locale
		 */
		var	TextDynContentLocale = function (id, elementType, instanceId, localeLocation, locale) {			
			this.id = id; // elementtype_instanceid
			this.elementType = elementType;
			this.instanceId = instanceId;
			this.localeLocation = localeLocation;		
			this.locale = locale;			
		};
				
		return TextDynContentLocale;
});

define('packaging-content-management/dyn-content-services/dynContentService',["jquery",
		"packaging-content-management/content/SingleTextContent",
		"packaging-content-management/dyn-content/TextDynContent",
		"packaging-content-management/dyn-content/TextDynContentLocale"
	],
	function ($,
		SingleTextContent,
		TextDynContent,
		TextDynContentLocale) {



		/**
		 * 
		 */
		var DynContentService = function () {

			this._isFetchingDynContentFor = {};

			this._dynContentsByDocVerID = [];
			
			this._dynContentLocaleByDocVerID = [];
		};

		/**
		 * 
		 * @param docVersionId
		 */
		DynContentService.prototype.getDynContentFor = function (docVersionId, forceUpdate) {

			// force the update of the cache
			if (forceUpdate) this._dynContentsByDocVerID[docVersionId] = null;

			var cacheItem = this._dynContentsByDocVerID[docVersionId];

			if (!cacheItem) {
				// create a new cache item for the data to be loaded
				cacheItem = {};
				this._dynContentsByDocVerID[docVersionId] = cacheItem;
			}

			if (!cacheItem.request) {
				// create a new Deferred object representing the result of this method (not only the AJAX call!)
				cacheItem.request = $.Deferred();
			} else {
				// return the Promise object in the cache (representing the request), which already contains 
				// the result or is waiting for the executed AJAX call to finish
				return cacheItem.request.promise();
			}

			// The parameters of the call
			var params = {
				"ajax": "1",
				"docverid": docVersionId
			};
			// The baseUrl of the service.
			var jspBaseUrl = window.webcenterConfig.jspBaseUrl;
			var url = jspBaseUrl + "GetDynContent.jsp?json=1&" + $.param(params, true);

			// Get the ajax JSON.
			$.getJSON(url, function (json) {

				// json = {
				//			textDynContents: [
				//				{
				//					contentStatement: <json>,
				//					locations: {
				//						fr-FR: [...],
				//						en-US: [...],
				//						...
				//					}
				//				},
				//				{
				//					...
				//				}, ...
				//			];
				// }

				var dynContents = [];
				if (json) {
					// Parse and generate the text dynamic content objects. 
					for (var i = 0; i < json.length; i++) {
						var contentStatement = new SingleTextContent(json[i]);
						for (var j = 0; j < contentStatement.element.length; j++) {
							var textElement = contentStatement.element[j];
							var locations = [];
							if (textElement.locationList) {
								locations = textElement.locationList;
							}
							var textDynContent = new TextDynContent(textElement, locations);
							dynContents.push(textDynContent);
						}
					}
				}
				// return the parsed value for the request.done() method.
				cacheItem.request.resolve(dynContents);


			}.bind(this)).fail(function (jqXHR, textStatus, errorThrown) {
				var errorXml = $.parseXML(jqXHR.responseText);
				$xmlErr = $(errorXml);
				$code = $xmlErr.find( "code" );
				// check for error - if attribute category is not set, or AC doesnt contain any text content documents, just return 
				if($code.text() == "CONTENT_NO_ATTR_EXIST"){
					return;
				}
				
				//Return with generic message, caller can show customized message
				cacheItem.request.reject("Unable to get Text Contents Documents");
			});

			// value not yet prepared in the cache (the loading is in progress) - return a Promise object
			// to be able to register callbacks in the caller(s)
			return cacheItem.request.promise();
		};
		
		/**
		 * Get locale information for the artwork
		 * @param docVersionId - artwork docversion id
		 * @returns
		 */
		DynContentService.prototype.getDynContentLocale = function (docVersionId) {
			var cacheItem = this._dynContentLocaleByDocVerID[docVersionId];

			if (!cacheItem) {
				// create a new cache item for the data to be loaded
				cacheItem = {};
				this._dynContentLocaleByDocVerID[docVersionId] = cacheItem;
			}

			if (!cacheItem.request) {
				// create a new Deferred object representing the result of this method (not only the AJAX call!)
				cacheItem.request = $.Deferred();
			} else {
				// return the Promise object in the cache (representing the request), which already contains 
				// the result or is waiting for the executed AJAX call to finish
				return cacheItem.request.promise();
			}

			// The parameters of the call
			var params = {
				"ajax": "1",
				"artworkdocVersionId": docVersionId
			};
			// The baseUrl of the service.
			var jspBaseUrl = window.webcenterConfig.jspBaseUrl;
			var url = jspBaseUrl + "GetDynContentLocale.jsp?json=1&" + $.param(params, true);

			// Get the ajax JSON.
			$.getJSON(url, function (json) {

			//			json =	{
			//					"WEBSITE_1": {
			//						"localeLocationList": {
			//							"3": [{
			//								"orgx": ..,
			//								"orgy": ..,
			//								"sizex": ..,
			//								"sizey": ..,
			//								"rotation": ..,
			//								"orientation": ..
			//							}],
			//							"2": [{
			//								"orgx": ..,
			//								"orgy": ..,
			//								"sizex": ..,
			//								"sizey": ..,
			//								"rotation": ..,
			//								"orientation": ..
			//							}]
			//						},
			//						"elementType": "WEBSITE",
			//						"instanceId": "1"
			//					}
			//			}

				var dynContentLocales = [];
				if (json) {
					// Parse and generate the text dynamic content objects. 
					$.each(json, _.bind(function(key, element){
						$.each(element.localeLocationList, _.bind(function(locale, locationInfo){							
							var dynContentLocale = new TextDynContentLocale(key, element.elementType, element.instanceId, locationInfo,
									locale);
							dynContentLocales.push(dynContentLocale);							
						}, this));
					}, this));					
					
				}
				// return the parsed value for the request.done() method.
				cacheItem.request.resolve(dynContentLocales);


			}.bind(this)).fail(function (jqXHR, textStatus, errorThrown) {
				//Return with generic message, caller can show customized message
				cacheItem.request.reject("Unable to get Locale Information");
			});

			// value not yet prepared in the cache (the loading is in progress) - return a Promise object
			// to be able to register callbacks in the caller(s)
			return cacheItem.request.promise();
		};

		return new DynContentService();
	});

define('web-viewer/textContent/DynContentWidget',["web-viewer/layout/AbstractWidget",
		"web-viewer/layout/LayoutConstants",
		"web-viewer/layout/component/MiniButton",
		"web-viewer/layout/component/DropdownMiniButton",
		"packaging-content-management/ContentConstants",
		"packaging-content-management/text-content-utils/LanguageUtils",
		"utils/ShapeUtils",
		"jquery",
		"underscore",
		"web-viewer/textContent/DynContentEntry",
		"utils/webi18n!viewer",
		"packaging-content-management/dyn-content-services/dynContentService"],
	function (AbstractWidget,
		LayoutConstants,
		MiniButton,
		DropdownMiniButton,
		ContentConstants,
		languageUtils,
		ShapeUtils,
		$,
		_,
		DynContentEntry,
		i18nViewerStrings,
		dynContentService) {
		"use strict";

		/**
		 * @exports DynContentWidget
		 * @class DynContentWidget
		 * @param {TextContentModule} textContentModule - 
		 * @param {Core.ViewerFacade} f - 
		 * @param {Array} contentStatementList
		 * @param {Array} elementTypeList
		 * @param {Object} languagesList
		 */
		var DynContentWidget = function DynContentWidget(textContentModule, f, contentStatementList, elementTypeList, languagesList) {
			AbstractWidget.call(this, f, LayoutConstants.Widget.TEXTCONTENT);

			// The module.
			this._textContentModule = textContentModule;
			this._dynContentModel = textContentModule.dynContentModel;

			// Viewer facade
			this.f = f;
			
			//Attribute category module required for full view
			this._acatModule = null;

			// Set the icon
			this.setIcon("icon icon-WCR_Measure-Text");

			// Array of complete element types
			this._elementTypeList = elementTypeList;

			// Array of TextContent documents referenced to the artwork
			this._contentStatementList = contentStatementList;
			this._sortContentStatementList();

			// Array of master and translation languages
			this._languagesList = languagesList;
			this._projectMasterLangs = languagesList.projectMasterLangs;
			this._projectTranslationLangs = languagesList.projectTranslationLangs;
			this._allMasterLangs = languagesList.allMasterLangs;
			this._allTranslationLangs = languagesList.allTranslationLangs;

			// Array of langues
			this._allAvailableMasterLangs = [];
			this._allAvailableTranslationLangs = [];
			this._findAllAvailableLanguages();

			// The wrapping div
			this._wrapper = $('<div>').addClass("DynContentViewerWidget");

			// Create the widget buttons and dropdowns
			this._saveButton = null;
			this._localeMappingButton = null;
			this._languageSelectDropdown = null;
			this._statusFilterDropdown = null;
			this._fullWidthViewButton = null;

			// The selected languages/state to filter on.
			this._selectedMasterLanguage = '';
			this._selectedTranslationLanguage = '';
			this._selectedState = undefined;

			// The create dynamic content entries ...
			this._dynContentEntries = [];

			// Create empty arrays for handling locale mapping
			this._allLocales = []; // All locales that is supported by the artwork
			this._selectDropDown = []; // Array if language mapping that is shown to user - locale to languages available in project
			this._dynContentLocale = []; // Holds array of TextDynContentLocale
			
			// Options for the widget
			this._options = {};
			this._options.viewOptions = {
				widgetview: 'viewer'
			};
			this._options.f = this.f;

			// Set the widget title
			this.setTitle(i18nViewerStrings.t("PCMTextWidgetTitle"));

			// Construct the widget ...
			this._constructWidget();

			/*
			 * When a dynamic content annotation was selected ...
			 */
			this._dynContentModel.on("selectedDynContents", _.bind(function (dynamicContentAnnotations, isDirectSelect) {
				// Extract the dynamic content objects from the dynamic content annotations.
				var selectedDynContents = [];
				for (var i = 0; i < dynamicContentAnnotations.length; i++) {
					selectedDynContents.push(dynamicContentAnnotations[i].getDynContent());
				}
				// highlight the selected dynamic contents.
				if (selectedDynContents.length > 0) {
					this.highlight(selectedDynContents, isDirectSelect);
				}
			}, this));

			/*
			 * When a new unsaved Text Content object was added ...
			 */
			this._dynContentModel.on("unsavedTextContent", _.bind(function (dynamicContentAnnotations, isDirectSelect) {
				this.updateSaveButton();
			}, this));

			/*
			 * When a text element was changed ...
			 */
			this._dynContentModel.on("textElementChanged", _.bind(function (textElement) {

				// Find the affected dynContentEntry.
				var affected;
				for (var i = 0; i < this._dynContentEntries.length; i++) {
					var contentStatement = this._dynContentEntries[i].getContentStatement();
					if (textElement.parentStatement == contentStatement) {
						affected = this._dynContentEntries[i];
					}
				}

				// If an affected entry was found.
				if (affected) {
					// Update it.
					affected.update(textElement);
				}

			}, this));

			/*
			 * When the content of the model changed. 
			 */
			this._dynContentModel.on("modelContentChanged", _.bind(function () {
				// Extract the text content documents from the annotations in the model.
				var annotations = this._dynContentModel.getDynContents();
				this._contentStatementList = [];
				for (var i = 0; i < annotations.length; i++) {
					if (annotations[i].getDynContent().getDynContentType() == "Text") {
						var element = annotations[i].getDynContent().getTextElement();
						var contentStatement = element.parentStatement;
						if ($.inArray(contentStatement, this._contentStatementList) < 0) {
							this._contentStatementList.push(contentStatement);
						}
					}
				}
				// Update the widget for these new content statements.
				this._sortContentStatementList();
				this._createDynContentEntries();
				this.updateSaveButton();
			}, this));
			
			// while saving, disable save button
			this._dynContentModel.on("save.started", _.bind(function () {
				if(this._saveButton){
					this._saveButton.setEnabled(false);
				}
			}, this));

		};

		DynContentWidget.prototype = Object.create(AbstractWidget.prototype);
		DynContentWidget.prototype.constructor = DynContentWidget;
		DynContentWidget.widgetName = LayoutConstants.Widget.TEXTCONTENT;

		/**
		 * 
		 */
		DynContentWidget.prototype._constructWidget = function () {
			this._createSaveButton();
			this._createLanguageSelectionButton();
			this._createLocaleMappingButton();
			this._createStatusFilterButton();
			this._createFullWidthViewButton();
			this._createDynContentEntries();
		};

		DynContentWidget.prototype._createSaveButton = function () {
			this._saveButton = new MiniButton(this.f, "saveDynContents", "icon-WCR_Save", true, _.bind(function () {
				// start saving annotations
				this._dynContentModel.save();
			}, this), "fontIconDisabled icon-WCR_Save");
			this.updateSaveButton();
		};

		DynContentWidget.prototype._createLanguageSelectionButton = function () {
			this._languageSelectDropdown = new DropdownMiniButton(this.f, "pcmLangSelection", "icon-WCR_Text-Translation2");
			this._languageSelectDropdown.setTooltip("viewer", "PCMSelLangTT");
			this._languageSelectDropdown.addButtonClass("pcmSelectLang");

			var onMasterLangChange = _.bind(function (selectedLangCode, toggle) {
				for (var i = 0; i < this._allAvailableMasterLangs.length; i++) {
					this._languageSelectDropdown.toggleOption(this._allAvailableMasterLangs[i].langCode, selectedLangCode === this._allAvailableMasterLangs[i].langCode);
					if (selectedLangCode === this._allAvailableMasterLangs[i].langCode) {
						this._selectedMasterLanguage = selectedLangCode;
					}
				}
				this._updateStatusFilterCount();
				this._createDynContentEntries();
			}, this);

			if (this._allAvailableMasterLangs && this._allAvailableMasterLangs.length > 0) {
				this._languageSelectDropdown.addHeader(this.f.i18n.t("PCMMasterLangMenuHeader"));

				for (var i = 0; i < this._allAvailableMasterLangs.length; i++) {
					var language = this._allAvailableMasterLangs[i];

					var selected = false;
					if (i === 0) {
						this._selectedMasterLanguage = language.langCode;
						selected = true;
					}

					this._languageSelectDropdown.addOption({
						name: language.langCode,
						content: language.langDesc,
						onchange: _.bind(onMasterLangChange, this, language.langCode),
						selected: selected,
						userCannotUncheck: true
					});
				}
			}

			var onTranslationLangChange = _.bind(function (selectedLangCode, toggle) {
				for (var i = 0; i < this._allAvailableTranslationLangs.length; i++) {
					this._languageSelectDropdown.toggleOption(this._allAvailableTranslationLangs[i].langCode, selectedLangCode === this._allAvailableTranslationLangs[i].langCode);
					if (selectedLangCode === this._allAvailableTranslationLangs[i].langCode) {
						this._selectedTranslationLanguage = selectedLangCode;
					}
				}
				this._dynContentModel.setCurrentTransLangCode(this._selectedTranslationLanguage);
				this._updateStatusFilterCount();
				this._createDynContentEntries();
			}, this);

			if (this._allAvailableTranslationLangs && this._allAvailableTranslationLangs.length > 0) {
				this._languageSelectDropdown.addHeader(this.f.i18n.t("PCMTranslationLangMenuHeader"));

				for (var i = 0; i < this._allAvailableTranslationLangs.length; i++) {
					var language = this._allAvailableTranslationLangs[i];

					if (language) {
						var selected = false;
						if (i === 0) {
							this._selectedTranslationLanguage = language.langCode;
							this._dynContentModel.setCurrentTransLangCode(this._selectedTranslationLanguage);
							selected = true;
						}

						this._languageSelectDropdown.addOption({
							name: language.langCode,
							content: language.langDesc,
							onchange: _.bind(onTranslationLangChange, this, language.langCode),
							selected: selected,
							userCannotUncheck: true
						});
					}
				}
			}

			if ((!this._allAvailableMasterLangs || this._allAvailableMasterLangs.length === 0) && (!this._allAvailableTranslationLangs || this._allAvailableTranslationLangs.length === 0)) {
				this._languageSelectDropdown.addHeader(this.f.i18n.t("PCMLangNotAddedTT"));
			}
		};
				
		/**
		 * Create locale mapping button. Make ajax call and get all the locales and location lists
		 */
		DynContentWidget.prototype._createLocaleMappingButton = function () {
			
			this._localeMappingButton = new DropdownMiniButton(this.f, "pcmLocaleMapping", "icon-WCR_Actions-Convert12");
			this._localeMappingButton.setTooltip("viewer", "PCMLocaleMappingTT");
			this._localeMappingButton.addButtonClass("pcmSelectLang");
			
			// Get all the locales that are available on this artwork
			var dynContLocaleReq = dynContentService.getDynContentLocale( this.f.getActiveDocument().getDocumentVersion().get("docversionid"));
			$.when(dynContLocaleReq).done(function (dynContLocale) {
				this._dynContentLocale = dynContLocale;
				for (var i = 0; i < dynContLocale.length; i++) {
					var locale = dynContLocale[i].locale;
					if ($.inArray(locale, this._allLocales) == -1) 
						this._allLocales.push(locale);
					
				}	
				this._allLocales.sort();
				
				// Create the locale mapping table.
				var localeMapTable = $("<table>", {"class" : "LocaleMapping"});
				var localeMapThead = $("<thead>", {"class" : "Header"});
				var localeMapTBody = $("<tbody>", {"class" : "Entries"});
				var localeMapFooter = $("<tbody>", {"class" : "Footer"});
				var localeMapTheadRow = $("<tr>");
				var localeMapTheadCell1 = $("<th>").text(this.f.i18n.t("PCMLocale"));
				var localeMapTheadCell2 = $("<th>").text(this.f.i18n.t("PCMLanguage"));
				localeMapTheadRow.append(localeMapTheadCell1, localeMapTheadCell2);
				localeMapThead.append(localeMapTheadRow);
				localeMapTable.append(localeMapThead);
				localeMapTable.append(localeMapTBody);
				localeMapTable.append(localeMapFooter);
				
				this._localeMappingButton.addContent(localeMapTable);
				
				// For every locale create an entry with locale id and drop down of all languages in project	
				for(var i=0; i< this._allLocales.length; i++){
					
					// Create a row for this locale mapping.
					var localeMapRow = $("<tr>");
					var localeLabel = $("<td>", {"class" : "localeCell"}).text(this._allLocales[i]);
					var localeLangSelector = $("<td>", {"class" : "langCell"});
					localeMapRow.append(localeLabel, localeLangSelector);
					localeMapTBody.append(localeMapRow);
					
					// Create the language selector.
					var languageCombo = $("<select>");
					localeLangSelector.append(languageCombo);
					var blankOption = $("<option/>").text("").val("blank");
					languageCombo.append(blankOption);
					
					// Add Master languages to drop down
					if (this._allAvailableMasterLangs && this._allAvailableMasterLangs.length > 0) {						
						for (var j = 0; j < this._allAvailableMasterLangs.length; j++) {
							var language = this._allAvailableMasterLangs[j];
							if (language) {									
								var option = $("<option/>").text(language.langDesc).val(language.langCode);
								languageCombo.append(option);
							}
						}
					}
					
					// Add Translation languages to drop down
					if (this._allAvailableTranslationLangs && this._allAvailableTranslationLangs.length > 0) {						
						for (var k = 0; k < this._allAvailableTranslationLangs.length; k++) {
							var language = this._allAvailableTranslationLangs[k];
							if (language) {								
								var option = $("<option/>").text(language.langDesc).val(language.langCode);
								languageCombo.append(option);
							}
						}
					}
					this._selectDropDown.push(languageCombo);
				}

				//Create a OK button
				var localeMapFooterRow = $("<tr>");
				var localeMapFooterCell = $("<td>", {"colspan" : "2"});
				var langButton = $("<button>").addClass("btn btn-primary").attr({"type":"button"}).text("OK");
				localeMapFooter.append(localeMapFooterRow);
				localeMapFooterRow.append(localeMapFooterCell);
				localeMapFooterCell.append(langButton);

				// On click of OK Button, update all DynContentAnnotations with new location list for corresponding language and instance id
				langButton.on("click", _.bind(function(){
					this._localeMappingButton.dropdown.hide();
					this._dynContentModel.localeMappingAction(this._selectDropDown, this._dynContentLocale, this._allLocales);
				}, this));
				
			}.bind(this)).fail(_.bind(function (errorMsg) { 
				this._localeMappingButton.setTooltip("viewer", "PCMDynContentLocaleErrorMessage");
			}, this));
		};
		
		
		
		DynContentWidget.prototype._createStatusFilterButton = function () {
			this._statusFilterDropdown = new DropdownMiniButton(this.f, "pcmStatusFilter", "icon-WCR_Filter");
			this._statusFilterDropdown.setTooltip("viewer", "PCMStatusFilterTT");
			this._statusFilterDropdown.addButtonClass("textStatusFilter");
			this._statusFilterDropdown.element.click(_.bind(function () {
				this._updateStatusFilterCount();
			}, this));

			this._statusFilterDropdown.addAction({
				name: "pcmDraftCountText",
				content: this.f.i18n.t("PCMDraftBtnTT") + " (0)",
				icon: "icon-WCR_Text-Status-Draft",
				enabled: true,
				action: _.bind(function (event) {
					if (!$(event.target).hasClass("selectedFilterState")) {
						$(this._statusFilterDropdown.dropdown.menu).find(".selectedFilterState").removeClass("selectedFilterState");
						$(event.target).addClass("selectedFilterState");
						this._selectedState = ContentConstants.State.DRAFT;
						this._statusFilterDropdown.setWarning();
						this._statusFilterDropdown.setTooltip("viewer", "PCMStatusFilterActiveTT");
					} else {
						$(event.target).removeClass("selectedFilterState");
						this._selectedState = undefined;
						this._statusFilterDropdown.removeWarning();
						this._statusFilterDropdown.setTooltip("viewer", "PCMStatusFilterTT");
					}
					this._dynContentModel.setDynContentFilterState(this._selectedState);
					this._createDynContentEntries();
					this._fireResized();
				}, this)
			});

			this._statusFilterDropdown.addAction({
				name: "pcmRFApprovalCountText",
				content: this.f.i18n.t("PCMPendingApprovalBtnTT") + " (0)",
				icon: "icon-WCR_Text-Status-Pending",
				enabled: true,
				action: _.bind(function (event) {
					if (!$(event.target).hasClass("selectedFilterState")) {
						$(this._statusFilterDropdown.dropdown.menu).find(".selectedFilterState").removeClass("selectedFilterState");
						$(event.target).addClass("selectedFilterState");
						this._selectedState = ContentConstants.State.READY_FOR_APPROVAL;
						this._statusFilterDropdown.setWarning();
						this._statusFilterDropdown.setTooltip("viewer", "PCMStatusFilterActiveTT");
					} else {
						$(event.target).removeClass("selectedFilterState");
						this._selectedState = undefined;
						this._statusFilterDropdown.removeWarning();
						this._statusFilterDropdown.setTooltip("viewer", "PCMStatusFilterTT");
					}
					this._dynContentModel.setDynContentFilterState(this._selectedState);
					this._createDynContentEntries();
					this._fireResized();
				}, this)
			});

			this._statusFilterDropdown.addAction({
				name: "pcmApprovedCountText",
				content: this.f.i18n.t("PCMTextSignedOff") + " (0)",
				icon: "icon-WCR_Text-Status-Approved icon-WCR_Approve",
				enabled: true,
				action: _.bind(function (event) {
					if (!$(event.target).hasClass("selectedFilterState")) {
						$(this._statusFilterDropdown.dropdown.menu).find(".selectedFilterState").removeClass("selectedFilterState");
						$(event.target).addClass("selectedFilterState");
						this._selectedState = ContentConstants.State.APPROVED;
						this._statusFilterDropdown.setWarning();
						this._statusFilterDropdown.setTooltip("viewer", "PCMStatusFilterActiveTT");
					} else {
						$(event.target).removeClass("selectedFilterState");
						this._selectedState = undefined;
						this._statusFilterDropdown.removeWarning();
						this._statusFilterDropdown.setTooltip("viewer", "PCMStatusFilterTT");
					}
					this._dynContentModel.setDynContentFilterState(this._selectedState);
					this._createDynContentEntries();
					this._fireResized();
				}, this)
			});

			this._statusFilterDropdown.addAction({
				name: "pcmRejectedCountText",
				content: this.f.i18n.t("PCMTextSignoffRejected") + " (0)",
				icon: "icon-WCR_Text-Status-Rejected icon-WCR_Reject",
				enabled: true,
				action: _.bind(function (event) {
					if (!$(event.target).hasClass("selectedFilterState")) {
						$(this._statusFilterDropdown.dropdown.menu).find(".selectedFilterState").removeClass("selectedFilterState");
						$(event.target).addClass("selectedFilterState");
						this._selectedState = ContentConstants.State.REJECTED;
						this._statusFilterDropdown.setWarning();
						this._statusFilterDropdown.setTooltip("viewer", "PCMStatusFilterActiveTT");
					} else {
						$(event.target).removeClass("selectedFilterState");
						this._selectedState = undefined;
						this._statusFilterDropdown.removeWarning();
						this._statusFilterDropdown.setTooltip("viewer", "PCMStatusFilterTT");
					}
					this._dynContentModel.setDynContentFilterState(this._selectedState);
					this._createDynContentEntries();
					this._fireResized();
				}, this)
			});
		};

		/**
		 * Update the count in the filter.
		 */
		DynContentWidget.prototype._updateStatusFilterCount = function () {
			var statusCount = {
				draft: 0,
				pending: 0,
				approved: 0,
				rejected: 0
			};
			for (var i = 0; i < this._contentStatementList.length; i++) {
				for (var j = 0; j < this._contentStatementList[i].element.length; j++) {
					var state = this._contentStatementList[i].element[j].state;
					if (state == ContentConstants.State.DRAFT && (this._selectedMasterLanguage == this._contentStatementList[i].element[j].language
							|| this._selectedTranslationLanguage == this._contentStatementList[i].element[j].language)) {
						statusCount.draft++;						
					}
					
				}
			}
			for (var i = 0; i < this._contentStatementList.length; i++) {
				for (var j = 0; j < this._contentStatementList[i].element.length; j++) {
					var state = this._contentStatementList[i].element[j].state;
					if (state == ContentConstants.State.READY_FOR_APPROVAL && (this._selectedMasterLanguage == this._contentStatementList[i].element[j].language
							|| this._selectedTranslationLanguage == this._contentStatementList[i].element[j].language)) {
						statusCount.pending++;
					}
					
				}
			}
			for (var i = 0; i < this._contentStatementList.length; i++) {
				for (var j = 0; j < this._contentStatementList[i].element.length; j++) {
					var state = this._contentStatementList[i].element[j].state;
					if (state == ContentConstants.State.APPROVED && (this._selectedMasterLanguage == this._contentStatementList[i].element[j].language
							|| this._selectedTranslationLanguage == this._contentStatementList[i].element[j].language)) {
						statusCount.approved++;
					}
					
				}
			}
			for (var i = 0; i < this._contentStatementList.length; i++) {
				for (var j = 0; j < this._contentStatementList[i].element.length; j++) {
					var state = this._contentStatementList[i].element[j].state;
					if (state == ContentConstants.State.REJECTED && (this._selectedMasterLanguage == this._contentStatementList[i].element[j].language
							|| this._selectedTranslationLanguage == this._contentStatementList[i].element[j].language)) {
						statusCount.rejected++;
					}
					
				}
			}

			var draftLabel = this.f.i18n.t("PCMDraftBtnTT") + " (" + statusCount.draft + ")";
			var pendingLabel = this.f.i18n.t("PCMPendingApprovalBtnTT") + " (" + statusCount.pending + ")";
			var approvedLabel = this.f.i18n.t("PCMTextSignedOff") + " (" + statusCount.approved + ")";
			var rejectedLabel = this.f.i18n.t("PCMTextSignoffRejected") + " (" + statusCount.rejected + ")";

			var updateDOMElement = function (htmlElement, statusLabel) {
				if (htmlElement) {
					htmlElement.textContent = statusLabel;
				}
			};

			updateDOMElement($(".pcmDraftCountText a[name='btn_pcmDraftCountText']").first().contents().last()[0], draftLabel);
			updateDOMElement($(".pcmRFApprovalCountText a[name='btn_pcmRFApprovalCountText']").first().contents().last()[0], pendingLabel);
			updateDOMElement($(".pcmApprovedCountText a[name='btn_pcmApprovedCountText']").first().contents().last()[0], approvedLabel);
			updateDOMElement($(".pcmRejectedCountText a[name='btn_pcmRejectedCountText']").first().contents().last()[0], rejectedLabel);
		};

		DynContentWidget.prototype._createFullWidthViewButton = function () {
			var fullWidthViewButtonHandler = _.bind(function () {
				var callback = _.bind(function () {
					//AttributeCategoryModule is already loaded while creating the button
					//Just directly open the "TEXTVIEW" in the modal popup
					if( this._acatModule ){
						this._acatModule.showViewInModalPopup("TEXTVIEW", this.f.i18n.t("pcmFullViewTitle"), this.f.i18n.t("PCMFullViewSaveBtnTT"));
					}
				}, this);

				//Before opening the Full view(Attributes View), prompt the user with unsaved text content changes popup
				//promptToSavedDynamicContent returns false if there were no pending save items in the list. Then we can 
				//directly call callback to show the full width mode
				var unsavedDynContent = this._dynContentModel.promptToSaveUnsavedDynamicContent(callback);
				//No unsaved text content elements found, so directly open the full width mode
				if(!unsavedDynContent){
					callback();
				}
			}, this);


			this._fullWidthViewButton = new MiniButton(this.f, "pcmFullView", "icon-WCR_FullScreen", true, fullWidthViewButtonHandler);
			this._fullWidthViewButton.setEnabled(false);

			//AttributeCategoryModule is required to open the full view
			this.f.requestModule("attributeCategory", _.bind(function (acatModule) {
				this._acatModule = acatModule;
				//Enable full view button only if view "TEXTVIEW" exists
				if($.inArray("TEXTVIEW", this.f.getActivePage().getAllAttributeCategoryViews()) !== -1){
					this._fullWidthViewButton.setEnabled(true);
					this._fullWidthViewButton.setTooltip("viewer", "PCMOpenFullViewTT");
				} else {
					this._fullWidthViewButton.setTooltip("viewer", "PCMNoFullViewTT");
				}
			}, this), false);
		};


		DynContentWidget.prototype.updateSaveButton = function () {
			if (this._saveButton) {
				var unsavedCount = this._dynContentModel.getUnsavedTextContentsCount();
				if (unsavedCount > 0) {
					this._saveButton.setEnabled(true);
					this._saveButton.setBadge(unsavedCount);
					this._saveButton.setTooltip("viewer", "PCMSaveMiniBtnTT", [unsavedCount]);
				} else {
					this._saveButton.setEnabled(false);
				}
			}
		};

		/**
		 * 
		 */
		DynContentWidget.prototype.highlight = function (selectedDynContents, isDirectSelect) {

			// If this was a direct single select, we need to make sure that the language and state which was selected
			// is not hidden by a filter ... if so ... reset the filter.
			if (isDirectSelect && selectedDynContents.length == 1) {
				this.ensureVisibility(selectedDynContents[0]);
			}

			// Find the content statements that we need to highlight.
			var contentStatementsToHighlight = [];
			for (var i = 0; i < selectedDynContents.length; i++) {
				var contentStatement = selectedDynContents[i].getTextElement().parentStatement;
				if ($.inArray(contentStatement, contentStatementsToHighlight) < 0) {
					contentStatementsToHighlight.push(contentStatement);
				}
			}

			// Unhighlight/highlight the right dynContentEntries
			for (var i = 0; i < this._dynContentEntries.length; i++) {
				var contentStatement = this._dynContentEntries[i].getContentStatement();
				if ($.inArray(contentStatement, contentStatementsToHighlight) < 0) {
					this._dynContentEntries[i].unHighlight();
				} else {
					this._dynContentEntries[i].highlight();
				}
			}
		};

		/**
		 * Make sure that the passed dynContent object is visible in the DynContent Widget.
		 * 
		 * @param dynContent
		 */
		DynContentWidget.prototype.ensureVisibility = function (dynContent) {
			var element = dynContent.getTextElement();
			var filterChanged = false;
			// Check that the correct master language is displayed.
			if (element.isMaster() && element.language != this._selectedMasterLanguage) {
				this._languageSelectDropdown.toggleOption(this._selectedMasterLanguage, false);
				this._selectedMasterLanguage = element.language;
				this._languageSelectDropdown.toggleOption(this._selectedMasterLanguage, true);
				filterChanged = true;
			}
			// Check that the correct translation language is displayed.
			if (!element.isMaster() && element.language != this._selectedTranslationLanguage) {
				this._languageSelectDropdown.toggleOption(this._selectedTranslationLanguage, false);
				this._selectedTranslationLanguage = element.language;
				this._languageSelectDropdown.toggleOption(this._selectedTranslationLanguage, true);
				this._dynContentModel.setCurrentTransLangCode(this._selectedTranslationLanguage);
				filterChanged = true;
			}
			// Check that the correct state is displayed, e.g. check that the parent contentstatement has an element witht the selected state.
			if (this._selectedState != undefined && !this._containsState(element.parentStatement, this._selectedState)) {
				this._selectedState = undefined;
				$(this._statusFilterDropdown.dropdown.menu).find(".selectedFilterState").removeClass("selectedFilterState");
				this._statusFilterDropdown.removeWarning();
				this._statusFilterDropdown.setTooltip("viewer", "PCMStatusFilterTT");
				filterChanged = true;
			}

			// If the filter changed.
			if (filterChanged) {
				this._dynContentModel.setDynContentFilterState(this._selectedState);
				this._createDynContentEntries();
			}
		};

		/**
		 * Check if the contentStatement contains an element with the given state.
		 */
		DynContentWidget.prototype._containsState = function (contentStatement, state) {
			var foundElementWithState = false;
			for (var j = 0; j < contentStatement.element.length; j++) {
				var textElement = contentStatement.element[j];
				if (textElement.state == state && (textElement.language == this._selectedMasterLanguage || 
						textElement.language == this._selectedTranslationLanguage)) {
					foundElementWithState = true;
					break;
				} else if (textElement.pastApprovals.length > 0) {
					var lastApprovedState = textElement.pastApprovals[textElement.pastApprovals.length - 1].state;
					if (lastApprovedState == state  && (textElement.language == this._selectedMasterLanguage || 
							textElement.language == this._selectedTranslationLanguage)) {
						foundElementWithState = true;
						break;
					}
				}
			}
			return foundElementWithState;
		};

		/**
		 * Create the dynamic content entries.
		 */
		DynContentWidget.prototype._createDynContentEntries = function () {

			// Empty the dynamic content entries
			this._wrapper.empty();
			this._dynContentEntries = [];

			// Create a new wrapper for the dynamic content entries.
			this._entryWrapper = $('<div>').addClass("DynContentEntries");
			this._wrapper.append(this._entryWrapper);

			if (this._dynContentModel.getDynContentsLoading()) {
				this._entryWrapper.append($('<div>', {
					"class": "NoTextContentsAvailable"
				}).text(i18nViewerStrings.t("PCMDynContentLoading")));
				return;
			}

			// Make sure languages were selected.
			if (this._allAvailableMasterLangs.length === 0 && this._allAvailableTranslationLangs.length === 0) {
				this._entryWrapper.append($('<div>', {
					"class": "NoTextContentsAvailable"
				}).text(i18nViewerStrings.t("PCMNoLangSelected")));
				return;
			}

			if ((this._allAvailableMasterLangs && this._allAvailableMasterLangs.length > 0) || 
					(this._allAvailableTranslationLangs && this._allAvailableTranslationLangs.length > 0)) {

				var buildSelectedCallback = function (dynContentEntry) {
					return function (langCode) {
						// When the dynamic content entry is selected do ...
						var contentStatement = dynContentEntry.getContentStatement();
						// Ask the module to select on dyn content annotations based on this statement.
						this._textContentModule.selectDynContentBasedOn(contentStatement, langCode);
					}.bind(this);
				}.bind(this);

				for (var i = 0; i < this._contentStatementList.length; i++) {
					var contentStatement = this._contentStatementList[i];

					// Check if there's a filter value on state.
					if (this._selectedState != undefined && !this._containsState(contentStatement, this._selectedState)) {
						// If we did not find element with the selected state, skip this contentstatement.
						continue;
					}

					var dynContentEntry = new DynContentEntry(contentStatement, this._selectedMasterLanguage, 
							this._selectedTranslationLanguage, this._languagesList, this._elementTypeList);
					dynContentEntry.onSelected(buildSelectedCallback(dynContentEntry));
					dynContentEntry.onElementSelected(buildSelectedCallback(dynContentEntry));
					this._entryWrapper.append(dynContentEntry.getJQElement());
					this._dynContentEntries.push(dynContentEntry);
				}
			}

			// no cards are available display no text contents message
			if (this._entryWrapper.children().length === 0) {
				this._entryWrapper.append($('<div>', {
					"class": "NoTextContentsAvailable"
				}).text(i18nViewerStrings.t("PCMNoDynContentFound")));
			}
		};

		/**
		 * Sort the content statements on color and element type name.
		 */
		DynContentWidget.prototype._sortContentStatementList = function () {

			// Define a function which compare two contentstatements ...
			var compare = function (c1, c2) {

				if (!this._elementTypeList[c1.elementType]) {
					return -1;
				}

				var color1 = this._elementTypeList[c1.elementType].color;
				var name1 = this._elementTypeList[c1.elementType].elementHumanReadable;
				var color2 = this._elementTypeList[c2.elementType] !== undefined ? this._elementTypeList[c2.elementType].color : "";
				var name2 = this._elementTypeList[c2.elementType] !== undefined ? this._elementTypeList[c2.elementType].elementHumanReadable : c2.elementType;

				// First sort on color ...
				if (color1 != color2) {
					// If the colors differ ... return wether we have the biggest color.
					if (color1 < color2) {
						return -1;
					} else {
						return 1;
					}
				} else {
					// If it's the same color ... sort on name ...
					if (name1 < name2) {
						return -1;
					} else if (name1 > name2) {
						return 1;
					} else {
						return 0;
					}
				}
			}.bind(this);
			this._contentStatementList.sort(compare);
		};

		/**
		 * Find all the available languages in the current content statement list.
		 */
		DynContentWidget.prototype._findAllAvailableLanguages = function () {
			// Iterate over all the contentStatements.
			for (var i = 0; i < this._contentStatementList.length; i++) {
				var contentStatement = this._contentStatementList[i];
				// Iterate over all the text elements.
				for (var j = 0; j < contentStatement.element.length; j++) {
					var element = contentStatement.element[j];
					// Check whether the element is a master or translation language.
					if (element.isMaster()) {
						// Get the master language of the element.
						var masterLang = languageUtils.getLangForCode(this._projectMasterLangs, element.language);
						// Check whether this master language of the element is already added to the "_allAvailableMasterLangs" array.
						if (masterLang && $.inArray(masterLang, this._allAvailableMasterLangs) < 0) {
							this._allAvailableMasterLangs.push(masterLang);
						}
					} else {
						// Get the master language of the element.
						var transLang = languageUtils.getLangForCode(this._projectTranslationLangs, element.language);
						// Check whether this translation language of the element is already added to the "_allAvailbeTransLangs" array.
						if (transLang && $.inArray(transLang, this._allAvailableTranslationLangs) < 0) {
							this._allAvailableTranslationLangs.push(transLang);
						}
					}
				}
			}
		};

		/**
		 * Set the context of the widget
		 * @override
		 * @param context
		 * @param headerExtra
		 */
		DynContentWidget.prototype.setContext = function (context, headerExtra) {
			AbstractWidget.prototype.setContext.call(this, context, headerExtra);
			this.context.addClass("enableTextSelection");
			this.headerExtra.append(this._saveButton.element).append(this._localeMappingButton.element).append(this._languageSelectDropdown.element).append(this._statusFilterDropdown.element).append(this._fullWidthViewButton.element);
			this._wrapper.appendTo(this.context);
		};

		/**
		 * The text content  widget is greedy, and wants to have all available extra space
		 * @override
		 * @returns {Boolean} true
		 */
		DynContentWidget.prototype.willFill = function () {
			return true;
		};

		/**
		 * Get the preferred size
		 * @override
		 */
		DynContentWidget.prototype.getPreferredSize = function () {
			return new ShapeUtils.Size(this._entryWrapper.outerWidth(true), this._entryWrapper.outerHeight(true));
		};

		/**
		 * Get the preferred size
		 * @override
		 */
		DynContentWidget.prototype.getMinimumSize = function () {
			return new ShapeUtils.Size(200, 100);
		};


		return DynContentWidget;
	});

define('web-viewer/textContent/DynContentAnnotation',["web-viewer/utils/LineworkWrapper",
		"web-viewer/utils/LineworkPoint",
		"utils/ShapeUtils",
		"web-viewer/utils/ViewerUtils",
		"web-viewer/utils/DrawUtils",
		"packaging-content-management/ContentConstants",
		"underscore"
	],
	function (LineworkWrapper,
		LineworkPoint,
		ShapeUtils,
		ViewerUtils,
		DrawUtils,
		ContentConstants,
		_) {
		"use strict";


		/**
		 * @class Represents an dynamic content object. It includes the linework and the data of the dynamic content.
		 * @exports DynContent
		 * @memberof TextContentModule
		 * @augments Objects.LineworkWrapper
		 * @constructor
		 * @param {Core.ViewerFacade} f
		 */
		var DynContentAnnotation = function (f, dynContent, dynContentLocation, pageSize) {
			LineworkWrapper.call(this);
			this.f = f;
			this._dynContent = dynContent;
			this._dynContentLocation = dynContentLocation;
			this._pageSize = pageSize;

			// Keep track wether this annotation has been selected or not.
			this.selected = false;

			// Boolean indicating whether this is a full page annotation. 
			// (check whether a location is provided)
			this._fillPage = dynContentLocation === undefined;

			this.calcRect();
			this.calcStyle();

		};

		// inherit
		DynContentAnnotation.prototype = Object.create(LineworkWrapper.prototype);
		// correct the constructor pointer 
		DynContentAnnotation.prototype.constructor = DynContentAnnotation;

		/**
		 * Calculate the position of the rectangle.
		 */
		DynContentAnnotation.prototype.calcRect = function () {

			if (this._dynContent.getDynContentType() == "Text") {
				// All text dyn contents annotations are rectangle.
				this.type = DrawUtils.LWTYPE_RECT;
				// Check whether this annotation fills the whole page.
				if (!this._fillPage) {
					// Create the rectangle at the correct position.
					var point = new ShapeUtils.Point(this._dynContentLocation.orgx, this._dynContentLocation.orgy - this._dynContentLocation.sizey);
					var size = new ShapeUtils.Size(this._dynContentLocation.sizex, this._dynContentLocation.sizey);
					this.rect = new ShapeUtils.Rect(point, size);
					// Find out wether a rotation was provided ... (not 360 or 0 degrees).
					var epsilon = 2.2204460492503130808472633361816E-16;
					if (Math.abs(this._dynContentLocation.rotation - 360) > 2 * epsilon && Math.abs(this._dynContentLocation.rotation) > 2 * epsilon) {
						// A rotation was provided, but we don't support rotated rectangles ... let's draw the bounding rectangle instead.
						// Calculate the points of the rectangle ...
						var point1 = point;
						var point2 = new ShapeUtils.Point(point.x + size.width, point.y);
						var point3 = new ShapeUtils.Point(point.x, point.y + size.height);
						var point4 = new ShapeUtils.Point(point.x + size.width, point.y + size.height);
						var center = new ShapeUtils.Point(point.x + size.width / 2, point.y + size.height / 2);

						// Rotate the points of the rectangle ...
						point1 = this._rotatePoint(point1, center, this._dynContentLocation.rotation);
						point2 = this._rotatePoint(point2, center, this._dynContentLocation.rotation);
						point3 = this._rotatePoint(point3, center, this._dynContentLocation.rotation);
						point4 = this._rotatePoint(point4, center, this._dynContentLocation.rotation);
						var rotPoints = [point1, point2, point3, point4];

						// Calculate the bounding rectangle of the rotated points ...
						var smallestX = Number.MAX_VALUE;
						var smallestY = Number.MAX_VALUE;
						var biggestX = Number.MIN_VALUE;
						var biggestY = Number.MIN_VALUE;
						for (var i = 0; i < rotPoints.length; i++) {
							if (rotPoints[i].x < smallestX) {
								smallestX = rotPoints[i].x;
							}
							if (rotPoints[i].x > biggestX) {
								biggestX = rotPoints[i].x;
							}
							if (rotPoints[i].y < smallestY) {
								smallestY = rotPoints[i].y;
							}
							if (rotPoints[i].y > biggestY) {
								biggestY = rotPoints[i].y;
							}
						}

						// Based on this, create the bounding rectangle ...
						var newPoint = new ShapeUtils.Point(smallestX, smallestY);
						var newSize = new ShapeUtils.Size(biggestX - smallestX, biggestY - smallestY);
						this.rect = new ShapeUtils.Rect(newPoint, newSize);
					}
				} else {
					// No location was provided for the DynContentAnnotation
					var origin = new ShapeUtils.Point(0, 0);
					this.rect = new ShapeUtils.Rect(origin, this._pageSize);
				}

				// Calc the location of the popup of this annotation.
				var popupOriginX = this.rect.origin.x;
				var popupOriginY = this.rect.origin.y - 38;
				var popupOrigin = new ShapeUtils.Point(popupOriginX, popupOriginY);
				this.popuprect = new ShapeUtils.Rect(popupOrigin, new ShapeUtils.Size(120, 38));
			}
		};

		/**
		 * Calculate the style of the annotation.
		 */
		DynContentAnnotation.prototype.calcStyle = function () {

			if (this._dynContent.getDynContentType() == "Text") {

				// Color according to the current state ...
				var state = this._dynContent.getTextElement().state;
				// However ... if somebody just reviewed ... color the soon to be state.
				var approvals = this._dynContent.getTextElement().approval;
				if (this._dynContent.getTextElement().approvalChanged && approvals && approvals.length > 0) {
					var lastApproval = approvals[approvals.length - 1];
					if (lastApproval.state) {
						state = lastApproval.state;
					}
				}

				// Determine the color based on the approval state of the element of the dynContent.
				if (state == ContentConstants.State.APPROVED) {
					this.color = ContentConstants.ApprovedColor.BASICCOLOR;
					if (!this._fillPage) {
						if (this.selected) {
							this.fillcolor = ContentConstants.ApprovedColor.FILLLIGHTCOLOR;
						} else {
							this.fillcolor = ContentConstants.ApprovedColor.FILLDARKCOLOR;
						}
					}
				} else if (state == ContentConstants.State.REJECTED) {
					this.color = ContentConstants.RejectColor.BASICCOLOR;
					if (!this._fillPage) {
						if (this.selected) {
							this.fillcolor = ContentConstants.RejectColor.FILLLIGHTCOLOR;
						} else {
							this.fillcolor = ContentConstants.RejectColor.FILLLIGHTCOLOR;
						}
					}
				} else if (state == ContentConstants.State.READY_FOR_APPROVAL) {
					this.color = ContentConstants.PendingSignedOffColor.BASICCOLOR;
					if (!this._fillPage) {
						if (this.selected) {
							this.fillcolor = ContentConstants.PendingSignedOffColor.FILLLIGHTCOLOR;
						} else {
							this.fillcolor = ContentConstants.PendingSignedOffColor.FILLLIGHTCOLOR;
						}
					}
				} else {
					this.color = ContentConstants.DraftColor.BASICCOLOR;
					if (!this._fillPage) {
						if (this.selected) {
							this.fillcolor = ContentConstants.DraftColor.FILLLIGHTCOLOR;
						} else {
							this.fillcolor = ContentConstants.DraftColor.FILLLIGHTCOLOR;
						}
					}
				}

				if (this.selected) {
					this.linewidth = 4;
				} else {
					this.linewidth = 2;
				}
			}
		};


		/**
		 * Recalculate the style and return wether there was a change.
		 */
		DynContentAnnotation.prototype.reCalcStyle = function () {

			// Remember the old style.
			var oldFillcolor = this.fillcolor;
			var oldColor = this.color;
			var oldLineWidth = this.linewidth;

			// Calculate the style again.
			this.calcStyle();

			// Return whether the style changed.
			if (oldFillcolor !== this.fillcolor || oldColor !== this.color || oldLineWidth !== this.linewidth) {
				return true;
			} else {
				return false;
			}
		};


		/**
		 * Return the dynContent.
		 */
		DynContentAnnotation.prototype.getDynContent = function () {
			return this._dynContent;
		};

		/**
		 * Indicate that the dynContent is selected.
		 */
		DynContentAnnotation.prototype.setSelected = function (isSelected) {
			this.selected = isSelected;
			this.calcStyle();
		};

		/**
		 * Utility function to calculate the rotation of the point
		 */
		DynContentAnnotation.prototype._rotatePoint = function (point, origin, angle) {
			angle = angle * Math.PI / 180.0;
			var x = Math.cos(angle) * (point.x - origin.x) - Math.sin(angle) * (point.y - origin.y) + origin.x;
			var y = Math.sin(angle) * (point.x - origin.x) + Math.cos(angle) * (point.y - origin.y) + origin.y;
			return new ShapeUtils.Point(x, y);
		};

		/**
		 * Set the scaling of the dynamic content annotation, all points of the annotation (linework) are scaled witht his value
		 * @param {ShapeUtils.Point|null} scaling
		 */
		DynContentAnnotation.prototype.setScale = function (scaling) {
			this.scale(scaling);
			this._scaling = scaling;
		};
		
		/**
		 * After setting the new content location, re-calculate the rectangle and style
		 * Reset the pageSize as well.
		 * @param dynContentLocation
		 */
		DynContentAnnotation.prototype.setDynContentLocation = function (dynContentLocation, pageSize) {
			this._dynContentLocation = dynContentLocation;
			this._pageSize = pageSize;
			this._fillPage = dynContentLocation === undefined;
			this.calcRect();
			this.calcStyle();
			this._dynContent.setLocations(undefined);
		};
		
		/**
		 * Returns _dynContentLocation
		 */
		DynContentAnnotation.prototype.getDynContentLocation = function () {
			return this._dynContentLocation;
		};

		return DynContentAnnotation;
	});

/**
 * TableTextContent object
 * 
 * @author PASH
 */
define('packaging-content-management/content/TableTextContent',["underscore",
        "packaging-content-management/content/TextContent",
		"packaging-content-management/content/TextContentPermission",
		"packaging-content-management/text-content-utils/ContentUtils",
		"packaging-content-management/text-content-utils/LanguageUtils",
		"packaging-content-management/ContentConstants",
		"packaging-content-management/content/TextContentElement"
	],
	function (_,
		TextContent,
		TextContentPermission,
		ContentUtils,
		LanguageUtils,
		ContentConstants,
		TextContentElement) {
		"use strict";
		
		/**
		 * @class Represents a table text content object.
		 * @exports TableTextContent
		 * @constructor
		 */
		var TableTextContent = function (json, tableContent) {
			this._tableContent = tableContent;
			
			// Call the super
			TextContent.call(this, json);
		};

		// inherit
		TableTextContent.prototype = Object.create(TextContent.prototype);
		// correct the constructor pointer 
		TableTextContent.prototype.constructor = TableTextContent;
		
		/**
		 * Clone this TableContent.
		 * 
		 * @returns {TableTextContent} A TableTextContent that is exactly the same.
		 */
		TableTextContent.prototype.clone = function () {
			var clone = new TableTextContent();
			
			// Return cloned object after copying all the content.
			return TextContent.prototype.copyIn.call(this, clone);
		};
		
		/**
		 * Get a content ID for this object. (It's only unique within a content object).
		 */
		TableTextContent.prototype.getContentId = function () {
			return this.elementType + "_" + this.instanceId;
		};
		
		/**
		 * Find out whether document is latest version or not.
		 * @returns
		 */
		TableTextContent.prototype.isLatestDocumentVersion = function () {
			return this._tableContent.isLatestDocumentVersion();
		};
		
		/**
		 * super{@link #getPermission()}
		 */
		TableTextContent.prototype.getPermission = function () {
			return this._tableContent.getPermission();
		};
		
		
		/**
		 * super{@link #isLatestDocumentVersion()}
		 */
		TableTextContent.prototype.isLatestDocumentVersion = function () {
			return this._tableContent.isLatestDocumentVersion();
		};
		
		/**
		 * Return the parent table content.
		 */
		TableTextContent.prototype.getParent = function () {
			return this._tableContent;
		};
		
		/**
		 * Checks if there are any translations in the document for given element type
		 * 
		 * @param csElem
		 * @returns {Boolean}
		 */
		TableTextContent.prototype.hasTranslations = function(csElem) {			
			var totalTranslations = $.grep(csElem.parentStatement.element, function(element, index){
				return !element.isMaster() && element.state !== 'EMPTY' && !element.deleted;
			});
			
			return (totalTranslations.length > 0);
		};
		
		/**
		 * Return cached user permissions for an element with the passed langcode.
		 * 
		 * @param langCode
		 * @returns
		 */
		TableTextContent.prototype.getCachedUserPermission = function(langCode) {
			if (this._tableContent.effectiveUserPermissionLanguageCache) {
				return this._tableContent.effectiveUserPermissionLanguageCache[langCode];
			} else {
				return undefined;
			}
		};
				
		/**
		 * Checks if the element passed is the last element to be deleted. Also checks if other elements are already marked for delete
		 * 
		 * @param element
		 */
		TableTextContent.prototype.checkDeleteAction = function(csElement) {
			// There is only one element in the array, which means we will have to delete full text content (wcc)
			if(this.element.length == 1){
				return true;
			}
			
			// Leaving out the csElement passed, check for rest of the elements in the TextContent if they are marked for delete.
			// if yes, add increment the counter
			var deleteCounter = 0;
			for(var i=0; i<this.element.length; i++){
				if(this.element[i].lang !== csElement.lang && this.element[i].deleted){
					deleteCounter++;
				}else{
					// Found an element that is not marked for delete, return false - breaks the loop
					return false;
				}
			}
			
			if(deleteCounter.length == this.element.length-1)
				return false;
		};
		
		/**
		 * This method is to set new state with calculation done by it's elements state.
		 * 
		 * Setting up current state of this object doesn't required to be saved on document.
		 * So save action will not be created for this operation.
		 */
		TableTextContent.prototype.updateCurrentState = function () {
			TextContent.prototype.updateCurrentState.call(this);
			
			// Update current state of the parent object.
			this.getParent().updateCurrentState();
		};
		
		/**
		 * Return true if the language passed is the last master to be removed
		 * else false
		 */
		TableTextContent.prototype.isLastMasterToBeRemoved = function (language, projectMasterLanguages) {
			// Iterate over all elements.
			for(var i=0; i < this.element.length ;i++) {
				// If element is not for master language then continue.
				if (!this.element[i].isMaster()) {
					continue;
				}
				
				// If element is in same which is being removed then continue.
				if (this.element[i].language == language) {
					continue;
				}
				
				// If element is deleted then continue.
				if (this.element[i].isDeleted()) {
					continue;
				}
				
				// If element is not even added.
				if (ContentConstants.State.EMPTY == this.element[i].getCurrentState()) {
					continue;
				}
				
				 if (!LanguageUtils.isAProjectAttrLang(projectMasterLanguages, this.element[i].language)) {
                     continue;
				 }
				 
				// If execution reaches here, that means deleted element was not last master.
				return false;
			}
			
			// The element which is removed was last master.
			return true;
		};
		
		
		return TableTextContent;
});





/**
 * TableContent object
 * @author PASH
 */
define('packaging-content-management/content/TableContent',["underscore",
        "jquery",
        "./Content",
		"./TextContent",
		"./TextContentPermission",
		"./TableTextContent",
		"../ContentConstants",
		"../text-content-utils/ContentUtils",
		"./TextContentElement"],
	function (_, $,
		Content,
		TextContent,
		TextContentPermission,
		TableTextContent,
		ContentConstants,
		ContentUtils,
		TextContentElement) {
		"use strict";
		
		/**
		 * @class Represents a content statement.
		 * @exports TextContent
		 * @constructor
		 */
		var	TableContent = function (json) {
			// Call the super
			Content.call(this, json);
			
			if (json) {
				this.textContents = [];
				_.each(json.tableTextContents, _.bind(function (textContentJson) {
					this.textContents.push(new TableTextContent(textContentJson, this));
				}, this));
				this.invariant = ContentUtils.getBooleanValue(json.invariant);
				this.structuredElementType = json.structuredElementType;
				this.approvalType = json.approvalType;
				this.preview = json.preview;
				this.state = json.state;
				this.textType = ContentUtils.getValidTextType(json.type);
				this.effectiveUserPermissionLanguageCache = json.effectiveUserPermissionLanguageCache;
				this.isApprovalPasswordRequired = ContentUtils.getBooleanValue(json.isApprovalPasswordRequired);
				this.instanceId = json.instanceId ? json.instanceId : 1;
				this.locationList = json.locationList;
				this.permission = [];
				_.each(json.permission, _.bind(function (perm) {
					this.permission.push(new TextContentPermission(perm));
				}, this));
			} else {
				this.textContents = [];
				this.invariant = false;
				this.structuredElementType = null;
				this.approvalType = null;
				this.preview = null;
				this.state = null;
				this.textType = ContentUtils.getValidTextType();
				this.effectiveUserPermissionLanguageCache = null;
				this.isApprovalPasswordRequired = false;
				this.instanceId = 1;
				this.locationList = [];
				this.permission = [];
			}
		};

		// inherit
		TableContent.prototype = Object.create(Content.prototype);
		// correct the constructor pointer 
		TableContent.prototype.constructor = TableContent;
		
		/**
		 * Clone this TableContent.
		 * 
		 * @returns {TableContent} A TableContent that is exactly the same.
		 */
		TableContent.prototype.clone = function () {
			var clone = new TableContent();
			
			// Return cloned object after copying all the content.
			return this.copyIn(clone);
		};
		
		/**
		 * Copy all information from this object to desired object.
		 * 
		 * @param copyInObj Object, where values needs to be updated from this. 
		 * @returns {TableContent} Object with all values of this object.
		 */
		TableContent.prototype.copyIn = function (copyInObj) {
			// Nothing to do if object is not of this type.
			if (!copyInObj instanceof TableContent) {
				return copyInObj;
			}
			
			// Copy all the text contents
			copyInObj.textContents = [];
			_.each(this.textContents, function (textContent) {
				var clonedTextContent = textContent.clone();
				clonedTextContent._tableContent = copyInObj;
				copyInObj.textContents.push(clonedTextContent);
			});

			// Copy permission
			copyInObj.permission = [];
			_.each(this.permission, _.bind(function (perm) {
				copyInObj.permission.push(perm.clone());
			}, this));
			
			// Update other information from this object.
			copyInObj.invariant = this.invariant;
			copyInObj.structuredElementType = this.structuredElementType;
			copyInObj.approvalType = this.approvalType;
			copyInObj.state = this.state;
			copyInObj.textType = this.textType;
			copyInObj.preview = this.preview;
			copyInObj.effectiveUserPermissionLanguageCache = this.effectiveUserPermissionLanguageCache;
			copyInObj.isApprovalPasswordRequired = this.isApprovalPasswordRequired;
			copyInObj.instanceId = this.instanceId;
			copyInObj.locationList = this.locationList;
			
			// Return updated object after copying all the content.
			return Content.prototype.copyIn.call(this, copyInObj);
		};
		
		/**
		 * This will update the permission changes done in role mapping page
		 * 
		 * @param permissionsArray
		 */
		TableContent.prototype.updatePermissions = function (permissionsArray) {
			if (permissionsArray.length > 0) {
				this.permission = permissionsArray ;
				this._saveActions.push({
					type: ContentConstants.SaveAction.PERMISSIONS,
					timeStamp : (new Date()).getTime(),
					textContentPermissionsSet: permissionsArray
				});
			}
		};
		
		/**
		 * This method removed request element and its dependent translations.
		 * 
		 * @param tableContentElement
		 * @param elementType
		 * @param instanceId
		 * @returns {Boolean}
		 */
		TableContent.prototype.removeTableTextContent = function (tableContentElement, projMasterLanguages) {
			var removedOtherElements = false;
			
			var textContent = tableContentElement.parentStatement;
			
			// Check if the element selected is the last master to be deleted, in that case we have to remove the whole wcc
			if((tableContentElement.isMaster() && textContent.isLastMasterToBeRemoved(tableContentElement.getLangCode(), projMasterLanguages) ||	
					textContent.checkDeleteAction(tableContentElement))){
				removedOtherElements = true;
				
				// Iterate over all the elements of this text content and mark them for delete.
				$.each(textContent.getElementsList(), _.bind(function (index, contentElement) {
					if (contentElement.getState() != ContentConstants.State.EMPTY) {
						contentElement.deleted = true;
						contentElement.newState = ContentConstants.State.DELETED;
					}
				}, this));
				
				// Since all the elements are removed for this text content, so mark this to remove from table content.
				this._saveActions.push({
					type: ContentConstants.SaveAction.REMOVETABLETEXTCONTENT,
					timeStamp : (new Date()).getTime(),
					elementTypeToBeRemoved : textContent.elementType,
					instanceIdToBeRemoved : textContent.instanceId,
					affectedTextContent : textContent
				});
			}
			
			// Mark current element also as deleted.
			tableContentElement.deleted = true;
			tableContentElement.newState = ContentConstants.State.DELETED;
			
			if (!removedOtherElements) {
				// Add a save action to remove the language, if other elements are not affected.
				this._saveActions.push({
					type: ContentConstants.SaveAction.REMOVEELEMENT,
					affectedTextContent: textContent,
					language: tableContentElement.language,
					timeStamp : (new Date()).getTime()
				});
			}
			
			// Check if the element selected was the last approved master to be deleted, in that case we have to revert status of the translation elements.
			if(tableContentElement.isMaster() && !textContent.isMasterApproved()) {
				// Iterate over all the elements of this text content and revert their state to draft.
				$.each(textContent.getElementsList(), _.bind(function (index, contentElement) {
					// Continue if element is not translation.
					if (contentElement.isMaster()) {
						return true;
					}
					
					// Nothing to do if element is deleted.
					if (contentElement.isDeleted()) {
						return true;
					}
					
					// Element is not even added, continue the loop.
					if (contentElement.getState() == ContentConstants.State.EMPTY) {
						return true;
					}
					
					// If translation element is not in draft state then revert state to draft. 
					if (ContentConstants.State.DRAFT != contentElement.getState()) {
						contentElement.setNewState(ContentConstants.State.DRAFT);
					}
				}, this));
			}
			
			return removedOtherElements;
		};
		
		/**
		 * Create JSON request object from TableContent
		 * 
		 * @param {String} password
		 * 
		 * @returns {Array} The list of all save actions
		 */
		TableContent.prototype.getSaveActions = function (password) {
			var allSaveActions = [];
			
			// Get the save actions of this content object.
			allSaveActions = allSaveActions.concat(this._saveActions);
			
			// Get the save actions of the text content elements.
			for (var i=0; i < this.textContents.length; i++) {
				allSaveActions = allSaveActions.concat(this.textContents[i].getSaveActions(password));
			}

			return allSaveActions;
		};
		
		/**
		 * Return whether this table content is invariant.
		 */
		TableContent.prototype.isInvariant = function() {
			return this.invariant;
		};
		
		/**
		 * Return the (GS1) element type for this table.
		 */
		TableContent.prototype.getElementType = function () {
			return this.structuredElementType;
		};
		
		/**
		 * Get the approval type of the TableContent object.
		 */
		TableContent.prototype.getApprovalType = function () {
			return this.approvalType;
		};
		
		/**
		 * Return the text type (rich or simple)
		 */
		TableContent.prototype.getTextType = function () {
			return this.textType;
		};
		
		/**
		 * Get the text contents for this table.
		 */
		TableContent.prototype.getTextContents = function () {
			return this.textContents;
		};
		
		/**
		 * Get the text content elements for this table.
		 */
		TableContent.prototype.getTextContentElements = function () {
			var allElements = [];
			$.each(this.textContents, function (i, textContent) {
				allElements = allElements.concat(textContent.getElementsList());
			});
			return allElements;
		};
		
		/**
		 * Get the unique collection of all language codes in the contained text content documents.
		 */
		TableContent.prototype.getLangCodes = function () {
			var langCodes = [];
			$.each(this.textContents, function (index, textContent) {
				var textContentlangCodes = textContent.getLangCodes();
				$.each(textContentlangCodes, function (index, langCode) {
					if ($.inArray(langCode, langCodes) < 0) {
						langCodes.push(langCode);
					}
				});
			});
			return langCodes;
		};
		
		/**
		 * Get the collection of master or translation language codes in the contained text content documents.
		 * 
		 * @param {Boolean} isMaster -  true will return master languages otherwise translation languages
		 * @returns {Array.<String>} langCodes - Array of language codes
		 */
		TableContent.prototype.getLangCodesOfElements = function (isMaster) {
			var langCodes = [];
			$.each(this.textContents, function (index, textContent) {
				var textContentlangCodes = textContent.getLangCodesOfElements(isMaster);
				$.each(textContentlangCodes, function (index, langCode) {
					if ($.inArray(langCode, langCodes) < 0) {
						langCodes.push(langCode);
					}
				});
			});
			return langCodes;
		};
		
		/**
		 * A method to get the master languages which are Signed Off
		 * 
		 * @param availableMasterLangs - Array of language objects
		 * @returns {Array}
		 */
		TableContent.prototype.getSignedOffMasterLangs = function(availableMasterLangs) {
			var signedOffMasterLangs = [];
			$.each(this.textContents, function (index, textContent) {
				var signedOffMasterLangsFromTextContent = textContent.getSignedOffMasterLangs(availableMasterLangs);
				$.each(signedOffMasterLangsFromTextContent, function (index, lang) {
					if ($.inArray(lang, signedOffMasterLangs) < 0) {
						signedOffMasterLangs.push(lang);
					}
				});
				
				//Remove a lang already added in the array but is not signed off in the new TextContent
				signedOffMasterLangs = $.grep(signedOffMasterLangs, function( lang, index ) {
					return ($.inArray(lang, signedOffMasterLangsFromTextContent) > 0);
				});
				
			});
			
			return signedOffMasterLangs;
		};
		
		/**
		 * Set state of the table content.
		 * 
		 * @param {ContentConstants.State} Content state as approved or as draft.
		 */
		TableContent.prototype.setNewState = function(newState) {
			// If new state is already updated.
			if (newState == this.state) {
				return;
			}
			
			// If all the text content elements are not signed off or not having resolved text data, then content is not allowed to be approved.
			if (!(this.isElementsApproved() && this.isTextDataResolved()) && ContentConstants.State.APPROVED == newState) {
				// Unfortunately this code is getting executed. Don't allow to approve.
				return;
			}
			
			// Create save action for table approval.
			this._processTableApproval(newState);
		};
		
		/**
		 * Update current state of the table content based on text contents available in it.
		 */
		TableContent.prototype.updateCurrentState = function () {
			var currentState = ContentConstants.State.APPROVED;
			
			// If all elements not are approved and text data for all elements is not resolved.
			if (!this.isElementsApproved() || !this.isTextDataResolved()) {
				// Keep current state of the table content as draft.
				currentState = ContentConstants.State.DRAFT;
			}
			
			// State and current state is not same. Create save action and update state.
			if (this.state != currentState) {
				
				// If content's text type is smart name and current state is approved.
				if (ContentConstants.State.APPROVED == currentState && ContentConstants.TextType.SMARTNAME == this.getTextType()) {
					// Don't update the state as approved, this should be done by setNewState method.
					return;
				}
				
				// Create save action for table approval.
				this._processTableApproval(currentState);
			}
		};
		
		/**
		 * Method is to get current state of this object.
		 * 
		 * @return {ContentConstants.State} Content state as approved or as draft.
		 */
		TableContent.prototype.getCurrentState = function () {
			return this.state;
		};

		/**
		 * 
		 */
		TableContent.prototype._processTableApproval = function (newState) {
			// Find previous reusable save action for table content approval.
			var saveAction = this._getReusableSaveAction(ContentConstants.SaveAction.TABLECONTENTAPPROVAL);
			
			// Create save action for updating state of table content, if not available.
			if (!saveAction) {
				// Create status save action for table content.
				this._saveActions.push({
					type: ContentConstants.SaveAction.TABLECONTENTAPPROVAL,
					timeStamp : new Date().getTime(),
					newState: newState,
					oldNewState: this.state
				});
			} else
			// If new state is became old state.
			if (newState == saveAction.oldNewState) {
				// Remove save action.
				this._saveActions.splice(_.indexOf(this._saveActions, saveAction), 1);
			} else
			// Update already available save action for new state.
			if (saveAction.newState != newState) {
				saveAction.timeStamp = new Date().getTime();
				saveAction.newState = newState;
			}
			
			// Update new state in state of this content.
			this.state = newState;
		};
		
		/**
		 * Find save action from available save actions based on type.
		 * 
		 * @param {ContentConstants.SaveAction} type: action type which needs to be found.
		 * 
		 * @return saveAction: if found then first occurrence of action, otherwise undefined.
		 */
		TableContent.prototype._getSaveActionByType = function (type) {
			// Find save action for requested type.
			var saveAction = undefined;
			
			if (type) {
				$.each(this._saveActions, _.bind(function (index, action) {
					if (type == action.type) {
						saveAction = action;
						return false;
					}
				}, this));
			}
			return saveAction;
		};
		
		
		/**
		 * Get reusable save action for the desired type of save action.
		 * 
		 * @param {ContentConstants.SaveAction} type: action type which needs to be found as last save action.
		 * 
		 * @return saveAction: if found as last action, otherwise undefined.
		 */
		TableContent.prototype._getReusableSaveAction = function (type) {
			// Get last save action.
			var lastSaveAction = this._saveActions[this._saveActions.length-1];
			
			// If last save action doesn't exist then return undefined.
			if (!lastSaveAction) {
				return undefined;
			}
			
			// If type is save as type of last save action, then return last save action.
			if (type && type == lastSaveAction.type) {
				return lastSaveAction;
			}
			
			// If last save action is not type of desired type, then return undefined.
			return undefined;
		};
		
		/**
		 * Return true if the current state of the Table Content document is changed.
		 */
		TableContent.prototype.isStatusChanged = function () {
			// Find previous save action for table content approval.
			var saveAction = this._getSaveActionByType(ContentConstants.SaveAction.TABLECONTENTAPPROVAL);
			
			// Save action is not available, that means there is no change happened in status.
			if (!saveAction) {
				return false;
			}
			
			// State is not same as old actual state, so state of table content is changed.
			if (this.state != saveAction.oldNewState) {
				return true;
			}
			
			// Reached here, means status is not changed.
			return false;
		};
		
		/**
		 * Return true if the current state of the Table Content document is approved.
		 */
		TableContent.prototype.isElementsApproved = function () {
			var isElementsApproved = true;	// Flag to check whether text data is approved or not.
			
			// Iterate over all the text contents to check status.
			$.each(this.getTextContents(), _.bind(function (index, textContent) {
				// In case 1 or more than 1 element is not in approved state.
				if (!textContent.isElementsApproved()) {
					// Text data is not signed off. Set this flag to false, so content is not signed off.
					isElementsApproved = false;
					
					// Break the loop.
					return false;
				}
			}, this));
			
			return isElementsApproved;
		};
		
		/**
		 * Returns true if current status is resolved for all the text data. <br>
		 * 
		 * For rich text or simple text this flag is always considered as true.
		 * 
		 * @return {boolean} current resolved status for all available elements.
		 */
		TableContent.prototype.isTextDataResolved = function() {
			var isTextDataResolved = true;	// Flag to check whether text data is resolved or not.
			
			// Return true is text type of the document is not smart name type.
			if (ContentConstants.TextType.SMARTNAME != this.getTextType()) {
				return isTextDataResolved;
			}
			
			// Iterate over all the text contents to check resolved status.
			_.each(this.textContents, _.bind(function (textContent) {
				var elements = textContent.getElementsList();	// Get elements from this text content.
				
				// Iterate over all the elements to find status.
				_.each(elements, _.bind(function (element) {
				
					// If element does not actually exists in document.
					if (ContentConstants.State.DELETED == element.getCurrentState() || 
							ContentConstants.State.EMPTY == element.getCurrentState()) {
						return true;
					}
					
					// If status of smart named text data is not resolved.
					if (ContentConstants.ResolvedStatus.RESOLVED != element.getTextData().status) {
						// Text data is not resolved. Set this flag to false, so content is not signed off.
						isTextDataResolved = false;
					}
					
				}, this));
			}, this));
			
			return isTextDataResolved;
		};
		
		/**
		 * Check if any approval action (Approve/Reject) is done and password required
		 * 
		 * @returns isPasswordRequired {boolean}
		 */
		TableContent.prototype.isPasswordRequiredForApproval = function() {
			var isPasswordRequired = false;
			
			// If password is required for approval as set by Admin in preferences
			if(this.isApprovalPasswordRequired) {
				
				// then, check whether any approval action is done on any language
				_.each(this.textContents, _.bind(function (textContent) {
					if (!isPasswordRequired &&  textContent.isPasswordRequiredForApproval()){
						isPasswordRequired = true;
						return false;
					}
				}));
			}
			
			return isPasswordRequired;
		};
		
		/**
		 * Marking invariant flag as true in table content.
		 * 
		 * @param invariant
		 *            the invariant to set
		 */
		TableContent.prototype.setInvariant = function (invariant) {
			// In case invariant flag is same, no need to do anything.
			if (this.invariant == invariant) {
				return;
			}
			
			// Variable to create save action.
			var needToAdd = true;
			
			$.each(this._saveActions, function (index, saveAction) {
				// Continue loop if save action is not for invariant flag change. 
				if (ContentConstants.SaveAction.INVARIANT != saveAction.type) {
					return true;
				}
				
				// remove save action for invariant change because flag is same as original.
				if (invariant == saveAction.oldInvariant) {
					this._saveActions.splice(index, 1);
					needToAdd = false;
					return false;
				}
				
				// Update new value for invariant flag to save action.
				saveAction.timeStamp = (new Date()).getTime();
				saveAction.shouldBecomeInvariant = invariant;
				needToAdd = false;
			}.bind(this));

			if (needToAdd) {
				// Create save action and keep it with all save actions.
				this._saveActions.push({
					type: ContentConstants.SaveAction.INVARIANT,
					timeStamp : (new Date()).getTime(),
					shouldBecomeInvariant: invariant,
					oldInvariant: this.invariant
				});
			}
			
			// Assign latest invariant value.
			this.invariant = invariant;
			
			_.each(this.textContents, function (textContent) {
				textContent.invariant = invariant;
				// We couldn't find any matching element type, return undefined foundTextContent				
			}.bind(this));			
			
		};
		
		/**
		 * Change text type of the table content document. 
		 * 
		 * @param textType
		 * 
		 * @return {boolean} isTextTypeUpdated : If text type is updated then it will return true otherwise false.
		 */
		TableContent.prototype.setTextType = function (textType) {
			var isTextTypeUpdated = false;
			// In case text type is same, no need to do anything.
			if (this.textType == textType) {
				return isTextTypeUpdated;
			}
			
			// Variable to create save action.
			var needToAdd = true;
			
			$.each(this._saveActions, function (index, saveAction) {
				// Continue loop if save action is not for text type. 
				if (ContentConstants.SaveAction.TEXTTYPE != saveAction.type) {
					return true;
				}
				
				// remove save action for text type because text type is became same as original.
				if (textType == saveAction.oldTextType) {
					this._saveActions.splice(index, 1);
					needToAdd = false;
					isTextTypeUpdated = false;
					return false;
				}
				
				// Update new text type to save action of text type change.
				saveAction.timeStamp = (new Date()).getTime();
				saveAction.newTextType = textType;
				isTextTypeUpdated = true;
				needToAdd = false;
			}.bind(this));

			if (needToAdd) {
				// Create save action and keep it with all save actions.
				this._saveActions.push({
					type: ContentConstants.SaveAction.TEXTTYPE,
					timeStamp : (new Date()).getTime(),
					newTextType: textType,
					oldTextType: this.textType
				});
				
				isTextTypeUpdated = true;
			}
			
			// Assign latest text type.
			this.textType = textType;
			
			return isTextTypeUpdated;
		};
		
		/**
		 * Change the approval type of the TextContent object.
		 */
		TableContent.prototype.setApprovalType = function (approvalType) {
			// In case approval type is same, no need to do anything.
			if (this.approvalType == approvalType) {
				return;
			}
			
			// Variable to create save action.
			var needToAdd = true;
			
			$.each(this._saveActions, function (index, saveAction) {
				// Continue loop if save action is not for approval type change. 
				if (ContentConstants.SaveAction.APPROVALTYPE != saveAction.type) {
					return true;
				}
				
				// remove save action for approval type because approval type is became same as original.
				if (approvalType == saveAction.oldApprovalType) {
					this._saveActions.splice(index, 1);
					needToAdd = false;
					return false;
				}
				
				// Update new approval type to save action of approval type change.
				saveAction.timeStamp = (new Date()).getTime();
				saveAction.newApprovalType = approvalType;
				needToAdd = false;
			}.bind(this));

			if (needToAdd) {
				// Create save action and keep it with all save actions.
				this._saveActions.push({
					type: ContentConstants.SaveAction.APPROVALTYPE,
					timeStamp : (new Date()).getTime(),
					newApprovalType: approvalType,
					oldApprovalType: this.approvalType
				});
			}
			
			// Assign latest approval type.
			this.approvalType = approvalType;
		};
		
		/**
		 * Set the new preview.
		 */
		TableContent.prototype.setNewPreview = function (preview) {
			// In case the preview not really changed, no need to do anything.
			var falseDefaultChange = ( preview.type == "Default" && (!this.preview));
			if (falseDefaultChange || ( this.preview && this.preview.name == preview.name && this.preview.type == preview.type)) {
				return;
			}
			
			// Set the new preview.
			this.preview = preview;
			
			// Check if last save action is available as a new preview ID.
			var lastSaveAction = this._saveActions[this._saveActions.length-1];
			if (lastSaveAction && ContentConstants.SaveAction.NEWPREVIEW == lastSaveAction.type) {
				lastSaveAction.timeStamp = (new Date()).getTime();
				lastSaveAction.newPreview = preview;
			} else {
				// Create save action and keep it with all save actions.
				this._saveActions.push({
					type: ContentConstants.SaveAction.NEWPREVIEW,
					timeStamp : (new Date()).getTime(),
					newPreview: preview
				});
			}
		};
		
		/**
		 * Checks if the param elementType and param instanceId is already added in the TableContent. If yes, return the TableTextContent.
		 * Else, creates copy
		 * 
		 * @param elementType
		 * @param instanceId
		 * @returns TableTextContent
		 */
		TableContent.prototype.checkAndReturnTableTextContent = function(elementType, instanceId){
			var foundTextContent;
			_.each(this.textContents, function (textContent) {
				if((textContent.elementType).toLowerCase() == (elementType).toLowerCase() && textContent.instanceId == instanceId){
					foundTextContent = textContent;
					return false;
				}
				// We couldn't find any matching element type, return undefined foundTextContent				
			}.bind(this));			
			
			return foundTextContent;
		};
		
		/**
		 * Add new TableTextContent to Table Content
		 */
		TableContent.prototype.addTableTextContent = function (elementType, instanceId, languageCode, isMaster) {
						
			var newTextContent = new TableTextContent(null, this);
			newTextContent.effectiveContentUserPermissions = this.effectiveContentUserPermissions;
			newTextContent.instanceId = instanceId;
			newTextContent.elementType = elementType;
			newTextContent.textType = this.getTextType();
							
			var textContentElement = new TextContentElement(null, newTextContent);
			
			textContentElement.state = ContentConstants.State.DRAFT;
			textContentElement.content = {};
			textContentElement.pastApprovals = [];
			textContentElement.language = languageCode;
			textContentElement.master = isMaster;
			textContentElement.effectiveElementUserPermissions = this.effectiveUserPermissionLanguageCache[languageCode];
			
			newTextContent.element.push(textContentElement);
			this.textContents.push(newTextContent);
			
			var lastSaveAction = this._saveActions[this._saveActions.length-1];
			if (lastSaveAction && lastSaveAction.type == ContentConstants.SaveAction.ADDTABLETEXTCONTENT
					&& lastSaveAction.newElementType == elementType && lastSaveAction.newInstanceId == instanceId) {
				lastSaveAction.timeStamp = (new Date()).getTime();
				lastSaveAction.newElementType = elementType;
				lastSaveAction.newInstanceId = instanceId;
				lastSaveAction.newElementLanguage = languageCode;
				lastSaveAction.isElementMaster = isMaster;
			} else {
				this._saveActions.push({
					type: ContentConstants.SaveAction.ADDTABLETEXTCONTENT,
					timeStamp : (new Date()).getTime(),
					newElementType: elementType,
					newInstanceId: instanceId,
					newElementLanguage: languageCode,
					isElementMaster: isMaster
				});
			}
			
			return textContentElement;
		};
		
		/**
		 * This method is used to identify if the element/parent passed was marked for delete. In that case, remove that entry from saveactions
		 * 
		 * @param csElement
		 */
		TableContent.prototype.removeMatchingSaveActions = function(csElem){
			for(var i=0; i<this._saveActions.length; i++){
				if(csElem.language == this._saveActions[i].language && 
						this._saveActions[i].type == ContentConstants.SaveAction.REMOVEELEMENT){
					this._saveActions.splice(i, 1);
					break;
				}
				
				if(csElem.parentStatement.instanceId == this._saveActions[i].instanceIdToBeRemoved && 
						csElem.parentStatement.elementType ==  this._saveActions[i].elementTypeToBeRemoved &&
						this._saveActions[i].type == ContentConstants.SaveAction.REMOVETABLETEXTCONTENT){
					this._saveActions.splice(i, 1);
					break;
				}
			}
		};
		
		/**
		 * This method will parse through all the tableTextContents and find the element types for which master language is added,
		 * and return the element types (element type code)
		 */
		TableContent.prototype.getMasterElementTypes = function(){
			var elementTypesArray = [];
			for(var i=0; i<this.textContents.length; i++){
				var elements = this.textContents[i].getMasterElements();
				if(elements.length > 0) 
					elementTypesArray.push(elements[0]);
			}
			return elementTypesArray;
		};
		

		/**
		 * Get a content ID for this object. (It's only unique within a content object).
		 */
		TableContent.prototype.getContentId = function () {
			return this.structuredElementType;
		};
		
		return TableContent;
});

/**
 * Common service class to load or save content as table or single text.
 * @PASH
 */
define('packaging-content-management/text-content-services/ContentService',["jquery",
        "packaging-content-management/content/SingleTextContent",
        "packaging-content-management/content/TableContent",
        "packaging-content-management/content/TextContentElement",
        "services/passwordValidationService",
        "utils/webi18n!TextContentStrings"], 
        function ($, 
        		SingleTextContent,
        		TableContent,
        		TextContentElement,
        		passwordValidationService,
        		TextContentStrings) {
	
	var ContentService = function () {
        
	};

	/**
	 * @param {String} contentRequest - Object indicating the circumstances under which the content should be requested.
	 * @param {Function} callback - Will be executed on successful return from the back end (and be passed the content).
	 * @param {Function} errorCallback - Will be executed on error from back end.
	 */
	ContentService.prototype.getContent = function (contentRequest, callback, errorCallback) {
		
		var params = {
				"ajax": "1",
				"contentRequest": JSON.stringify(contentRequest)
		};
		
		// The baseUrl of the service.
        var jspBaseUrl = window.webcenterConfig.jspBaseUrl;
		var url = jspBaseUrl+"GetContent.jsp?json=1&" + $.param(params, true);
		$.getJSON(url, function(jsonData) {
			var content;
			if (jsonData.objType == "SingleTextContent") {
				content = new SingleTextContent(jsonData);
			} else if (jsonData.objType == "TableContent") {
				content = new TableContent(jsonData);
			} else {
				content = new SingleTextContent(jsonData);
			}
        	callback(content);
        }.bind(this)).fail(function(jqXHR, textStatus, errorThrown) {
        	if(errorCallback) {
            	var errorCode = null;
            	errorCode = $(jqXHR.responseText).find('error').find('code').text();
            	if(errorCode && ('INVALIDPARAMETER_TAG' === errorCode || '002' === errorCode || '003' === errorCode)) {
            		errorCallback(TextContentStrings.t("TEXTCONTENT_DOCVERSION_NOT_FOUND"));
            		return;
            	}
        		errorCallback(TextContentStrings.t("TEXTCONTENT_LOAD_ERROR"));
        	}
        });
	};
	
	/**
	 * Save the changes in a Content object.
	 * 
	 * The Content should already exist!
	 * 
	 * @param {Content} content - The Content object to be saved.
	 * @param {Function} callback - To be executed on save action (Will be passed the updated content or
	 * 								the content for which the update failed and a possible error message).
	 */
	ContentService.prototype.saveContent = function (content, callback) {
		this.saveContents([content], callback);
	};
	
	/**
	 * Save the changes in multiple Content objects.
	 * 
	 * These Contents should already exist!
	 * 
	 * @param {Content} contents - The Contents objects to be saved.
	 * @param {Function} callback - To be executed on save action (Will be passed the updated contents, 
	 * 								the contents for which the update failed and error messages).
	 */
	ContentService.prototype.saveContents = function (contents, callback) {
		
		var password = passwordValidationService.getValidatedPassword();
		
		var saveActionJSONs = [];
		var docVersionIds = [];
		var docVersionIdMap = [];
		for (var i=0; i < contents.length; i++) {
			// Create an array of SaveAction JSON's.
			var saveActionJSON = JSON.stringify(contents[i].getSaveActions(password), function (key, value) {
				// We have to be careful to not have circular references in our SaveActions, therefore we will need to handle specific fields carefully.
				if (key == 'affectedTableContent' || key == 'affectedTextContent' || key == 'affectedTextContentElement') {
					return value.getContentId();
				} else {
					return value;
				}
			});
			
			saveActionJSONs.push(saveActionJSON);
			docVersionIds.push(contents[i].docVersionId);
			docVersionIdMap[contents[i].docVersionId] = contents[i];
		}
		
		var url = window.webcenterConfig.jspBaseUrl + 'SaveContent.jsp';
		$.ajax(url, {
			dataType: "json",
			cache: false,
			noAjaxParam: false,
			contentType: "application/x-www-form-urlencoded; charset=UTF-8",
			type: "POST",
			data: {
				saveactions: saveActionJSONs,
				docverids : docVersionIds
			},
			success: function (json) {
				
				// Get all the error messages.
				var errorMsgs = {};
				// Get all the updated contents;
				var updatedContents = {};
				
				// If a general error occurred.
				if (json.error) {
					// Add the general error occurred.
					errorMsgs[0] = json.error;
					// All contents failed.
					updatedContents = contents.slice(0, contents.length);
				}
				// Find out which updates succeeded and get the new updated contents.
				else if (json["updates"]) {
					// Iterate over all update entries ...
					for (var i=0; i < json.updates.length; i++) {
						var update = json.updates[i];
						// Check if an error occurred during the update ...
						if (update["error"]) {
							errorMsgs[update["id"]] = update["error"];
						}
						// Check if we have a newly updated version of the content.
						if (update["new"]) {
							if (update["new"].objType == "TableContent") {
								updatedContents[update["id"]] = new TableContent(update["new"]);
							} else {
								updatedContents[update["id"]] = new SingleTextContent(update["new"]);
							}
						}
					}
				}
				
				// If a callback was specified.
				if (callback) {
					callback(updatedContents, errorMsgs);
				}
				
			},
			error: function (jqXHR, textStatus, errorThrown) {
				var errorXml = $.parseXML(jqXHR.responseText);
				$xmlErr = $(errorXml);
				$message = $xmlErr.find( "message" );
				// If user login failed, the redirect him to login page
				if($message.text() == "User login failed"){
					var urlwanted = window.location.href;
					window.location.replace("home.jsp?urlwanted="+urlwanted);
					return;
				}
				
				if(callback) {
					callback([], contents.slice(0, contents.length), [TextContentStrings.t("TEXTCONTENT_SAVE_FAILED")]);
				}
			}
		});
	};
	
	return new ContentService();
	
});

define('web-viewer/textContent/DynContentModel',["web-viewer/core/PrivateChannel",
		"utils/ShapeUtils",
		"web-viewer/utils/ListenerUtil",
		"web-viewer/utils/ViewerUtils",
		"web-viewer/layout/component/ModalPopup",
		"web-viewer/layout/component/ViewerToolbarButton",
		"web-viewer/layout/LayoutConstants",
		"web-viewer/textContent/DynContentAnnotation",
		"packaging-content-management/dyn-content-services/dynContentService",
		"packaging-content-management/text-content-services/ContentService",
		"packaging-content-management/ContentConstants",
		"component/passwordpopup/PasswordValidationPopup",
		"underscore",
		"jquery"
	],
	function (PrivateChannel,
		ShapeUtils,
		ListenerUtil,
		ViewerUtils,
		ModalPopup,
		ViewerToolbarButton,
		LayoutConstants,
		DynContentAnnotation,
		dynContentService,
		ContentService,
		ContentConstants,
		PasswordValidationPopup,
		_,
		$) {
		"use strict";

		/**
		 * Constructs a new Dynamic Content model
		 * @exports DynContentModel
		 * @memberof TextContentModule
		 * @class
		 * The dynamic content model is the main model within the viewer that keeps track of the dynamic content objects and their selection. The model has its main function "setDynamicContents".
		 * @constructor
		 * @param {Core.ViewerFacade} f - Viewer facade
		 * @param {String} IID - Unique channel ID of the dynamic content model
		 */
		var DynContentModel = function (f, IID) {
			PrivateChannel.installTo(this, f, ['dynContentModel', IID]);
			ListenerUtil.mixin(this, f);

			/**
			 * Facade
			 */
			this.f = f;

			/**
			 * The page to which the current dynamic content annotations belong
			 * @private
			 * @type {Data.AbstractDocumentPage}
			 */
			this._page = null;

			/**
			 * Dynamic content annotations of the main document.
			 */
			this._dynContentAnnotations = [];

			/**
			 * Flag to specify loading dyn content 
			 */
			this._isDynContentsLoading = false;

			/**
			 * Keeps the list of dynamic content annotations that are selected.
			 */
			this._selectedDynContentAnnotations = [];

			/**
			 * An array containing all the annotations that are currently visible.
			 */
			this._visibleDynContentAnnotations = [];

			/**
			 * Keeps the list of Text Content objects that are unsaved.
			 */
			this._unsavedTextContents = [];

			/**
			 *  The currently active scaling, all dynamic content annotations are scaled with this scaling. This is used to initialize new annotations.
			 */
			this._currentScaling = null;

			/**
			 * Indicates whether we're currently in the process of saving the dynamic content.
			 */
			this._isSavingDynamicContents = false;

			/**
			 * The state on which we're filtering in the viewer.
			 */
			this._dynContentFilterState = undefined;

			/**
			 * By default the model is not disabled.
			 */
			this._disabled = false;
			
			/**
			 * This keep the list of Text Content that we got from initial page load
			 */
			this._dynContents = [];
		};

		/**
		 * Toggle the dynamic content annotation visibility
		 * @param {Boolean} [toggle] - force visibility
		 */
		DynContentModel.prototype.toggleVisibility = function (toggle) {
			if (toggle === undefined) {
				toggle = this.f.getOption("PREFERENCES_DYNCONTENTTOOLS_VISIBLE") == 1;
				toggle = !toggle;
			} else if (toggle && this.f.getOption("PREFERENCES_DYNCONTENTTOOLS_VISIBLE") == 1) { // yes! we compare with == and not with === (we are not sure what is in the preference (true, false)
				// nothing changed
				return;
			}

			if (!toggle) {
				this.f.setOption("PREFERENCES_DYNCONTENTTOOLS_VISIBLE", 0);
				this.unselectAllDynContents(false, true);
			} else {
				this.f.setOption("PREFERENCES_DYNCONTENTTOOLS_VISIBLE", 1);
			}
			this.modelChanged();
		};

		/**
		 * Get the page for which the dynamic content is visible
		 * @returns {Data.AbstractDocumentPage}
		 */
		DynContentModel.prototype.getDynContentPage = function () {
			return this._page;
		};

		/**
		 * Disable the model, e.g. clear all the dynamic content annotations and prevent them to be set.
		 */
		DynContentModel.prototype.disable = function () {
			this._disabled = true;
			this._dynContentAnnotations = [];
			this._visibleDynContentAnnotations = [];
			this.modelContentChanged();
		};

		/**
		 * Set the annotations objects for this model
		 * @param {Array<DynContentAnnotation>} dynContents - List of annotations
		 */
		DynContentModel.prototype.setDynContents = function (dynContents) {
			if (!this._disabled) {
				this.scaleAllDynContents(null);
				this._dynContentAnnotations = dynContents;
				this._visibleDynContentAnnotations = dynContents.slice(0, dynContents.length);
				//TODO allow the reference page the compensated, the Java Viewer does not allow this, as it returns wrong parameter values
				if (this._page && this._page !== this.f.getDocumentController().getDifferencePage()) {
					this.scaleAllDynContents(this._page.getCurrentScaling());
				}
				this.modelContentChanged();
			}
		};

		/**
		 * @returns {Array.<DynContentAnnotation>} dyn content of the model (unfiltered)
		 */
		DynContentModel.prototype.getDynContents = function () {
			return this._dynContentAnnotations;
		};

		/**
		 * @returns {Boolean} - True if loading dyn content is in progress 
		 */
		DynContentModel.prototype.getDynContentsLoading = function () {
			return this._isDynContentsLoading;
		};

		/**
		 * Save 1 or all dynamic content.
		 * 
		 * @param {ContentStatementElement} [textElement] if specified, only this statements will be saved. If not, all statements will be saved
		 * @param {Function} [callbackFunction] will be called when the annotations have been saved
		 */
		DynContentModel.prototype.save = function (textElement, callbackFunction) {
			if (!this._isSavingDynamicContents) {
				
				this._isSavingDynamicContents = true;
				if (this._page) {
					this.unselectAllDynContents(false, true);

					var unsavedTextContents = [];
					if (textElement) {
						// First make sure if the text content of this passed dynamic content is in the array of unsaved text contents.
						var textContent = textElement.parentStatement;
						if ($.inArray(textContent, this._unsavedTextContents) < 0) {
							// Attempting to save a text content that is not in the list of unsaved.
							// Stop here.
							this._isSavingDynamicContents = false;
							if (callbackFunction) {
								callbackFunction();
							}
							this._emit("save.finished");
							this.modelChanged();
							this.modelContentChanged();
							return;
						} else {
							unsavedTextContents.push(textContent);
						}
					} else {
						unsavedTextContents = this.getUnsavedTextContents();
					}

					// Find out if we need password validation.
					var isPasswordRequired = false;
					for (var i = 0; i < unsavedTextContents.length; i++) {
						isPasswordRequired = unsavedTextContents[i].isPasswordRequiredForApproval();
						if (isPasswordRequired) {
							break;
						}
					}

					// Create a function that will send the actual content statement save request.
					var doSaveContentStatements = function () {
						this._emit("save.started");
						// Save the content statements
						for(var j=0; j < unsavedTextContents.length; j++){
							unsavedTextContents[j].instanceId = 1;
						}
						
						ContentService.saveContents(unsavedTextContents, function (updatedTextContents, errorMsgs) {

							// Make sure no annotations are selected.
							this.unselectAllDynContents(false, true);

							// Show the errors ...
							var numErrors = Object.keys(errorMsgs).length;
							var errorString = this.f.i18n.t("PCMDynContentSaveFailed", numErrors)+"\n";
							for (var id in errorMsgs) {
								  if (errorMsgs.hasOwnProperty(id)) {
									  errorString += "\n" + errorMsgs[id];
								  }
							}
							if (numErrors > 0) {
								this.f.emit("userMessage", "warn", errorString, false);
							} else {
								this.f.emit("userMessage", "success", this.f.i18n.t("PCMDynContentSaveSucces"), true);
							}

							// Find out which text content documents were successfully saved and remove them from the array.
							$.each(updatedTextContents, function (id, updatedTextContent) {
								for (var i = 0; i < this._unsavedTextContents.length; i++) {
									if (this._unsavedTextContents[i].docVersionId == id) {
										this._unsavedTextContents.splice(i, 1);
										i--;
									}
								}
							}.bind(this));

							// Update the annotations of the successfully updated text content docuemnts.
							$.each(updatedTextContents, function (id, updatedTextContent) {
								for (var i = 0; i < this._dynContentAnnotations.length; i++) {
									var parentStatement = this._dynContentAnnotations[i].getDynContent().getTextElement().parentStatement;
									if (parentStatement.docVersionId == id) {
										var oldTextElement = this._dynContentAnnotations[i].getDynContent().getTextElement();
										var updatedTextElement = updatedTextContent.getElement(oldTextElement.language, oldTextElement.isMaster());
										// Update the Text Element.
										this._dynContentAnnotations[i].getDynContent().setTextElement(updatedTextElement);
										this._dynContentAnnotations[i].reCalcStyle();
									}
								}
							}.bind(this));

							// Finish the saving action ...
							this._isSavingDynamicContents = false;
							if (callbackFunction) {
								callbackFunction();
							}
							this._emit("save.finished");
							this.modelChanged();
							this.modelContentChanged();

						}.bind(this));

					}.bind(this);


					// Query the password ...
					if (isPasswordRequired) {
						var options = {};
						options.f = this.f;
						options.viewType = "viewer";

						this.passwordValidationPopup = new PasswordValidationPopup(options);
						// When the validation of the password was successfull ...
						this.passwordValidationPopup.onSubmit(function () {
							// Finally save the content statements.
							doSaveContentStatements();
						}.bind(this));

						// When the validation of the password failed ...
						this.passwordValidationPopup.onCancel(function () {
							// We're no longer saving.
							this._isSavingDynamicContents = false;
						}.bind(this));

						// Show the password validation popup
						this.passwordValidationPopup.open();

					} else {
						// No need for password validation first ... just save them.
						doSaveContentStatements();
					}

				} else {
					this._isSavingDynamicContents = false;
					// we didn't need to save, notify that the safe action is finsihed
					this._emit("save.finished");
				}
			} else {
				this.f.emit("error.WARNING", this.f.i18n.t("PCMDynContentAlreadyBeingSaved"), true);
			}
		};

		/**
		 * Get the currently selected translation language.
		 */
		DynContentModel.prototype.setDynContentFilterState = function (filterState) {

			// If there's no new filter state just return.
			if (filterState == this._dynContentFilterState) {
				return;
			}

			// Set the new state.
			this._dynContentFilterState = filterState;

			// Check if the "NO FILTER" state is set.
			if (!filterState || filterState == undefined) {
				this._visibleDynContentAnnotations = this._dynContentAnnotations;
			} else {
				// A new filter state was specified, calculate the newly visible annotations.
				this._visibleDynContentAnnotations = [];
				for (var i = 0; i < this._dynContentAnnotations.length; i++) {
					var approvals = this._dynContentAnnotations[i].getDynContent().getTextElement().pastApprovals;
					var state = this._dynContentAnnotations[i].getDynContent().getTextElement().state;
					if (state == filterState) {
						this._visibleDynContentAnnotations.push(this._dynContentAnnotations[i]);
					} else if (approvals.length > 0 && approvals[approvals.length - 1].state == filterState) {
						this._visibleDynContentAnnotations.push(this._dynContentAnnotations[i]);
					}
				}
				// Check if we have to deselect the currently selected annotation as they might be no longer visible.
				for (i = 0; i < this._selectedDynContentAnnotations.length; i++) {
					var selectedAnnotation = this._selectedDynContentAnnotations[i];
					if ($.inArray(selectedAnnotation, this._visibleDynContentAnnotations) < 0) {
						// One of the selected annotations is no longer visible, deselect the annotations.
						this.unselectAllDynContents(false, false);
						break;
					}
				}
			}

			this._emit("visibleDynContentChanged", this._visibleDynContentAnnotations);
			this.modelChanged();
		};

		/**
		 * Get the currently selected translation language.
		 */
		DynContentModel.prototype.getDynContentFilterState = function (state) {
			return this._dynContentFilterState;
		};

		/**
		 * Get the currently selected translation language.
		 */
		DynContentModel.prototype.setCurrentTransLangCode = function (langCode) {
			this._currentTransLangCode = langCode;
			this._emit("translationLangChanged", langCode);
		};

		/**
		 * Get the currently selected translation language.
		 */
		DynContentModel.prototype.getCurrentTransLangCode = function () {
			return this._currentTransLangCode;
		};

		/**
		 *
		 * @returns {Number} the count of all unsaved text content objects.
		 */
		DynContentModel.prototype.getUnsavedTextContentsCount = function () {
			return this.getUnsavedTextContents().length;
		};

		/**
		 * Get an array of unsaved text content objects.
		 * @returns {Array.<Annotation>} Array of unsaved annotations
		 */
		DynContentModel.prototype.getUnsavedTextContents = function () {
			return this._unsavedTextContents;
		};

		/**
		 * @returns {Array.<DynContentAnnotation>} the visible annotations to be displayed on the viewport
		 */
		DynContentModel.prototype.getVisibleDynContents = function () {
			// if annotation tools are disabled, or the module is temporarily disabled, do not show any annotations
			if (this.f.getOption("PREFERENCES_DYNCONTENTTOOLS_VISIBLE") === 0) {
				return [];
			} else {
				return this._visibleDynContentAnnotations;
			}
		};

		/**
		 * Get annotations for the given text element
		 * @param {ContentStatementElement} textElement - The text element
		 * @returns {Array.<<DynContentAnnotation>>} the dynamic content annotations linked to a specific text element
		 */
		DynContentModel.prototype.getDynContentAnnotationsForTextElement = function (textElement) {
			var forTextElement = [];
			for (var i = 0; i < this._dynContentAnnotations.length; i++) {
				if (this._dynContentAnnotations[i].getDynContent().getTextElement() == textElement) {
					forTextElement.push(this._dynContentAnnotations[i]);
				}
			}
			return forTextElement;
		};

		/**
		 * When a text element changed ...
		 * 
		 * @param {ContentStatementElement} textElement - The text element which got changed.
		 * @param {Object} fromWidget - The source of the changed.
		 */
		DynContentModel.prototype.textElementChanged = function (textElement, fromWidget) {
			this._emit("textElementChanged", textElement, fromWidget);

			// Put the parent text object in the list of text content objects that need to be saved.
			var existingTCIndex = $.inArray(textElement.parentStatement, this._unsavedTextContents);
			if ( existingTCIndex < 0) {
				this._unsavedTextContents.push(textElement.parentStatement);
				this._emit("unsavedTextContent", this._unsavedTextContents);
			} else {
				//Remove text content object from  array if it is not changed(status reverted)
				var existingTC = this._unsavedTextContents[existingTCIndex];
				if(!existingTC.isContentChanged()){
					this._unsavedTextContents.splice(existingTCIndex, 1);
					this._emit("unsavedTextContent", this._unsavedTextContents);
				}
			}

			// Check to see if any dynamic content annotations are affected (e.g. they need to change color or ...).
			var affectedDynContentAnnotations = this.getDynContentAnnotationsForTextElement(textElement);
			var changed = false;
			for (var i = 0; i < affectedDynContentAnnotations.length; i++) {
				var annotation = affectedDynContentAnnotations[i];
				// Recalculate the style for the annotation.
				var styleChanged = annotation.reCalcStyle();
				changed = changed || styleChanged;
			}

			// If the style for any annotation changed ...
			if (changed) {
				this.modelChanged();
			}
		};


		/**
		 * 
		 * @param contentStatement
		 */
		DynContentModel.prototype.selectDynContentBasedOn = function (contentStatement, langCode) {
			this.unselectAllDynContents(false, true);
			for (var i = 0; i < this._visibleDynContentAnnotations.length; i++) {
				var dynContentAnnotation = this._visibleDynContentAnnotations[i];
				var dynContent = dynContentAnnotation.getDynContent();
				if (dynContent.getTextElement().parentStatement == contentStatement) {
					// If a langCode was specified, filter on that ... but only when one was specified.
					if (langCode && langCode == dynContent.getTextElement().language) {
						this._selectedDynContentAnnotations.push(dynContentAnnotation);
						dynContentAnnotation.setSelected(true);
					} else if (!langCode) {
						this._selectedDynContentAnnotations.push(dynContentAnnotation);
						dynContentAnnotation.setSelected(true);
					}
				}
			}

			//If user has selected state filter and then selects the text in text content widget that is other than the filter, 
			//then we dont zoom or show the text highlight on the canvas, as the annotations are removed for other states than filter.
			//Eg: filter is set to draft, and in widget user select statement that is signed-off, then we dont do anything on canvas

			if (this._selectedDynContentAnnotations.length > 0) {
				// Indicate that we should zoom to these dynContents
				this.f.emit("module.dyncontent.zoomToDynContents", this._selectedDynContentAnnotations);

				// Indicate that these dynContents are selected 
				this._emit("selectedDynContents", this._selectedDynContentAnnotations, true);

				this.ensureVisibility();
			}

			this.modelChanged();
		};


		/**
		 * Select a dynamic content. All other selected dynamic contents will be unselected first
		 * 
		 * @param {DynContentAnnotation} dynContentAnnotation - Dynamic Content to be selected
		 * @param {Boolean} force - makes the unselectAllDynamicContents forced
		 */
		DynContentModel.prototype.selectDynContent = function (dynContentAnnotation, force) {

			if (!dynContentAnnotation) {
				return;
			}

			if (this._visibleDynContentAnnotations.length === 1) {
				var sDyn = this._visibleDynContentAnnotations[0];
				if (dynContentAnnotation == sDyn) {
					return;
				}
			}

			this.unselectAllDynContents(false, force);
			// Select the targeted one.
			this._selectedDynContentAnnotations.push(dynContentAnnotation);
			dynContentAnnotation.setSelected(true);
			// Select also all other dyncontent annotation with the same text element.
			var textElement = dynContentAnnotation.getDynContent().getTextElement();
			// Loop over all dyncontent annotations.
			for (var i = 0; i < this._visibleDynContentAnnotations.length; i++) {
				// If the dyncontent has the same text element as the selected one ...
				if (this._visibleDynContentAnnotations[i].getDynContent().getTextElement() == textElement) {
					// Select that annotation if it's not already.
					if ($.inArray(this._visibleDynContentAnnotations[i], this._selectedDynContentAnnotations) < 0) {
						this._selectedDynContentAnnotations.push(this._visibleDynContentAnnotations[i]);
						this._visibleDynContentAnnotations[i].setSelected(true);
					}
				}
			}
			this.ensureVisibility();

			// On mobile devices ... also zoom 
			if (this._layoutType == LayoutConstants.LayoutType.MOBILE) {
				this.f.emit("module.dyncontent.zoomToDynContents", this._selectedDynContentAnnotations);
			}

			// Indicate that we selected a dynContent annotation.
			this._emit("selectedDynContents", this._selectedDynContentAnnotations, true);
			this.modelChanged();
		};

		/**
		 * Make sure that the annotations are visible. If not, set the visible property back to 1
		 */
		DynContentModel.prototype.ensureVisibility = function () {
			if (!this.f.getOption("PREFERENCES_DYNCONTENTTOOLS_VISIBLE")) {
				this.f.setOption("PREFERENCES_DYNCONTENTTOOLS_VISIBLE", 1);
			}
		};

		/**
		 * Get an annotation based on the annotation name
		 * @param {Number} i - The index of the dynamic content.
		 */
		DynContentModel.prototype.getDynamicContent = function (i) {
			return this._dynContentAnnotations[i];
		};

		/**
		 * Unselect all the dynamic contents
		 * @param {Boolean} [donotbroadcast] - if set, the model will not broadcast that this happened (only used when the caller will call modelChanged() itself)
		 * @param {Boolean} [force] - if set, it will ignore the lockSelection flag
		 */
		DynContentModel.prototype.unselectAllDynContents = function (donotbroadcast, force) {
			if (this._selectedDynContentAnnotations.length <= 0) {
				return;
			}

			var selectedDynContents = this._selectedDynContentAnnotations;
			this._selectedDynContentAnnotations = [];

			_.each(selectedDynContents, _.bind(function (dynContent) {
				dynContent.setSelected(false);
			}, this));

			if (!donotbroadcast) {
				this.modelChanged();
				this._emit("unselectedDynContents", selectedDynContents, force);
			}
		};

		/**
		 * Get the selected dynamic contents
		 * 
		 * @returns {Array.<DynContentAnnotation>} list of selected annotations
		 */
		DynContentModel.prototype.getSelectedDynamicContents = function () {
			return this._selectedDynContentAnnotations;
		};

		/**
		 * Inform the listeners that the model has changed.
		 * 
		 * @param {DynContentAnnotation} dynContent - the dynamic content that has been updated
		 */
		DynContentModel.prototype.modelChanged = function () {
			this._emit("modelChanged");
		};

		/**
		 * Inform the listeners that the complete content has changed for the model (i.o.w, the _annotations are changed)
		 */
		DynContentModel.prototype.modelContentChanged = function () {
			this._emit("modelContentChanged");
		};

		/**
		 * Set the page for which dynamic content  should be displayed (this method will fetch the annotation for the page if necessary)
		 * @param {Data.AbstractDocumentPage} newPage - page for which dynamic content should be displayed
		 * @param {Function} [callback] - called when the page has changed
		 */
		DynContentModel.prototype.setPage = function (newPage, callback, forceUpdate) {
			if (newPage != this._page || forceUpdate) {

				// reset annotations
				this._isDynContentsLoading = true;
				this.setDynContents([]);

				this._emit("changed.page");
				this.unselectAllDynContents(false, true);
				this._page = newPage;

				if (newPage) {
					// load the annotations for the newPage
					var dynContentReq = dynContentService.getDynContentFor(newPage.getDocumentVersion().getDocumentVersionID(), forceUpdate);
					$.when(dynContentReq).done(function (dynContents) {
							this._dynContents = dynContents;
							var dynContentAnnotations = [];
							var pageSize = this._page.getPageSize();
							for (var i = 0; i < dynContents.length; i++) {
								var dynContLocations = dynContents[i].getLocations();
								if (dynContLocations.length > 0) {
									for (var j = 0; j < dynContLocations.length; j++) {
										var loc = dynContLocations[j];
										loc.orgy = loc.orgy + pageSize.height;
										dynContentAnnotations.push(new DynContentAnnotation(this.f, dynContents[i], loc));
									}
								} else {
									dynContentAnnotations.push(new DynContentAnnotation(this.f, dynContents[i], undefined, pageSize));
								}
							}
							this._isDynContentsLoading = false;
							this.setDynContents(dynContentAnnotations);
							if (callback) {
								callback(dynContents);
							}
						}.bind(this))
						.fail(_.bind(function (errorMsg) { // on error
							this.f.emit("userMessage", "warn", this.f.i18n.t("PCMDynContentErrorMessage"), false);
						}, this));

				}
			} else {
				if (callback !== undefined) {
					callback([]);
				}
			}
			this.modelChanged();
		};

		/**
		 * Get the page for which annotations are shown currently
		 * @returns {Data.AbstractDocumentPage}
		 */
		DynContentModel.prototype.getPage = function () {
			return this._page;
		};

		/**
		 * Prompt to save unsaved dynamic contents if there are any
		 * if there are unsaved dynamic contents, save them
		 *
		 * NOTE: this is not a pure model function, but to limit regressions, we keep it this way...
		 * @param {Function} callbackOnOK - function which is called when the popup is closed and annotations are saved
		 * @param {Function} [callbackOnCancel] - if provided, this callback is called when the user presses cancel
		 * @param {Function} [callbackOnDontSave] - adds the possibility to not save unsaved annotation but to continue with the action, on the contrary, cancel will cancel the action and don't save. Note that reloading the annotations should be done by the caller!
		 * @returns {Boolean} true if there are unsaved items and the popup is shown, false if not
		 */
		DynContentModel.prototype.promptToSaveUnsavedDynamicContent = function (callbackOnOK, callbackOnCancel, callbackOnDontSave) {
			
			if (this._page && this.getUnsavedTextContents().length > 0) {
				this.f.loadBundle("viewer", function () {
					// show popup if there are unsaved items
					var modalPopup = new ModalPopup(this.f, "unsavedDynContentsPopup", this.f.getContext());
					modalPopup.setRemoveFromDomAfterUsage(true);
					modalPopup.setOkAction(_.bind(function () {
						modalPopup.enableOkBtn(false);

						// save annotations
						this.save(null, _.bind(function () {
							// saving succeeded, so hide
							modalPopup.hide();
							if (callbackOnOK) {
								callbackOnOK();
							}
							this.toggleVisibility(true);
						}, this));
					}, this));

					modalPopup.setCancelAction(_.bind(function () {
						if (callbackOnCancel) {
							callbackOnCancel();
						}
						this.toggleVisibility(true);
					}, this));

					if (callbackOnDontSave) {
						var dontSaveButton = new ViewerToolbarButton(this.f, "dontSaveDynContents", $("<span>").append(this.f.t("RevertDynChanges")), false, _.bind(function () {
							modalPopup.hide();
							this.toggleVisibility(true);

							if (callbackOnDontSave) {
								callbackOnDontSave();
							}
						}, this));
						modalPopup.addButton(dontSaveButton);
					}

					// Header + Content
					modalPopup.setHeader($("<span/>").addClass("popupTitle").text(this.f.i18n.t("PCMUnsavedWarningTitle")));
					modalPopup.setContent($("<div/>").addClass("unsavedItemsContent").text(this.f.i18n.t("PCMUnsavedWarningMsg")));
					modalPopup.setOkBtnText(this.f.i18n.t("Save"));
					this.toggleVisibility(false);
					modalPopup.show();
					modalPopup.recalculateSize(600);
				}, this);

				return true;
			} else {
				return false;
			}
		};

		/**
		 * Scale all the dynamic contents of the model with a given factor, both horizontal as vertical, changes all the points and rectangle of the annotation,
		 * first undos the scaling and than applies the new scaling, if no scaleFactor is provided the current scaling is undone
		 * @param {ShapeUtils.Point} scaleFactor
		 */
		DynContentModel.prototype.scaleAllDynContents = function (scaleFactor) {
			if (this._currentScaling) {
				_.each(this._dynContentAnnotations, function (dynContent) {
					if (dynContent.isScaled()) {
						dynContent.scale(new ShapeUtils.Point(1 / dynContent.getScale().x, 1 / dynContent.getScale().y));
					}
				}, this);
			}
			this._currentScaling = scaleFactor;
			_.each(this._dynContentAnnotations, function (dynContent) {
				dynContent.setScale(scaleFactor);
			});
		};
		
		/**
		 * Identify the location information from dynContentLocale for dynContent - Use element type, instance id to determine the location
		 * @param dynContent
		 * @param selectDropDown
		 * @param dynContLocale
		 * @param allLocales
		 * @returns
		 */
		DynContentModel.prototype._getLocations = function (dynContent, selectDropDown, dynContLocale, allLocales){
			var lang = dynContent.getTextElement().language;
			var localeId = undefined;
			
			// find localeid for this language, if user has specified one!!
			for(var i=0; i<selectDropDown.length; i++){
				if(selectDropDown[i].val() == lang){
					localeId = allLocales[i];
					break;
				}
			}
			
			if(localeId){
				// find the location list of this localeId
				var matchingDynContLocale = $.grep(dynContLocale, function(dynContentLocale, index){
					return dynContentLocale.id == dynContent.getUid()
							&& dynContentLocale.locale == localeId;
				});
				
				// Found the matching dynContent which has location information - This should be mostly 1 entry in the array
				if(matchingDynContLocale.length > 0){
					return matchingDynContLocale[0].localeLocation;
				}else{
					return null;
				}
			}
		};
		
		/**
		 * Action method what should happend when user updates locale mapping and clicks ok 
		 * @param selectDropDown - Options updated by user in drop down
		 * @param dynContLocale - Array of TextDynContentLocale object
		 * @param allLocales - All locales supported by artwork
		 */
		DynContentModel.prototype.localeMappingAction = function (selectDropDown, dynContLocale, allLocales) {
			this.setDynContents([]);
			this.unselectAllDynContents(true, true);
			
			var pagesize = this._page.getPageSize();
			var dynContentAnnotations = [];
			
			for (var i = 0; i < this._dynContents.length; i++) {
				var dynContLocations = this._getLocations(this._dynContents[i], selectDropDown, dynContLocale, allLocales);
				if (dynContLocations != null && dynContLocations.length > 0) {
					for (var j = 0; j < dynContLocations.length; j++) {
						var loc = {};
						// make a copy of location information, lets not update original dynContLocale
						$.extend(true, loc, dynContLocations[j]);
						loc.orgy = loc.orgy + pagesize.height;
						dynContentAnnotations.push(new DynContentAnnotation(this.f, this._dynContents[i], loc));
					}
				} else {
					dynContentAnnotations.push(new DynContentAnnotation(this.f, this._dynContents[i], undefined, pagesize));
				}
			}
			
			this.setDynContents(dynContentAnnotations);
		};
	
		/**
		 * Get the currently active scaling
		 * @returns {ShapeUtils.Point}
		 */
		DynContentModel.prototype.getCurrentScaling = function () {
			return this._currentScaling;
		};

		return DynContentModel;

	});

define('web-viewer/textContent/DynContentLayerModel',["web-viewer/viewport/model/ViewportLayerModel",
        "web-viewer/textContent/DynContentAnnotation",
		"utils/ShapeUtils",
		"web-viewer/utils/ListenerUtil",
		"web-viewer/viewControls/ViewControlsConstants",
		"underscore"
	],
	function (ViewportLayerModel,
		DynContentAnnotation,
		ShapeUtils,
		ListenerUtil,
		ViewControlsConstants,
		_
	) {
		"use strict";

		/**
		 * Create a new annotation layer model
		 * @exports DynContentLayerModel
		 * @memberof TextContentModule
		 *
		 * @class This class is responsible for drawing annotations	 *
		 * @constructor
		 * @param {Core.ViewerFacade} f - Viewerfacade
		 * @param {String} ID - Id of the layer
		 * @param {DynContentModel} dynContentModel - Model of the dynamic content objects.
		 */
		var DynContentLayerModel = function (f, ID, dynContentModel) {
			ViewportLayerModel.call(this, f, ID);
			ListenerUtil.mixin(this, f);

			this.f = f;
			this.dynContentModel = dynContentModel;

			this._registerListener("modelChanged", this._calculateTransformation, this, this.dynContentModel);
			this._registerListener("modelContentChanged", this.modelChanged, this, this.dynContentModel);
			this._registerListener("parameters.changed", this._calculateTransformation, this, this.f.getDocumentController());
			this._registerListener("transform.viewportWidget.transformChanged", this._calculateTransformation, this);
		};
		
		DynContentLayerModel.prototype = Object.create(ViewportLayerModel.prototype);
		DynContentLayerModel.prototype.constructor = DynContentLayerModel;

		/**
		 * Calculates the transformation for the dynamic content layer, takes compensation for distortion and scaling into account
		 */
		DynContentLayerModel.prototype._calculateTransformation = function () {
			var page = this.dynContentModel.getDynContentPage();
			if (page !== null && page !== undefined) {
				this.resetTransformation();
				this.getTransform().scale(1, -1);

				var rotation = page.getRotation();

				var worldBounds = this.f.getModule("viewport").getWorldBounds();

				//calculate the rest of the tranformation, for rotation, flipped state
				this.calculateTransformation(worldBounds, page.getPageSize(), new ShapeUtils.Size(), rotation, page.isFlipped());
			}
			this.modelChanged();
		};
		
		/**
		 * @override
		 */
		DynContentLayerModel.prototype.getLinework = function (animated, rotationanimation) {
			
			// Get all visible dyncontent annotations.
			var dynContentAnnotations = this.dynContentModel.getVisibleDynContents();
			// Make a quick shallow copy of this array.
			dynContentAnnotations = dynContentAnnotations.slice(0,dynContentAnnotations.length);
			
			// Get the selected annotations.
			var selectedDynContents = this.dynContentModel.getSelectedDynamicContents();
			// Generate the selection boxes for the selected annotations.
			var selectionBoxes = [];
			for (var i=0; i < selectedDynContents.length; i++) {
				// Only show selection boxes if the dynContent is visible.
				if ($.inArray(selectedDynContents[i], dynContentAnnotations) > -1) {
					selectionBoxes.push(selectedDynContents[i].getSelectionBox());
				}
			}
			
			// Make sure we don't double fill annotations on top of each other.
			// Group the annotations based on their location.
			var annotationsGrouped = [];
			while (dynContentAnnotations.length > 0) {
				var annotation1 = dynContentAnnotations.shift();
				var annotationGroup = [annotation1];
				for (var i=0; i < dynContentAnnotations.length; i++) {
					var annotation2 = dynContentAnnotations[i];
					if (annotation1.rect.rectEquals(annotation2.rect)) {
						annotationGroup.push(annotation2);
						dynContentAnnotations.splice(i, 1);
						i--;
					}
				}
				annotationsGrouped.push(annotationGroup);
			}
			
			// Iterate over every annotation group (all annotations in a group or on the same location).
			for (var i=0; i < annotationsGrouped.length; i++) {
				var annotationGroup = annotationsGrouped[i];
				
				// Check if there are multiple annotations in this group.
				if (annotationGroup.length > 1) {
					
					var transLang = this.dynContentModel.getCurrentTransLangCode();
					annotationGroup.sort(function(annotation1, annotation2) {
						// First sort on selected.
						if (annotation1.selected && !annotation2.selected) {
							return 1;
						} else if (!annotation1.selected && annotation2.selected) {
							return -1;
						} else if (annotation1.selected && annotation2.selected) {
							return 0;
						} else {
							// Sort on language.
							var lang1 = annotation1.getDynContent().getTextElement().language;
							var lang2 = annotation2.getDynContent().getTextElement().language;
							if (lang1 == transLang) {
								return 1;
							} else if (lang2 == transLang) {
								return -1;
							} else {
								return 0;
							}
						}
					});
					
					// Now disable the fill color of every annotation but the last.
					for (var j=0; j < annotationGroup.length; j++) {
						if (j != annotationGroup.length-1) {
							annotationGroup[j].fillcolor = undefined;
						} else {
							annotationGroup[j].reCalcStyle();
						}
					}
				}
			}
			// After removing any potential anoying fills ... flatten our grouped annotations again.
			dynContentAnnotations = _.flatten(annotationsGrouped);
			
			var linework = _.union(dynContentAnnotations, _.without(_.flatten(selectionBoxes), undefined, null));
			return linework;
			
		};
		
		return DynContentLayerModel;
});

define('web-viewer/viewport/model/ViewportPopupModel',["underscore",
		"web-viewer/core/PrivateChannel"
	],
	function (_,
		PrivateChannel) {
		/**
		 * Construct a new viewport popup model
		 * @exports ViewportPopupModel
		 * @memberof ViewportModule
		 * @class
		 * This model is responsible for the state (shown/not shown) of the popup.
		 * It also contains the popup itself.
		 * @param {Core.ViewerFacade} f - Viewerfacade
		 * @param {String} id - Id of the viewport popup model
		 */
		var ViewportPopupModel = function (f, id) {
			this.f = f;
			this.id = id;
			this.shown = true;
		};

		/**
		 * Get the id of the popup model
		 * @returns {String} The id of the popup model
		 */
		ViewportPopupModel.prototype.getId = function () {
			return this.id;
		};

		/**
		 * Indicate that the popup should be shown.
		 */
		ViewportPopupModel.prototype.show = function () {
			this.shown = true;
		};

		/**
		 * Indicate that the popup should be hidden.
		 */
		ViewportPopupModel.prototype.hide = function () {
			this.shown = false;
		};

		/**
		 * Check whether the popup is shown.
		 * @returns {Boolean} True if the popup is shown, false otherwise/
		 */
		ViewportPopupModel.prototype.isShown = function () {
			return this.shown;
		};

		/**
		 * Get the popup belonging to this model.
		 * Override this function.
		 * @param {ViewportLayer} viewportLayer - The layer where the popups should be shown.
		 * @returns {Popup} The popup belonging to this model.
		 */
		ViewportPopupModel.prototype.getPopup = function (viewportLayer) {
			// override
			return undefined;
		};

		/**
		 * Called when the popup model is destroyed.
		 * Override this function.
		 * Useful to do some cleanup.
		 */
		ViewportPopupModel.prototype.onDestroy = function () {
			// override to do some cleanup
		};

		/**
		 * Return the world origin of the popup
		 * Override this function.
		 * @returns {ShapeUtils.Point} - Origin of the popup.
		 */
		ViewportPopupModel.prototype.getWorldOrigin = function () {
			// override
			return undefined;
		};

		/**
		 * Returns the world size of the popup
		 * Override this function.
		 * @returns {ShapeUtils.Size} - Size of the popup.
		 */
		ViewportPopupModel.prototype.getWorldSize = function () {
			// override
			return undefined;
		};

		/**
		 * When there needs to be added an offset to the popup location (in scene pixels), return the offset here
		 * @returns {ShapeUtils.Size} offset in pixels that needs to be added to the popuplocation
		 */
		ViewportPopupModel.prototype.getSceneOffset = function () {
			return undefined;
		};

		/**
		 * Function called by the layer after translating the scene rectangle to world coordinates.
		 * Override this function.
		 * @param {ShapeUtils.Rect} worldRect - Rectangle in world coordinates
		 * @param {Boolean} autoAdapted - True if the event is fired because the content was auto adapted (e.g. from a makeMeVisible trigger from an element in the content), false otherwise
		 */
		ViewportPopupModel.prototype.onResized = function (worldRect, autoAdapted) {
			// override
		};

		/**
		 * Function called by the layer after translating the scene point to world coordinates.
		 * Override this function.
		 * @param {ShapeUtils.Point} worldPoint - Point in world coordinates
		 */
		ViewportPopupModel.prototype.onDragged = function (worldPoint) {
			// override
		};

		return ViewportPopupModel;
	});


define('utils/webcss-text!lib/summernote/summernote.css',[],function () { return '@font-face{font-family:"summernote";font-style:normal;font-weight:normal;src:url("font/summernote.eot?ad8d7e2d177d2473aecd9b35d16211fb");src:url("font/summernote.eot?#iefix") format("embedded-opentype"),url("font/summernote.woff?ad8d7e2d177d2473aecd9b35d16211fb") format("woff"),url("font/summernote.ttf?ad8d7e2d177d2473aecd9b35d16211fb") format("truetype")}[class^="note-icon-"]:before,[class*=" note-icon-"]:before{display:inline-block;font:normal normal normal 14px summernote;font-size:inherit;-webkit-font-smoothing:antialiased;text-decoration:inherit;text-rendering:auto;text-transform:none;vertical-align:middle;speak:none;-moz-osx-font-smoothing:grayscale}.note-icon-align-center:before{content:"\\f101"}.note-icon-align-indent:before{content:"\\f102"}.note-icon-align-justify:before{content:"\\f103"}.note-icon-align-left:before{content:"\\f104"}.note-icon-align-outdent:before{content:"\\f105"}.note-icon-align-right:before{content:"\\f106"}.note-icon-align:before{content:"\\f107"}.note-icon-arrows-alt:before{content:"\\f108"}.note-icon-bold:before{content:"\\f109"}.note-icon-caret:before{content:"\\f10a"}.note-icon-chain-broken:before{content:"\\f10b"}.note-icon-circle:before{content:"\\f10c"}.note-icon-close:before{content:"\\f10d"}.note-icon-code:before{content:"\\f10e"}.note-icon-eraser:before{content:"\\f10f"}.note-icon-font:before{content:"\\f110"}.note-icon-frame:before{content:"\\f111"}.note-icon-italic:before{content:"\\f112"}.note-icon-link:before{content:"\\f113"}.note-icon-magic:before{content:"\\f114"}.note-icon-menu-check:before{content:"\\f115"}.note-icon-minus:before{content:"\\f116"}.note-icon-orderedlist:before{content:"\\f117"}.note-icon-pencil:before{content:"\\f118"}.note-icon-picture:before{content:"\\f119"}.note-icon-question:before{content:"\\f11a"}.note-icon-redo:before{content:"\\f11b"}.note-icon-special-character:before{content:"\\f11c"}.note-icon-square:before{content:"\\f11d"}.note-icon-strikethrough:before{content:"\\f11e"}.note-icon-subscript:before{content:"\\f11f"}.note-icon-summernote:before{content:"\\f120"}.note-icon-superscript:before{content:"\\f121"}.note-icon-table:before{content:"\\f122"}.note-icon-text-height:before{content:"\\f123"}.note-icon-trash:before{content:"\\f124"}.note-icon-underline:before{content:"\\f125"}.note-icon-undo:before{content:"\\f126"}.note-icon-unorderedlist:before{content:"\\f127"}.note-icon-video:before{content:"\\f128"}.note-editor{position:relative}.note-editor .note-dropzone{position:absolute;z-index:100;display:none;color:#87cefa;background-color:white;opacity:.95;pointer-event:none}.note-editor .note-dropzone .note-dropzone-message{display:table-cell;font-size:28px;font-weight:bold;text-align:center;vertical-align:middle}.note-editor .note-dropzone.hover{color:#098ddf}.note-editor.dragover .note-dropzone{display:table}.note-editor .note-editing-area{position:relative}.note-editor .note-editing-area .note-editable{outline:0}.note-editor .note-editing-area .note-editable sup{vertical-align:super}.note-editor .note-editing-area .note-editable sub{vertical-align:sub}.note-editor.note-frame{border:1px solid #a9a9a9}.note-editor.note-frame.codeview .note-editing-area .note-editable{display:none}.note-editor.note-frame.codeview .note-editing-area .note-codable{display:block}.note-editor.note-frame .note-editing-area{overflow:hidden}.note-editor.note-frame .note-editing-area .note-editable{padding:10px;overflow:auto;color:#000;background-color:#fff}.note-editor.note-frame .note-editing-area .note-editable[contenteditable="false"]{background-color:#e5e5e5}.note-editor.note-frame .note-editing-area .note-codable{display:none;width:100%;padding:10px;margin-bottom:0;font-family:Menlo,Monaco,monospace,sans-serif;font-size:14px;color:#ccc;background-color:#222;border:0;-webkit-border-radius:0;-moz-border-radius:0;border-radius:0;box-shadow:none;-webkit-box-sizing:border-box;-moz-box-sizing:border-box;-ms-box-sizing:border-box;box-sizing:border-box;resize:none}.note-editor.note-frame.fullscreen{position:fixed;top:0;left:0;z-index:1050;width:100%}.note-editor.note-frame.fullscreen .note-editable{background-color:white}.note-editor.note-frame.fullscreen .note-resizebar{display:none}.note-editor.note-frame .note-statusbar{background-color:#f5f5f5;border-bottom-right-radius:4px;border-bottom-left-radius:4px}.note-editor.note-frame .note-statusbar .note-resizebar{width:100%;height:8px;padding-top:1px;cursor:ns-resize}.note-editor.note-frame .note-statusbar .note-resizebar .note-icon-bar{width:20px;margin:1px auto;border-top:1px solid #a9a9a9}.note-editor.note-frame .note-placeholder{padding:10px}.note-popover.popover{max-width:none}.note-popover.popover .popover-content a{display:inline-block;max-width:200px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;vertical-align:middle}.note-popover.popover .arrow{left:20px!important}.note-popover .popover-content,.panel-heading.note-toolbar{padding:0 0 5px 5px;margin:0}.note-popover .popover-content>.btn-group,.panel-heading.note-toolbar>.btn-group{margin-top:5px;margin-right:5px;margin-left:0}.note-popover .popover-content .btn-group .note-table,.panel-heading.note-toolbar .btn-group .note-table{min-width:0;padding:5px}.note-popover .popover-content .btn-group .note-table .note-dimension-picker,.panel-heading.note-toolbar .btn-group .note-table .note-dimension-picker{font-size:18px}.note-popover .popover-content .btn-group .note-table .note-dimension-picker .note-dimension-picker-mousecatcher,.panel-heading.note-toolbar .btn-group .note-table .note-dimension-picker .note-dimension-picker-mousecatcher{position:absolute!important;z-index:3;width:10em;height:10em;cursor:pointer}.note-popover .popover-content .btn-group .note-table .note-dimension-picker .note-dimension-picker-unhighlighted,.panel-heading.note-toolbar .btn-group .note-table .note-dimension-picker .note-dimension-picker-unhighlighted{position:relative!important;z-index:1;width:5em;height:5em;background:url(\'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASAgMAAAAroGbEAAAACVBMVEUAAIj4+Pjp6ekKlAqjAAAAAXRSTlMAQObYZgAAAAFiS0dEAIgFHUgAAAAJcEhZcwAACxMAAAsTAQCanBgAAAAHdElNRQfYAR0BKhmnaJzPAAAAG0lEQVQI12NgAAOtVatWMTCohoaGUY+EmIkEAEruEzK2J7tvAAAAAElFTkSuQmCC\') repeat}.note-popover .popover-content .btn-group .note-table .note-dimension-picker .note-dimension-picker-highlighted,.panel-heading.note-toolbar .btn-group .note-table .note-dimension-picker .note-dimension-picker-highlighted{position:absolute!important;z-index:2;width:1em;height:1em;background:url(\'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASAgMAAAAroGbEAAAACVBMVEUAAIjd6vvD2f9LKLW+AAAAAXRSTlMAQObYZgAAAAFiS0dEAIgFHUgAAAAJcEhZcwAACxMAAAsTAQCanBgAAAAHdElNRQfYAR0BKwNDEVT0AAAAG0lEQVQI12NgAAOtVatWMTCohoaGUY+EmIkEAEruEzK2J7tvAAAAAElFTkSuQmCC\') repeat}.note-popover .popover-content .note-style h1,.panel-heading.note-toolbar .note-style h1,.note-popover .popover-content .note-style h2,.panel-heading.note-toolbar .note-style h2,.note-popover .popover-content .note-style h3,.panel-heading.note-toolbar .note-style h3,.note-popover .popover-content .note-style h4,.panel-heading.note-toolbar .note-style h4,.note-popover .popover-content .note-style h5,.panel-heading.note-toolbar .note-style h5,.note-popover .popover-content .note-style h6,.panel-heading.note-toolbar .note-style h6,.note-popover .popover-content .note-style blockquote,.panel-heading.note-toolbar .note-style blockquote{margin:0}.note-popover .popover-content .note-color .dropdown-toggle,.panel-heading.note-toolbar .note-color .dropdown-toggle{width:20px;padding-left:5px}.note-popover .popover-content .note-color .dropdown-menu,.panel-heading.note-toolbar .note-color .dropdown-menu{min-width:340px}.note-popover .popover-content .note-color .dropdown-menu .btn-group,.panel-heading.note-toolbar .note-color .dropdown-menu .btn-group{margin:0}.note-popover .popover-content .note-color .dropdown-menu .btn-group:first-child,.panel-heading.note-toolbar .note-color .dropdown-menu .btn-group:first-child{margin:0 5px}.note-popover .popover-content .note-color .dropdown-menu .btn-group .note-palette-title,.panel-heading.note-toolbar .note-color .dropdown-menu .btn-group .note-palette-title{margin:2px 7px;font-size:12px;text-align:center;border-bottom:1px solid #eee}.note-popover .popover-content .note-color .dropdown-menu .btn-group .note-color-reset,.panel-heading.note-toolbar .note-color .dropdown-menu .btn-group .note-color-reset{width:100%;padding:0 3px;margin:3px;font-size:11px;cursor:pointer;-webkit-border-radius:5px;-moz-border-radius:5px;border-radius:5px}.note-popover .popover-content .note-color .dropdown-menu .btn-group .note-color-row,.panel-heading.note-toolbar .note-color .dropdown-menu .btn-group .note-color-row{height:20px}.note-popover .popover-content .note-color .dropdown-menu .btn-group .note-color-reset:hover,.panel-heading.note-toolbar .note-color .dropdown-menu .btn-group .note-color-reset:hover{background:#eee}.note-popover .popover-content .note-para .dropdown-menu,.panel-heading.note-toolbar .note-para .dropdown-menu{min-width:216px;padding:5px}.note-popover .popover-content .note-para .dropdown-menu>div:first-child,.panel-heading.note-toolbar .note-para .dropdown-menu>div:first-child{margin-right:5px}.note-popover .popover-content .dropdown-menu,.panel-heading.note-toolbar .dropdown-menu{min-width:90px}.note-popover .popover-content .dropdown-menu.right,.panel-heading.note-toolbar .dropdown-menu.right{right:0;left:auto}.note-popover .popover-content .dropdown-menu.right::before,.panel-heading.note-toolbar .dropdown-menu.right::before{right:9px;left:auto!important}.note-popover .popover-content .dropdown-menu.right::after,.panel-heading.note-toolbar .dropdown-menu.right::after{right:10px;left:auto!important}.note-popover .popover-content .dropdown-menu.note-check li a i,.panel-heading.note-toolbar .dropdown-menu.note-check li a i{color:deepskyblue;visibility:hidden}.note-popover .popover-content .dropdown-menu.note-check li a.checked i,.panel-heading.note-toolbar .dropdown-menu.note-check li a.checked i{visibility:visible}.note-popover .popover-content .note-fontsize-10,.panel-heading.note-toolbar .note-fontsize-10{font-size:10px}.note-popover .popover-content .note-color-palette,.panel-heading.note-toolbar .note-color-palette{line-height:1}.note-popover .popover-content .note-color-palette div .note-color-btn,.panel-heading.note-toolbar .note-color-palette div .note-color-btn{width:20px;height:20px;padding:0;margin:0;border:1px solid #fff}.note-popover .popover-content .note-color-palette div .note-color-btn:hover,.panel-heading.note-toolbar .note-color-palette div .note-color-btn:hover{border:1px solid #000}.note-dialog>div{display:none}.note-dialog .form-group{margin-right:0;margin-left:0}.note-dialog .note-modal-form{margin:0}.note-dialog .note-image-dialog .note-dropzone{min-height:100px;margin-bottom:10px;font-size:30px;line-height:4;color:lightgray;text-align:center;border:4px dashed lightgray}@-moz-document url-prefix(){.note-image-input{height:auto}}.note-placeholder{position:absolute;display:none;color:gray}.note-handle .note-control-selection{position:absolute;display:none;border:1px solid black}.note-handle .note-control-selection>div{position:absolute}.note-handle .note-control-selection .note-control-selection-bg{width:100%;height:100%;background-color:black;-webkit-opacity:.3;-khtml-opacity:.3;-moz-opacity:.3;opacity:.3;-ms-filter:alpha(opacity=30);filter:alpha(opacity=30)}.note-handle .note-control-selection .note-control-handle{width:7px;height:7px;border:1px solid black}.note-handle .note-control-selection .note-control-holder{width:7px;height:7px;border:1px solid black}.note-handle .note-control-selection .note-control-sizing{width:7px;height:7px;background-color:white;border:1px solid black}.note-handle .note-control-selection .note-control-nw{top:-5px;left:-5px;border-right:0;border-bottom:0}.note-handle .note-control-selection .note-control-ne{top:-5px;right:-5px;border-bottom:0;border-left:none}.note-handle .note-control-selection .note-control-sw{bottom:-5px;left:-5px;border-top:0;border-right:0}.note-handle .note-control-selection .note-control-se{right:-5px;bottom:-5px;cursor:se-resize}.note-handle .note-control-selection .note-control-se.note-control-holder{cursor:default;border-top:0;border-left:none}.note-handle .note-control-selection .note-control-selection-info{right:0;bottom:0;padding:5px;margin:5px;font-size:12px;color:white;background-color:black;-webkit-border-radius:5px;-moz-border-radius:5px;border-radius:5px;-webkit-opacity:.7;-khtml-opacity:.7;-moz-opacity:.7;opacity:.7;-ms-filter:alpha(opacity=70);filter:alpha(opacity=70)}.note-hint-popover{min-width:100px;padding:2px}.note-hint-popover .popover-content{max-height:150px;padding:3px;overflow:auto}.note-hint-popover .popover-content .note-hint-group .note-hint-item{display:block!important;padding:3px}.note-hint-popover .popover-content .note-hint-group .note-hint-item.active,.note-hint-popover .popover-content .note-hint-group .note-hint-item:hover{display:block;clear:both;font-weight:400;line-height:1.4;color:white;text-decoration:none;white-space:nowrap;cursor:pointer;background-color:#428bca;outline:0}\r\n.note-image-input.form-control{height: auto;}\r\n.panel.note-editor{margin-bottom: 0px;}';});



define('utils/webcss-text!packaging-content-management/text-content-element-widget/RichTextEditor.css',[],function () { return '.w .RichTextEditor {\r\n\twidth: 100%;\r\n\theight: 100%;\r\n\toverflow-y: auto;\r\n\tpadding: 3px;\r\n\tcursor: text;\r\n\tbackground-color: white;\r\n}\r\n.w .RichTextEditor p:empty {\r\n\tmargin-top: 3px;\r\n\tmin-height: 16px;\r\n}\r\n.w .RichTextEditor p:first-child {\r\n\tmargin-top: 0px;\r\n}\r\n.w .RichTextEditorPlaceholder {\r\n\t"word-wrap": "break-word";\r\n}\r\n.w .RichTextEditorPlaceholder:focus {\r\n\toutline: 0px solid transparent;\r\n}';});


define('packaging-content-management/text-content-element-widget/RichTextEditor',["jquery",
        "utils/webi18n!TextContentStrings",
        "component/tooltip/Tooltip",
        "utils/Promisify",
        "utils/webcss!lib/summernote/summernote.css",
        "utils/webcss!./RichTextEditor.css"],
	function ($,
			TextContentStrings,
			Tooltip,
			Promisify) {
	
	
	var RichTextEditor = function (content, height) {
		
		// The array holding all the "onChange" callbacks.
		this._onChange = [];
		this._onFocus = [];
		this._onBlur = [];
		
		// Save the height.
		this._height = height;
		
		// An actual Rich Text editor is created, already start requiring summernote.
		this._summerNotePromise = Promisify.makeQueryable(Promisify.require("lib/summernote/summernote"));
		
		// The wrapping div of the editor.
		this._wrapper = $("<div>");
		
		this._editorWrapper = $("<div>");
		this._editorWrapper.addClass("RichTextEditor");
		this._wrapper.append(this._editorWrapper);

		// Return whether the editor is still in "lazy" mode, e.g. whether a real summernote editor was constructed.
		this._isLazy = true;
		
		// Whether we're disabled or not.
		this._disabled = false;
		
		// This will be showed until the user clicks on the editor.
		this._lazyPlaceholder =  $("<div>", {"contenteditable" : "true", "class" : "RichTextEditorPlaceholder"});
		this._lazyPlaceholder.css({
			"height: ": (this._height-16)+"px"
		});
		
		// Parse the content.
		var parsedContent = undefined;
		try {
			parsedContent = $(content.content);
		} catch (exception) {
			// This is not valid html ... ugh ... just insert in the editor and hope for the best.
			this._lazyPlaceholder.html(content.content);
		}
		// Check if the content could be parsed.
		if (parsedContent && parsedContent.length == 0) {
			// Parsed content could not be parsed, just dump it in the editor and hope for the best.
			this._lazyPlaceholder.html(content.content);
		}
		// Check if the root element of content is "<body>" (we can't insert that in the editor).
		else if (parsedContent && parsedContent.length == 1 && parsedContent.is("body")) {
			// We need to insert all of the parsed content except the body tag itself.
			this._lazyPlaceholder.html(parsedContent.html());
		} 
		// If we get here, then we have perfectly fine rich text. 
		else {
			this._lazyPlaceholder.html(content.content);
		}
		
		// Add the lazyPlaceholder
		this._editorWrapper.append(this._lazyPlaceholder);
		
		// As soon as the lazyPlaceholder on hover, make the widget not lazy anymore.
		this._lazyPlaceholder.hover(function () {
			this._makeNotLazy();
		}.bind(this));
		
		// As soon as the lazyPlaceholder gains focus, make the widget not lazy anymore (to be safe).
		this._lazyPlaceholder.focus(function () {
			this._makeNotLazy();
			// Call the callbacks (to be sure)
			$.each(this._onFocus, function (i, callback) {
				callback();
			});
		}.bind(this));
		
		// As soon as the lazyPlaceholder has click, make the widget not lazy anymore (to be safe).
		this._lazyPlaceholder.click(function () {
			this._makeNotLazy();
			// Call the callbacks (to be sure)
			$.each(this._onFocus, function (i, callback) {
				callback();
			});
		}.bind(this));
	};
	
	/**
	 * Make the widget no longer "lazy", e.g. create a real summernote editor that can be used to change the content.
	 * 
	 * @param cursorRange - The position of the cursor in the real editor.
	 */
	RichTextEditor.prototype._makeNotLazy = function (cursorRange) {
		
		// Only do this if we're still lazy and not disabled.
		if (this._isLazy && !this._disabled) {
			
			// Check whether summernote is loaded first ...
			if (this._summerNotePromise.isResolved()) {
				
				// Create the div that will be hidden and function as the handle for summernote.
				this._handle = $("<div>");
						
				// Transfer the contents from the placeholder to the editor.
				this._handle.html(this._lazyPlaceholder.html());
				
				// Remove the placeholder from the wrapper and add the handle.
				this._editorWrapper.empty();
				this._editorWrapper.append(this._handle);
				
				// Create the editor.
				this._handle.summernote({
					airMode: true,
					disableDragAndDrop: true,
					popover: {
						air: [['style', ['bold', 'italic', 'underline', 'clear']],
						      ['font', ['strikethrough', 'superscript', 'subscript']]]
					},
					keyMap: {
						  pc: {
						    'ENTER': 'insertParagraph',
						    'CTRL+Z': 'undo',
						    'CTRL+Y': 'redo',
						    'TAB': 'tab',
						    'SHIFT+TAB': 'untab',
						    'CTRL+B': 'bold',
						    'CTRL+I': 'italic',
						    'CTRL+U': 'underline',
						    'CTRL+SHIFT+S': 'strikethrough',
						    'CTRL+BACKSLASH': 'removeFormat'
						  },
						  mac: {
						    'ENTER': 'insertParagraph',
						    'CMD+Z': 'undo',
						    'CMD+SHIFT+Z': 'redo',
						    'TAB': 'tab',
						    'SHIFT+TAB': 'untab',
						    'CMD+B': 'bold',
						    'CMD+I': 'italic',
						    'CMD+U': 'underline',
						    'CMD+SHIFT+S': 'strikethrough',
						    'CMD+BACKSLASH': 'removeFormat',
						    'CMD+SHIFT+NUM7': 'insertUnorderedList',
						    'CMD+SHIFT+NUM8': 'insertOrderedList',
						    'CMD+LEFTBRACKET': 'outdent',
						    'CMD+RIGHTBRACKET': 'indent'
						  }
					},
					callbacks: {
						onPaste: this._handlePaste.bind(this),
						onFocus: function () {
							$.each(this._onFocus, function (i, callback) {
								callback();
							});
						}.bind(this),
						onBlur: function () {
							$.each(this._onBlur, function (i, callback) {
								callback();
							});
						}.bind(this)
					}
				});
				this._handle.summernote("setStyle", "word-wrap", "break-word");
				
				// On click of the wrapper.
				this._editorWrapper.on("mousedown", function (e) {
					// If the wrapper itself is clicked ... 
					if (this._editorWrapper[0] == e.target) {
						// Check if the editor has focus ...
						if (!this.hasFocus()) {
							// The editor has no focus ... give it focus.
							this._handle.summernote("focus");
						}
						// Prevent the real "click" from happening as this will cause the editor to lose focus.
						e.preventDefault();
					}
				}.bind(this));
				
				// Execute change call-backs when content is changed in editor.
				this._handle.on('summernote.change', function () {
					$.each(this._onChange, function (index, changeCallback) {
						changeCallback();
					}.bind(this));
				}.bind(this));
				
				// We're not lazy anymore.
				this._isLazy = false;
				
				// Clean out the rich text html.
				this.cleanRichText();
				
			}
			// Summernote is not loaded yet ... postpone the not lazy making.
			else {
				// Make this editor not lazy as soon as summernote is loaded.
				this._summerNotePromise.then(this._makeNotLazy.bind(this));
			}
		}
	};
	
	/**
	 * Filter the god damn frigging paste event.
	 */
	RichTextEditor.prototype._handlePaste = function(e) {
		// Defer the handling of this event.
		window.setTimeout(function (e) {
			this.cleanRichText();
		}.bind(this, e), 0);
	};

	/**
	 * Clean out the HTML of the rich text. 
	 * (Has only effect when not lazy)
	 */
	RichTextEditor.prototype.cleanRichText = function() {
		if (!this._isLazy) {
			var allowedTags = ["p", "b", "i", "u", "sup", "br", "sub", "strike", "s"];
			var allowedEmptyTags = ["br"];
			var allowedAttributes = [];
			var changed = this._handle.summernote('cleanEditable', allowedTags, allowedEmptyTags, allowedAttributes);
			if (changed) {
				$.each(this._onChange, function (index, changeCallback) {
					changeCallback();
				}.bind(this));
			}
			
			// Update max character warning with cleaned content.
			this.setMaxChar(this._setMaxChar);
		}
	};
	
	/**
	 * Set the height.
	 */
	RichTextEditor.prototype.setHeight = function (height) {
		if (this._isLazy) {
			this._lazyPlaceholder.height((height-16)+"px");
		}
		this._height = height;
	};
	
	/**
	 * Disable editing.
	 */
	RichTextEditor.prototype.disable = function () {
		this._disabled = true;
		this._editorWrapper.addClass("Disabled");
		if (this._isLazy) {
			this._lazyPlaceholder.attr("contenteditable", "false");
		} else {
			this._editorWrapper.find('.note-editable').attr('contenteditable', false);
		}
	};
	
	/**
	 * Enable editing.
	 */
	RichTextEditor.prototype.enable = function () {
		this._disabled = false;
		this._editorWrapper.removeClass("Disabled");
		if (this._isLazy) {
			this._lazyPlaceholder.attr("contenteditable", "true");
		} else {
			this._editorWrapper.find('.note-editable').attr('contenteditable', true);
		}
	};

	
	/**
	 * Focus the rich text editor.
	 */
	RichTextEditor.prototype.focus = function () {
		this._makeNotLazy();
		if (!this._isLazy) {
			this._handle.summernote('focus');
			this._handle.summernote('restoreRange');
		}
	};
	
	/**
	 * Blur the editor.
	 */
	RichTextEditor.prototype.blur = function () {
		if (!this._isLazy) {
			this._handle.summernote('saveRange');
			this._handle.summernote('blur');
		}
		// Also clear the current selection.
		if (window.getSelection()) {
			window.getSelection().removeAllRanges();
		} else if (document.selection) {
			document.selection.empty();
		}
	};
	
	/**
	 * Return whether the editor has focus.
	 * 
	 * @returns {Boolean}
	 */
	RichTextEditor.prototype.hasFocus = function () {
		// Return whether the focussed element is inside this "editor wrapper".
		return $.contains(this._editorWrapper[0], document.activeElement);
	};
	
	/**
	 * Get the god damn content.
	 * 
	 * @returns
	 */
	RichTextEditor.prototype.getContent = function () {
		var newContent;
		if (this._isLazy) {
			newContent = this._lazyPlaceholder[0].innerHTML;
		} else {
			newContent = this._handle.summernote('code');
		}
		
		var parsedNewContent = $.parseHTML(newContent);
		// Check if newCotent has one single root tag.
		if (parsedNewContent && parsedNewContent.length > 1) {
			// Create a "body" root tag to contain all the elements.
			var root = $("<body>");
			root.append(parsedNewContent);
			return {
				content: root[0].outerHTML
			};
		} else {
			return {
				content: newContent
			};
		}
	};
	
	/**
	 * Return whether the RichTextEditor is currently displaying a scrollbar or not.
	 */
	RichTextEditor.prototype.hasVerticalScroll = function () {
		if (this._editorWrapper[0].scrollHeight > this._editorWrapper[0].clientHeight) {
			return true;
		} else {
			return false;
		}
	};
	
	/**
	 * Update the content of the editor.
	 * 
	 * @param textData
	 */
	RichTextEditor.prototype.setContent = function (textData) {
		if (this._isLazy) {
			this._lazyPlaceholder.html(textData.content);
		} else {
			this._handle.summernote('code', textData.content);
			this.cleanRichText();
		};
	};
	
	/**
	 * This is going to be called when the editor is shown in the page.
	 */
	RichTextEditor.prototype.shownInPage = function () {
		if (this._setMaxChar) {
			this.setMaxChar(this._setMaxChar);
		}
	};
	
	/**
	 * Set the maximum number of chars
	 * 
	 * @param {Number} - maxChar
	 * @param {Boolean} - isSingleLineMode
	 */
	RichTextEditor.prototype.setMaxChar = function (maxChar) {
		this._setMaxChar = maxChar;
		var actualText = $('<div>').html(this.getContent().content).text();
		var maxCharInt = parseInt(this._setMaxChar);

		if(! this._maxCharDiv){
			this._maxCharDiv = $('<div>', {"class" : "MaxCharIndicator"});
			this._wrapper.append(this._maxCharDiv);
		}

		if (parseInt(this._setMaxChar) < actualText.length) {

			if(!this._maxCharWarningIcon){
				this._maxCharWarningIcon = $("<i>", {"class": "icon icon-normal icon-WCR_Msg-Warning icon-orange", "name": "maxcharwarning"});
				this._maxCharDiv.append(this._maxCharWarningIcon);		
			}
			
			var msg = TextContentStrings.t("PCM_MAX_CHARS")+": " + actualText.length+"/"+maxCharInt;
			if (!this._maxCharWarningTT) {
				this._maxCharWarningTT = new Tooltip(undefined, this._maxCharWarningIcon, $("body"), $("body"), false, msg, undefined, undefined, {color: "#EBEBE4", cssClass : "TextContent-Restricted-Popover", restrictBorder : 8});
			} else {
				this._maxCharWarningTT.setTooltipContent(msg);
			}

			//Avoid overlap if scroll bar is displayed
			if(this.hasVerticalScroll()){
				this._maxCharDiv.css({"right": "25px"});
			} else {
				this._maxCharDiv.css({"right": "5px"});
			}

			this._maxCharWarningIcon.show();
		} else {
			//Hide the max warning icon if is shown already
			if(this._maxCharWarningIcon)
				this._maxCharWarningIcon.hide();
		}
	};
	
	/**
	 * Register an "onFocus" callback.
	 * 
	 * @param callback
	 */
	RichTextEditor.prototype.onFocus = function (callback) {
		this._onFocus.push(callback);
	};
	
	/**
	 * Register an "onBlur" callback.
	 * 
	 * @param callback
	 */
	RichTextEditor.prototype.onBlur = function (callback) {
		this._onBlur.push(callback);
	};
	
	/**
	 * Register an "onChange" callback.
	 * 
	 * @param callback
	 */
	RichTextEditor.prototype.onChange = function (callback) {
		this._onChange.push(callback);
	};
	
	/**
	 * Return the wrapping jQuery element.
	 * @returns
	 */
	RichTextEditor.prototype.getJQElement = function () {
		return this._wrapper;
	};
	
	return RichTextEditor;
});

define('packaging-content-management/text-content-element-widget/SimpleEditor',["jquery", 
        "utils/webi18n!TextContentStrings",
        "component/tooltip/Tooltip",
        "wcr/webcenter_xml"], 
        function ($,
        		TextContentStrings,
        		Tooltip,
        		WCXML) {
	
	var SimpleEditor = function (content) {
		
		// The wrapping div of the editor.
		this._wrapper = $("<div>");
		
		this._editorWrapper = $('<div>', {"class" : "SimpleEditor"});
		this._input = $('<textarea>', {"class" : "SimpleTextArea"}).text(content.content);
		this._editorWrapper.append(this._input);
		this._wrapper.append(this._editorWrapper);
	};
	
	SimpleEditor.prototype.focus = function () {
		this._input.focus();
	};
	
	SimpleEditor.prototype.blur = function () {
		this._input.blur();
	};
	
	SimpleEditor.prototype.onFocus = function (callback) {
		this._input.on("focus", callback);
	};
	
	SimpleEditor.prototype.onBlur= function (callback) {
		this._input.on("blur", callback);
	};
	
	SimpleEditor.prototype.onChange = function (callback) {
		this._input.on("change keyup", callback);
	};
	
	SimpleEditor.prototype.enable = function () {
		this._input.removeProp("readonly");
		this._editorWrapper.removeClass("Disabled");
	};
	
	SimpleEditor.prototype.disable= function () {
		this._input.prop("readonly", "readonly");
		this._editorWrapper.addClass("Disabled");
	};
	
	SimpleEditor.prototype.setHeight = function (height) {
		// Don't do anything.
	};
	
	SimpleEditor.prototype.setContent = function (content) {
		this._input.text(content.content);
	};
	
	/**
	 * This is going to be called when the editor is shown in the page.
	 */
	SimpleEditor.prototype.shownInPage = function () {
		if (this._setMaxChar) {
			this.setMaxChar(this._setMaxChar);
		}
	};
	
	/**
	 * Set the maximum number of chars
	 * 
	 * @param {Number} - maxChar
	 * @param {Boolean} - isSingleLineMode
	 */
	SimpleEditor.prototype.setMaxChar = function (maxChar) {
		this._setMaxChar = maxChar;
		
		var encodedContent = WCXML.xmlencode(this.getContent().content);
		var actualText = $('<div>').html(encodedContent).text();
		var maxCharInt = parseInt(this._setMaxChar);

		if(! this._maxCharDiv){
			this._maxCharDiv = $('<div>', {"class" : "MaxCharIndicator"});
			this._wrapper.append(this._maxCharDiv);
		}

		if (parseInt(this._setMaxChar) < actualText.length) {

			if(!this._maxCharWarningIcon){
				this._maxCharWarningIcon = $("<i>", {"class": "icon icon-normal icon-WCR_Msg-Warning icon-orange", "name": "maxcharwarning"});
				this._maxCharDiv.append(this._maxCharWarningIcon);		
			}
			
			var msg = TextContentStrings.t("PCM_MAX_CHARS")+": " + actualText.length+"/"+maxCharInt;
			if (!this._maxCharWarningTT) {
				this._maxCharWarningTT = new Tooltip(undefined, this._maxCharWarningIcon, $("body"), $("body"), false, msg, undefined, undefined, {color: "#EBEBE4", cssClass : "TextContent-Restricted-Popover", restrictBorder : 8});
			} else {
				this._maxCharWarningTT.setTooltipContent(msg);
			}

			//Avoid overlap if scroll bar is displayed
			if(this.hasVerticalScroll()){
				this._maxCharDiv.css({"right": "25px"});
			} else {
				this._maxCharDiv.css({"right": "5px"});
			}

			this._maxCharWarningIcon.show();
		} else {
			//Hide the max warning icon if is shown already
			if(this._maxCharWarningIcon)
				this._maxCharWarningIcon.hide();
		}
	};
	
	SimpleEditor.prototype.getContent = function () {
		return {
			content: this._input.val()
		};
	};
	
	SimpleEditor.prototype.hasVerticalScroll = function () {
		return this._input[0].scrollHeight > this._input[0].clientHeight;
	};
	
	SimpleEditor.prototype.getJQElement = function () {
		return this._wrapper;
	};

	return SimpleEditor;
	
});

define('packaging-content-management/text-content-element-widget/SmartNameEditor',["jquery",
        "packaging-content-management/ContentConstants",
        "component/smartnames/smartfield/smartnamedictionaryservice",
        "utils/Promisify"], function ($, ContentConstants, SmartNameDictionaryService, Promisify) {
	
	var SmartNameEditor = function (textData) {
		
		this._onFocus = [];
		this._onBlur = [];
		this._onChange = [];
		
		// Variable keeping track of whether the editor is disabled.
		this._isDisabled = false;
		
		// Variable keeping track of whether the editor has focus.
		this._hasFocus = false;
		
		// Variable keeping track of whether the cursor is hovering the editor.
		this._hasHover = false;
			
		// Variable keeping track of whether the smart name popover panel is shown.
		this._isSmartNamePopoverShown = false;
		
		// Variable keeping track of whether the smart name selector popup is shown.
		this._isSmartNameSelectorShown = false;
		
		// Remember the status/smartname/resolved of the text data.
		this._status = textData.status;
		this._smartNameString = textData.smartName;
		this._resolved = textData.content;
		
		// Indicate whether we're showing the smartname or resolved content.
		this._smartNameMode = true;
		
		// The wrapper.
		this._wrapper = $("<div>", {"class" : "SmartNameEditor"});
		
		
		// When an editor is really created, load the smart field.
		var promise = Promisify.require("component/smartnames/smartfield/smartfield").then(function (SmartField) {
			
			// Create the smart field
			var input = $("<input>", {"type" : "text"});
			this._smartField = new SmartField(input, false);
			this._smartField.setWidth("100%");
			
			// Add the smart field
			this._wrapper.append(this._smartField.getJQElement());
			
			// Set the correct content
			if (textData.smartName) {
				this._smartField.setValue(textData.smartName);
			}
			
			// On Focus ...
			this._smartField.onFocus(function () {
				if (this._smartField.isDisabled()) {
					return;
				}
				// Set the variable.
				this._hasFocus = true;
				// Execute the registered callbacks.
				for (var i=0; i < this._onFocus.length; i++) {
					this._onFocus[i]();
				}
				// Update the editor
				this.update();
			}.bind(this));
			
			// On Blur ...
			this._smartField.onBlur(function () {
				// Set the variable.
				this._hasFocus = false;
				// Execute the registered callbacks.
				for (var i=0; i < this._onBlur.length; i++) {
					this._onBlur[i]();
				}
				// Update the editor
				this.update();
			}.bind(this));
			
			// On Change ...
			this._smartField.onValueChange(function (value) {
				if (!this._smartNameMode) {
					// This should never happen.
					return; // Ignore changes when not in smartname mode.
				}
				
				if (value == this._smartNameString) {
					// There is no change happen in smart name string.
					return;
				}
				// Save the smartnamed value internally.
				this._smartNameString = value;
				this._resolved = "";
				this._status = ContentConstants.ResolvedStatus.NOT_RESOLVED;
				this._smartField.setSelectorIcon("normal");
				
				// Execute the registered callbacks.
				for (var i=0; i < this._onChange.length; i++) {
					this._onChange[i]();
				}
			}.bind(this));
			
			// When the smart name button is pressed and the smart name dictionary selector opens ...
			this._smartField.onSmartNameSelectorOpened(function () {
				this._isSmartNameSelectorShown = true;
			}.bind(this));
			
			// When the smart name dictionary selector is closed ...
			this._smartField.onSmartNameSelectorClosed(function () {
				this._isSmartNameSelectorShown = false;
			}.bind(this));
			
			// On Smart Name Popover Shown ...
			this._smartField.onSmartNamePopoverShow(function () {
				this._isSmartNamePopoverShown = true;
			}.bind(this));
			
			// On Smart Name Popover Hide ...
			this._smartField.onSmartNamePopoverHide(function () {
				this._isSmartNamePopoverShown = false;
				this.update();
			}.bind(this));
			
			// Update the smartfield.
			this.update();
			
		}.bind(this));
		
		// Keep track of the loading of the smartfield in this promise object.
		// We make the promise queryable so we can "query" whether the promise is resolved or not.
		this._smartFieldPromise = Promisify.makeQueryable(promise);
		
		// On mouse enter, the editor should show the smartname value.
		this._wrapper.on("mouseenter", function () {
			this._hasHover = true;
			// Update the editor
			this.update();
		}.bind(this));
		
		// On mouse out, the editor should show the resolved value.
		this._wrapper.on("mouseleave", function () {
			// Set the variable.
			this._hasHover = false;
			// Update the editor
			this.update();
		}.bind(this));
	};
	
	/**
	 * Show the smartnamed content in the editor.
	 */
	SmartNameEditor.prototype.update = function () {
	
		// Check whether the smart field was already fetched and created.
		if (this._smartFieldPromise.isResolved()) {
			
			// Check whether the value of the text data is resolved or not ...
			var hasResolvedValue = this._status == ContentConstants.ResolvedStatus.RESOLVED;
			
			// When the input has hover or focus or does not  have a resolved value, switch to smartname mode.
			if (this._hasHover || this._hasFocus || !hasResolvedValue || this._isSmartNamePopoverShown || this._isSmartNameSelectorShown) {
				this._switchToSmartName();
			} else {
				this._switchToResolved();
			}
			
		} else {
			// Only update once the smart field is loaded and created
			this._smartFieldPromise.then(this.update.bind(this));
		};
		
	};
	
	/**
	 * Show the smartnamed content in the editor.
	 */
	SmartNameEditor.prototype._switchToSmartName = function () {
		
		if (this._status == ContentConstants.ResolvedStatus.NOT_RESOLVED) {
			this._smartField.setSelectorIcon("normal");
		} else if (this._status == ContentConstants.ResolvedStatus.FAILED_RESOLVE) {
			this._smartField.setSelectorIcon("warning");
		} else if (this._status == ContentConstants.ResolvedStatus.RESOLVED) {
			this._smartField.setSelectorIcon("resolved");
		}
		
		if (this._smartNameMode) {
			return; // Already in smartname mode.
		}
		
		// Check whether we have a smartname value.
		if (!this._smartNameString) {
			this._smartNameString = "";
		}
		this._smartNameMode = true;
		this._smartField.setValue(this._smartNameString);
		if (!this._isDisabled) {
			this._smartField.enable();
		}
		
		this._wrapper.addClass("SmartNameMode");
	};
	
	SmartNameEditor.prototype._switchToResolved = function () {
		
		if (!this._smartNameMode) {
			return; // Already in resolved mode.
		}
		
		// Check whether we have a resolved value.
		if (!this._resolved) {
			this._resolved = "";
		}
		this._smartNameMode = false;
		this._smartField.blur();
		this._smartField.setValue(this._resolved);
		this._smartField.disable();
		this._smartField.setSelectorIcon("resolved");
		this._wrapper.addClass("ResolvedMode");
	};
	
	SmartNameEditor.prototype.focus = function () {
		// Check whether the smart field was already fetched and created.
		if (this._smartFieldPromise.isResolved()) {
			// The smart field already exists so just focus on it.
			this._smartField.focus();
		} else {
			// Only focus once the smart field is loaded and created
			this._smartFieldPromise.then(this.focus.bind(this));
		};
	};
	
	SmartNameEditor.prototype.blur = function () {
		// Check whether the smart field was already fetched and created.
		if (this._smartFieldPromise.isResolved()) {
			// The smart field already exists so just blur it.
			this._smartField.blur();
		} else {
			// Only blur once the smart field is loaded and created
			this._smartFieldPromise.then(this.blur.bind(this));
		};
	};
	
	SmartNameEditor.prototype.onFocus = function (callback) {
		this._onFocus.push(callback);
	};
	
	SmartNameEditor.prototype.onBlur= function (callback) {
		this._onBlur.push(callback);
	};
	
	SmartNameEditor.prototype.onChange = function (callback) {
		this._onChange.push(callback);
	};
	
	SmartNameEditor.prototype.enable = function () {
		
		// Set the disabled flag on false.
		this._isDisabled = false;
		
		// Check whether the smart field was already fetched and created.
		if (this._smartFieldPromise.isResolved()) {
			// The smart field already exists so just enable it.
			this._smartField.enable();
		} else {
			// Only enable once the smart field is loaded and created
			this._smartFieldPromise.then(this.enable.bind(this));
		};
	};
	
	SmartNameEditor.prototype.disable= function () {
		
		// Set the disabled flag on true.
		this._isDisabled = true;
		
		// Check whether the smart field was already fetched and created.
		if (this._smartFieldPromise.isResolved()) {
			// The smart field already exists so just disable it.
			this._smartField.disable();
		} else {
			// Only disable once the smart field is loaded and created
			this._smartFieldPromise.then(this.disable.bind(this));
		};
	};
	
	SmartNameEditor.prototype.setHeight = function (height) {
		// Don't do anything.
	};
	
	SmartNameEditor.prototype.hasVerticalScroll = function () {
		return false;
	};
	
	SmartNameEditor.prototype.setContent = function (textData) {
		// Remember the status/smartname/resolved of the text data.
		this._status = textData.status;
		this._smartNameString = textData.smartName;
		this._resolved = textData.content;
		// Update the widget.
		this.update();
	};
	
	SmartNameEditor.prototype.getContent = function () {
		return {
			status: this._status,
			smartName: this._smartNameString,
			content: this._resolved
		};
	};
	
	SmartNameEditor.prototype.setMaxChar = function (maxChar) {
		//Not yet supported
	};
	
	/**
	 * This is going to be called when the editor is shown in the page.
	 */
	SmartNameEditor.prototype.shownInPage = function () {
		//Not yet supported
	};

	SmartNameEditor.prototype.getJQElement = function () {
		return this._wrapper;
	};
	
	return SmartNameEditor;
});


define('utils/webcss-text!packaging-content-management/text-content-element-widget/TextContentElementWidgetView.css',[],function () { return '\r\n.w .TextContentElementWidget {\r\n\theight: 120px;\r\n\tposition: relative;\r\n\twidth: 100%;\r\n}\r\n.w .TextContentElementWidget .TextContent-ApprovalCol {\r\n\tposition: absolute;\r\n\tleft: 0px;\r\n\ttop: 0px;\r\n\tbottom: 0px;\r\n\twidth: 60px;\r\n\ttext-align: center;\r\n}\r\n.w .TextContentElementWidget .TextContentElement-Status {\r\n\tvertical-align: middle;\r\n\tcolor: white;\r\n\tpadding: 5px;\r\n\theight: 100%;\r\n\tposition: absolute;\r\n\ttop: 0px;\r\n\tbottom: 0px;\r\n\tleft: 0px;\r\n\tright: 0px;\r\n\tbackground-color: #D3D3D3;\r\n\tborder: 0px;\r\n}\r\n.w .TextContentElementWidget .TextContent-ApprovalStatus {\r\n\tposition: relative;\r\n\ttop: 50%;\r\n\ttransform: translateY(-50%);\r\n\t-webkit-transform: translateY(-50%);\r\n}\r\n.w .TextContentElementWidget .TextContent-StatusIcon i {\r\n\tfont-size: 32px;\r\n\theight: 32px;\r\n\twidth: 32px;\r\n\tdisplay: inline;\r\n}\r\n.w .TextContentElementWidget .ElementStatusDraft {\r\n\tbackground-color: #a7a9ac;\r\n}\r\n.w .TextContentElementWidget .ElementStatusPending {\r\n\tbackground-color: #46b8da;\r\n}\r\n.w .TextContentElementWidget .ElementStatusApproved {\r\n\tbackground-color: #4cae4c;\r\n}\r\n.w .TextContentElementWidget .ElementStatusRejected {\r\n\tbackground-color: #d43f3a;\r\n}\r\n.w .TextContentElementWidget .ElementStatusIconAndLabel {\r\n\tcolor: #fff;\r\n}\r\n.w .TextContentElementWidget .DeleteIconAndLabel {\r\n\tcolor: #5F5F5F;\r\n}\r\n.w .TextContentElementWidget .TextContent-Approval-NextStates {\r\n\tposition: absolute;\r\n\theight: 100%;\r\n\ttop: 0px;\r\n\tbottom: 0px;\r\n\tleft: 0px;\r\n\tright: 0px;\r\n\tborder: 0px;\r\n}\r\n.w .TextContentElementWidget .TextContent-ApprovalAction {\r\n\tcolor: white;\r\n\tcursor: pointer;\r\n}\r\n.w .TextContentElementWidget .ApprovalAction-InnerDiv {\r\n\tposition: relative;\r\n\ttop: 50%;\r\n\ttransform: translateY(-50%);\r\n\t-webkit-transform: translateY(-50%);\r\n}\r\n.w .TextContentElementWidget .ApproveText {\r\n\tbackground-color: #dff0d8;\r\n}\r\n.w .TextContentElementWidget .ApproveText:hover {\r\n\tbackground-color: #c3e3b5;\r\n}\r\n.w .TextContentElementWidget .ApproveTextIconAndLabel {\r\n\tcolor: #3c763d;\r\n}\r\n.w .TextContentElementWidget .RejectText {\r\n\tbackground-color: #ebccd1;\r\n}\r\n.w .TextContentElementWidget .RejectText:hover {\r\n\tbackground-color: #e2b6bd;\r\n}\r\n.w .TextContentElementWidget .RejectTextIconAndLabel {\r\n\tcolor: #a94442;\r\n}\r\n.w .TextContentElementWidget .StartTextApproval {\r\n\tbackground-color: #bce8f1;\r\n}\r\n.w .TextContentElementWidget .StartTextApproval:hover {\r\n\tbackground-color: #96dbe9;\r\n}\r\n.w .TextContentElementWidget .StartTextApprovalIconAndLabel {\r\n\tcolor: #31708f;\r\n}\r\n.w .TextContentElementWidget .RevertTextToDraft {\r\n\tbackground-color: #a7a9ac;\r\n}\r\n.w .TextContentElementWidget .RevertTextToDraft:hover {\r\n\tbackground-color: #96989c;\r\n}\r\n.w .TextContentElementWidget .RevertTextToDraftIconAndLabel {\r\n\tcolor: #e5e6e6;\r\n}\r\n.w .TextContentElementWidget .RevertApprovalAction {\r\n\tbackground-color: #e5e5e5;\r\n\tcursor: pointer;\r\n}\r\n.w .TextContentElementWidget .RevertApprovalAction:hover {\r\n\tbackground-color: #d9d9d9;\r\n}\r\n.w .TextContentElementWidget .RevertApprovalActionIconAndLabel {\r\n\tcolor: #4d4d4d;\r\n}\r\n.w .TextContentElementWidget .TextContent-1ApprovalAction {\r\n\tposition: relative;\r\n\theight: 100%;\r\n}\r\n.w .TextContentElementWidget .TextContent-1ApprovalAction i {\r\n\tfont-size: 32px;\r\n\theight: 32px;\r\n\twidth: 32px;\r\n\tdisplay: inline;\r\n}\r\n.w .TextContentElementWidget .TextContent-2ApprovalActions {\r\n\tposition: relative;\r\n\theight: 50%;\r\n}\r\n.w .TextContentElementWidget .TextContent-2ApprovalActions i {\r\n\tfont-size: 32px;\r\n\theight: 32px;\r\n\twidth: 32px;\r\n\tdisplay: inline;\r\n}\r\n.w .TextContentElementWidget .TextContent-3ApprovalActions {\r\n\tposition: relative;\r\n\theight: 33.33%;\r\n}\r\n.w .TextContentElementWidget .TextContent-3ApprovalActions i {\r\n\tfont-size: 32px;\r\n\theight: 32px;\r\n\twidth: 32px;\r\n\tdisplay: inline;\r\n}\r\n.w .TextContentElementWidget .TextContent-ContentCol {\r\n\tposition: absolute;\r\n\ttop: 0px;\r\n\tleft: 60px;\r\n\tright: 0px;\r\n\tbottom: 0px;\r\n\theight: 100%;\r\n}\r\n.w .TextContentElementWidget .TextContent-InnerContentCol {\r\n\tposition: relative;\r\n\theight: 100%;\r\n\twidth: 100%;\r\n}\r\n.w .TextContentElementWidget .TextContent-TitleRow {\r\n\tposition: absolute;\r\n    top: 0px;\r\n    right: 0px;\r\n    left: 0px;\r\n    height: 33px;\r\n\tcolor: #5f7e7e;\r\n\tbackground-color: #f2f2f2;\r\n\toverflow: hidden;\r\n\tborder-top: 1px solid #dddddd;\r\n\tborder-right: 1px solid #dddddd;\r\n}\r\n.w .TextContentElementWidget .TextHeaderDraft {\r\n\tbackground-color: #f2f2f2;\r\n}\r\n.w .TextContentElementWidget .TextHeaderPending {\r\n\tbackground-color: #eaf8fb;\r\n}\r\n.w .TextContentElementWidget .TextHeaderApproved {\r\n\tbackground-color: #f0f8ed;\r\n}\r\n.w .TextContentElementWidget .TextHeaderRejected {\r\n\tbackground-color: #f8edee;\r\n}\r\n.w .TextContentElementWidget .TextContent-TitleRow .TextContent-Title {\r\n\tfloat: left;\r\n\tpadding: 8px 12px;\r\n}\r\n.w .TextContentElementWidget .TextContent-TitleRow .TextContent-Title img {\r\n\tpadding-right: 5px;\r\n}\r\n.w .TextContentElementWidget .TextContent-TitleRow .TextContent-Action {\r\n\tpadding-top: 8px;\r\n\tpadding-bottom: 7px;\r\n\tpadding-left: 10px;\r\n\tpadding-right: 10px;\r\n\tborder-left: 1px solid #dddddd;\r\n\tfloat: right;\r\n\tcursor: pointer;\r\n}\r\n.w .TextContentElementWidget .TextContent-TitleRow .TextContent-Action i {\r\n\tfont-size: 16px;\r\n\theight: 16px;\r\n\twidth: 16px;\r\n\tdisplay: inline;\r\n}\r\n.w .TextContentElementWidget .TextContent-TitleRow .TextContent-Action:hover {\r\n\tbackground-color: #E5E5E5;\r\n}\r\n.w .TextContentElementWidget .Content-ContentRow {\r\n\tposition: absolute;\r\n\ttop: 33px;\r\n\tleft: 0px;\r\n\tright: 0px;\r\n\tbottom: 0px;\r\n\tborder: 1px solid #dddddd;\r\n\tborder-left: 0px;\r\n\toverflow: hidden;\r\n\tbackground-color: #ffffff;\r\n}\r\n.w .TextContentElementWidget .Content-ContentRow.NotEditable {\r\n\tbackground-color: #f2f2f2;\r\n}\r\n.w .TextContentElementWidget.Selected {\r\n\t-webkit-box-shadow: 0px 0px 3px 0px rgba(0,0,0,0.75);\r\n\t-moz-box-shadow: 0px 0px 3px 0px rgba(0,0,0,0.75);\r\n\tbox-shadow: 0px 0px 3px 0px rgba(0,0,0,0.75);\r\n}\r\n.w .TextContentElementWidget .ContentArea {\r\n\twidth: 100%;\r\n\theight:100%;\r\n\tborder: none;\r\n}\r\n.w .TextContentElementWidget .ContentArea .MaxCharIndicator {\r\n\tposition: absolute;\r\n    bottom: 0px;\r\n    margin-bottom: 4px;\r\n}\r\n.w .TextContentElementWidget .TextComment {\r\n\tposition: absolute;\r\n\ttop: 120px;\r\n\tleft: 60px;\r\n\tcolor: #5f7e7e;\r\n\tborder: 1px solid #dddddd;\r\n\tborder-top: 0px;\r\n\toverflow: hidden;\r\n\tmax-height: 200px;\r\n\theight: auto;\r\n\tpadding: 2px;\r\n\toverflow-y: auto;\r\n\tbackground-color: white;\r\n\tz-index: 100000;\r\n\tright: 0px;\r\n\t-webkit-box-shadow: 0px 4px 3px 2px rgba(0,0,0,0.17);\r\n\t-moz-box-shadow: 0px 4px 3px 2px rgba(0,0,0,0.17);\r\n\tbox-shadow: 0px 4px 3px 2px rgba(0,0,0,0.17);\r\n}\r\n.w .TextContentElementWidget .TextComment .TextComments {\r\n\twidth: 100%;\r\n\tmargin-top: 5px;\r\n\tfont-size: 11px;\r\n}\r\n.w .TextContentElementWidget .TextComment .Comment {\r\n\toverflow: hidden;\r\n}\r\n.w .TextContentElementWidget .TextComment .CommentAuthor {\r\n\tcolor: #5f7e7e;\r\n\tmax-width: 150px;\r\n\tfont-weight: bold;\r\n\tpadding: 0px;\r\n\tpadding-right: 5px;\r\n\tpadding-top: 5px;\r\n\twhite-space: nowrap;\r\n\ttext-overflow: ellipsis;\r\n\toverflow: hidden;\r\n}\r\n.w .TextContentElementWidget .TextComment .CommentContent {\r\n\tcolor: #5f7e7e;\r\n\toverflow: hidden;\r\n\tpadding: 5px;\r\n\tfont-style: italic;\r\n}\r\n.w .TextContentElementWidget .TextComment .CommentText {\r\n\twhite-space: pre-wrap;\r\n}\r\n.w .TextContentElementWidget .TextComment .CommentContent .CommentDate {\r\n\tcolor: #D1D1D1;\r\n\tfont-size: 10px;\r\n}\r\n.w .TextContentElementWidget .TextComment .CommentField {\r\n\tborder: 1px solid #dddddd;\r\n\twidth: 100%;\r\n\theight: 50px;\r\n\tresize: vertical;\r\n}\r\n.w .TextContentElementWidget .TextComment .CommentFieldButton {\r\n\twidth: 100%;\r\n\ttext-align: right;\r\n\tfont-style: normal;\r\n}\r\n.w .TextContentElementWidget .MyApprovalStatus {\r\n\tpadding-top: 9px;\r\n\tfloat: left;\r\n}\r\n.w .TextContentElementWidget .MyApprovalStatus .MyStatusIconStack {\r\n\tposition: relative;\r\n\tdisplay: inline-block;\r\n\twidth: 24px;\r\n\theight: 24px;\r\n\tline-height: 24px;\r\n\tvertical-align: middle;\r\n\tmargin-top: -5px;\r\n}\r\n.w .TextContentElementWidget .MyStatusIconStack i {\r\n\tposition: absolute;\r\n\ttext-align: center;\r\n\tfont-size: 16px;\r\n\twidth: 100%;\r\n\tcursor: default;\r\n}\r\n.w .TextContentElementWidget .MyStatusApprovedIcon {\r\n\tpadding-top: 2px;\r\n\tpadding-left: 4px;\r\n\tcolor: #4CCC4C;\r\n}\r\n.w .TextContentElementWidget .MyStatusRejectedIcon {\r\n\tfont-size: 14px;\r\n\tpadding-top: 3px;\r\n\tpadding-left: 4px;\r\n\tcolor: #FF4C4C;\r\n}\r\n.w .TextContentElementWidget .MyStatusPendingIcon {\r\n\tfont-size: 14px;\r\n\tpadding-top: 0px;\r\n\tpadding-left: 10px;\r\n\ttransform: rotate(45deg);\r\n\tdisplay: inline-block;\r\n\tmargin-top: -2px;\r\n\tcolor: #0600FF;\r\n}\r\n.w .TextContentElementWidget-Restricted-Popover {\r\n\tfont-family: \'Open Sans\', \'Helvetica Neue\', Helvetica, \'hiragino kaku gothic pro\', \'ms pgothic\', Arial;\r\n\tfont-size: 12px;\r\n\tpadding: 4px 8px 4px 8px;\r\n\tcolor: grey;\r\n}\r\nbody > .TextContent-Restricted-Popover > div.content {\r\n\tmargin: 3px;\r\n}\r\n.w .TextContentElementWidget.DocTableXView {\r\n\theight: 78px;\r\n}\r\n.w .TextContentElementWidget.DocTableXView .TextContent-RightCol {\r\n\tcolor: #5f7e7e;\r\n\tbackground-color: #f2f2f2;\r\n\tborder: 1px solid #dddddd;\r\n\tborder-left: 0px;\r\n\twidth: 33px;\r\n\tfloat: right;\r\n\theight: 100%;\r\n}\r\n.w .TextContentElementWidget.DocTableXView .TextContent-ActionDocX {\r\n\tfont-size: 16px;\r\n\ttext-align: center;\r\n\theight: 50%;\r\n\tpadding-top: 8px;\r\n\tcursor: pointer;\r\n}\r\n.w .TextContentElementWidget.DocTableXView .TextContent-ActionBorder {\r\n\tborder-bottom: 1px solid #dddddd;\r\n}\r\n.w .TextContentElementWidget.DocTableXView .TextContent-Action:hover {\r\n\tbackground-color: #E5E5E5;\r\n}\r\n.w .TextContentElementWidget.DocTableXView .TextContent-ContentCol {\r\n\tright: 33px;\r\n\tleft: 40px;\r\n}\r\n.w .TextContentElementWidget.DocTableXView .Content-ContentRow {\r\n\ttop: 0px;\r\n}\r\n.w .TextContentElementWidget.DocTableXView .TextComment {\r\n\ttop: 78px;\r\n\tleft: 40px;\r\n\tright: 33px;\r\n}\r\n.w .TextContentElementWidget.DocTableXView .TextContent-ApprovalCol {\r\n\twidth: 40px;\r\n}\r\n.w .TextContentElementWidget.DocTableXView .TextContent-StatusIcon i {\r\n\tfont-size: 24px;\r\n}\r\n.w .TextContentElementWidget.DocTableXView .ActionIcon-1ApprovalAction i {\r\n\tfont-size: 28px;\r\n\theight: 28px;\r\n\twidth: 28px;\r\n}\r\n.w .TextContentElementWidget.DocTableXView .ActionIcon-2ApprovalActions i {\r\n\tfont-size: 24px;\r\n\theight: 24px;\r\n\twidth: 24px;\r\n}\r\n.w .TextContentElementWidget.DocTableXView .ActionIcon-3ApprovalActions i {\r\n\tfont-size: 20px;\r\n\theight: 20px;\r\n\twidth: 20px;\r\n}\r\n.w .TextContentElementWidget.TableView {\r\n\theight: 78px;\r\n}\r\n.w .TextContentElementWidget.TableView .TextContent-RightCol {\r\n\tcolor: #5f7e7e;\r\n\tbackground-color: #fafafa;\r\n\tborder: 1px solid #dddddd;\r\n\tborder-left: 0px;\r\n\twidth: 33px;\r\n\tfloat: right;\r\n\theight: 100%;\r\n}\r\n.w .TextContentElementWidget.TableView .TextContent-ActionTable {\r\n\tfont-size: 16px;\r\n\ttext-align: center;\r\n\theight: 50%;\r\n\tpadding-top: 8px;\r\n\tcursor: pointer;\r\n\tbackground-color: #fafafa;\r\n}\r\n.w .TextContentElementWidget.TableView .TextContent-ActionTable:hover {\r\n\tbackground-color: #f2f2f2;\r\n}\r\n.w .TextContentElementWidget.TableView .TextContent-ActionBorder {\r\n\tborder-bottom: 1px solid #dddddd;\r\n}\r\n.w .TextContentElementWidget.TableView .TextContent-Action:hover {\r\n\tbackground-color: #E5E5E5;\r\n}\r\n.w .TextContentElementWidget.TableView .TextContent-ContentCol {\r\n\tright: 0px;\r\n\tleft: 40px;\r\n}\r\n.w .TextContentElementWidget.TableView .Content-ContentRow {\r\n\ttop: 0px;\r\n}\r\n.w .TextContentElementWidget.TableView .TextComment {\r\n\ttop: 78px;\r\n\tleft: 40px;\r\n\tright: 33px;\r\n}\r\n.w .TextContentElementWidget.TableView .TextContent-ApprovalCol {\r\n\twidth: 40px;\r\n}\r\n.w .TextContentElementWidget.TableView .TextContent-StatusIcon i {\r\n\tfont-size: 24px;\r\n}\r\n.w .TextContentElementWidget.TableView .ActionIcon-1ApprovalAction i {\r\n\tfont-size: 28px;\r\n\theight: 28px;\r\n\twidth: 28px;\r\n}\r\n.w .TextContentElementWidget.TableView .ActionIcon-2ApprovalActions i {\r\n\tfont-size: 24px;\r\n\theight: 24px;\r\n\twidth: 24px;\r\n}\r\n.w .TextContentElementWidget.TableView .ActionIcon-3ApprovalActions i {\r\n\tfont-size: 20px;\r\n\theight: 20px;\r\n\twidth: 20px;\r\n}\r\n.w .TextContentElementWidget.Viewer {\r\n\tmin-height: 78px;\r\n\theight: 100%\r\n}\r\n.w .TextContentElementWidget.Viewer .TextContent-ContentCol {\r\n\tright: 0px;\r\n\tleft: 50px;\r\n}\r\n.w .TextContentElementWidget.Viewer .Content-ContentRow {\r\n\ttop: 0px;\r\n\tborder-top: 0px;\r\n\tborder-bottom: 0px;\r\n}\r\n.w .TextContentElementWidget.Viewer .TextContent-ApprovalCol {\r\n\twidth: 50px;\r\n}\r\n.w .TextContentElementWidget.Viewer .TextContent-StatusIcon i {\r\n\tfont-size: 24px;\r\n}\r\n.w .TextContentElementWidget.Viewer .ActionIcon-1ApprovalAction i {\r\n\tfont-size: 28px;\r\n\theight: 28px;\r\n\twidth: 28px;\r\n}\r\n.w .TextContentElementWidget.Viewer .ActionIcon-2ApprovalActions i {\r\n\tfont-size: 24px;\r\n\theight: 24px;\r\n\twidth: 24px;\r\n}\r\n.w .TextContentElementWidget.Viewer .ActionIcon-3ApprovalActions i {\r\n\tfont-size: 20px;\r\n\theight: 20px;\r\n\twidth: 20px;\r\n}\r\n.w .TextContentElementWidget .ContentArea  {\r\n\tfont-size: 13px;\r\n}\r\n.w .TextContentElementWidget .ContentArea .RichTextEditor  {\r\n\tpadding-top: 11px;\r\n}\r\n.w .RichTextEditor.Disabled {\r\n\tbackground-color: #f2f2f2;\r\n}\r\n.w .TextContentElementWidget .ContentArea .SimpleEditor {\r\n\theight: 100%\r\n}\r\n.w .TextContentElementWidget .ContentArea .RichTextEditor.Disabled {\r\n\tbackground-color: #f2f2f2;\r\n}\r\n.w .TextContentElementWidget .ContentArea .SimpleEditor .SimpleTextArea {\r\n\toutline: none;\r\n\tborder: 0px;\r\n\twidth: 100%;\r\n\theight: 100%;\r\n\tpadding-top: 11px;\r\n\tresize: none;\r\n}\r\n.w .TextContentElementWidget .ContentArea .SimpleEditor.Disabled > .SimpleTextArea {\r\n\tbackground-color: #f2f2f2;\r\n}\r\n.w .TextContentElementWidget .ContentArea.SmartNameEditor  {\r\n\tpadding-top: 2px;\r\n}\r\n.w .TextContentElementWidget .ContentArea.SmartNameEditor > .SmartField  {\r\n\tpadding-top: 4px;\r\n}\r\n.w .TextContentElementWidget .ContentArea.SmartNameEditor > .SmartField  {\r\n\tpadding-top: 4px;\r\n}\r\n.w .TextContentElementWidget .ContentArea.SmartNameEditor > .SmartField > .input-group .form-control {\r\n\tborder: 0px;\r\n\tbox-shadow: initial;\r\n\tbackground: initial;\r\n}\r\n.w .TextContentElementWidget .ContentArea.SmartNameEditor > .SmartField > .input-group .SmartNameInput {\r\n    background: initial;\r\n}\r\n.w .TextContentElementWidget .ContentArea.SmartNameEditor > .SmartField > .input-group .SmartNameInput .form-control {\r\n    background: initial;\r\n}\r\n.w .TextContentElementWidget .ContentArea.SmartNameEditor > .SmartField > .input-group .ace-smartnamefield.ace_smartinput_disabled {\r\n\tbackground: initial;\r\n}\r\n.w .TextContentElementWidget .ContentArea.SmartNameEditor > .SmartField > .input-group .SmartNameSelector.input-group-addon {\r\n\tborder: 0px;\r\n\tbox-shadow: initial;\r\n\tbackground-color: initial;\r\n}\r\n.w .TextContentElementWidget .ContentArea.SmartNameEditor.ResolvedMode > .SmartField .ace-smartnamefield  {\r\n\tcolor: #797979;\r\n}\r\n.w .TextContentElementWidget .ContentArea.SmartNameEditor.SmartNameMode > .SmartField  {\r\n\t\r\n}\r\n.w .TextContentElementWidget.SingleLineMode {\r\n\theight: 40px;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode .TextContent-Approval-NextStates {\r\n\theight: 40px;\r\n\tz-index: 348;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode .TextContent-Approval-NextStates.TextContent-Approval-Next1State {\r\n\twidth: 40px;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode .TextContent-Approval-NextStates.TextContent-Approval-Next2States {\r\n\twidth: 80px;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode .TextContent-Approval-NextStates.TextContent-Approval-Next3States {\r\n\twidth: 120px;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode .TextContent-Approval-NextStates .TextContent-ApprovalAction {\r\n\twidth: 40px;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode .TextContent-Approval-NextStates .TextContent-1ApprovalAction {\r\n\theight: 100%;\r\n\tfloat: left;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode .TextContent-Approval-NextStates .TextContent-3ApprovalActions {\r\n\theight: 100%;\r\n\tfloat: left;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode .ContentArea .MaxCharIndicator {\r\n\tmargin-bottom: 10px;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode .TextContent-ActionBorder {\r\n\tborder-bottom: 0px;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode .TextContent-ActionBorder {\r\n\tborder-right: 1px solid #dddddd;;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode .TextComment {\r\n    top: 40px;\r\n    right: 66px;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode .TextContent-Approval-NextStates .TextContent-2ApprovalActions {\r\n\theight: 100%;\r\n\tfloat: left;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode.DocTableXView .TextContent-ActionDocX {\r\n\tfloat: left;\r\n\theight: 100%;\r\n\twidth: 32px;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode.DocTableXView .TextContent-RightCol {\r\n\twidth: 66px;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode.DocTableXView .TextContent-ContentCol  {\r\n\tright: 66px;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode.TableView .TextContent-ActionTable {\r\n\tfloat: left;\r\n\theight: 100%;\r\n\twidth: 32px;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode.TableView .TextContent-RightCol {\r\n\twidth: 33px;\r\n}\r\n.w .TextContentElementWidget.SingleLineMode.TableView .TextContent-TableAction i {\r\n\tfont-size: 20px;\r\n\theight: 100%;\r\n\twidth: 16px;\r\n}';});


define('packaging-content-management/text-content-element-widget/TextContentElementWidgetView',["underscore",
        "jquery",
        "utils/webi18n!TextContentStrings",
        "utils/ConvertUtils",
        "../ContentConstants",
        "component/modal/Modal",
        "component/tooltip/Tooltip",
        "./RichTextEditor",
        "./SimpleEditor",
        "./SmartNameEditor",
        "utils/webcss!./TextContentElementWidgetView.css"],
	function (_,
			$,
			TextContentStrings,
			ConvertUtils,
			ContentConstants,
			Modal,
			Tooltip,
			RichTextEditor,
			SimpleEditor,
			SmartNameEditor) {
	
		"use strict";

		/**
		 * Create the default TextContentElementWidgetView.
		 * 
		 * @param {Object} content - The content object from the TextContentElementWidget represented by this widget.
		 * @param {Boolean} isMaster - Flag which specifies whether the language is a Master or Translation
		 * @param {Array} comments - The array of Comment objects from the TextContentElementWidget represented by this widget.
		 * @param {String} state - The state of the TextContentElementWidget represented by this widget.
		 * @param {String} newState - The potential new state of the TextContentElementWidget represented by this widget.
		 * @param {String} languageCode - The language object of the TextContentElementWidget represented by this widget.
		 * @param {Boolean} isContentManagerView - Specifies whether the current user is a Content_Manager
		 * @param {Object} [viewOptions] - An object containing some specific variables indicating how the widget will be rendered.
		 * @param {String} textType - text type as "richtext" or "simple".
		 */
		var TextContentElementWidgetView = function (content, isMaster, comments, state, newState, languageCode, 
				canEdit, whyCanNotEdit, hasEdit, canReview, whyCanNotReview, hasReview, isContentManagerView, 
				viewOptions, textType) {
			
			this._content = content;
			if (!this._content.content) {
				this._content.content = "";
			}
			this._isMaster = isMaster;
			this._comments = comments;
			this._state = state;
			this._newState = newState;
			this._langaugeCode = languageCode;
			this._textType = textType;
			this._canEdit = canEdit;
			this._whyCanNotEdit = whyCanNotEdit;
			this._hasEdit = hasEdit;
			this._canReview = canReview;
			this._whyCanNotReview = whyCanNotReview;
			this._hasReview = hasReview;
			this._isContentManagerView = isContentManagerView;
			
			// Let the viewOptions override the default, extend one these default values.
			this._viewOptions = {
				// Some configuration might override this variable to disable the editing capabilities of this widget.
				editable: true,
				// Some configuration might override this variable to disable the review capabilities of this widget.
				reviewable: true,
				// Whether or not the view supports "single line mode".
				supportSingleLineMode: false,
				// The default height of the content.
				defaultContentHeight: 85
			};
			$.extend(this._viewOptions, viewOptions);
			
			// Variable holding wether we're in single line mode or not.
			this._isSingleLineMode = false;
			
			// If the widgets supports single line mode.
			if (this._viewOptions.supportSingleLineMode) {
				// Listen to the window resize to make sure it's still possible to display it in a single line.
				$( window ).resize(_.debounce(function() {
					this.trySingleLine();
				}.bind(this)).bind(this));
			}
			
			// Define the current height.
			this._contentHeight = this._viewOptions.defaultContentHeight;
			
			//max chars
			this._maxChars = this._viewOptions.maxChars;
			
			// Create the callback arrays
			this._onApproveCallbacks = [];
			this._onRejectCallbacks = [];
			this._onStartApprovalCallbacks = [];
			this._onRevertToDraftCallbacks = [];
			this._onCommentCallbacks = [];
			this._onUndoCallbacks = [];
			this._onApprovalInfoCallbacks = [];
			this._onMainContentCallbacks = [];
			this._onFocus = [];
			this._onBlur = [];			
			
			// callbacks to be executed when the view toggles between the normal or single line mode.
			this._onSingleLineModeToggleCallbacks = [];
			
			// Create the common HTML elements for the view.
			this._approveButton = null;
			this._rejectButton = null;
			this._startApprovalButton = null;
			this._revertToDraftButton = null;
			this._editor = null;
			this._commentTextArea = null;
			this._commentButton = null;
			this._approvalInfoButton = null;
			this._undoButton = null;
			this._customActionButtons = [];
			

			// Wether to show popovers on why the user does not have certain rights. 
			this._showTooltips = true;
			
			// Create the wrapping div of this widget.
			this._wrapper = $("<div>").addClass("TextContentElementWidget");
			
			if(this._viewOptions.widgetview === 'default') {
				// Start constructing the default view
				this._constructView();
			} else {
				return;
			}
		};
		
		/**
		 * Needs to be called when the widget is added to the page.
		 */
		TextContentElementWidgetView.prototype.shownInPage = function () {
			
			// Notify the editor that it was added to the page.
			this._editor.shownInPage();
			
			// When this widget is added to the page, it should try displaying itself in single line mode.
			this.trySingleLine();
			
		};
		
		/**
		 * Try to display this widget as a single line.
		 * 
		 * @param content
		 */
		TextContentElementWidgetView.prototype.trySingleLine = function () {
			
			var wasSingleLineMode = this._isSingleLineMode;
			
			// Only allow if this view does support the single line mode.
			if (this._viewOptions.supportSingleLineMode) {
								
				// Set it on single line mode.
				this._setSingleLineMode(true);
				
				// Check if a scroll bar is showing.
				var showingScroll = this._editor.hasVerticalScroll();
				
				// If a scroll bar is showing, do not show in single line mode.
				if (showingScroll) {
					this._setSingleLineMode(false);
				}
			}
			
			// When we finally from single line mode to normal or vice versa ... execute callbacks for this.
			if (this._isSingleLineMode != wasSingleLineMode) {
				for (var i=0; i < this._onSingleLineModeToggleCallbacks.length; i++) {
					// Call the callback and indicate wether we switched to single line mode or not.
					this._onSingleLineModeToggleCallbacks[i](this._isSingleLineMode);
				}
			}
			
			// Return whether or not we succeeded to go to single line mode.
			return this._isSingleLineMode;
		};
		
		/**
		 * Toggle wether we're in single line mode or not.
		 */
		TextContentElementWidgetView.prototype.setSingleLineMode = function (singleLineMode) {
			
			var wasSingleLineMode = this._isSingleLineMode;
			
			this._setSingleLineMode(singleLineMode);
			
			if (this._isSingleLineMode != wasSingleLineMode) {
				for (var i=0; i < this._onSingleLineModeToggleCallbacks.length; i++) {
					// Call the callback and indicate wether we switched to single line mode or not.
					this._onSingleLineModeToggleCallbacks[i](this._isSingleLineMode);
				}
			}
		};
		
		/**
		 * Toggle wether we're in single line mode or not (without potential callback).
		 */
		TextContentElementWidgetView.prototype._setSingleLineMode = function (singleLineMode) {
			// Only allow if this view does support the single line mode.
			if (this._viewOptions.supportSingleLineMode) {
				
				// Do nothing if we're already in single line mode or not.
				if (singleLineMode == this._isSingleLineMode) {
					return;
				}
				
				// Set wether we're in single line mode or not
				if (singleLineMode) {
					this._wrapper.addClass("SingleLineMode");
					this._contentHeight = 32;
					this._isSingleLineMode = true;
				} else {
					this._wrapper.removeClass("SingleLineMode");
					this._contentHeight = 78;
					this._isSingleLineMode = false;
				}
				this._editor.setHeight(this._contentHeight);
			}
		};
		
		/**
		 * Construct the HTML elements of this view.
		 */
		TextContentElementWidgetView.prototype._constructView = function () {
			
			// Detach custom buttons so that they keep their bindings.
			$.each(this._customActionButtons, function (index, button) {
				button.detach();
			});
			
			// Empty the wrapper.
			this._wrapper.empty();
						
			// Init the elements.
			this._initializeDOMElements();
			
			// create widget elements and append to the wrapper
			this._wrapper.append(
					this._constructApprovalDiv(),
					$('<div>').addClass("TextContent-ContentCol").append(
							$('<div>').addClass("TextContent-InnerContentCol").append(
									this._constructHeaderDiv(),
									this._constructTextDiv()
							)
					),
					this._constructCommentsDiv()
			);
		};
		
		/**
		 * Provides a dialog for Default view to show approval info
		 * @param approvalInfoContent {JQuery} - Approval information as jquery elements
		 */
		TextContentElementWidgetView.prototype.showApprovalInfoDialog = function (approvalInfoContent) {
			// Condition check to avoid creating multiple approval info modal
			if (!this._approvalInfoModal) {
				this._approvalInfoModal = new Modal(approvalInfoContent, {"customClass" : "ApprovalOverviewWidgetModal"});

				this._approvalInfoModal.setTitle(TextContentStrings.t("PCM_APPROVAL_INFO_POPUP_TITLE"));
			} else {
				this._approvalInfoModal.setContent(approvalInfoContent);
			}
			this._approvalInfoModal.open();
		};
		
		/**
		 * Method to update the widget and repaint
		 * 
		 * @param content
		 * @param isMaster
		 * @param comments
		 * @param state
		 * @param newState
		 * @param {String} myApprovalState - The state of the TextContentElementWidget represented by this widget for the current logged in user.
		 * @param languageCode
		 * @param canEdit
		 * @param whyCanNotEdit
		 * @param hasEdit
		 * @param canReview
		 * @param whyCanNotReview
		 * @param hasReview
		 * @param isContentManagerView
		 * @param textType
		 */
		TextContentElementWidgetView.prototype.updateWidgetView = function(textData, isMaster, comments, state, newState, myApprovalState, languageCode, canEdit, whyCanNotEdit, hasEdit, canReview, whyCanNotReview, hasReview, isContentManagerView, textType) {
			
			// These booleans will keep track on when we actually need to reconstruct the view.
			// We want to avoid doing this on "false" updates as this operation is expensive (especially creating the editors).
			
			var reconstructView = false;
			var updateTextData = false;
			
			// Update the content and check if something changed.
			updateTextData = (this._content.content != textData.content) || (this._content.smartName != textData.smartName) || (this._content.status != textData.status);
			this._content = textData;
			
			// Update whether this is a master document and check if something changed.
			reconstructView = reconstructView || this._isMaster != isMaster;
			this._isMaster = isMaster;
				
			// Update the comments and check if something changed.
			reconstructView = reconstructView || this._comments != comments;
			this._comments = comments;
			
			// Update the state of the widget and check if something changed.
			reconstructView = reconstructView || this._state != state;
			this._state = state;
			
			// Update the new state of the widget and check if something changed.
			reconstructView = reconstructView || this._newState != newState;
			this._newState = newState;
			
			// Update the language code of the widget and check if something changed.
			reconstructView = reconstructView || this._langaugeCode != languageCode;			
			this._langaugeCode = languageCode;
			
			// Update the can edit permission of the widget and check if something changed.
			reconstructView = reconstructView || this._canEdit != canEdit;			
			this._canEdit = canEdit;
			
			// Update the has edit permission of the widget and check if something changed.
			reconstructView = reconstructView || this._hasEdit != hasEdit;			
			this._hasEdit = hasEdit;
			
			// Update the no edit reason of the widget and check if something changed.
			reconstructView = reconstructView || this._whyCanNotEdit != whyCanNotEdit;			
			this._whyCanNotEdit = whyCanNotEdit;
			
			// Update the can review permission of the widget and check if something changed.
			reconstructView = reconstructView || this._canReview != canReview;			
			this._canReview = canReview;
			
			// Update the has review permission of the widget and check if something changed.
			reconstructView = reconstructView || this._hasReview != hasReview;			
			this._hasReview = hasReview;
			
			// Update the no review reason of the widget and check if something changed.
			reconstructView = reconstructView || this._whyCanNotReview != whyCanNotReview;			
			this._whyCanNotReview = whyCanNotReview;

			// Update the content manager permission of the widget and check if something changed.
			reconstructView = reconstructView || this._isContentManagerView != isContentManagerView;			
			this._isContentManagerView = isContentManagerView;

			// Update the my approval status of the widget and check if something changed.
			reconstructView = reconstructView || this._myApprovalStatus != myApprovalState;			
			this._myApprovalStatus = myApprovalState;
			
			// Update the text data type of the widget and check if something changed.
			reconstructView = reconstructView || this._textType != textType;			
			this._textType = textType;
			
			// If something critical was actually changed ...
			if (reconstructView) {
				// Construct the view again.
				this._constructView();
			}
			
			// If just the content was updated ...
			if (updateTextData) {
				// Just update the content of the editor.
				this._editor.setContent(this._content);
			}
			
		};
		
		/**
		 * Just update the text data of the widget.
		 */
		TextContentElementWidgetView.prototype.updateTextData = function(textData) {
			this._content = textData;
			this._editor.setContent(this._content);
		};
		
		
		/**
		 * Initialize the DOM elements to repaint the widget
		 */
		TextContentElementWidgetView.prototype._initializeDOMElements = function() {
			
			// Create StartApproval button
			this._startApprovalButton = $('<div>').attr({"name": "startApprovalButton"}).addClass("TextContent-ApprovalAction StartTextApproval").append($('<div>').addClass("ApprovalAction-InnerDiv").append(
					$('<div>').addClass("TextContent-ApprovalSymbol").append($('<i>').addClass("icon icon-WCR_Text-Action-Start").addClass("StartTextApprovalIconAndLabel")))
			);
			
			// Create RevertToDraft button
			this._revertToDraftButton = $('<div>').attr({"name": "revertToDraftButton"}).addClass("TextContent-ApprovalAction RevertTextToDraft").append($('<div>').addClass("ApprovalAction-InnerDiv").append(
					$('<div>').addClass("TextContent-ApprovalSymbol").append($('<i>').addClass("icon icon-WCR_Text-Action-Draft").addClass("RevertTextToDraftIconAndLabel")))
			);
			
			// Create Approve button
			this._approveButton = $('<div>').attr({"name": "approveButton"}).addClass("TextContent-ApprovalAction ApproveText").append($('<div>').addClass("ApprovalAction-InnerDiv").append(
					$('<div>').addClass("TextContent-ApprovalSymbol").append($('<i>').addClass("icon icon-WCR_Text-Action-Approve").addClass("ApproveTextIconAndLabel")))
			);
			
			// Create Reject button
			this._rejectButton = $('<div>').attr({"name": "rejectButton"}).addClass("TextContent-ApprovalAction RejectText").append($('<div>').addClass("ApprovalAction-InnerDiv").append(
					$('<div>').addClass("TextContent-ApprovalSymbol").append($('<i>').addClass("icon icon-WCR_Text-Action-Reject").addClass("RejectTextIconAndLabel")))
			);
			
			// Undo your latest approval
			this._undoButton = $('<div>').attr({"name": "revertButton"}).addClass("RevertApprovalAction TextContent-ApprovalAction TextContent-1ApprovalAction").append($('<div>').addClass("ApprovalAction-InnerDiv").append(
					$('<div>').addClass("TextContent-ApprovalSymbol ActionIcon-1ApprovalAction").append($('<i>').addClass("icon icon-WCR_Revert").addClass("RevertApprovalActionIconAndLabel")))
			);
			
			// Bind events to execute call backs for each action
			
			// Define the callback that should be executed every time a state button get's clicked.
			var onStateClicked = function (state, callbacks) {
				
				// If we're in single line mode, it could be that the editor is moved in order to not get overlapped
				// with the next state options.
				if (this._isSingleLineMode) {
					var editorElement = this._editor.getJQElement();
					editorElement.finish();
					editorElement.animate({marginLeft: '0px'}, 500, 'swing');
				}
				
				// Update the approval column.
				this._deactivateApprovalActions();
				window.setTimeout(function () {
					this._activateApprovalActions();
				}.bind(this), 200);

				// Update the header
				this.updateHeader();
				
				// Run all the necessary call backs
				_.each(callbacks, _.bind(function(callback) {
					callback();
				}, this));
				
			}.bind(this);
			
			// What happens when the approval button is pressed?
			this._approveButton.click(function () {
				onStateClicked(ContentConstants.State.APPROVED, this._onApproveCallbacks);
			}.bind(this));
			
			// What happens when the reject button is pressed?
			this._rejectButton.click(function () {
				onStateClicked(ContentConstants.State.REJECTED, this._onRejectCallbacks);
			}.bind(this));
			
			// What happens when the start approval button is pressed?
			this._startApprovalButton.click(function () {
				onStateClicked(ContentConstants.State.READY_FOR_APPROVAL, this._onStartApprovalCallbacks);
			}.bind(this));
			
			// What happens when the revert to draft button is pressed?
			this._revertToDraftButton.click(function () {
				// Check whether we are reverting from an approved statement ....
				var proceed = true;
				if(this._state === ContentConstants.State.APPROVED){
					var confirmStr = this._isMaster ? TextContentStrings.t("PCM_MASTER_STATE_CHANGED_FROM_SIGNEDOFF_TO_DRAFT") : TextContentStrings.t("PCM_SIGNEDOFF_TO_DRAFT");
					proceed = confirm(confirmStr);
				}
				// Only continue if the user allows to proceed.
				if (proceed) {
					onStateClicked(ContentConstants.State.DRAFT, this._onRevertToDraftCallbacks);
				}
			}.bind(this));
			
			// What happens when somebody clicked undo ...
			this._undoButton.click(function () {
				
				// First run the "undo" call backs.
				_.each(this._onUndoCallbacks, _.bind(function(callback) {
					callback();
				}, this));
				
				// Then the widget should be updated from the controller (e.g. TextContentElementWidgetView will call the update method after it undid the last change).
			}.bind(this));
			
			// Create the comment button
			this._commentButton = $('<div>').attr({"name": "commentButton"}).attr({"title": TextContentStrings.t("PCM_COMMENT")}).addClass("ToggleComment TextContent-Action");
			// On click etc. will be set later as it depends on permissions and whether there are comments.
			
			// Create the comment area
			this._commentTextArea = $('<textarea>').attr({"name": "addCommentTextArea"});
			this._commentTextArea.on("change keyup", _.bind(function(event) {
				var commentText = $.trim($(event.target).val());
				_.each(this._onCommentCallbacks, _.bind(function(commentText, callback) {
					callback(commentText);
				}, this, commentText));
			}, this));
			
			// Create the approval info button
			this._approvalInfoButton = $('<div>').attr({"name": "approvalInfoButton"}).addClass("TextContent-Action").attr({"title": TextContentStrings.t("PCM_APPROVAL_INFO")});
			this._approvalInfoButton.append($('<i>').addClass("icon icon-WCR_Info"));
			
			// What needs to happen when the approval info button is clicked.
			this._approvalInfoButton.on("click", function (){
				// Execute all the call backs ...
				for (var i=0; i < this._onApprovalInfoCallbacks.length; i++) {
					this._onApprovalInfoCallbacks[i]();
				}
			}.bind(this));
			
			// Create the editor.
			if (ContentConstants.TextType.RICHTEXT === this._textType) {
				// Create a rich text editor.
				this._editor = new RichTextEditor(this._content, this._contentHeight);
			} else if (ContentConstants.TextType.SIMPLE === this._textType) {
				// Create a simple text editor.
				this._editor = new SimpleEditor(this._content);
			} else if (ContentConstants.TextType.SMARTNAME === this._textType) {
				// Create a smartname text editor.
				this._editor = new SmartNameEditor(this._content);
			}
			
			// Set the height of the editor.
			this._editor.setHeight(this._contentHeight);
			
			if(this._maxChars && this._maxChars.length > 0){
				this._editor.setMaxChar(this._maxChars);
			}
			
			// Add the class
			this._editor.getJQElement().addClass("ContentArea");
			// Register content change event in rich text editor
			this._editor.onChange(_.bind(function () {
				var content = this._editor.getContent();
				this._executeContentChange(content);
			}, this));
			// Register Focus and Blur event in the rich text editor.
			this._editor.onFocus(_.bind(function () {
				if (this._canEdit) {
					$.each(this._onFocus, function (i, callback) {
						callback();
					});
				}
			}, this));
			this._editor.onBlur(_.bind(function () {
				$.each(this._onBlur, function (i, callback) {
					callback();
				});
			}, this));
		};
		
		
		
		/**
		 * Method is to update content if its actually changed.
		 * @param currentContent {String} - content from content area
		 */
		TextContentElementWidgetView.prototype._executeContentChange = function(currentContent) {
			
			// Findout whether the content was changed.
			var contentChanged = false;
			if (ContentConstants.TextType.SMARTNAME === this._textType) {
				contentChanged = currentContent.smartName != this._content.smartName;
			} else {
				contentChanged = currentContent.content != this._content.content;
			}
			
			// Avoid update if content is not modified
			if (contentChanged) {
				_.each(this._onMainContentCallbacks, _.bind(function(currentContent, callback) {
					callback(currentContent);
				}, this, currentContent));
				
				// Update current text data value to this object also. 
				this._content = currentContent;
				
				// If single line mode is supported ... try to show it in a single line.
				if (this._viewOptions.supportSingleLineMode) {
					this.trySingleLine();
				}
				
				if(this._maxChars && this._maxChars.length > 0){
					this._editor.setMaxChar(this._maxChars, this._isSingleLineMode);
				}
			}
		};
		
		/**
		 * Set the language indicator of the view.
		 * 
		 * @param language - language object {langCode, langDesc, langFlag}
		 */
		TextContentElementWidgetView.prototype.setLanguage = function (language) {
			
			// Remember the language object for this textContentElementWidget
			if (language) {
				this._language = language;
			}
			
			// Update the header.
			this.updateHeader();
		};
		
		/**
		 * Set the maximum number of chars
		 */
		TextContentElementWidgetView.prototype.setMaxChar = function (maxChar) {
			this._maxChars = maxChar;
			this._editor.setMaxChar(this._maxChars);
		};
		
		/**
		 * Allow other widget to add custom buttons to this widget.
		 * 
		 * @param button
		 */
		TextContentElementWidgetView.prototype.addCustomActionButton = function(button) {
			this._customActionButtons.push(button);
			button.insertBefore(this._headerDiv.find(".ActionCloser"));
		};
		
		/**
		 * Allow other widgets to remove custom buttons from this widget
		 * 
		 * @param button
		 */
		TextContentElementWidgetView.prototype.removeCustomActionButton = function(button) {
			//TODO: to remove the buttons one by one
		};		
		
		/**
		 * Construct the approval column of the widget
		 * @returns approvalDiv - approval column container
		 */
		TextContentElementWidgetView.prototype._constructApprovalDiv = function () {
			
			// Create the approval column and passing true to allow creation of approval actions.
			this._approvalCol = this._constructApprovalColumn(true);
			
			// Activate the approval column (put a little delay).
			window.setTimeout(function () {
				this._activateApprovalActions();
			}.bind(this), 200);
			
			
			return this._approvalCol;
		};
		
		
		/**
		 * Construct the approval column of the widget
		 * 
		 * @param constructApprovalAction {boolean} - Flag to identify whether approval action needs to be created.
		 * @returns approvalDiv - approval column container
		 */
		TextContentElementWidgetView.prototype._constructApprovalColumn = function (constructApprovalAction) {
			
			// A wrapper column containing two additional overlapping columns.
			this._approvalCol = $('<div>').addClass("TextContent-ApprovalCol");
			this._approvalStatusCol = this._constructElementStatus(constructApprovalAction);
			this._approvalActionCol = $('<div>').attr({"name": "TextContent-ActionsDiv"}).addClass("TextContent-Approval-NextStates");

			// Add the current status
			this._approvalCol.append(this._approvalStatusCol);
			
			// If true, then create next approval action or undo action for approval column.
			if (constructApprovalAction) {
				// If no approval action is taken add approval buttons, add revert button otherwise
				if(!this._newState) {
					this._approvalActionCol = this._constructApprovalActions();
					this._approvalCol.append(this._approvalActionCol);
				} else {
					// If new state is not equal to deleted then create undo action.
					if (ContentConstants.State.DELETED != this._newState) {
						this._approvalActionCol = this._constructUndoAction();
						this._approvalCol.append(this._approvalActionCol);
					}
				}
			}
			
			return this._approvalCol;
		};
		
		/**
		 * Creates hover and mouseleave event listeners for the actions
		 */
		TextContentElementWidgetView.prototype._deactivateApprovalActions = function() {
			
			// Only do this when there are approval actions available to the element ...
			if (!this._hasAction) {
				return;
			}
			
			var curState = this._approvalCol.find("div[name='TextContent-StatusDiv']");
			var actions = this._approvalCol.find("div[name='TextContent-ActionsDiv']");
			
			// Stop the animations
			curState.finish();
			actions.finish();
			this._editor.getJQElement().finish();
			this._editor.getJQElement().css("margin-left","0px");
			
			// Make sure the 
			this._approvalCol.unbind('mouseenter mouseleave');
			
			this._approvalCol.remove();
			
			// Since approval column is not going to be activated, so pass false to avoid creation of approval action.
			this._constructApprovalColumn(false);
			this._wrapper.prepend(this._approvalCol);
		};
		
		/**
		 * Creates hover and mouseleave event listeners for the actions
		 */
		TextContentElementWidgetView.prototype._activateApprovalActions = function() {
			
			// Only do this when there are approval actions available to the element ...
			if (!this._hasAction) {
				return;
			}
			
			// Create a handler when mouseover element status to view approval actions
			if (!this._actionsDivHandlerIn) {
				this._actionsDivHandlerIn = _.bind(function () {
					
					// Get the actions and curState elements.
					var curState = this._approvalCol.find("div[name='TextContent-StatusDiv']");
					var actions = this._approvalCol.find("div[name='TextContent-ActionsDiv']");
					
					// Don't do anything when there are no actions.
					if (actions.length == 0) {
						return;
					}
					
					// There are actions ...
					
					// Fade-in the actions.
					curState.finish();
					actions.finish();
					curState.animate({opacity: 0}, 400, 'swing');
					actions.animate({opacity: 1}, 400, 'swing');
					actions.show();
					
					// If we're in single line mode, we need to move the editor so it does not get overlapped
					// with the actions.
					if (this._isSingleLineMode) {
						// Figure out how far the actions will span.
						var offset = 0;
						if (actions.hasClass("TextContent-Approval-Next2States")) {
							offset = 40;
						} else if (actions.hasClass("TextContent-Approval-Next3States")) {
							offset = 80;
						}
						var editorElement = this._editor.getJQElement();
						editorElement.finish();
						if (offset > 0) {
							editorElement.animate({'marginLeft': offset+'px'}, 500);
						}
					}
				}, this);
			}
						
			// Create a handler when mouseout element status to hide approval actions
			if (!this._actionsDivHandlerOut) {
				this._actionsDivHandlerOut = _.bind(function () {
					
					// Get the actions and curState elements.
					var curState = this._approvalCol.find("div[name='TextContent-StatusDiv']");
					var actions = this._approvalCol.find("div[name='TextContent-ActionsDiv']");
					
					// Don't do anything when there are no actions.
					if (actions.length == 0) {
						return;
					}
					
					// There are actions ...
					
					// Fade-out the actions.
					curState.finish();
					actions.finish();
					curState.animate({opacity: 1}, 400, 'swing');
					actions.animate({opacity: 0}, 400, 'swing', function () {
						actions.hide();
					});
					
					// If we're in single line mode, it could be that the editor is moved in order to not get overlapped
					// with the next state options.
					if (this._isSingleLineMode) {
						var nextStates = this._wrapper.find(".TextContent-Approval-NextStates");
						// Make sure the editors are in place again.
						var editorElement = this._editor.getJQElement();
						editorElement.finish();
						nextStates.show();
						editorElement.animate({marginLeft: '0px'}, 500, 'swing');
						
					}
				}, this);
			}
			
			// add the hover handler for approval actions
			this._approvalCol.unbind('mouseenter mouseleave');
			this._approvalCol.on("mouseenter", this._actionsDivHandlerIn);
			this._approvalCol.on("mouseleave", this._actionsDivHandlerOut);
		};
		
		/**
		 * Create TextContent status
		 * 
		 * @param constructApprovalAction {boolean} - Flag to identify whether approval action needs to be created.
		 * @returns elementStatusDiv - jQuery element for TextContent status
		 */
		TextContentElementWidgetView.prototype._constructElementStatus = function (constructApprovalAction) {
			var elementStatusDiv = $('<div>').attr({"name": "TextContent-StatusDiv"}).css({'opacity': '1'});
			
			// User is not an editor or reviewer and if approval actions are being created then provide default cursor.
			if(!(this._canEdit || this._canReview) || !constructApprovalAction) {
				elementStatusDiv.css({'cursor': 'default'});
			} else {
				elementStatusDiv.css({'cursor': 'pointer'});
			}
			
			var elementStatusIconClass = null;
			var elementStatusClass = null;
			if(!this._newState) { // If no new state is defined, render the current state.
				switch(this._state) {
				case ContentConstants.State.DRAFT:
					elementStatusIconClass = "icon icon-WCR_Text-Status-Draft ElementStatusIconAndLabel";
					elementStatusClass = "TextContentElement-Status ElementStatusDraft";
					break;
				case ContentConstants.State.READY_FOR_APPROVAL:
					if(this._canReview && this._myApprovalStatus === ContentConstants.State.READY_FOR_APPROVAL) {
						elementStatusIconClass = "icon icon-WCR_Text-Status-Pending-You ElementStatusIconAndLabel";
					} else if(this._myApprovalStatus === ContentConstants.State.APPROVED) {
						elementStatusIconClass = "icon icon-WCR_Text-Status-Pending-YouApproved ElementStatusIconAndLabel";
					} else if(this._myApprovalStatus === ContentConstants.State.REJECTED) {
						elementStatusIconClass = "icon icon-WCR_Text-Status-Pending-YouRejected ElementStatusIconAndLabel";
					} else {
						elementStatusIconClass = "icon icon-WCR_Text-Status-Pending ElementStatusIconAndLabel";
					}
					elementStatusClass = "TextContentElement-Status ElementStatusPending";
					break;
				case ContentConstants.State.APPROVED:
					elementStatusIconClass = "icon icon-WCR_Text-Status-Approved ElementStatusIconAndLabel";
					elementStatusClass = "TextContentElement-Status ElementStatusApproved";
					break;
				case ContentConstants.State.REJECTED:
					elementStatusIconClass = "icon icon-WCR_Text-Status-Rejected ElementStatusIconAndLabel";
					elementStatusClass = "TextContentElement-Status ElementStatusRejected";
					break;
				default :
					elementStatusIconClass = "icon icon-WCR_Text-Status-NA ElementStatusIconAndLabel";
					elementStatusClass = "TextContentElement-Status";
					break;	
				}
			} else { // If a new state is defined, render the current state.
				switch(this._newState) {
				case ContentConstants.State.DRAFT:
					elementStatusIconClass = "icon icon-WCR_Text-Action-Draft RevertTextToDraftIconAndLabel";
					elementStatusClass = "TextContentElement-Status RevertTextToDraft";
					break;
				case ContentConstants.State.READY_FOR_APPROVAL:
					elementStatusIconClass = "icon icon-WCR_Text-Action-Start StartTextApprovalIconAndLabel";
					elementStatusClass = "TextContentElement-Status StartTextApproval";
					break;
				case ContentConstants.State.APPROVED:
					elementStatusIconClass = "icon icon-WCR_Text-Action-Approve ApproveTextIconAndLabel";
					elementStatusClass = "TextContentElement-Status ApproveText";
					break;
				case ContentConstants.State.REJECTED:
					elementStatusIconClass = "icon icon-WCR_Text-Action-Reject RejectTextIconAndLabel";
					elementStatusClass = "TextContentElement-Status RejectText";
					break;
				case ContentConstants.State.DELETED:
					elementStatusIconClass = "icon icon-WCR_Text-Status-NA ElementStatusIconAndLabel";
					elementStatusClass = "TextContentElement-Status";
					break;
				default :
					// Exectution should not reach here.
					break;
				}
			}			
			
			// Display the language status
			elementStatusDiv.removeClass().addClass(elementStatusClass).append(
					$('<div>').addClass("TextContent-ApprovalStatus").append(
							$('<div>').addClass("TextContent-StatusIcon").append($('<i>').addClass(elementStatusIconClass)))
			);
			
			return elementStatusDiv;
		};
		
		/**
		 * Create Approval action buttons
		 * 
		 * @returns approvalActionsDiv - jQuery element for approval action buttons
		 */
		TextContentElementWidgetView.prototype._constructApprovalActions = function () {
			var approvalActionsDiv = $('<div>').attr({"name": "TextContent-ActionsDiv"}).addClass("TextContent-Approval-NextStates").css({'display': 'none', 'opacity': '0'});
			
			// Variable keeping track of whether we have actions available.
			this._hasAction = true;
			
			// If the language is ready for approval, show Approve, Reject and RevertToDraft buttons based on the permissions
			if(this._state === ContentConstants.State.READY_FOR_APPROVAL) {
				// If User is have both EDITOR and APPROVER permissions and TextContent is in Pending-Signoff - add Draft, Approve and Reject buttons
				if(this._canReview && this._hasEdit) {
					approvalActionsDiv.append(this._approveButton, this._rejectButton, this._revertToDraftButton);
					approvalActionsDiv.addClass("TextContent-Approval-Next3States");
					approvalActionsDiv.find(".TextContent-ApprovalAction").addClass("TextContent-3ApprovalActions");
					approvalActionsDiv.find(".TextContent-ApprovalSymbol").addClass("ActionIcon-3ApprovalActions");
				}
				// If User can approve - add Approve and Reject buttons
				else if(this._canReview) {
					approvalActionsDiv.append(this._approveButton, this._rejectButton);
					approvalActionsDiv.addClass("TextContent-Approval-Next2States");
					approvalActionsDiv.find(".TextContent-ApprovalAction").addClass("TextContent-2ApprovalActions");
					approvalActionsDiv.find(".TextContent-ApprovalSymbol").addClass("ActionIcon-2ApprovalActions");
				}
				// If the User has EDITOR permission - add the RevertToDraft button
				else if (this._hasEdit) {
					approvalActionsDiv.append(this._revertToDraftButton);
					approvalActionsDiv.addClass("TextContent-Approval-Next1State");
					approvalActionsDiv.find(".TextContent-ApprovalAction").addClass("TextContent-1ApprovalAction");
					approvalActionsDiv.find(".TextContent-ApprovalSymbol").addClass("ActionIcon-1ApprovalAction");
				} else {
					this._hasAction = false;
				}
			}
			else if (this._state === ContentConstants.State.DRAFT) {
				// If the language is in Draft and user has both EDITOR and APPROVER permissions, then add Start Approval & Approve button (User can skip start approval)
				if(this._canEdit && this._canReview) {
					approvalActionsDiv.append(this._approveButton, this._startApprovalButton);
					approvalActionsDiv.addClass("TextContent-Approval-Next2States");
					approvalActionsDiv.find(".TextContent-ApprovalAction").addClass("TextContent-2ApprovalActions");
					approvalActionsDiv.find(".TextContent-ApprovalSymbol").addClass("ActionIcon-2ApprovalActions");
				} 
				// If the language is in Draft and user has EDITOR permission, then add StartApproval button
				else if(this._canEdit) {
					approvalActionsDiv.append(this._startApprovalButton);
					approvalActionsDiv.addClass("TextContent-Approval-Next1State");
					approvalActionsDiv.find(".TextContent-ApprovalAction").addClass("TextContent-1ApprovalAction");
					approvalActionsDiv.find(".TextContent-ApprovalSymbol").addClass("ActionIcon-1ApprovalAction");
				} else {
					this._hasAction = false;
				}
			}
			// If the language is rejected, add a explict move to draft button
			// if the language is approved, and user has content manager permission, then revert draft is possible
			else if((this._hasEdit && this._state === ContentConstants.State.REJECTED) ||
					(this._isContentManagerView && this._state === ContentConstants.State.APPROVED)) {
				approvalActionsDiv.append(this._revertToDraftButton);
				approvalActionsDiv.addClass("TextContent-Approval-Next1State");
				approvalActionsDiv.find(".TextContent-ApprovalAction").addClass("TextContent-1ApprovalAction");
				approvalActionsDiv.find(".TextContent-ApprovalSymbol").addClass("ActionIcon-1ApprovalAction");
			} else {
				this._hasAction = false;
			}
			
			return approvalActionsDiv;
		};
		
		/**
		 * Create the Revert Approval button
		 * @returns approvalActionsDiv - jQuery element for revert approval action button
		 */
		TextContentElementWidgetView.prototype._constructUndoAction = function () {
			this._hasAction = true;
			var approvalActionsDiv = $('<div>').attr({"name": "TextContent-ActionsDiv"}).addClass("TextContent-Approval-NextStates").css({'opacity': '0'});
			approvalActionsDiv.append(this._undoButton);
			return approvalActionsDiv;
		};
		
		
		/**
		 * Construct the header of the widget
		 * 
		 * @returns headerDiv - jQuery element for Language header and other actions
		 */
		TextContentElementWidgetView.prototype._constructHeaderDiv = function () {
			
			// create the header div
			this._headerDiv = $('<div>').addClass("TextContent-TitleRow");
			
			// Add language description div to header
			this._headerDiv.append($('<div>').attr({'name': 'languageDescDiv'}));
			
			// create and append comment button to header
			this._createCommentButton();
			this._headerDiv.append(this._commentButton);
			
			// create and append approval info button to header
			this._headerDiv.append(this._approvalInfoButton);
			
			// Add a custom header div
			for (var i=0; i < this._customActionButtons.length; i++) {
				this._headerDiv.append(this._customActionButtons[i]);
			}
			
			// Clear
			this._headerDiv.append($('<div>').css({'clear': 'both'}).addClass("ActionCloser"));
			
			// Update the header (This will display the language).
			this.updateHeader();
			
			return this._headerDiv;
		};
		
		/**
		 * Update the header
		 */
		TextContentElementWidgetView.prototype.updateHeader = function() {
			
			// Check if we have a header div.
			if (!this._headerDiv) {
				return;
			}
			
			// Update the style of the header based on the state.
			// Get the current state ...
			var state = this._state;
			if (this._newState) {
				state = this._newState;
			}
			var headerClass = null;
			if(ContentConstants.State.DRAFT == state) {
				headerClass = "TextContent-TitleRow TextHeaderDraft";
			} else if(ContentConstants.State.READY_FOR_APPROVAL == state) {
				headerClass = "TextContent-TitleRow TextHeaderPending";
			} else if(ContentConstants.State.APPROVED == state) {
				headerClass = "TextContent-TitleRow TextHeaderApproved";
			} else if(ContentConstants.State.REJECTED == state) {
				headerClass = "TextContent-TitleRow TextHeaderRejected";
			} else {
				headerClass = "TextContent-TitleRow";
			}
			this._headerDiv.removeClass();
			this._headerDiv.addClass(headerClass);
			
			// Update the language.
			if (this._language) {

				// Find the language header and update it with the right label and flag.
				var languageDescDiv = this._headerDiv.find("div[name='languageDescDiv']");
				languageDescDiv.addClass("TextContent-Title");
				
				var languageLabel = null;
				if (this._language.langDesc) {
					languageLabel = this._language.langDesc;
				} else if (this._language.langCode) {
					languageLabel = this._language.langCode;
				} else {
					languageLabel = this._langaugeCode;
				}
				
				languageDescDiv.empty();
				if(this._isMaster) {
					languageDescDiv.append($('<b>').text(languageLabel));
				} else {
					languageDescDiv.append($('<span>').text(languageLabel));
				}
				
				if(this._language.langFlag) {
					languageDescDiv.prepend($('<img>').attr({"src": "images/country_flags/" + this._language.langFlag}));
				}
			}
			
		};
		
		/**
		 * Create comment button
		 */
		TextContentElementWidgetView.prototype._createCommentButton = function() {
			// Add the Comment button based on the permissions
			var commentIcon = null;
			if(this._comments && this._comments.length > 0) {
				commentIcon = "icon icon-WCR_Text-Comment-full";
			} else {
				commentIcon = "icon icon-WCR_Text-Comment-outline";
			}
			this._commentButton.append($('<i>').addClass(commentIcon));
			
			
			if((this._hasEdit || this._hasReview || this._isContentManagerView) || (this._comments && this._comments.length > 0)) {
				// click event handler for comment button
				this._commentButton.click(_.bind(function(event) {
					if(this._commentsDiv.hasClass("commentshidden")) {
						this._showCommentSection();
					} else {
						this._hideCommentSection();
					}
				}, this));
				
				// hide the comments when clicked anywhere on the page except the comment button
				$(document).mouseup(_.bind(function (e) {
					if (!this._commentsDiv.is(e.target) 
							&& this._commentsDiv.has(e.target).length === 0 && !this._commentButton.is(e.target) && !this._commentButton.find("i:first").is(e.target)) {
						// Check if we should hide the comments section.
						if(!this._commentsDiv.hasClass("commentshidden")) {
							this._hideCommentSection();
						}
					}
					e.stopPropagation();
				}, this));
			} else {
				this._commentButton.prop({'disabled': 'disabled'}).css({'cursor': 'not-allowed'});
			}
		};
		
		/**
		 * Show the comments section
		 */
		TextContentElementWidgetView.prototype._showCommentSection = function() {
			this._commentsDiv.removeClass("commentshidden").slideDown(200);
			// Focus on comment text area to allow user to type immediately.
			this._commentTextArea.focus();
		};

		/**
		 * Hide the comments section
		 */
		TextContentElementWidgetView.prototype._hideCommentSection = function() {
			this._commentsDiv.addClass("commentshidden").slideUp(200);
		};

		
		/**
		 * Construct the TextContent area
		 * @returns contentDiv
		 */
		TextContentElementWidgetView.prototype._constructTextDiv = function () {

			// Create the div that will be holding the content.
			this._contentDiv = $('<div>').addClass("Content-ContentRow").attr({"name": "Content-ContentAreaDiv"});

			// Add the text editor to the content div.
			this._contentDiv.append(this._editor.getJQElement());

			// Reset the "editability" tooltip.
			this._nonEditableTooltip = undefined;
			this.applyEditPermission();

			return this._contentDiv;

		};
		
		/**
		 * Apply edit permission if allowed or provide tool tip message on disabled field.
		 */
		TextContentElementWidgetView.prototype.applyEditPermission = function () {
			// We can only edit when you have the edit permission and the state is "DRAFT" or "REJECTED".
			if (!this._canEdit) {
				// Disable content editing.
				this._editor.disable();
				this._contentDiv.addClass("NotEditable");

				// If we can't edit because we lack permissions, say why ...
				var msgTag = undefined;
				if (!this._canEdit) {
					// Get the message tag.
					msgTag = this._whyCanNotEdit;
					// If the state is "EMPTY", make sure the "NO_PCM_PERM_NOT_ADDED" message is shown.
					if (this._state === ContentConstants.State.EMPTY) {
						msgTag = "NO_PCM_PERM_NOT_ADDED";
					}
				} else if (this._state === ContentConstants.State.READY_FOR_APPROVAL) {
					msgTag = "NO_PCM_PERM_EDIT_READY_FOR_APPROVAL";
				} else if (this._canEdit && this._state === ContentConstants.State.EMPTY) {
					msgTag = "NO_PCM_PERM_NOT_ADDED";
				}
				
				// If we have a reason, display it. 
				if (msgTag && this._showTooltips) {
					if (!this._nonEditableTooltip ) {
						// Create the tooltip
						this._nonEditableTooltip = new Tooltip(undefined, this._contentDiv, this._wrapper, $("body"), false, TextContentStrings.t(msgTag), undefined, undefined, {color: "#EBEBE4", cssClass : "TextContent-Restricted-Popover", restrictBorder : 8});
					} else {
						this._nonEditableTooltip.setTooltipContent(TextContentStrings.t(msgTag));
					}
				}
			} else {
				// Enable content editing.
				this._editor.enable();
				this._contentDiv.removeClass("NotEditable");
			}
		};	
		
		/**
		 * update the TextContent area
		 * @param content {"content": content} - An object for the text content statement
		 * @returns textDiv - jQuery element for TextContent textarea
		 */
		TextContentElementWidgetView.prototype.updateContent = function (content) {
			
			// Create an empty content object if none was passed.
			if (!content) {
				content = {content : ""};
			}
			this._content = content;
			
			// Set the content.
			this._editor.setContent(content);
			
			// Make an attempt to show the widget in a single line (if configured so).
			this.trySingleLine();
			
			// Apply the edit permissions again.
			this.applyEditPermission();
		};
		
		
		/**
		 * Construct the comments column of the widget
		 * 
		 * @returns commentDiv - jQuery element for comments column
		 */
		TextContentElementWidgetView.prototype._constructCommentsDiv = function () {
			// If user does not have permissions and there are no existing comments, then do not create comments div
			if((!this._hasEdit && !this._hasReview && !this._isContentManagerView) && (this._comments && this._comments.length === 0)) {
				return;
			}
			
			this._commentsDiv = $('<div>').attr({"name": "commentsDiv"});
			
			// hide the comments initially
			this._commentsDiv.addClass("TextComment commentshidden").hide();
			this._commentsDiv.append(
					$('<table>').addClass("TextComments").append(
							$('<tbody>')
					)
			);
			
			// Show the Add comment content area if the user has permissions to add comment
			if(this._hasEdit || this._hasReview || this._isContentManagerView) {
				this._commentsDiv.find("tbody:first").append($('<tr>').addClass("Comment").append(
						$('<td>').addClass("CommentContent").append(
								$('<div>').addClass("CommentAuthor").text(TextContentStrings.t("PCM_COMMENT_CURRENT_USER")),
								this._commentTextArea.addClass("CommentField").attr({"placeholder": TextContentStrings.t("PCM_ADD_COMMENT_PLACEHOLDER")})
						)
				));
			}
			
			// Add the existing comments to the comments div
			if(this._comments && this._comments.length > 0) {
				var textcomments = $.extend(true, [], this._comments);
				textcomments.reverse();
				
				var newComment = null;
				_.each(textcomments, _.bind(function(comment) {
					if(!comment.isNew) {
						this._commentsDiv.find("tbody:first").append(
								$('<tr>').addClass("Comment").append(
										$('<td>').addClass("CommentContent").append(
												$('<div>').addClass("CommentAuthor").text(comment.user),
												$('<div>').addClass("CommentText").text(comment.content),
												$('<div>').addClass("CommentDate").text(ConvertUtils.getLangFormattedDateAndTime(TextContentStrings, new Date(WCXML.xmlencode(comment.created))))
										)
								)
						);
					} else {
						newComment = comment;
					}
				}, this));
				
				if(newComment) {
					this._commentTextArea.text(newComment.content);
				}
			}
			
			return this._commentsDiv;
		};
		
		/**
		 * Get the localized value for a text content state
		 * 
		 * @param {String} [stateCode] 
		 * @returns {String} [localizedState]
		 */
		TextContentElementWidgetView.prototype._getLocalizedContentState = function(state, myapprovalstatus) {
			var localizedState = state;
			switch (state) {
			case ContentConstants.State.APPROVED:
				localizedState = TextContentStrings.t("PCM_CONTENT_STATUS_APPROVED");
				break;
			case ContentConstants.State.DRAFT:
				localizedState = TextContentStrings.t("PCM_CONTENT_STATUS_DRAFT");
				break;
			case ContentConstants.State.READY_FOR_APPROVAL:
				if(myapprovalstatus === ContentConstants.State.APPROVED) {
					localizedState = TextContentStrings.t("PCM_CONTENT_STATUS_PENDING_YOUAPPROVED");
				} else if(myapprovalstatus === ContentConstants.State.REJECTED) {
					localizedState = TextContentStrings.t("PCM_CONTENT_STATUS_PENDING_YOUREJECTED");
				} else if(myapprovalstatus === ContentConstants.State.READY_FOR_APPROVAL) {
					localizedState = TextContentStrings.t("PCM_CONTENT_STATUS_PENDING_YOUPENDING");
				} else {
					localizedState = TextContentStrings.t("PCM_CONTENT_STATUS_PENDING");
				}
				break;
			case ContentConstants.State.EMPTY:
				localizedState = TextContentStrings.t("PCM_CONTENT_STATUS_EMPTY");
				break;
			case ContentConstants.State.REJECTED:
				localizedState = TextContentStrings.t("PCM_CONTENT_STATUS_REJECTED");
				break;
			default:
				break;
			}
			
			return localizedState;
		};
		
		/**
		 * Get the localized action value for a text content state
		 * 
		 * @param {String} [stateCode] 
		 * @returns {String} [localizedAction]
		 */
		TextContentElementWidgetView.prototype._getLocalizedContentAction = function(state) {
			var localizedAction = state;
			switch (state) {
			case ContentConstants.State.APPROVED:
				localizedAction = TextContentStrings.t("PCM_ACTION_APPROVE");
				break;
			case ContentConstants.State.DRAFT:
				localizedAction = TextContentStrings.t("PCM_ACTION_DRAFT");
				break;
			case ContentConstants.State.READY_FOR_APPROVAL:
				localizedAction = TextContentStrings.t("PCM_ACTION_START_APPROVAL");
				break;
			case ContentConstants.State.REJECTED:
				localizedAction = TextContentStrings.t("PCM_ACTION_REJECT");
				break;
			default:
				break;
			}
			
			return localizedAction;
		};
		
		/**
		 * Select the widget.
		 */
		TextContentElementWidgetView.prototype.select = function (selected) {
			if (selected) {
				this._wrapper.addClass("Selected");
			} else {
				this._wrapper.removeClass("Selected");
			}
		};
		
		/**
		 * Focus on the widget.
		 */
		TextContentElementWidgetView.prototype.focus = function (focus) {
			if (focus) {
				// Focus on the text editor
				this._editor.focus();
			} else {
				// Blur the text editor
				this._editor.blur();
			}
		};
		
		/**
		 * Register a callback to be called on widget focus.
		 */
		TextContentElementWidgetView.prototype.onFocus = function (callback) {
			// Remember the callback
			this._onFocus.push(callback);
		};
		
		/**
		 * Register a callback to be called on widget blur.
		 */
		TextContentElementWidgetView.prototype.onBlur = function (callback) {
			// Remember the callback
			this._onBlur.push(callback);
		};
		
		/**
		 * Enable/Disable the widget.
		 */
		TextContentElementWidgetView.prototype.enable = function (enable, msgTag) {
			// Enable widget.
			if (enable) {
				// Construct the view again to enable widget based on user permissions.
				this._constructView();
			} 
			// Disable widget.
			else {
				// Check which type of editor to disable/enable.
				this._editor.disable();
				this._contentDiv.addClass("NotEditable");
				if(this._customActionDiv)
					this._customActionDiv.hide();
				
				
				// If we have a reason, display it. 
				if (msgTag && this._showTooltips) {
					if (!this._nonEditableTooltip) {
						// Create the tooltip
						this._nonEditableTooltip = new Tooltip(undefined, this._contentDiv, this._wrapper, $("body"), false, TextContentStrings.t(msgTag), undefined, undefined, {color: "#EBEBE4", cssClass : "TextContent-Restricted-Popover", restrictBorder : 8});
					} else {
						this._nonEditableTooltip.setTooltipContent(TextContentStrings.t(msgTag));
					}
				}
				
				// Remove the hover handler for approval actions
				this._deactivateApprovalActions();
				
			}
		};
		
		/**
		 * Return wether or not the widget is in single line mode or not.
		 */
		TextContentElementWidgetView.prototype.isSingleLineMode = function () {
			return this._isSingleLineMode;
		};
		
		/**
		 * Add callback for Start Approval action
		 * @param callback - callback function to perform the start approval action
		 * @returns
		 */
		TextContentElementWidgetView.prototype.onStartApproval = function (callback) {
			return this._onStartApprovalCallbacks.push(callback);
		};
		
		/**
		 * Add callback for Reject action
		 * @param callback - callback function to perform the reject action
		 * @returns
		 */
		TextContentElementWidgetView.prototype.onReject = function (callback) {
			return this._onRejectCallbacks.push(callback);
		};
		
		/**
		 * Add callback for Approve action
		 * @param callback - callback function to perform the approve action
		 * @returns
		 */
		TextContentElementWidgetView.prototype.onApprove = function (callback) {
			return this._onApproveCallbacks.push(callback);
		};
		
		/**
		 * Add callback for Revert to Draft action
		 * @param callback - callback function to perform the revert to draft action
		 * @returns
		 */
		TextContentElementWidgetView.prototype.onRevertToDraft = function (callback) {
			return this._onRevertToDraftCallbacks.push(callback);
		};
		
		/**
		 * Add callback for adding comment
		 * @param - callback function to add comment using comment textarea
		 */
		TextContentElementWidgetView.prototype.onComment = function (callback) {
			return this._onCommentCallbacks.push(callback);
		};
		
		/**
		 * Add callback for when the view toggles single line mode or not.
		 */
		TextContentElementWidgetView.prototype.onSingleLineModeToggle = function (callback) {
			return this._onSingleLineModeToggleCallbacks.push(callback);
		};
		
		/**
		 * Add callback for reverting the approval
		 * @param callback - callback function to revert the approval action (approve/reject/revert-to-draft/start-approval)
		 */
		TextContentElementWidgetView.prototype.onUndoApproval = function (callback) {
			return this._onUndoCallbacks.push(callback);
		};
		
		/**
		 * Add callback that should be executed when the approval info button is clicked.
		 * 
		 * @param callback - callback function to update the textcontent
		 */
		TextContentElementWidgetView.prototype.onApprovalInfo = function (callback) {
			return this._onApprovalInfoCallbacks.push(callback);
		};
		
		/**
		 * Add callback that should be executed when the main content is clicked.
		 * 
		 * @param callback - callback function to update the textcontent
		 */
		TextContentElementWidgetView.prototype.onMainContent = function (callback) {
			return this._onMainContentCallbacks.push(callback);
		};
		
		/**
		 * Method to return the wrapper jQuery element of the widget
		 * 
		 * @returns wrapper - Return the wrapping jquery element.
		 */
		TextContentElementWidgetView.prototype.getJQElement = function () {
			return this._wrapper;
		};
		
		/**
		 * Method to check if the element state is EMPTY
		 * 
		 * @returns {Boolean}
		 */
		TextContentElementWidgetView.prototype.isEmptyElement = function () {
			return this._state === ContentConstants.State.EMPTY;
		};
		
		// Return the constructor.
		return TextContentElementWidgetView;
});

define('packaging-content-management/text-content-element-widget/TextContentElementWidgetDocXView',["underscore",
        "jquery",
        "./TextContentElementWidgetView",
        "../ContentConstants",
        "utils/webi18n!TextContentStrings"],
	function (_,
			$,
			TextContentElementWidgetView,
			ContentConstants,
			TextContentStrings) {
	
		"use strict";

		/**
		 * Create the default TextContentElementWidgetDocXView.
		 * 
		 * @param {Object} text - The content object from the TextContentElementWidget represented by this widget.
		 * @param {Array} comments - The array of Comment objects from the TextContentElementWidget represented by this widget.
		 * @param {String} state - The state of the TextContentElementWidget represented by this widget.
		 * @param {String} language - The language object of the TextContentElementWidget represented by this widget.
		 * @param {Boolean} isContentManagerView - Specifies whether the current user is a Content_Manager
		 * @param {Object} [viewOptions] - An object containing some specific variables indicating how the widget will be rendered.
		 * @param {String} markedApprovalState - Approval action taken if any, Current status otherwise
		 * @param {String} textType - text type as "richtext" or "simple".
		 */
		var TextContentElementWidgetDocXView = function (text, isMaster, comments, state, newState, languageCode, 
				canEdit, whyCanNotEdit, hasEdit, canReview, whyCanNotReview, hasReview, isContentManagerView, 
				viewOptions, textType) {
			
			// This view always supports single line mode.
			viewOptions.supportSingleLineMode = true;
			
			// By default, the height of the widget is 76px.
			viewOptions.defaultContentHeight  = 76;
			
			// call the parent prototype object to inherit properties
			TextContentElementWidgetView.call(this, text, isMaster, comments, state, newState, languageCode, 
					canEdit, whyCanNotEdit, hasEdit, canReview, whyCanNotReview, hasReview, isContentManagerView, 
					viewOptions, textType);
			
			// call the overridden function to render the doctablex view of the widget
			this._constructView();
		};
		
		TextContentElementWidgetDocXView.prototype = Object.create(TextContentElementWidgetView.prototype);
		TextContentElementWidgetDocXView.prototype.constructor = TextContentElementWidgetDocXView;
		TextContentElementWidgetDocXView.prototype.parent = TextContentElementWidgetView.prototype;
		
		/**
		 * Construct the HTML elements of this view.
		 * 
		 */
		TextContentElementWidgetDocXView.prototype._constructView = function () {
			this._wrapper.empty();
			this._wrapper.addClass("DocTableXView");
			
			// Init the elements.
			this._initializeDOMElements();
			
			// create widget elements and append to the wrapper
			this._wrapper.append(
					this._constructApprovalDiv(),
					$('<div>').addClass("TextContent-ContentCol TextContent-ContentColDocX").append(
							$('<div>').addClass("TextContent-InnerContentCol").append(
									this._constructTextDiv()
							)
					),
					this._constructRightColDiv(),
					this._constructCommentsDiv()
			);
			
			// Update css for TextContent textarea div
			$("div[name='Content-ContentAreaDiv']", this._wrapper).addClass("Content-ContentRowDocX");
			
			// Update css for comments div
			$(".TextComment", this._wrapper).addClass("TextCommentDocX");
		};
		
		/**
		 * Construct the right column with comment, approval info, mystatus buttons
		 * 
		 * @returns rightPanel - jQuery element for the right side actions column of the widget
		 */
		TextContentElementWidgetDocXView.prototype._constructRightColDiv = function() {
			var rightPanel = $('<div>').addClass("TextContent-RightCol");
			
			// If the element status is empty - don't add comment, approvalinfo, mystatus buttons
			if(!this.isEmptyElement()) {
				this._createCommentButton();
				rightPanel.append(this._commentButton.removeClass().addClass("TextContent-ActionDocX TextContent-ActionBorder"));
				rightPanel.append(this._approvalInfoButton.removeClass().addClass("TextContent-ActionDocX"));
			}
			
			return rightPanel;
		};
		
		/**
		 * Show the comments section
		 */
		TextContentElementWidgetDocXView.prototype._showCommentSection = function() {
			
			// When showing the comments section in the last row of the DocTableX, it could be hidden as DocTableX hides vertical overflow.
			// Check if this is the case and otherwise make some room by adding some padding to the bottom row. 
			// (While not ideal, it's the best place for this at the moment).
			
			// Select the DocTableX row in which this widget is sitting.
			var docXRow = this._wrapper.closest("tbody.DocEntry");
			// Check if we found a row and wether it's the last row of the table.
			if (docXRow.length > 0 && docXRow.is(':last-child')) {
				// Get the DocTableX cell in which this widget is sitting.
				var parentCell = this._wrapper.parent();
				// Make sure we found a cell.
				if (parentCell.length > 0 && parentCell.prop("tagName").toLowerCase() == "td") {
					// Set the bottom padding to the height of the comments div to make place for it.
					docXRow.find("> tr:first-child > td").css({
						"padding-bottom" : this._commentsDiv.height()+6+"px"
					});	
				}
			}
			
			this._commentsDiv.removeClass("commentshidden").slideDown(200);
		};

		/**
		 * Hide the comments section
		 */
		TextContentElementWidgetDocXView.prototype._hideCommentSection = function() {
			
			// When showing the comments section in the last row of the DocTableX, it could be hidden as DocTableX hides vertical overflow.
			// Check if this is the case and otherwise make some room by adding some padding to the bottom row.
			// When hiding the comment section we need to remove that space again.
			
			// Select the DocTableX row in which this widget is sitting.
			var docXRow = this._wrapper.closest("tbody.DocEntry");
			// Check if we found a row and wether it's the last row of the table.
			if (docXRow.length > 0 && docXRow.is(':last-child')) {
				// Get the DocTableX cell in which this widget is sitting.
				var parentCell = this._wrapper.parent();
				// Make sure we found a cell.
				if (parentCell.length > 0 && parentCell.prop("tagName").toLowerCase() == "td") {
					// Reset the bottom padding of 6px.
					docXRow.find("> tr:first-child > td").css({
						"padding-bottom" : ""
					});	
				}
			}
			this._commentsDiv.addClass("commentshidden").slideUp(200);
		};
		
		
		return TextContentElementWidgetDocXView;	
});

define('packaging-content-management/text-content-element-widget/TextContentElementWidgetViewerView',["underscore",
        "jquery",
        "./TextContentElementWidgetView",
        "../ContentConstants",
        "utils/webi18n!TextContentStrings"],
	function (_,
			$,
			TextContentElementWidgetView,
			ContentConstants,
			TextContentStrings) {
	
		"use strict";

		/**
		 * Create the TextContentElementWidgetViewerView.
		 * 
		 * @param {Object} text - The content object from the TextContentElementWidget represented by this widget.
		 * @param {Array} comments - The array of Comment objects from the TextContentElementWidget represented by this widget.
		 * @param {String} state - The state of the TextContentElementWidget represented by this widget.
		 * @param {String} language - The language object of the TextContentElementWidget represented by this widget.
		 * @param {Boolean} isContentManagerView - Specifies whether the current user is a Content_Manager
		 * @param {Object} [viewOptions] - An object containing some specific variables indicating how the widget will be rendered.
		 * @param {String} markedApprovalState - Approval action taken if any, Current status otherwise
		 * @param {String} textType - text type as "richtext" or "simple".
		 */
		var TextContentElementWidgetViewerView = function (text, isMaster, comments, state, newState, languageCode, 
				canEdit, whyCanNotEdit, hasEdit, canReview, whyCanNotReview, hasReview, isContentManagerView, 
				viewOptions, textType) {
			
			// This view always supports single line mode.
			viewOptions.supportSingleLineMode = false;
			
			// By default, the height of the widget is 76px.
			viewOptions.defaultContentHeight  = 76;
			
			// call the parent prototype object to inherit properties
			TextContentElementWidgetView.call(this, text, isMaster, comments, state, newState, languageCode, 
					canEdit, whyCanNotEdit, hasEdit, canReview, whyCanNotReview, hasReview, isContentManagerView, 
					viewOptions, textType);
			
			// Do not show tooltips in the viewer.
			this._showTooltips = false;
			
			// call the overridden function to render the doctablex view of the widget
			this._constructView();
		};
		
		TextContentElementWidgetViewerView.prototype = Object.create(TextContentElementWidgetView.prototype);
		TextContentElementWidgetViewerView.prototype.constructor = TextContentElementWidgetViewerView;
		TextContentElementWidgetViewerView.prototype.parent = TextContentElementWidgetView.prototype;
		
		/**
		 * First override the content height before executing the initializeDOMElements method.
		 */
		TextContentElementWidgetViewerView.prototype._initializeDOMElements = function () {
			this._contentHeight = 76;
			TextContentElementWidgetView.prototype._initializeDOMElements.call(this);
		};
		
		/**
		 * Construct the HTML elements of this view.
		 */
		TextContentElementWidgetViewerView.prototype._constructView = function () {
			this._wrapper.empty();
			this._wrapper.addClass("Viewer");
			this._wrapper.addClass("enableTextSelection");
			
			// Init the elements.
			this._initializeDOMElements();
			
			// create widget elements and append to the wrapper
			this._wrapper.append(
					this._constructApprovalDiv(),
					$('<div>').addClass("TextContent-ContentCol").append(
							$('<div>').addClass("TextContent-InnerContentCol").append(this._constructTextDiv())
					)
			);
		};
		
		return TextContentElementWidgetViewerView;
		
});

define('packaging-content-management/text-content-element-widget/TextContentElementWidgetTableView',["underscore",
        "jquery",
        "./TextContentElementWidgetView",
        "../ContentConstants",
        "utils/webi18n!TextContentStrings"],
	function (_,
			$,
			TextContentElementWidgetView,
			ContentConstants,
			TextContentStrings) {
	
		"use strict";

		/**
		 * Create the default TextContentElementWidgetTableView.
		 * 
		 * @param {Object} text - The content object from the TextContentElementWidget represented by this widget.
		 * @param {Array} comments - The array of Comment objects from the TextContentElementWidget represented by this widget.
		 * @param {String} state - The state of the TextContentElementWidget represented by this widget.
		 * @param {String} language - The language object of the TextContentElementWidget represented by this widget.
		 * @param {Boolean} isContentManagerView - Specifies whether the current user is a Content_Manager
		 * @param {Object} [viewOptions] - An object containing some specific variables indicating how the widget will be rendered.
		 * @param {String} markedApprovalState - Approval action taken if any, Current status otherwise
		 * @param {String} textType - text type as "richtext" or "simple".
		 */
		var TextContentElementWidgetTableView = function (text, isMaster, comments, state, newState, languageCode, 
				canEdit, whyCanNotEdit, hasEdit, canReview, whyCanNotReview, hasReview, isContentManagerView, 
				viewOptions, textType) {
			
			// This view always supports single line mode.
			viewOptions.supportSingleLineMode = true;
			
			// By default, the height of the widget is 76px.
			viewOptions.defaultContentHeight  = 76;
			
			// call the parent prototype object to inherit properties
			TextContentElementWidgetView.call(this, text, isMaster, comments, state, newState, languageCode, 
					canEdit, whyCanNotEdit, hasEdit, canReview, whyCanNotReview, hasReview, isContentManagerView, 
					viewOptions, textType);
			
			// call the overridden function to render the doctablex view of the widget
			this._constructView();
			
			// Add some extra styling on focus and blur.
			this.onFocus(function () {
				this.select(true);
			}.bind(this));
			this.onBlur(function () {
				this.select(false);
			}.bind(this));
		};
		
		TextContentElementWidgetTableView.prototype = Object.create(TextContentElementWidgetView.prototype);
		TextContentElementWidgetTableView.prototype.constructor = TextContentElementWidgetTableView;
		TextContentElementWidgetTableView.prototype.parent = TextContentElementWidgetView.prototype;
		
		/**
		 * Construct the HTML elements of this view.
		 * 
		 */
		TextContentElementWidgetTableView.prototype._constructView = function () {
			
			// Detach custom buttons so that they keep their bindings.
			$.each(this._customActionButtons, function (index, button) {
				button.detach();
			});
			
			// Empty the wrapper.
			this._wrapper.empty();
			this._wrapper.addClass("TableView");
			
			// Init the elements.
			this._initializeDOMElements();
			
			// Create widget elements and append to the wrapper
			this._approvalDiv = this._constructApprovalDiv();
			this._textDiv = this._constructTextDiv();
			this._contentColDiv = $('<div>').addClass("TextContent-ContentCol");
			this._customActionDiv = this._constructCustomActionDiv();
			this._wrapper.append(
				this._approvalDiv, this._contentColDiv.append(
						$('<div>').addClass("TextContent-InnerContentCol").append(this._textDiv)
				),
				this._customActionDiv
			);
			
			// Figure out the style for the actions div.
			if (this._customActionButtons.length > 0) {
				this._contentColDiv.css("right", "33px");
				this._customActionDiv.show();
			} else {
				this._contentColDiv.css("right", "0px");
				this._customActionDiv.hide();
			}
			
			// Update css for TextContent textarea div
			$("div[name='Content-ContentAreaDiv']", this._wrapper).addClass("Content-ContentRowDocX");
			
			// Update css for comments div
			$(".TextComment", this._wrapper).addClass("TextCommentDocX");
		};
		
		/**
		 * Add a custom action button a part for the view that will hold custom actions.
		 */
		TextContentElementWidgetTableView.prototype.addCustomActionButton = function(button) {
			this._customActionButtons =[button];
			this._contentColDiv.css("right", "33px");
			this._customActionDiv.empty();
			this._customActionDiv.append(button);
			this._customActionDiv.show();
		};
		
		/**
		 * Removes all a custom action buttons.
		 */
		TextContentElementWidgetTableView.prototype.removeCustomActionButton = function() {			
			//Remove the button from the array of buttons
			this._customActionButtons.length = 0;
			this._contentColDiv.css("right", "0px");
			this._customActionDiv.hide();
			this._customActionDiv.empty();			
		};
		
		/**
		 * Create a part for the view that will hold custom actions.
		 */
		TextContentElementWidgetTableView.prototype._constructCustomActionDiv = function() {
			var customActionWrapper = $('<div>').addClass("TextContent-RightCol");
			for (var i=0; i < this._customActionButtons.length; i++) {
				customActionWrapper.append(this._customActionButtons[i]);
			}
			return customActionWrapper;
		};
		
		return TextContentElementWidgetTableView;	
});


define('tpl!packaging-content-management/text-content-element-widget/ApprovalOverviewWidgetView', function(){return function(d){
var __t,__p='',__j=Array.prototype.join,print=function(){__p+=__j.call(arguments,'');};
__p+='<table class="table ApprovalOverviewTable">\r\n	<tbody>\r\n	';
 if (d.approvals != undefined && d.approvals.length != 0) { 
__p+='\r\n		';
 _.each(d.approvals, function(approval, index){ 
__p+='\r\n			<tr>\r\n				<td style="text-align: left;">\r\n					';
 if (approval.state == "draft") { 
__p+='\r\n					<i class="icon icon-WCR_Text-Status-Draft" style="color: #a7a9ac"></i>&nbsp;\r\n					<span>'+
((__t=(d.i18n("PCM_STATUS_MARK_DRAFT")))==null?'':_.escape(__t))+
'</span>\r\n					';
 } else if (approval.state == "ready-for-approval") { 
__p+='\r\n					<i class="icon icon-WCR_Text-Status-Pending" style="color: #46b8da"></i>&nbsp;\r\n					<span>'+
((__t=(d.i18n("PCM_START_APPROVAL")))==null?'':_.escape(__t))+
'</span>\r\n					';
 } else if (approval.state == "signed-off") { 
__p+='\r\n					<i class="icon icon-WCR_Text-Status-Approved" style="color: #4cae4c"></i>&nbsp;\r\n					<span>'+
((__t=(d.i18n("PCM_APPROVE")))==null?'':_.escape(__t))+
'</span>\r\n					';
 } else if (approval.state == "signoff-rejected") { 
__p+='\r\n					<i class="icon icon-WCR_Text-Reject" style="color: #d43f3a"></i>&nbsp;\r\n					<span>'+
((__t=(d.i18n("PCM_REJECT")))==null?'':_.escape(__t))+
'</span>\r\n					';
 } 
__p+='\r\n				</td>\r\n				<td>\r\n					'+
((__t=(approval.user))==null?'':_.escape(__t))+
'\r\n				</td>\r\n				<td style="text-align: right;">\r\n					'+
((__t=(approval.ts))==null?'':_.escape(__t))+
'\r\n				</td>\r\n			</tr>\r\n		';
 }); 
__p+='\r\n	';
 } else { 
__p+='\r\n		<tr>\r\n			<td colspan="3">'+
((__t=(d.i18n("PCM_NO_ONGOING_APPROVAL_CYCLE")))==null?'':_.escape(__t))+
'</td>\r\n		</tr>\r\n	';
 } 
__p+='\r\n	</tbody>\r\n</table>';
return __p;
}});

define('utils/webcss-text!packaging-content-management/text-content-element-widget/ApprovalOverviewWidgetStyle.css',[],function () { return '.w .ApprovalOverviewWidgetModal > .modal-dialog > .modal-content > .modal-body {\r\n\tmargin:0px;\r\n\tpadding: 0px;\r\n}\r\n.w .ApprovalOverviewWidgetModal .table.ApprovalOverviewTable {\r\n\tborder:0px;\r\n}\r\n.w .ApprovalOverviewWidgetModal .table.ApprovalOverviewTable > tbody > tr:first-child > td {\r\n\tborder:0px;\r\n}\r\n.w .ApprovalOverviewWidgetModal .table.ApprovalOverviewTable >  tbody > tr > td {\r\n\tpadding:15px;\r\n}';});


define('packaging-content-management/text-content-element-widget/ApprovalOverviewWidgetView',["underscore",
        "jquery",
        "Template",
        "utils/ConvertUtils",
        "tpl!./ApprovalOverviewWidgetView",
        "utils/webi18n!TextContentStrings",
        "../ContentConstants",
        "utils/webcss!./ApprovalOverviewWidgetStyle.css"],
	function (_, 
			$,
			Template, 
			ConvertUtils,
			tpl,
			textContentStrings,
			ContentConstants,
			ApprovalOverviewWidgetStyle) {
		
		"use strict";

		/**
		 * Create a widget to display the approval overview. 
		 */
		var ApprovalOverviewWidgetView = function (approvals) {
			
			this._callbacks = [];
			
			this._approvalsArr = [];
			// Create the wrapper.
			this._wrapper = $("<div>");
			
			// Create the template
			this._t = new Template(textContentStrings, tpl);
			
			// Add the template to the wrapper.
			this._t.setContext(this._wrapper);
			
			for (var i = 0; i < approvals.length; i++) {
				var formattedTime = ConvertUtils.getLangFormattedDateAndTime(textContentStrings, new Date(approvals[i].ts));
				var approvalObj = {'state':approvals[i].state, 'ts':formattedTime, 'user':approvals[i].user};
				this._approvalsArr.push(approvalObj);
			}
			
			// Assign the formatted approvals in the template
			this._t.d.approvals = this._approvalsArr;
			
			// Render
			this._t.render();
			
		};
		
		ApprovalOverviewWidgetView.prototype.update = function (approvals) {
			// Update the approvals in the template.
			this._t.d.approvals = approvals;
			// Render
			this._t.render();
		};
		
		ApprovalOverviewWidgetView.prototype.getJQElement = function () {
			return this._wrapper;
		};
		
		return ApprovalOverviewWidgetView;
});

define('packaging-content-management/text-content-element-widget/ApprovalOverviewWidget',["underscore",
        "jquery",
        "./ApprovalOverviewWidgetView",
        "utils/webi18n!TextContentStrings",
        "../ContentConstants"],
	function (_, 
			$,
			ApprovalOverviewWidgetView,
			TextContentStrings,
			ContentConstants) {
		
		"use strict";

		/**
		 * Create a widget to display the approval overview. 
		 */
		var ApprovalOverviewWidget = function (contentStatementElement) {
			
			this._csElement = contentStatementElement;
			this._view = new ApprovalOverviewWidgetView(this._csElement.pastApprovals);
		};
		
		ApprovalOverviewWidget.prototype.update = function () {
			this._view.update(this._csElement.approval);
		};
		
		ApprovalOverviewWidget.prototype.getJQElement = function () {
			return this._view.getJQElement();
		};
		
		return ApprovalOverviewWidget;
});

define('packaging-content-management/PCMEventBus',["jquery",
        "underscore",
        "lib/EventEmitter2"],
		function($, _,	EventEmitter2) {
			
		"use strict";
		
		if (!window.pcmEventBus) {
			window.pcmEventBus = new EventEmitter2({
				wildcard: true, // should the event emitter use wildcards.
				delimiter: '.', // the delimiter used to segment namespaces,
				newListener: true // if you want to emit the newListener event
			});
			
			window.pcmEventBus.setMaxListeners(999); 
		}
		
		return window.pcmEventBus;
});

define('packaging-content-management/text-content-element-widget/TextContentElementWidget',["underscore",
        "jquery",
        "./TextContentElementWidgetView",
        "./TextContentElementWidgetDocXView",
        "./TextContentElementWidgetViewerView",
        "./TextContentElementWidgetTableView",
        "../text-content-services/languageService",
        "../text-content-services/elementTypeService",
        "../text-content-utils/LanguageUtils",
        "./ApprovalOverviewWidget",
        "utils/webi18n!TextContentStrings",
        "../ContentConstants",
        "../PCMEventBus"],
	function (_, 
			$, 
			TextContentElementWidgetView,
			TextContentElementWidgetDocXView,
			TextContentElementWidgetViewerView,
			TextContentElementWidgetTableView,
			languageService,
			elementTypeService,
			LanguageUtils,
			ApprovalOverviewWidget,
			TextContentStrings,
			ContentConstants,
			pcmEventBus) {
		
		"use strict";

		/**
		 * Create a Widget in order to display and potentially edit the contents of a 'TextContentElement'.
		 * 
		 * @param {TextContentElement} textContentElement - The textcontent for this widget.
		 * @param {Object} options - An object containing some variables specifying how the widget should behave.
		 * 
		 */
		var TextContentElementWidget = function (textElement, options) {
			
			this._textElement = textElement;
			this._elementTypeCode = textElement.parentStatement.elementType;
			this._textType = textElement.parentStatement.textType;
			this._options = options;
			
			// Extract the fields from the TextContentElementWidget that are needed for the view.
			var content = this._textElement.content;
			var languageCode = this._textElement.language;
			var comments = this._textElement.comment;
			var state = this._textElement.state;
			var newState = this._textElement.newState;
			var isMaster = this._textElement.master;
			var editPermission = this._textElement.canEdit(this._projMasterLanguages);
			var canEdit = editPermission.allowed; 
			var whyCanNotEdit = editPermission.message;
			var hasEdit = this._textElement.hasEdit().allowed;
			var reviewPermission = this._textElement.canReview(this._projMasterLanguages);
			var canReview = reviewPermission.allowed;
			var whyCanNotReview = reviewPermission.message;
			var hasReview = this._textElement.hasReview().allowed;
			var isContentManagerView = this._textElement.parentStatement.canManage().allowed;

			// Extract the 'viewOptions' from the passed options.
			var viewOptions = {};
			if (this._options && typeof this._options.viewOptions === 'object') {
				viewOptions = this._options.viewOptions;
			}
			
			// callbacks to be executed when any changes happen in the widget
			this._onChangeCallbacks = [];
			
			// callbacks to be executed when the view toggles between the normal or single line mode.
			this._onSingleLineModeToggleCallbacks = [];
			
			// create the view of the widget based on the viewOptions
			switch(viewOptions.widgetview) {
			case 'default':
				this._view = new TextContentElementWidgetView(content, isMaster, comments, state, newState, languageCode, 
						canEdit, whyCanNotEdit, hasEdit, canReview, whyCanNotReview, hasReview, isContentManagerView, 
						viewOptions, this._textType);
				this._setLanguageHeader(isMaster, isContentManagerView);
				break;
			case 'doctablex':
				this._view = new TextContentElementWidgetDocXView(content, isMaster, comments, state, newState, languageCode, 
						canEdit, whyCanNotEdit, hasEdit, canReview, whyCanNotReview, hasReview, isContentManagerView, 
						viewOptions, this._textType);
				break;
			case 'viewer':
				this._view = new TextContentElementWidgetViewerView(content, isMaster, comments, state, newState, languageCode, 
						canEdit, whyCanNotEdit, hasEdit, canReview, whyCanNotReview, hasReview, isContentManagerView, 
						viewOptions, this._textType);
				break;
			case 'table':
				this._view = new TextContentElementWidgetTableView(content, isMaster, comments, state, newState, languageCode, 
						canEdit, whyCanNotEdit, hasEdit, canReview, whyCanNotReview, hasReview, isContentManagerView, 
						viewOptions, this._textType);
				break;
			default:
				break;
			}

			// Specify what should happen on Approval actions
			this._view.onApprove(_.bind(function () {
				this.approve();
			}, this));
			
			this._view.onReject(_.bind(function () {
				this.reject();
			}, this));
			
			this._view.onStartApproval(_.bind(function () {
				this.startApproval();
			}, this));
			
			this._view.onRevertToDraft(_.bind(function () {
				this.revertToDraft();
			}, this));
			
			// Specify what should happen when the approval action is reverted
			this._view.onUndoApproval(_.bind(function() {
				this.undoApproval();
			}, this));
			
			// Specify what should happen when a comment is added/edited
			this._view.onComment(_.bind(function(commentText) {
				this.comment(commentText);			
			}, this));
			
			// What needs to happen when the approval info button is clicked
			this._view.onApprovalInfo(_.bind(function () {
				// Create a new approval overview widget.
				this._aprovalOverviewWidget = new ApprovalOverviewWidget(this._textElement);
				this._view.showApprovalInfoDialog(this._aprovalOverviewWidget.getJQElement(), this._options);
			}, this));
			
			// What needs to happen when content is changed in editor.
			this._view.onMainContent(_.bind(function (content) {
				this.updateCurrentContent(content);
			}, this));
			
			// When the view toggled between single line or normal mode ... execute these callbacks.
			this._view.onSingleLineModeToggle(_.bind(function(isSingleLineMode) {
				for (var i=0; i < this._onSingleLineModeToggleCallbacks.length; i++) {
					this._onSingleLineModeToggleCallbacks[i](isSingleLineMode);
				}
			}, this));
			
			// Also listen on the PCMEventBus for potential changes of the current textcontent.
			pcmEventBus.on("PCM.TextContentElementWidget.update", function(textContent){
				if (this._textElement.parentStatement === textContent) {
					this.update(this._textElement);
				}
			}.bind(this));
			
			pcmEventBus.on("PCM.TextContent.langRemoved", function (textContent, textElement) {
				if (textContent == this._textElement.parentStatement && this._textElement.language === textElement.language) {
					this._textElement = this._textElement.parentStatement.provideElement(textElement.language, textElement.isMaster());
					this.update(this._textElement);
				}
			}.bind(this));
			
			pcmEventBus.on("PCM.TextContent.langAdded", function (textContent, textElement) {
				if (textContent == this._textElement.parentStatement && this._textElement.language === textElement.language) {
					this._textElement = textElement;
					this.update(this._textElement);
				}
			}.bind(this));
			
			// Get master and translation project languages and then only proceed. These languages are static for current view, so it's better to keep them ready in the beginning.
			languageService.getLanguages(textElement.parentStatement.projectId, _.bind(function (projMastLangs, projTransLangs) {
				
				this._projMasterLanguages = projMastLangs;
				this._pronTranslationLanguages = projTransLangs;
			
				this.update(this._textElement);
				
			}, this));
			
		};
		
		/**
		 * Needs to be called when the widget is added to the page.
		 */
		TextContentElementWidget.prototype.shownInPage = function () {
			return this._view.shownInPage();
		};
		
		/**
		 * Try to display this widget in single line mode.
		 */
		TextContentElementWidget.prototype.trySingleLine = function () {
			return this._view.trySingleLine();
		};
		
		/**
		 * Approve this element.
		 */
		TextContentElementWidget.prototype.approve = function () {	
			this._textElement.setNewState(ContentConstants.State.APPROVED);
			this._executeOnChange(ContentConstants.OnChangeCallbackType.APPROVED, true);
		};
		
		/**
		 * Reject this element.
		 */
		TextContentElementWidget.prototype.reject = function () {	
			this._textElement.setNewState(ContentConstants.State.REJECTED);
			this._executeOnChange(ContentConstants.OnChangeCallbackType.STARTED_APPROVAL, true);
		};
		
		/**
		 * Start the approval for this element.
		 */
		TextContentElementWidget.prototype.startApproval = function () {	
			this._textElement.setNewState(ContentConstants.State.READY_FOR_APPROVAL);
			this._executeOnChange(ContentConstants.OnChangeCallbackType.STARTED_APPROVAL, true);
		};
		
		/**
		 * Revert the element back to draft.
		 */
		TextContentElementWidget.prototype.revertToDraft = function () {	
			this._textElement.setNewState(ContentConstants.State.DRAFT);
			this._executeOnChange(ContentConstants.OnChangeCallbackType.REVERTED_TO_DRAFT, true);
		};
		
		/**
		 * Undo the last approval action of the element.
		 */
		TextContentElementWidget.prototype.undoApproval = function () {	
			// We assume that an undo action will try to undo the last approval action.
			this._textElement.cancelLastApprovalAction();
			this._executeOnChange(ContentConstants.OnChangeCallbackType.APPROVAL_REVERTED, true);
			return this._textElement;
		};
		
		/**
		 * Add a comment through the widget.
		 */
		TextContentElementWidget.prototype.comment = function (commentText) {	
			// Action to add/update comment
			this._textElement.addTextContentElementComment(commentText);				
			this._executeOnChange(ContentConstants.OnChangeCallbackType.COMMENTED);
		};
		
		/**
		 * Update the content currently in the widget.
		 */
		TextContentElementWidget.prototype.updateCurrentContent = function (currentContent) {
			
			// Findout whether the content was changed.
			var contentChanged = false;
			if (ContentConstants.TextType.SMARTNAME === this._textType) {
				contentChanged = currentContent.smartName != this._textElement.content.smartName;
			} else {
				contentChanged = currentContent.content != this._textElement.content.content;
			}
			
			// Update should be done only if content is actually changed
			if (contentChanged) {
				var notifyOtherWidgets = this._textElement.setTextData(currentContent);
				this._executeOnChange(ContentConstants.OnChangeCallbackType.TEXT_UPDATED, notifyOtherWidgets);
			}			
		};
		
		/**
		 * Resolve the text data in this widget.
		 */
		TextContentElementWidget.prototype.resolve = function (resolvedText) {
			
			if (resolvedText != null) {
				// Create a new resolved textData object for the element and resolve it.
				this._textElement.resolveSmartNamedTextData({
					smartName : this._textElement.getTextData().smartName,
					content : resolvedText,
					status : ContentConstants.ResolvedStatus.RESOLVED
				});
			} else {
				// Create a new resolved textData object for the element and resolve it.
				this._textElement.resolveSmartNamedTextData({
					smartName : this._textElement.getTextData().smartName,
					content : "",
					status : ContentConstants.ResolvedStatus.FAILED_RESOLVE
				});
			}
			
			
			this.focus(false);
			this._view.updateTextData(this._textElement.getTextData());
			this._executeOnChange(ContentConstants.OnChangeCallbackType.TEXT_UPDATED, false);
		};
		
		/**
		 * Make sure the widget is updated with the latest state of the passed TextContentElement.
		 */
		TextContentElementWidget.prototype.update = function (textContentElement) {
			this._textElement = textContentElement;
			
			// Extract the fields from the TextContentElementWidget that are needed for the view.
			var content = textContentElement.content;
			var languageCode = textContentElement.language;
			var comments = textContentElement.comment;
			var state = textContentElement.state;
			var newState = this._textElement.getNewState();
			var myApprovalState = this._textElement.getMyApprovalStatus(this._projMasterLanguages);
			
			var editPermission = textContentElement.canEdit(this._projMasterLanguages);
			var canEdit = editPermission.allowed; 
			var whyCanNotEdit = editPermission.message;
			var hasEdit = textContentElement.hasEdit().allowed;
			
			var reviewPermission = textContentElement.canReview(this._projMasterLanguages);
			var canReview = reviewPermission.allowed;
			var whyCanNotReview = reviewPermission.message;
			var hasReview = textContentElement.hasReview().allowed;
			
			var isMaster = textContentElement.master;
			var isContentManagerView = textContentElement.parentStatement.canManage().allowed;
			var textType = textContentElement.parentStatement.textType;
			
			this._view.updateWidgetView(content, isMaster, comments, state, newState, myApprovalState, languageCode, canEdit, whyCanNotEdit, hasEdit, 
					canReview, whyCanNotReview, hasReview, isContentManagerView, textType);
		};
		
		/**
		 * Update the language header of the widget
		 * 
		 * @param isMaster
		 * @param isContentManagerView
		 */
		TextContentElementWidget.prototype._setLanguageHeader = function(isMaster, isContentManagerView) {
			// Retrieve the languages for this text element.
			var projId = this._textElement.parentStatement.projectId;
			languageService.getAllLanguages(projId, isMaster, function (allLangs) {
				this._view.setLanguage(LanguageUtils.getLangForCode(allLangs, this._textElement.language));
			}.bind(this));
		};
		
		/**
		 * Execute the onchange callback when anything changes in the widget
		 */
		TextContentElementWidget.prototype._executeOnChange = function (changetype, notifyOtherWidgets) {
			
			if (notifyOtherWidgets) {
				// Also listen on the PCMEventBus for potential changes of the current element.
				pcmEventBus.emit("PCM.TextContentElementWidget.update", this._textElement.parentStatement);
			}
			
			_.each(this._onChangeCallbacks, _.bind(function(changetype, callback) {
				callback(changetype, this._textElement);
			}, this, changetype));
		};
		
		/**
		 * Allow other widgets to add custom buttons to the widget.
		 */
		TextContentElementWidget.prototype.addCustomActionButton = function(button) {
			this._view.addCustomActionButton(button);
		};
		
		
		TextContentElementWidget.prototype.removeCustomActionButton = function(button) {
			this._view.removeCustomActionButton(button);
		};
		
		/**
		 * Add callback to be executed when any changes is done in the widget
		 */
		TextContentElementWidget.prototype.onChange = function (callback) {
			this._onChangeCallbacks.push(callback);
		};
		
		/**
		 * Add callback to be executed when the widget is focused.
		 */
		TextContentElementWidget.prototype.onFocus = function (callback) {
			this._view.onFocus(callback);
		};
		
		/**
		 * Add callback to be executed when the widget is blurred.
		 */
		TextContentElementWidget.prototype.onBlur = function (callback) {
			this._view.onBlur(callback);
		};
	
		/**
		 * Add callback for when the view toggles single line mode or not.
		 */
		TextContentElementWidget.prototype.onSingleLineModeToggle = function (callback) {
			return this._onSingleLineModeToggleCallbacks.push(callback);
		};
		
		/**
		 * Return whether or not the widget is in single line mode.
		 */
		TextContentElementWidget.prototype.isSingleLineMode = function () {
			return this._view.isSingleLineMode();
		};
		
		/**
		 * Set whether or not the widget is in single line mode.
		 */
		TextContentElementWidget.prototype.setSingleLineMode = function (isSingleLineMode) {
			return this._view.setSingleLineMode(isSingleLineMode);
		};
		
		/**
		 * Select/Unselect the widget.
		 */
		TextContentElementWidget.prototype.select = function (selected) {
			this._view.select(selected);
		};
		
		/**
		 * Focus/Blur the widget.
		 */
		TextContentElementWidget.prototype.focus = function (focus) {
			this._view.focus(focus);
		};
		
		/**
		 * Disable the widget.
		 */
		TextContentElementWidget.prototype.disable = function (msgTag) {
			this._view.enable(false, msgTag);
		};
		
		/**
		 * Enable the widget.
		 */
		TextContentElementWidget.prototype.enable = function () {
			this._view.enable(true);
		};
		
		/**
		 * Get the current text element
		 */
		TextContentElementWidget.prototype.getTextContentElement = function () {
			return this._textElement;
		};
		
		/**
		 * Set maximum number of chars for this widget
		 */
		TextContentElementWidget.prototype.setMaxChar = function(maxChar) {
			this._view.setMaxChar(maxChar);
		};
		
		/**
		 * Return the jQuery HTML element of the widget
		 * @returns
		 */
		TextContentElementWidget.prototype.getJQElement = function () {
			return this._view.getJQElement();
		};
		
		// Return the constructor.
		return TextContentElementWidget;
		
});

/**
 * ContentStatementElement object
 * @author HUBU
 */
define('web-viewer/textContent/TextElementDynContentWidget',["jquery",
        "packaging-content-management/text-content-element-widget/TextContentElementWidget",
        "packaging-content-management/text-content-services/languageService",
		"packaging-content-management/text-content-utils/LanguageUtils",
		"utils/ShapeUtils",
		"utils/webi18n!viewer"
	],
	function ($,
			TextContentElementWidget,
			languageService,
			languageUtils,
			ShapeUtils,
			i18nViewerStrings) {
		"use strict";
		
		var TextElementDynContentWidget = function (dynContentModel, dynContentPopupModel, textElement) {
			
			this.dynContentModel = dynContentModel;
			this.dynContentPopupModel = dynContentPopupModel;
			this.textElement = textElement;
			this.popup = this.dynContentPopupModel.popup;
			this.transTextElement;

			// Create the wrapping table.
			this._wrapper = $("<table>").css("height","100%").css("width","100%");
			
			// Initialize the widget.
			this.init();
		};
		
		/**
		 * Initialize the widget.
		 */
		TextElementDynContentWidget.prototype.init = function () {

			// Create a TextContentElementWidget.
			this._widget = new TextContentElementWidget(this.textElement, {
				viewOptions: {
					widgetview : "viewer",
					maxChars : this.textElement.getParent().getMaxChars()
				}
			});
			this._widget.onChange(function () {
				// Show the save button if it's not already there.
				if (this._rightOptionCell.has(this._saveButton)) {
					this._rightOptionCell.append(this._saveButton);
				}
				this.dynContentModel.textElementChanged(this.textElement, this);
			}.bind(this));
			// Add the TextContentElementWidget to the wrapper.
			this._masterTextWidgetRow = $("<tr>", {"style" : "height: 100%;"});
			this._masterTextWidgetCell = $("<td>", {"style" : "height: 100%;"});
			this._wrapper.append(this._masterTextWidgetRow.append(this._masterTextWidgetCell.append(this._widget.getJQElement())));
			
			// Add a hidden row to show the header of a potential translation language.
			this._translationHeaderCell = $("<td>");
			this._translationHeaderRow = $("<tr>",{"class" : "TransHeaderRow"}).hide();
			this._wrapper.append(this._translationHeaderRow.append(this._translationHeaderCell));
			
			// Add a hidden row to show the widget of a potential translation language.
			this._transWidget;
			this._translationWidgetCell = $("<td>", {"style" : "height: 100%;"});
			this._translationWidgetRow = $("<tr>", {"style" : "height: 100%;"}).hide();
			this._wrapper.append(this._translationWidgetRow.append(this._translationWidgetCell));
			
			// Create a bottom bar to show additional options.
			this._leftOptionCell = $("<td>", {"class" : "LeftOption"});
			this._rightOptionCell = $("<td>", {"class" : "RightOption"});
			this._optionBar = $("<table>", {"class" : "OptionBar"}).append($("<tr>").append(this._leftOptionCell).append(this._rightOptionCell));
				
			// Add the save button.
			this._saveButton = $("<a>", {"class": "btn btn-default btn-mini btn-success"});
			this._saveButton.append($("<span>", {"class" : "icon icon-WCR_Save12 marginRight5 icon-normal", "style" : "color: #333;"}));
			this._saveButton.append($("<span>").text(i18nViewerStrings.t("PCMDynContentSave")));
			this._saveButton.on("click", function (e) {
				this.dynContentModel.save(this.textElement);
			}.bind(this));
			if (this.textElement.isChanged()) {
				this._rightOptionCell.append(this._saveButton);
			}
			
			
			// Add the option bar to the wrapper.
			this._wrapper.append($("<tr>", {"class" : "OptionRow"}).append($("<td>").append(this._optionBar)));
			
			// Show the option to translate the statement.
			this._updateShowTranslationOption();
			
			// When the translation language changes ... update also the translation option.
			this.dynContentModel.on("translationLangChanged", function () {
				this._updateShowTranslationOption();
				this.hideTranslation();
			}.bind(this));
			
			// When a text element was changed from within a widget.
			this.dynContentModel.on("textElementChanged", function (textElement, fromWidget) {
				if (fromWidget == this) {
					return false;
				}
				if (textElement == this.textElement) {
					this._widget.update(textElement);
					this._rightOptionCell.empty();
					this._rightOptionCell.append(this._saveButton);
					return true;
				} else if (textElement == this.transTextElement) {
					this._transWidget.update(textElement);
					this._rightOptionCell.empty();
					this._rightOptionCell.append(this._saveButton);
					return true;
				}
			}.bind(this));
			
			// Disable the widget when save operation starts.
			this.dynContentModel.on("save.started", function (textElement, fromWidget) {
				// Disable the widgets and buttons.
				if (this._widget) {
					this._widget.disable();
				}
				if (this._transWidget) {
					this._transWidget.disable();
				}
				if (this._saveButton) {
					this._saveButton.prop('disabled', true);
				}
			}.bind(this));
			
			// Enable the widget when save operation finishes.
			this.dynContentModel.on("save.finished", function (textElement, fromWidget) {
				// Disable the widgets and buttons.
				if (this._widget) {
					this._widget.enable();
				}
				if (this._transWidget) {
					this._transWidget.enable();
				}
				if (this._saveButton) {
					this._saveButton.prop('disabled', false);
				}
			}.bind(this));
			
		};
		
		/**
		 * This is going to be called when the widget is shown in the page.
		 */
		TextElementDynContentWidget.prototype.shownInPage = function () {
			this._widget.shownInPage();
		};
		
		/**
		 * Update the widget with a different text element.
		 * 
		 * @param textElement
		 */
		TextElementDynContentWidget.prototype.update = function (textElement) {
			// Update the textElement.
			this.textElement = textElement;
			this.transTextElement = undefined;
			// Re-init the widget.
			this._wrapper.empty();
			this.init();
		};
		
		/**
		 * Show another translation language allong the master language.
		 * 
		 * @param langCode
		 */
		TextElementDynContentWidget.prototype.showTranslation = function (transTextElement) {
			
			// Check if this is a master language.
			if (!this.textElement.isMaster()) {
				return;
			}
			
			// If we're already showing a translation.
			if (this.showingTranslation) {
				return;
			}
			
			// If this is a new transTextElement.
			if (transTextElement != this.transTextElement) {
				this.transTextElement = transTextElement;
				
				// Create a TextContentElementWidget for this translation.
				this._transWidget = new TextContentElementWidget(transTextElement, {
					viewOptions: {
						widgetview : "viewer",
						maxChars : this.textElement.getParent().getMaxChars()
					}
				});
				this._transWidget.onChange(function () {
					// Show the save button if it's not already there.
					if (this._rightOptionCell.has(this._saveButton)) {
						this._rightOptionCell.append(this._saveButton);
					}
					this.dynContentModel.textElementChanged(this.transTextElement, this);
				}.bind(this));
				this._translationWidgetCell.empty();
				this._translationWidgetCell.append(this._transWidget.getJQElement());
				
				// Create a header for this translation.
				languageService.getLanguages(this.textElement.parentStatement.projectId, function(projectMasterLangs, projectTranslationLangs, allMasterLangs, allTranslationLangs) {
					// Get the translang object.
					var language = languageUtils.getLangForCode(allTranslationLangs, transTextElement.language);

					// Generate the language header.
					var transHeader = $("<span>", {"class": "TransHeader"});
					transHeader.append($("<img>", {"src": "./images/country_flags/"+language.langFlag, "style" : "margin-top: -3px; margin-right: 5px;"}));
					transHeader.append($("<span>", {"style":"font-weight: bold"}).text(language.langDesc));
					
					// Add it to the row
					this._translationHeaderCell.empty();
					this._translationHeaderCell.append(transHeader);
				}.bind(this));
				
			} else {
				// This translation language is already set, just show it again.
			}
			
			// Set the variable on true
			this.showingTranslation = true;
			
			// Make room to show the translation.
			this._resizeToShowTranslation();
			
			// Apply the correct CSS to fill.
			this._translationWidgetCell.attr("style", "height: 45%;)");
			this._translationWidgetRow.attr("style", "height: 45%;");
			this._masterTextWidgetRow.attr("style", "height: 45%;");
			this._masterTextWidgetCell.attr("style", "height: 45%;");
			
			// Show/Hide the necessary elements.
			this._translationHeaderRow.show();
			this._translationWidgetRow.show();
			this._hideTransButton.show();
			this._showTransButton.hide();
		};
		
		/**
		 * Hide the translation language for this master language.
		 * 
		 * @param langCode
		 */
		TextElementDynContentWidget.prototype.hideTranslation = function () {
			
			// Check if this is a master language.
			if (!this.textElement.isMaster()) {
				return;
			}
			
			// If we're already hiding the translation.
			if (!this.showingTranslation) {
				return;
			}
			
			// Set the variable on false.
			this.showingTranslation = false;
			
			// Clear room to show only the master text.
			this._resizeToHideTranslation();
			
			// Apply the correct CSS to fill.
			this._translationWidgetCell.attr("style", "height: 100%;");
			this._translationWidgetRow.attr("style", "height: 100%;");
			this._masterTextWidgetRow.attr("style", "height: 100%;");
			this._masterTextWidgetCell.attr("style", "height: 100%;");
			
			// Show/Hide the necessary elements.
			this._translationHeaderRow.hide();
			this._translationWidgetRow.hide();
			this._hideTransButton.hide();
			this._showTransButton.show();
		};
		
		/**
		 * Resize the containing popup so that there's room to show the translation.
		 */
		TextElementDynContentWidget.prototype._resizeToShowTranslation = function () {
			// Only make vertically room.
			var curHeight = this.popup.element.height();
			// How many of that space is taken up by the master text?
			var masterTextHeight = Math.max(curHeight-(26+36+2), 78);
			// We'll have to be carefull to not make the widget to big, therefore ceil the masterTextHeight to 120px;
			var ceiledMasterTextHeight = Math.min(120, masterTextHeight);
			// The new height should be twice the height of the master text + space of the translation header.
			var newHeight = 26 + ceiledMasterTextHeight + 26 + ceiledMasterTextHeight + 36 + 2;
			// Create the new size.
			var newSize = new ShapeUtils.Size(this.popup.element.width()+2, newHeight);
			// Calculate the new min size.
			this.popup.minHeight = this.popup.minHeight + 78 + 26;
			var minSize = new ShapeUtils.Size(this.popup.minWidth, this.popup.minHeight);
			
			// Set the new size.
			this.popup.setMinSize(minSize);
			this.popup.setSize(newSize);
			var ui = {
					position: {
						left: this.popup.element.position().left,
						top: this.popup.element.position().top
					},
					size: {
						width: newSize.width,
						height: newSize.height
					}
				};
			this.popup._fireResized(ui, false);
		};
		
		/**
		 * Resize the containing popup so that room will free up since the translation no longer needs to be shown.
		 */
		TextElementDynContentWidget.prototype._resizeToHideTranslation = function () {
			// Only make vertically room. curHeight = master header (26) + translation header (26) + flag area (36) + text area for two languages (78*2)
			var curHeight = this.popup.element.height();
			// How many space do both texts take up? 
			var bothTextHeight = Math.max(curHeight-(26+26+36), 2*78);
			// We'll have to be carefull to not make the widget to big
			var masterTextHeight = Math.floor(bothTextHeight/2);
			// The new height should be twice the height of the master text + space of the translation flag.
			var newHeight = 26 + masterTextHeight + 36 + 2;
			// Create the new size.
			var newSize = new ShapeUtils.Size(this.popup.element.width()+2, newHeight);			
			// Calculate the new min size.
			this.popup.minHeight = 144;
			var minSize = new ShapeUtils.Size(this.popup.minWidth, this.popup.minHeight);			
			// Set the new size.
			this.popup.setMinSize(minSize);
			this.popup.setSize(newSize);
			var ui = {
					position: {
						left: this.popup.element.position().left,
						top: this.popup.element.position().top
					},
					size: {
						width: newSize.width,
						height: newSize.height
					}
				};
			this.popup._fireResized(ui, false);
		};
		
		
		/**
		 * This will possibly generate a button to display the text of current translation language along with the current master text of this text element.
		 * (Will only show when this is a popup for a master text).
		 */
		TextElementDynContentWidget.prototype._updateShowTranslationOption = function () {
			
			if (this.textElement.isMaster()) {
				// Get the current translation language.
				var curTransLang = this.dynContentModel.getCurrentTransLangCode();
				
				// Check if this master statement has the translation attached of the current translation language.
				var transTextElement = undefined;
				for (var i=0; i < this.textElement.parentStatement.element.length; i++) {
					var aTextElement = this.textElement.parentStatement.element[i];
					if (aTextElement.language == curTransLang && !aTextElement.isMaster()) {
						transTextElement = aTextElement;
						break;
					}
				}
				
				// If such a translation was found, generate a button to show it in this popup.
				if (transTextElement) {
					// Generate the language header.
					languageService.getLanguages(this.textElement.parentStatement.projectId, function(projectMasterLangs, projectTranslationLangs, allMasterLangs, allTranslationLangs) {
						// Find the language object for this text element.
						
						var language = languageUtils.getLangForCode(allTranslationLangs, curTransLang);
						
						// Generate the show translate button.
						this._showTransButton = $("<a>", {"class": "btn btn-default btn-mini"});
						this._showTransButton.append($("<span>").text(i18nViewerStrings.t("PCMDynContentShow")));
						this._showTransButton.append($("<img>", {"src": "./images/country_flags/"+language.langFlag, "style" : "margin-top: -2px; margin-left: 5px;"}));
						
						// Generate the hide translate button.
						this._hideTransButton = $("<a>", {"class": "btn btn-default btn-mini"});
						this._hideTransButton.append($("<span>").text(i18nViewerStrings.t("PCMDynContentHide")));
						this._hideTransButton.append($("<img>", {"src": "./images/country_flags/"+language.langFlag, "style" : "margin-top: -2px; margin-left: 5px;"}));
						this._hideTransButton.hide();
						
						// When the show translate button is clicked.
						this._showTransButton.on("click", function () {
							this.showTranslation(transTextElement);
						}.bind(this));
						
						// When the show translate button is clicked.
						this._hideTransButton.on("click", function () {
							this.hideTranslation();
						}.bind(this));
						
						// Add it.
						this._leftOptionCell.empty();
						this._leftOptionCell.append(this._showTransButton);
						this._leftOptionCell.append(this._hideTransButton);
						
						//if there was already a translation that was opened on canvas, then close that and show the new language that was clicked from filter
						if(this.showingTranslation){
							this.hideTranslation();		
							this.showTranslation(transTextElement);
						}
							
					}.bind(this));
				} else {
									
					this._leftOptionCell.empty();
				}
			} else {
				this._leftOptionCell.empty();
			}
			
		};
		
		/**
		 * Focus on this popup widget.
		 */
		TextElementDynContentWidget.prototype.focus = function (focus) {
			this._widget.focus(focus);
		};
		
		/**
		 * 
		 * @returns
		 */
		TextElementDynContentWidget.prototype.onChange = function (callback) {
			this._widget.onChange(callback);
		};
		
		/**
		 * 
		 * @returns
		 */
		TextElementDynContentWidget.prototype.getJQElement = function () {
			return this._wrapper;
		};
		
		return TextElementDynContentWidget;
});

define('web-viewer/textContent/DynContentPopup',["web-viewer/layout/component/Popup",
		"web-viewer/layout/component/MiniButton",
		"./TextElementDynContentWidget",
		"packaging-content-management/text-content-services/languageService",
		"packaging-content-management/text-content-utils/LanguageUtils",
		"jquery",
		"underscore"
	],
	function (Popup,
		MiniButton,
		TextElementDynContentWidget,
		languageService,
		languageUtils,
		$,
		_) {
		"use strict";

		/**
		 * Create an annotation popup. 
		 * Initial (re)paint should be called by caller
		 * 
		 * @exports DynContentPopup
		 * @memberof TextContentModule
		 * @class
		 * The dyncontent annotation popup controls the popup for dyncontent annotation details
		 * @constructor	  
		 * @augments Layout.Popup
		 * @param {Core.ViewerFacade} f - Viewerfacade
		 * @param {DynContentModel} dynContentModel - The dynamic content model
		 * @param {String} id - Id of the popup used for its private channel
		 * @param {List<DynContentAnnotation>} dynContentAnnotations - DynContentAnnotations this popup belongs to
		 * @param {JQueryObj} container - The container where the popup should stay in
		 */
		var DynContentPopup = function (f, id, dynContentModel, dynContentPopupModel, textElement, container) {
			this.f = f;
			Popup.call(this, f, id, container);

			this.dynContentPopupModel = dynContentPopupModel;
			this.dynContentModel = dynContentModel;
			this.textElement = textElement;
			this.element.addClass("DynContentPopup");

			// By default, the popup is not visible.
			this.visible = false;

			// The text element widget
			this._textElementWidget = undefined;

			this.minWidth = 300;
			this.minHeight = 144;
		};

		DynContentPopup.prototype = Object.create(Popup.prototype);
		DynContentPopup.prototype.constructor = DynContentPopup;

		/**
		 * Initialize the popup, create needed DOM events, listeners
		 * 
		 * @private
		 * @override
		 */
		DynContentPopup.prototype._initialize = function () {
			if (!this._isInitialized) {
				Popup.prototype._initialize.call(this);

				// Generate the language header.
				languageService.getLanguages(this.textElement.parentStatement.projectId, function (projectMasterLangs, projectTranslationLangs, allMasterLangs, allTranslationLangs) {
					// Find the language object for this text element.
					var language;
					if (this.textElement.isMaster()) {
						language = languageUtils.getLangForCode(allMasterLangs, this.textElement.language);
					} else {
						language = languageUtils.getLangForCode(allTranslationLangs, this.textElement.language);
					}

					// Generate the language header.
					var langHeader = $("<span>", {
						"class": "TransHeader"
					});
					langHeader.append($("<img>", {
						"src": "./images/country_flags/" + language.langFlag,
						"style": "margin-top: -3px; margin-right: 5px;"
					}));
					langHeader.append($("<span>", {
						"style": "font-weight: bold"
					}).text(language.langDesc));

					// Add it to the header
					this.header.append(langHeader);
				}.bind(this));

				// Create the TextElementDynContentWidget
				this._textElementWidget = new TextElementDynContentWidget(this.dynContentModel, this.dynContentPopupModel, this.textElement);
				this.setContent(this._textElementWidget.getJQElement());
			}
		};
		
		/**
		 * 
		 * @param location
		 * @param width
		 */
		DynContentPopup.prototype.show = function (location, width) {
			Popup.prototype.show.call(this, location, width);
			this._textElementWidget.shownInPage();
		};

		/**
		 * Update the popup with a new textElement.
		 * 
		 * @param textElement
		 */
		DynContentPopup.prototype.update = function (textElement) {

			// Only update if a different text element is passed.
			if (textElement == this.textElement) {
				return;
			}

			// Set the new text element.
			this.textElement = textElement;
			if (this._textElementWidget) {
				this._textElementWidget.update(textElement);
			}
		};

		/**
		 * Set focus on or off on the widget.
		 */
		DynContentPopup.prototype.focus = function (focus) {
			if (this._textElementWidget) {
				this._textElementWidget.focus(focus);
			}
		};

		return DynContentPopup;
	});

define('web-viewer/textContent/DynContentPopupModel',["web-viewer/viewport/model/ViewportPopupModel",
		"web-viewer/textContent/DynContentPopup",
		"utils/ShapeUtils",
		"underscore"
	],
	function (ViewportPopupModel,
		DynContentPopup,
		ShapeUtils,
		_) {
		"use strict";

		/**
		 * Create a new DynContent Popup Model.
		 * @exports DynContentPopupModel
		 * @memberof TextContentModule
		 * @class
		 * The dyncontent popup model is responsible for a dyncontent popup and its content.
		 * It binds the events of the popup and reacts on them.
		 * @augments Viewport.ViewportPopupModel
		 * @constructor
		 * @param {Core.ViewerFacade} f - Viewerfacade
		 * @param {String} id - Id of the popup model.
		 * @param {DynContentAnnotation} dynContentAnnotation - The dycontent annotation this model belongs to.
		 * @param {DynContentModel} dynContentModel - Model of the dyncontents.
		 */
		var DynContentPopupModel = function (f, id, dynContentAnnotations, dynContentModel) {
			ViewportPopupModel.call(this, f, id);

			this.dynContentAnnotations = dynContentAnnotations;
			this.targetedDynContentAnnotation = dynContentAnnotations[0];
			this.dynContentModel = dynContentModel;
			this.popup = null;

			// When the content of the model changed.
			this.dynContentModel.on("modelContentChanged", function () {
				if (this.popup) {
					this.popup.update(this.targetedDynContentAnnotation.getDynContent().getTextElement());
				}
			}.bind(this));
		};

		DynContentPopupModel.prototype = Object.create(ViewportPopupModel.prototype);
		DynContentPopupModel.prototype.constructor = DynContentPopupModel;

		/**
		 * Repaint the popup
		 */
		DynContentPopupModel.prototype.repaint = function (refDynContentAnnotation) {
			if (this.popup != null) {
				this.popup.repaint(refDynContentAnnotation);
			}
		};

		/**
		 * Set the targeted annotation.
		 */
		DynContentPopupModel.prototype.setTargetAnnotation = function (annotation) {
			this.targetedDynContentAnnotation = annotation;
		};

		/**
		 * Set the targeted annotation.
		 */
		DynContentPopupModel.prototype.focus = function (focus) {
			this.popup.focus(focus);
		};

		/**
		 * @override
		 * This method saves the origin in the annotation.
		 * @param {ShapeUtils.Point} point - Point (origin) of the popup in world coordinates
		 */
		DynContentPopupModel.prototype.onDragged = function (worldPoint) {
			var point = worldPoint.copy();
			point.y -= this.targetedDynContentAnnotation.popuprect.size.height;

			if (!this.targetedDynContentAnnotation.popuprect.origin.equals(point)) {
				this.targetedDynContentAnnotation.popuprect.origin = point;
			}
		};

		/**
		 * @override
		 * This method saves the rectangle in the annotation.
		 * @param {ShapeUtils.Rect} rect - Rectangle (origin/size) of the popup in world coordinates
		 * @param {Boolean} autoAdapted - True if the event is fired because the content was auto adapted (e.g. from a makeMeVisible trigger from an element in the content), false otherwise
		 */
		DynContentPopupModel.prototype.onResized = function (worldRect, autoAdapted) {
			var copy = worldRect.copy();
			// compensate for origin in left bottom corner
			copy.origin.y -= copy.size.height;

			if (!this.targetedDynContentAnnotation.popuprect.rectEquals(copy)) {
				this.targetedDynContentAnnotation.popuprect = copy;
			}
		};

		/**
		 * Get the DynContent popup
		 * @param {ViewportLayer} viewportLayer - The layer where the popups should be shown.
		 * @returns {DynContentPopup} The dyncontent popup of this model.
		 */
		DynContentPopupModel.prototype.getPopup = function (viewportLayer) {
			var container = viewportLayer.getLayerElement();
			if (this.popup === null) {
				this._createPopup(container);
			} else {
				this.popup.setContainment(container);
			}
			return this.popup;
		};

		/**
		 * Create a dyncontent annotation popup {DynContentPopup} for the given layer
		 * and bind all events.
		 * @param {JQueryObj} container - Container for the popup
		 */
		DynContentPopupModel.prototype._createPopup = function (container) {

			// Get the text element.
			var textElement = this.targetedDynContentAnnotation.getDynContent().getTextElement();
			// Create the popup.
			this.popup = new DynContentPopup(this.f, this.id, this.dynContentModel, this, textElement, container);

			// we want the resized in world rect instead of scene rect, so don't bind them here, but in the layer, and let the layer call the model functions
			this.popup.on("closed", _.bind(this.onClosed, this));
			this.popup.on("clicked", _.bind(this.onClicked, this));
		};

		/**
		 * Method called when the model is destroyed.
		 * Useful for some cleanup in the popup/content
		 */
		DynContentPopupModel.prototype.onDestroy = function () {
			if (this.popup != null) {
				this.popup.remove();
			}
		};

		/**
		 * This function is bind to the "closed" popup event and called when the popup is closed.
		 */
		DynContentPopupModel.prototype.onClosed = function () {
			this.popup.focus(false);
			this.dynContentModel.unselectAllDynContents(false, true);
		};

		/**
		 * This function is bind to the "clicked" dyncontent annotation popup event and called when the popup is clicked.
		 */
		DynContentPopupModel.prototype.onClicked = function () {
			this.popup.focus(true);
		};

		/**
		 * Fire that a dyncontent annotation has changed
		 * @param {String} what - indicate what was changed
		 * @returns {Boolean} True when fired, false otherwise
		 */
		DynContentPopupModel.prototype._fireDynContentAnnotationChanged = function (what) {
			for (var i = 0; i < this.dynContentAnnotations.length; i++) {
				this.dynContentAnnotations[i].setModified(what);
			}
			this.dynContentModel.modelChanged();
		};

		/**
		 * Get the origin of the popup in world coordinates
		 * @returns {ShapeUtils.Point} - The origin of the popup in world coordinates
		 */
		DynContentPopupModel.prototype.getWorldOrigin = function () {
			// origin in left bottom corner
			return new ShapeUtils.Point(this.targetedDynContentAnnotation.popuprect.left(), this.targetedDynContentAnnotation.popuprect.bottom());
		};


		/**
		 * Get the size of the popup in world coordinates
		 * @returns {ShapeUtils.Size} - The size of the popup in world coordinates
		 */
		DynContentPopupModel.prototype.getWorldSize = function () {
			return this.targetedDynContentAnnotation.popuprect.size;
		};

		return DynContentPopupModel;

	});

define('web-viewer/textContent/DynContentPopupsLayerModel',["web-viewer/viewport/model/ViewportLayerModel",
		"web-viewer/textContent/DynContentPopupModel",
		"utils/ShapeUtils",
		"underscore"
	],
	function (ViewportLayerModel,
		DynContentPopupModel,
		ShapeUtils,
		_) {
		"use strict";

		/**
		 * @exports DynContentPopupsLayerModel
		 * @memberof TextContentModule
		 * @class
		 * Create a new dynamic content layer model for dynamic content popups
		 * @constructor
		 * @param {Core.ViewerFacade} f - Viewerfacade
		 * @param {String} ID - Id of the layer
		 * @param {DynContentModel} dynContentModel - Model of the dynamic contents.
		 */
		var DynContentPopupsLayerModel = function (f, ID, dynContentModel) {
			ViewportLayerModel.call(this, f, ID);

			this.f = f;
			this.dynContentModel = dynContentModel;
			
			// New annotations received
			this._createModels();
			this.dynContentModel.on("modelContentChanged", _.bind(function () {
				this.removeAllPopupModels();
				this._createModels();
			}, this));
			
			// DynContent model changed events
			this.dynContentModel.on("modelChanged", _.bind(function () {
				var page = this.dynContentModel.getDynContentPage();
				if (page !== null && page !== undefined) {
					this.resetTransformation();
					this.getTransform().scale(1, -1);
					var rotation = page.getRotation();
					var worldBounds = this.f.getModule("viewport").getWorldBounds();
					this.calculateTransformation(worldBounds, page.getPageSize(), new ShapeUtils.Size(), rotation, page.isFlipped());
				}
				this.modelChanged();
			}, this));

			/*
			 * When dynamic content annotations are selected.
			 */
			this.dynContentModel.on("selectedDynContents", _.bind(function (dynamicContentAnnotations, isDirectSelect) {
				// Only show a popup when annotations are selected for a single dynContent object.
				var singleDynContentSelected = false;
				if (dynamicContentAnnotations && dynamicContentAnnotations.length > 0) {
					var selectedDynContent =  dynamicContentAnnotations[0].getDynContent();
					singleDynContentSelected = true;
					for (var i=1; i < dynamicContentAnnotations.length; i++) {
						if (selectedDynContent != dynamicContentAnnotations[i].getDynContent()) {
							singleDynContentSelected = false;
							break;
						}
					}
				}
				// If a single dynamic content element is selected.
				if (singleDynContentSelected) {
					// The selected annotation.
					var annotation = dynamicContentAnnotations[0];
					var popupModel = this.getPopupModel(annotation.getDynContent().getId());
					popupModel.setTargetAnnotation(annotation);
					popupModel.show();
					this.modelChanged();
				}
			}, this));

			/*
			 * When dynamic content annotations are deselected.
			 */ 	
			this.dynContentModel.on("unselectedDynContents", _.bind(function (dynamicContentAnnotations, force) {
				// Hide the popups for all these dynamic contents.
				for (var i=0; i < dynamicContentAnnotations.length; i++) {
					var annotation = dynamicContentAnnotations[i];
					var popup = this.getPopupModel(annotation.getDynContent().getId());
					popup.focus(false);
					popup.hide();
				}
				this.modelChanged();
			}, this));
		};
		
		DynContentPopupsLayerModel.prototype = Object.create(ViewportLayerModel.prototype);
		DynContentPopupsLayerModel.prototype.constructor = DynContentPopupsLayerModel;
		
		/**
		 * Create the annotation popup models
		 */
		DynContentPopupsLayerModel.prototype._createModels = function () {
			// Get all the textElements for all the dynamic contents.
			var textElements = [];
			_.each(this.dynContentModel.getDynContents(), function (dynContentAnnotation) {
				var textElement = dynContentAnnotation.getDynContent().getTextElement();
				if ($.inArray(textElement, textElements) < 0) {
					textElements.push(textElement);
				}
			});
			// Create a popup for each textElement and it's linked annotations.
			_.each(textElements, function (textElement) {
				var annotations = this.dynContentModel.getDynContentAnnotationsForTextElement(textElement);
				this._createModel(annotations);
			}, this);
			this.modelChanged();
		};
		
		/**
		 * Create the annotation popup model for the given annotation
		 * @param {Annotation} annotation - Annotation to create the model of
		 */
		DynContentPopupsLayerModel.prototype._createModel = function (dynContentAnnotations) {
			// This will create the appropriate popup (AnnotationPopupNew vs AnnotationPopupExisting)
			var popupModel = new DynContentPopupModel(this.f, dynContentAnnotations[0].getDynContent().getId(), dynContentAnnotations, this.dynContentModel);
			this.addPopupModel(popupModel);
			// Hide the popupModels by default ...
			popupModel.hide();
		};
		
		return DynContentPopupsLayerModel;
		
});

define('web-viewer/textContent/DynContentTool',["underscore",
		"web-viewer/viewport/tools/AbstractTool",
		"web-viewer/textContent/DynContentAnnotation",
		"utils/ShapeUtils",
		"web-viewer/utils/DrawUtils",
		"web-viewer/utils/ViewerUtils",
		"web-viewer/core/CoreConstants"
	],
	function (_,
		AbstractTool,
		DynContentAnnotation,
		ShapeUtils,
		DrawUtils,
		ViewerUtils,
		CoreConstants) {
		"use strict";
		
		/**
		 * Construct a new Dynamic Content Tool
		 * @exports DynContentTool
		 * @memberof TextContentModule
		 *
		 * @class Tool to select and edit annotations
		 * @constructor
		 * @param {Core.ViewerFacade} f - Viewer facade
		 * @param {AnnotationModel} annotationModel - Annotation model
		 */
		var DynContentTool = function (f, dynContentModel) {
			AbstractTool.call(this, f, CoreConstants.TOOLS.DYNCONTENT);

			/**
			 * Different states constants
			 */
			this._defaultState = "defaultState";
			this._hoverState = "hoverState";
			
			this._targetDynContent = null;
			this._dynContentModel = dynContentModel;
			
			/**
			 * Variable to keep track of where interaction started
			 */
			this._touchDown = null;
			
			/**
			 * The default state
			 */
			this.registerState(this._defaultState, (function (that) {
				return {
					"mousemove": function (e) {
						var l = that._getDynContentLayer(e);
						if (!l || !l.isVisible()) {
							return;
						}

						that._verifyObjects(e, l);
						if (that._targetDynContent || that._anchor) {
							that.requestActivation();
						}
					},
					"mouseup": function (e) {

					},
					"mousedown": function (e) {
						var l = that._getDynContentLayer(e);
						if (!l) {
							return;
						}

						dynContentModel.unselectAllDynContents();
						e.originalEvent.preventDefault();
					},
					"mouseout": function (e) {
						if (that.isActive()) {
							f.emit("toolManager.request.deactivation", that);
						}
					},
					"mouseleave": function () {
						if (that.isActive()) {
							f.emit("toolManager.request.deactivation", that);
						}
					},
					"contextmenu": function (e) {
						e.preventDefault();
						e.stopPropagation();
						return false;
					}
				};
			}(this)));

			/**
			 * The hover state
			 */
			this.registerState(this._hoverState, _.defaults(function (that) {
				return {
					"mousedown": function (e) {
						if (e.which === 1) {
							that._verifyObjects(e);
							dynContentModel.selectDynContent(that._targetDynContent);
						}
						e.originalEvent.preventDefault();
					},
					"mousemove": function (e) {
						that._verifyObjects(e);
						that.cursorShouldChange();
					}
				};
			}(this), this.getState(this._defaultState)));

			this._override("initialize", _.bind(function (widget, toolManager) {
				this._super(widget, toolManager);
				this.changeState(this._defaultState);
				this.registerPassiveEvents(["mousemove", "mousedown"]);
				this.registerActiveEvents(["mousemove", "mousedown", "mouseup", "mouseout", "mouseleave", "contextmenu"]);
			}, this));

			this._override("activate", _.bind(function (interruptRequest) {
				this._super(interruptRequest);
				this.changeState(this._hoverState);
			}, this));

			this._override("deactivate", _.bind(function (interruptRequest) {
				this._super(interruptRequest);
				this.changeState(this._defaultState);
			}, this));

			this.f = f;
		};
		
		// inherit
		DynContentTool.prototype = Object.create(AbstractTool.prototype);
		// correct the constructor pointer 
		DynContentTool.prototype.constructor = DynContentTool;

		
		/**
		 * Returns default select cursor
		 */
		DynContentTool.prototype.getDefaultCursor = function () {
			return this._cursorForAnchor();			
		};

		/**
		 * Deactivate the current Dynamic Content tool
		 * @param that
		 * @param e
		 */
		DynContentTool.prototype._deActivate = function (e) {
			if (this.isActive()) {
				this.changeState(this._defaultState);
				this.f.emit("toolManager.request.deactivation", this);
			}
		};
		
		/**
		 * @returns {String} the cursor for the anchor state
		 */
		DynContentTool.prototype._cursorForAnchor = function () {
			return "cursor-select";
		};
		
		/**
		 * Get the dynamic content layer based on a point
		 * @param {String|Event} either the name of the view or an event that will calculate the view of the dynamic content layer
		 * @returns {ViewportLayer} Annotations layer of null if not found
		 */
		DynContentTool.prototype._getDynContentLayer = function (e) {
			var v = this._widget.requestView(e);
			if (v) {
				var l = v.getLayer("Dyncontent");
				if (l) {
					return l;
				}
			}
			return null;
		};
		
		/**
		 * Get the closest linework from a given point
		 * @param {Event} e - mouse event to calcuate the point to
		 * @param {ViewportLayer} [layer] - if the layer was already fetched
		 * @returns {LineworkWrapper} the closest lineworkwrapper to a certain point
		 */
		DynContentTool.prototype._getClosestLineworkFromPoint = function (e, layer) {
			var l = layer;
			if (!l) {
				l = this._getDynContentLayer(e);
			}

			if (l) {
				return l.getClosestLineworkFromPoint(this.getScenePoint(e));
			} else {
				return null;
			}
		};

		/**
		 * Converts a point from an event to the world, makes sure the point is containt in the document page
		 * @param {Event} e - mouse event
		 * @returns {ShapeUtils.Point} point in world coordinates
		 */
		DynContentTool.prototype._getWorldPoint = function (e) {
			var activePage = this._dynContentModel.getDynContentPage();
			var worldPoint = this.keepPointWithinWorldBounds(this.getWorldPoint(e), false);

			//convert the coordinate system from world coordinates to annotation coordinates
			worldPoint.y = activePage.getPageSize().height - worldPoint.y;

			var origin = activePage.getDocumentPageOrigin();

			worldPoint.offset(new ShapeUtils.Size(-origin.x, origin.y));

			var trimboxSize = activePage.getTrimboxRect().size;
			var missingHeight = 0; //pages with wrong XMP-data (page size) can have a missing part in the height, annotationlocation needs to be compensated for this
			if (trimboxSize.width !== 0 && trimboxSize.height !== 0) {
				missingHeight = activePage.getPageSize().height - (trimboxSize.height + activePage.getMargins().top + activePage.getMargins().bottom);
			}

			var margin = activePage.getMargins();
			if (activePage.isReaderSpread() && activePage.get("isRightPage")) { //check if the active page is on the right side of reader spread
				margin.left = -margin.left;
			}
			worldPoint.offset(new ShapeUtils.Size(-margin.left, -margin.bottom - missingHeight));

			return worldPoint;
		};

		/**
		 * Verify the current situation, so calcutate where the mouse is for the moment on the canvas
		 * @param {Event} e - mouse event to calcuate the point to
		 * @param {ViewportLayer} [layer] - if the layer was already fetched
		 */
		DynContentTool.prototype._verifyObjects = function (e, layer) {
			if (!layer) {
				layer = this._getDynContentLayer(e);
				if (!layer) {
					return;
				}
			}
			var object = this._getClosestLineworkFromPoint(e, layer);

			this._targetDynContent = null;
			this._anchor = null;
			if (object) {
				if (object instanceof DynContentAnnotation) {
					this._targetDynContent = object;
				} else if (object.anchor) {
					this._anchor = object;
					this._targetDynContent = object.linework;
				}
			}
			if (!object && !this._targetDynContent) {
				this._deActivate(e);
			}
		};
		
		
		return DynContentTool;
});

define('web-viewer/textContent/DynContentToolbarComponent',["component/toolbar/ToolbarComponent",
		"component/toolbar/ButtonGroup",
		"web-viewer/layout/component/ViewerToolbarButton",
		"web-viewer/layout/component/SubtoolbarButton",
		"web-viewer/layout/LayoutConstants",
	],
	function (ToolbarComponent,
		ButtonGroup,
		ViewerToolbarButton,
		SubtoolbarButton,
		LayoutConstants) {
		"use strict";

		
		/**
		 * @exports DynContentToolbarComponent
		 * @memberof DynContentModule
		 * @constructor
		 * @param {Core.ViewerFacade} f - Viewer facade
		 * @param {DynContentModel} dynContentModel - Dynamic Content model
		 * @param {DynContentTool} dynContentTool - The dynamic content tool
		 */
		var DynContentToolbarComponent = function (f, dynContentModel, dynContentTool) {
			ToolbarComponent.call(this, LayoutConstants.ToolbarComponent.DYNCONTENT, f);
			this.f = f;
			this.dynContentModel = dynContentModel;
			/**
			 * Group: annotate
			 */
			var dynContentGroup = new ButtonGroup("DynContentGroup");
			dynContentGroup.setTitle(f.i18n, "viewer", "DynContentBtnGroupTitle");
			this.addButtonGroup(dynContentGroup);
			
			// DynContent ViewerToolbarButton
			var toggleDynContentButton = new ViewerToolbarButton(f, "ToggleDynContentButton", f.getOption("PREFERENCES_DYNCONTENTTOOLS_VISIBLE") ? "icon-WCR_Annotation-DC-Hide" : "icon-WCR_Annotation-DC-Show", true, function () {
				dynContentModel.toggleVisibility();
			});
			// set initial tooltip
			toggleDynContentButton.setTooltip("viewer", f.getOption("PREFERENCES_DYNCONTENTTOOLS_VISIBLE") ? "HideDynContentsBtnTT" : "ShowDynContentsBtnTT");
			// react on preference changes
			f.getCurrentUser().on("options.changed.PREFERENCES_DYNCONTENTTOOLS_VISIBLE", function (oldValue, newValue) {
				if (newValue) {
					toggleDynContentButton.setTooltip("viewer", "HideDynContentsBtnTT");
					toggleDynContentButton.setIcon("icon-WCR_Annotation-DC-Hide");
				} else {
					toggleDynContentButton.setTooltip("viewer", "ShowDynContentsBtnTT");
					toggleDynContentButton.setIcon("icon-WCR_Annotation-DC-Show");
				}
			});
			dynContentGroup.addButton(toggleDynContentButton);
		};
		
		DynContentToolbarComponent.prototype = Object.create(ToolbarComponent.prototype);
		DynContentToolbarComponent.prototype.constructor = DynContentToolbarComponent;
		DynContentToolbarComponent.toolbarName = LayoutConstants.ToolbarComponent.DYNCONTENT;
		
		
		return DynContentToolbarComponent;
});
		

define('web-viewer/textContent/TextContentModule',["web-viewer/core/AbstractModule",
		"web-viewer/utils/ListenerUtil",
		"utils/ShapeUtils",
		"web-viewer/textContent/DynContentWidget",
		"web-viewer/layout/component/ModalPopup",
		"web-viewer/textContent/DynContentModel",
		"web-viewer/textContent/DynContentLayerModel",
		"web-viewer/textContent/DynContentPopupsLayerModel",
		"web-viewer/textContent/DynContentTool",
		"web-viewer/textContent/DynContentToolbarComponent",
		"packaging-content-management/ContentConstants",
		"underscore",
		"packaging-content-management/text-content-services/languageService",
		"packaging-content-management/text-content-services/elementTypeService"
	],
	function (AbstractModule,
		ListenerUtil,
		ShapeUtils,
		DynContentWidget,
		ModalPopup,
		DynContentModel,
		DynContentLayerModel,
		DynContentPopupsLayerModel,
		DynContentTool,
		DynContentToolbarComponent,
		ContentConstants,
		_,
		languageService,
		elementTypeService) {

		"use strict";
		/**
		 * This module is responsible for adding the text content widget
		 *
		 * @exports TextContentModule
		 * @constructor
		 * @augments Core.AbstractModule
		 * @param {Core.ViewerFacade} f
		 * @param {Boolean} silenced
		 */
		var TextContentModule = function (f, silenced) {
			AbstractModule.call(this, f, silenced, "dyncontent");
			ListenerUtil.mixin(this, f);

			/**
			 * Layer Models
			 */
			this.layerModels = {};

			/**
			 * The dynamic content model
			 */
			this.dynContentModel = new DynContentModel(f, 'dyncontent');

			/**
			 * Component: dynamic content
			 */
			this._dynContentComponent = null; // set the annotation tool bar component as unavailable


			this.f.getDocumentController().whenActivePageChanged(_.bind(this._whenActivePageChanged, this));

			/*
			 * What to do when we need to zoom to certain dyn contents.
			 */
			this.on("zoomToDynContents", _.bind(function (dynamicContentAnnotations) {
				var options = {};
				// Constrain the zoom so it never goes lower than 2 cm
				var zoomRect;
				if (dynamicContentAnnotations && dynamicContentAnnotations.length == 1) {
					// Single annotation selected, zoom on the single annotation.
					zoomRect = dynamicContentAnnotations[0].rect.copy();
				} else {
					// Multiple annotation selected, zoom on the bounding box.
					var smallestX = Number.MAX_VALUE;
					var smallestY = Number.MAX_VALUE;
					var biggestX = Number.MIN_VALUE;
					var biggestY = Number.MIN_VALUE;
					for (var i = 0; i < dynamicContentAnnotations.length; i++) {
						var rectOrigin = dynamicContentAnnotations[i].rect.origin;
						var rectSize = dynamicContentAnnotations[i].rect.size;
						var rectBiggestX = rectOrigin.x + rectSize.width;
						var rectSmallestX = rectOrigin.x;
						var rectBiggestY = rectOrigin.y + rectSize.height;
						var rectSmallestY = rectOrigin.y;
						if (smallestX > rectSmallestX) {
							smallestX = rectSmallestX;
						}
						if (smallestY > rectSmallestY) {
							smallestY = rectSmallestY;
						}
						if (biggestX < rectBiggestX) {
							biggestX = rectBiggestX;
						}
						if (biggestY < rectBiggestY) {
							biggestY = rectBiggestY;
						}
					}
					var origin = new ShapeUtils.Point(smallestX, smallestY);
					var size = new ShapeUtils.Size(biggestX - smallestX, biggestY - smallestY);
					zoomRect = new ShapeUtils.Rect(origin, size);
				}

				var minSize = 20;

				var diff = null;
				if (Math.abs(zoomRect.size.width) < minSize) {
					diff = (minSize - zoomRect.size.width) / 2;
					zoomRect.origin.x -= diff;
					zoomRect.size.width = minSize;
				}
				if (Math.abs(zoomRect.size.height) < minSize) {
					diff = (minSize - zoomRect.size.height) / 2;
					zoomRect.origin.y -= diff;
					zoomRect.size.height = minSize;
				}

				// Convert annotation rect to world
				var transform = this.layerModels['DynContentLayer'].getTransform().copy();
				options.rect = transform.transformedRect(zoomRect);
				options.constrain = true;
				options.animated = true;

				this.dynContentModel.ensureVisibility();

				f.emit("viewport.fitInRect", options);
			}, this));

			this._docVersionID = this.f.getActiveDocument().getDocumentVersion().get("docversionid");
			this._projectID = this.f.getActiveDocument().getProjectID();
		};

		// inherit
		TextContentModule.prototype = Object.create(AbstractModule.prototype);
		TextContentModule.prototype.constructor = TextContentModule;

		/**
		 * When the dynamic contents are loaded ...
		 */
		TextContentModule.prototype.onDynContentsLoaded = function (dynContents) {
			// Check if actually dyn contents were loaded.
			if (dynContents && dynContents.length === 0) {
				return;
			}
			this._dynContents = dynContents;
			var contentStatementList = [];
			for (var i = 0; i < dynContents.length; i++) {
				if (dynContents[i].getDynContentType() == "Text") {
					var element = dynContents[i].getTextElement();
					var contentStatement = element.parentStatement;
					if ($.inArray(contentStatement, contentStatementList) < 0) {
						contentStatementList.push(contentStatement);
					}
				}
			}
			var textContentsLangs = "";
			_.each(contentStatementList, _.bind(function (contentStatement) {
				if (contentStatement && contentStatement.element && contentStatement.element.length > 0) {
					_.each(contentStatement.element, _.bind(function (csElement) {
						if (csElement && csElement.master) {
							textContentsLangs += csElement.language + ":m,";
						} else if (csElement) {
							textContentsLangs += csElement.language + ":t,";
						}
					}, this));
				}
			}, this));
			$.when(this._loadElementTypeList(), this._loadLanguages(textContentsLangs)).done(_.bind(function (csList, elementTypeList, languagesList) {

				// Check if at least one master language was selected in the project.
				var foundMasterLang = false;
				if (languagesList && languagesList.projectMasterLangs) {
					foundMasterLang = Object.keys(languagesList.projectMasterLangs).length;
				}

				// Check if a master language was found before publishing the tools and the widget.
				if (foundMasterLang) {

					// Publish the dynamic content widget.
					this._publishWidget(DynContentWidget.widgetName, _.bind(function (layoutType) {
						this._dynContentWidget = new DynContentWidget(this, this.f, contentStatementList, elementTypeList, languagesList);
						return this._dynContentWidget;
					}, this, contentStatementList, elementTypeList, languagesList));

					// Publish the dynamic content tool.
					this._selectTool = new DynContentTool(this.f, this.dynContentModel);
					this._publishTool(this._selectTool);

					// publish annotate tool bar component
					this._publishToolbarComponent(DynContentToolbarComponent.toolbarName, _.bind(function (layoutType) {
						this._dynContentComponent = new DynContentToolbarComponent(this.f, this.dynContentModel, this._selectTool);
						return this._dynContentComponent;
					}, this));

				} else {
					// Disable the dynamic content annotations.
					this.dynContentModel.disable();
				}


			}, this, contentStatementList));
		};

		/**
		 * Are there still unsaved Text?
		 * @override
		 * @returns {Boolean}
		 */
		TextContentModule.prototype.hasUnsavedElements = function () {
			return this.dynContentModel.getUnsavedTextContentsCount() > 0;
		};

		/**
		 * @override
		 * @returns {String}
		 */
		TextContentModule.prototype.getUnsavedElementsName = function () {
			return this.f.i18n.t("PCMTextWidgetTitle");
		};
		
		/**
         * Save all unsaved elements
         * @override
         * @param callbackFunction
         */
		TextContentModule.prototype.saveAllUnsavedElements = function (callbackFunction) {
            this.dynContentModel.save(null, callbackFunction);
        };

		/**
		 * Prompt the user the save unsaved text content changes (if there are unsaved text content changes)
		 * @param {Function} callbackOnOk     - called when everything is OK (text contents saved)
		 * @param {Function} callbackOnCancel - called when the user cancels the operation (text contents are not saved)
		 * @param {Boolean} [canNotBeCancelled] - indicates the action cannot be cancelled, it is either revert or save
		 * @returns {Boolean} true if a prompt is shown
		 */
		TextContentModule.prototype.promptToSaveUnsavedChanges = function (callbackOnOk, callbackOnCancel, canNotBeCancelled) {
			if (this.hasUnsavedElements()) {
				this.f.loadBundle("viewer", function () {

					var modalPopup = new ModalPopup(this.f, "saveUnsavedTextContentChanges", this.f.getContext(), canNotBeCancelled);
					modalPopup.setRemoveFromDomAfterUsage(true);

					// the user wants to Save attributes before the callbackOnOk is executed
					modalPopup.setOkAction(_.bind(function () {
						// indicate to user that save operation is ongoing
						var loadingIndicator = $("<div>").css({
							'background': "url('" + requirejs.toUrl('web-viewer/layout/img/loaderTransparent.gif') + "') no-repeat 2px center",
							'padding-left': '20px',
							'line-height': '20px'
						}).addClass("unsavedItemsContent").text(this.f.t("PCMSaveOngoing"));
						modalPopup.setContent(loadingIndicator);

						//disable buttons while saving
						modalPopup.toggleButtons(false);
						modalPopup.toggleHeaderIcons(false);

						var validatePasswordAndSaveCallback = this._dynContentWidget.getValidatePasswordAndSaveHandler();

						$.when(validatePasswordAndSaveCallback()).done(function (status) {
							if (status === ContentConstants.ServerCall.SUCCESS) {
								// text contents are saved successfully!
								callbackOnOk();
							} else {
								// save operation failed
								if (callbackOnCancel) {
									callbackOnCancel();
								}
							}
							modalPopup.hide();
						}).fail(function () {
							if (callbackOnCancel) {
								callbackOnCancel();
							}
							modalPopup.hide();
						});

					}, this));

					if (!canNotBeCancelled) {
						// cancel the pending action
						modalPopup.setCancelAction(_.bind(function () {
							if (callbackOnCancel) {
								callbackOnCancel();
							}
						}, this));
						modalPopup.setCancelBtnText(this.f.i18n.t("Cancel"));
					}

					// Header + Content
					modalPopup.setHeader($("<span/>").addClass("popupTitle").text(this.f.t("PCMUnsavedWarningTitle")));
					modalPopup.setContent($("<div/>").addClass("unsavedItemsContent").text(this.f.t("PCMUnsavedWarningMsg")));
					modalPopup.setOkBtnText(this.f.i18n.t("Save"));
					modalPopup.show();
				}, this);
				return true;
			} else {
				// everything is OK, go on with OK action
				callbackOnOk();
				return false;
			}
		};

		TextContentModule.prototype._loadElementTypeList = function () {
			var deferred = $.Deferred();

			// load element type list
			elementTypeService.getElementTypes(_.bind(function (elementTypes) {
				deferred.resolve(elementTypes);
			}, deferred));

			return deferred.promise();
		};

		TextContentModule.prototype._loadLanguages = function (textContentsLangs) {
			var deferred = $.Deferred();

			// load language list
			languageService.getLanguages(this._projectID, _.bind(function (projectMasterLangs, projectTranslationLangs, allMasterLangs, allTranslationLangs) {
				var languagesList = {};
				languagesList.projectMasterLangs = projectMasterLangs;
				languagesList.projectTranslationLangs = projectTranslationLangs;
				languagesList.allMasterLangs = allMasterLangs;
				languagesList.allTranslationLangs = allTranslationLangs;

				deferred.resolve(languagesList);
			}, deferred), textContentsLangs);

			return deferred.promise();
		};

		/**
		 * When the active page has changed, react on it:
		 *
		 * Load text content data, unregister/unregister listners and display the widget if needed
		 *
		 * @param {AbstractDocumentPage} oldPage - previous active page
		 * @param {AbstractDocumentPage} newPage - new active page
		 */
		TextContentModule.prototype._whenActivePageChanged = function (oldPage, newPage) {

			//handle new page
			if (this.layerModels['DynContentLayer'] === undefined) {
				// Create the annotations layer
				this.layerModels['DynContentLayer'] = new DynContentLayerModel(this.f, "DynContent", this.dynContentModel);
				this.layerModels['DynContentPopupsLayer'] = new DynContentPopupsLayerModel(this.f, "DynContentPopups", this.dynContentModel);

				var viewportModule = this.f.getModule("viewport");
				// Global layer
				viewportModule.addLayer("Dyncontent", this.layerModels['DynContentLayer']);
				viewportModule.addLayer("Dyncontentpopups", this.layerModels['DynContentPopupsLayer']);
			}

			// unregister listeners
			if (oldPage) {
				this._unregisterAllListenersForObject(oldPage);
			}

			if (newPage) {
				//When attribute save happens in any AttributeCategoryModule(in the Attributes - Text Content View)
				//reload the widget with updated text contents
				this._registerListener("attributeCategory.saveFinished", function () {
					this._attributeSaveHappened = true;
				}, this, newPage);

				this._registerListener("attributeCategory.modalPopupClosed", function () {
					if (this._attributeSaveHappened === true) {
						this._attributeSaveHappened = false;
						this.dynContentModel.setPage(newPage, function (dynContents) {
							this.onDynContentsLoaded(dynContents);
						}.bind(this), true);
						this.dynContentModel.modelChanged();
					}
				}, this, newPage);

				this.dynContentModel.setPage(newPage, function (dynContents) {
					this.onDynContentsLoaded(dynContents);
				}.bind(this));
				this.dynContentModel.modelChanged();
			}
		};

		/**
		 * Select all the dynamic content annotations for a given Content Statement.
		 * 
		 * @param contentStatement
		 */
		TextContentModule.prototype.selectDynContentBasedOn = function (contentStatement, langCode) {
			this.dynContentModel.selectDynContentBasedOn(contentStatement, langCode);
		};

		return TextContentModule;
	});

